-- sql
-- $Source: icd9-script.sql
-- $Revision: 1
-- $Author: Jim Busser, GNUmed project
-- ---------------------------
-- Description:
-- script for importing ICD9_en data
-- … into GNUmed ref.icd9
-- … renamed as 'install-data-pack.sql' within GNUmed data packs
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--   git://gitorious.org/gnumed/gnumed.git
--   http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
--   http://www.gnumed.de/downloads/data/data-packs.conf
--   http://wiki.gnumed.de
-- ----------------------

-- uncomment the following to run from psql (instead of from GNUmed GUI)
-- set default_transaction_read_only to off;

-----------------------------------------------------------------------------
-- ************************************************************
-- set ON_ERROR_STOP 1
-- ************************************************************
-- ---------------------------------------------------------------------------
\set ON_ERROR_STOP 1


-----------------------------------------------------------------------------
-- ************************************************************
-- create staging table
-- ************************************************************
-- -----------------------------------------------------------------------------
-- ---------------------------------------------
-- ensure absence of leftover (incompatible) tables
\unset ON_ERROR_STOP
DROP TABLE staging.icd9 CASCADE;
\set ON_ERROR_STOP 1

begin;

CREATE TABLE staging.icd9 (
    code varchar,
    description varchar
);
-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- -----------------------------------------------------------------------------
--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: icd9; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.icd9 (code, description) VALUES ('001', 'CHOLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('0010', 'DUE TO VIBRIO CHOLERAE');
INSERT INTO staging.icd9 (code, description) VALUES ('0011', 'DUE TO VIBRIO CHOLERAE EL TOR');
INSERT INTO staging.icd9 (code, description) VALUES ('0019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('002', 'TYPHOID AND PARATYPHOID FEVERS');
INSERT INTO staging.icd9 (code, description) VALUES ('0020', 'TYPHOID FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0021', 'PARATYPHOID FEVER ''A''');
INSERT INTO staging.icd9 (code, description) VALUES ('0022', 'PARATYPHOID FEVER ''B''');
INSERT INTO staging.icd9 (code, description) VALUES ('0023', 'PARATYPHOID FEVER ''C''');
INSERT INTO staging.icd9 (code, description) VALUES ('0029', 'PARATYPHOID FEVER, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('003', 'OTHER SALMONELLA INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0030', 'SALMONELLA GASTROENTERITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0031', 'SALMONELLA SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0032', 'LOCALIZED SALMONELLA INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0038', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0039', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('004', 'SHIGELLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0040', 'SHIGELLA DYSENTERIAE');
INSERT INTO staging.icd9 (code, description) VALUES ('0041', 'SHIGELLA FLEXNERI');
INSERT INTO staging.icd9 (code, description) VALUES ('0042', 'SHIGELLA BOYDII');
INSERT INTO staging.icd9 (code, description) VALUES ('0043', 'SHIGELLA SONNEI');
INSERT INTO staging.icd9 (code, description) VALUES ('0048', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0049', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('005', 'OTHER FOOD POISONING(BACTERIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('0050', 'STAPHYLOCOCCAL FOOD POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('0051', 'BOTULISM');
INSERT INTO staging.icd9 (code, description) VALUES ('0052', 'FOOD POISONING DUE TO CLOSTRIDIUM PERFRINGENS (CL.WELCHII)');
INSERT INTO staging.icd9 (code, description) VALUES ('0053', 'FOOD POISONING DUE TO OTHER CLOSTRIDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0054', 'FOOD POISONING DUE TO VIBRIO PARAHAEMOLYTICUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0058', 'OTHER BACTERIAL FOOD POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('0059', 'FOOD POISONING, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('006', 'AMOEBIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0060', 'ACUTE AMOEBIC DYSENTERY WITHOUT MENTION OF ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('0061', 'CHRONIC INTESTINAL AMOEBIASIS WITHOUT MENTION OF ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('0062', 'AMOEBIC NONDYSENTERIC COLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0063', 'AMOEBIC LIVER ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('0064', 'AMOEBIC LUNG ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('0065', 'AMOEBIC BRAIN ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('0066', 'AMOEBIC SKIN ULCERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('0068', 'AMOEBIC INFECTION OF OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('0069', 'AMOEBIASIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('007', 'OTHER PROTOZOAL INTESTINAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0070', 'BALANTIDIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0071', 'GIARDIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0072', 'COCCIDIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0073', 'INTESTINAL TRICHOMONIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0078', 'OTHER PROTOZOAL INTESTINAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0079', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('008', 'INTESTINAL INFECTIONS DUE TO OTHER ORGANISMS');
INSERT INTO staging.icd9 (code, description) VALUES ('0080', 'ESCHERICHIA COLI');
INSERT INTO staging.icd9 (code, description) VALUES ('0081', 'ARIZONA');
INSERT INTO staging.icd9 (code, description) VALUES ('0082', 'AEROBACTER AEROGENES');
INSERT INTO staging.icd9 (code, description) VALUES ('0083', 'PROTEUS (MIRABILIS) (MORGANII)');
INSERT INTO staging.icd9 (code, description) VALUES ('0084', 'OTHER SPECIFIED BACTERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0085', 'BACTERIAL ENTERITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0086', 'ENTERITIS DUE TO SPECIFIED VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0088', 'OTHER ORGANISM, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('009', 'ILL-DEFINED INTESTINAL INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0090', 'INFECTIOUS COLITIS, ENTERITIS AND GASTROENTERITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0091', 'COLITIS, ENTERITIS AND GASTROENTERITIS OF PRESUMED INFECTIOUS ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('0092', 'INFECTIOUS DIARRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('0093', 'DIARRHOEA, OF PRESUMED INFECTIOUS ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('010', 'PRIMARY TUBERCULOUS INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('0100', 'PRIMARY TUBERCULOUS COMPLEX');
INSERT INTO staging.icd9 (code, description) VALUES ('0101', 'TUBERCULOUS PLEURISY IN PRIMARY PROGRESSIVE TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0108', 'OTHER PRIMARY PROGRESSIVE TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0109', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('011', 'PULMONARY TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0110', 'TUBERCULOSIS OF LUNG, INFILTRATIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('0111', 'TUBERCULOSIS OF LUNG, NODULAR');
INSERT INTO staging.icd9 (code, description) VALUES ('0112', 'TUBERCULOSIS OF LUNG WITH CAVITATION');
INSERT INTO staging.icd9 (code, description) VALUES ('0113', 'TUBERCULOSIS OF BRONCHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0114', 'TUBERCULOUS FIBROSIS OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('0115', 'TUBERCULOUS BRONCHIECTASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0116', 'TUBERCULOUS PNEUMONIA (ANY FORM)');
INSERT INTO staging.icd9 (code, description) VALUES ('0117', 'TUBERCULOUS PNEUMOTHORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('0118', 'OTHER PULMONARY TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0119', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('012', 'OTHER RESPIRATORY TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0120', 'TUBERCULOUS PLEURISY');
INSERT INTO staging.icd9 (code, description) VALUES ('0121', 'TUBERCULOSIS OF INTRATHORACIC LYMPH NODES');
INSERT INTO staging.icd9 (code, description) VALUES ('0122', 'ISOLATED TRACHEAL OR BRONCHIAL TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0123', 'TUBERCULOUS LARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0128', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('013', 'TUBERCULOSIS OF MENINGES AND CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('0130', 'TUBERCULOUS MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0131', 'TUBERCULOMA OF MENINGES');
INSERT INTO staging.icd9 (code, description) VALUES ('0138', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0139', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('014', 'TUBERCULOSIS OF INTESTINES, PERITONEUM AND MESENTERIC GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('015', 'TUBERCULOSIS OF BONES AND JOINTS');
INSERT INTO staging.icd9 (code, description) VALUES ('0150', 'VERTEBRAL COLUMN');
INSERT INTO staging.icd9 (code, description) VALUES ('0151', 'HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('0152', 'KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('0157', 'OTHER BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('0158', 'OTHER JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('0159', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('016', 'TUBERCULOSIS OF GENITOURINARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('0160', 'KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('0161', 'OTHER URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('0162', 'EPIDIDYMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0163', 'OTHER MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('0164', 'FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('0169', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('017', 'TUBERCULOSIS OF OTHER ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('0170', 'SKIN AND SUBCUTANEOUS CELLULAR TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('0171', 'ERYTHEMA NODOSUM WITH HYPERSENSITIVITY REACTION IN TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0172', 'PERIPHERAL LYMPH NODES');
INSERT INTO staging.icd9 (code, description) VALUES ('0173', 'EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('0174', 'EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('0175', 'THYROID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('0176', 'ADRENAL GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('0177', 'SPLEEN');
INSERT INTO staging.icd9 (code, description) VALUES ('0178', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('018', 'MILIARY TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0180', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('0188', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0189', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('020', 'PLAGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('0200', 'BUBONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0201', 'CELLULOCUTANEOUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0202', 'SEPTICAEMIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0203', 'PRIMARY PNEUMONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0204', 'SECONDARY PNEUMONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0205', 'PNEUMONIC, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0208', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0209', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('021', 'TULARAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('022', 'ANTHRAX');
INSERT INTO staging.icd9 (code, description) VALUES ('0220', 'CUTANEOUS ANTHRAX');
INSERT INTO staging.icd9 (code, description) VALUES ('0221', 'PULMONARY ANTHRAX');
INSERT INTO staging.icd9 (code, description) VALUES ('0222', 'GASTROINTESTINAL ANTHRAX');
INSERT INTO staging.icd9 (code, description) VALUES ('0223', 'ANTHRAX SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0228', 'OTHER MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0229', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('023', 'BRUCELLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0230', 'BRUCELLA MELITENSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0231', 'BRUCELLA ABORTUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0232', 'BRUCELLA SUIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0233', 'BRUCELLA CANIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0238', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0239', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('024', 'GLANDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('025', 'MELIOIDOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('026', 'RAT-BITE FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0260', 'SPIRILLARY FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0261', 'STREPTOBACILLARY FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('027', 'OTHER ZOONOTIC BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0270', 'LISTERIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0271', 'ERYSIPELOTHRIX INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('0272', 'PASTEURELLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0278', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0279', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('030', 'LEPROSY');
INSERT INTO staging.icd9 (code, description) VALUES ('0300', 'LEPROMATOUS (TYPE L)');
INSERT INTO staging.icd9 (code, description) VALUES ('0301', 'TUBERCULOID (TYPE T)');
INSERT INTO staging.icd9 (code, description) VALUES ('0302', 'INDETERMINATE (GROUP I)');
INSERT INTO staging.icd9 (code, description) VALUES ('0303', 'BORDERLINE (GROUP B)');
INSERT INTO staging.icd9 (code, description) VALUES ('0308', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0309', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('031', 'DISEASES DUE TO OTHER MYCOBACTERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0310', 'PULMONARY');
INSERT INTO staging.icd9 (code, description) VALUES ('0311', 'CUTANEOUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0318', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0319', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('032', 'DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0320', 'FAUCIAL DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0321', 'NASOPHARYNGEAL DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0322', 'ANTERIOR NASAL DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0323', 'LARYNGEAL DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0328', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0329', 'DIPHTHERIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('033', 'WHOOPING COUGH');
INSERT INTO staging.icd9 (code, description) VALUES ('0330', 'BORDETELLA PERTUSSIS (B.PERTUSSIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('0331', 'BORDETELLA PARAPERTUSSIS (B.PARAPERTUSSIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('0338', 'OTHER SPECIFIED ORGANISM');
INSERT INTO staging.icd9 (code, description) VALUES ('0339', 'WHOOPING COUGH, UNSPECIFIED ORGANISM');
INSERT INTO staging.icd9 (code, description) VALUES ('034', 'STREPTOCOCCAL SORE THROAT AND SCARLATINA');
INSERT INTO staging.icd9 (code, description) VALUES ('0340', 'STREPTOCOCCAL SORE THROAT');
INSERT INTO staging.icd9 (code, description) VALUES ('0341', 'SCARLATINA');
INSERT INTO staging.icd9 (code, description) VALUES ('035', 'ERYSIPELAS');
INSERT INTO staging.icd9 (code, description) VALUES ('036', 'MENINGOCOCCAL INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('0360', 'MENINGOCOCCAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0361', 'MENINGOCOCCAL ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0362', 'MENINGOCOCCAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0363', 'WATERHOUSE-FRIDERICHSEN SYNDROME, MENINGOCOCCAL');
INSERT INTO staging.icd9 (code, description) VALUES ('0364', 'MENINGOCOCCAL CARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0368', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0369', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('037', 'TETANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('038', 'SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0380', 'STREPTOCOCCAL SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0381', 'STAPHYLOCOCCAL SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0382', 'PNEUMOCOCCAL SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0383', 'SEPTICAEMIA DUE TO ANAEROBES');
INSERT INTO staging.icd9 (code, description) VALUES ('0384', 'SEPTICAEMIA DUE TO OTHER GRAM-NEGATIVE ORGANISMS');
INSERT INTO staging.icd9 (code, description) VALUES ('0388', 'OTHER SPECIFIED SEPTICAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('0389', 'UNSPECIFIED SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('039', 'ACTINOMYCOTIC INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0390', 'CUTANEOUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0391', 'PULMONARY');
INSERT INTO staging.icd9 (code, description) VALUES ('0392', 'ABDOMINAL');
INSERT INTO staging.icd9 (code, description) VALUES ('0393', 'CERVICOFACIAL');
INSERT INTO staging.icd9 (code, description) VALUES ('0394', 'MADURA FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('0398', 'OF OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('0399', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('040', 'OTHER BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0400', 'GAS GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('0401', 'RHINOSCLEROMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0402', 'WHIPPLE''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0403', 'NECROBACILLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0408', 'OTHER BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('041', 'BACTERIAL INFECTION IN CONDITIONS CLASSIFIED ELSEWHERE AND OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('0410', 'STREPTOCOCCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0411', 'STAPHYLOCOCCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0412', 'PNEUMOCOCCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0413', 'FRIEDLANDER''S BACILLUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0414', 'ESCHERICHIA COLI');
INSERT INTO staging.icd9 (code, description) VALUES ('0415', 'HAEMOPHILUS INFLUENZAE (H.INFLUENZAE)');
INSERT INTO staging.icd9 (code, description) VALUES ('0416', 'PROTEUS (MIRABILIS) (MORGANII)');
INSERT INTO staging.icd9 (code, description) VALUES ('0417', 'PSEUDOMONAS');
INSERT INTO staging.icd9 (code, description) VALUES ('0418', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0419', 'BACTERIAL INFECTION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('042', 'HUMAN IMMUNODEFICIENCY VIRUS (HIV) INFECTION WITH SPECIFIED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0420', 'HIV INFECTION WITH CERTAIN SPECIFIED INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0421', 'HIV INFECTION CAUSING OTHER SPECIFIED INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0422', 'HIV INFECTION WITH SPECIFIED MALIGNANT NEOPLASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('0429', 'ACQUIRED IMMUNODEFICIENCY SYNDROME WITH OR WITHOUT OTHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('043', 'HUMAN IMMUNODEFICIENCY VIRUS (HIV) INFECTION CAUSING OTHER SPECIFIED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0430', 'HIV INFECTION CAUSING LYMPHADENOPATHY (785.6)');
INSERT INTO staging.icd9 (code, description) VALUES ('0431', 'HIV INFECTION CAUSING SPECIFIED DISEASES OF THE CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('0432', 'HIV INFECTION CAUSING OTHER DISORDERS INVOLVING THE IMMUNE MECHANISM (279)');
INSERT INTO staging.icd9 (code, description) VALUES ('0433', 'HIV INFECTION CAUSING OTHER SPECIFIED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0439', 'ACQUIRED IMMUNODEFICIENCY SYNDROME-RELATED COMPLEX WITH OR WITHOUT OTHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('044', 'OTHER HUMAN IMMUNODEFICIENCY VIRUS (HIV) INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('0440', 'HIV INFECTION CAUSING SPECIFIED ACUTE INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0449', 'HIV INFECTION NOT OTHERWISE SPECIFIED (WITH OR WITHOUT OTHER CONDITIONS NOT CLASSIFIABLE TO 042, 043, 044.0)');
INSERT INTO staging.icd9 (code, description) VALUES ('045', 'ACUTE POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0450', 'ACUTE PARALYTIC POLIOMYELITIS SPECIFIED AS BULBAR');
INSERT INTO staging.icd9 (code, description) VALUES ('0451', 'ACUTE POLIOMYELITIS WITH OTHER PARALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0452', 'ACUTE NONPARALYTIC POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0459', 'ACUTE POLIOMYELITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('046', 'SLOW VIRUS INFECTION OF CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('0460', 'KURU');
INSERT INTO staging.icd9 (code, description) VALUES ('0461', 'JAKOB-CREUTZFELDT DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0462', 'SUBACUTE SCLEROSING PANENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0463', 'PROGRESSIVE MULTIFOCAL LEUCOENCEPHALOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('0468', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0469', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('047', 'MENINGITIS DUE TO ENTEROVIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0470', 'COXSACKIE VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0471', 'ECHO VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0478', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0479', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('048', 'OTHER ENTEROVIRUS DISEASES OF CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('049', 'OTHER NON-ARTHROPOD-BORNE VIRAL DISEASES OF CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('0490', 'LYMPHOCYTIC CHORIOMENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0491', 'MENINGITIS DUE TO ADENOVIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0498', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0499', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('050', 'SMALLPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('0500', 'VARIOLA MAJOR');
INSERT INTO staging.icd9 (code, description) VALUES ('0501', 'ALASTRIM');
INSERT INTO staging.icd9 (code, description) VALUES ('0502', 'MODIFIED SMALLPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('0509', 'SMALLPOX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('051', 'COWPOX AND PARAVACCINIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0510', 'COWPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('0511', 'PSEUDOCOWPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('0512', 'CONTAGIOUS PUSTULAR DERMATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0519', 'PARAVACCINIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('052', 'CHICKENPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('053', 'HERPES ZOSTER');
INSERT INTO staging.icd9 (code, description) VALUES ('0530', 'WITH MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0531', 'WITH OTHER NERVOUS SYSTEM COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0532', 'WITH OPHTHALMIC COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0537', 'WITH OTHER COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0538', 'WITH UNSPECIFIED COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('0539', 'HERPES ZOSTER WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('054', 'HERPES SIMPLEX');
INSERT INTO staging.icd9 (code, description) VALUES ('0540', 'ECZEMA HERPETICUM');
INSERT INTO staging.icd9 (code, description) VALUES ('0541', 'GENITAL HERPES');
INSERT INTO staging.icd9 (code, description) VALUES ('0542', 'HERPETIC GINGIVOSTOMATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0543', 'HERPETIC MENINGOENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0544', 'WITH OPHTHALMIC COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0545', 'HERPETIC SEPTICAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0546', 'HERPETIC WHITLOW');
INSERT INTO staging.icd9 (code, description) VALUES ('0547', 'WITH OTHER COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0548', 'WITH UNSPECIFIED COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('0549', 'HERPES SIMPLEX WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('055', 'MEASLES');
INSERT INTO staging.icd9 (code, description) VALUES ('0550', 'POSTMEASLES ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0551', 'POSTMEASLES PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0552', 'POSTMEASLES OTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0557', 'WITH OTHER COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0558', 'WITH UNSPECIFIED COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('0559', 'MEASLES WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('056', 'RUBELLA');
INSERT INTO staging.icd9 (code, description) VALUES ('0560', 'WITH NEUROLOGICAL COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0567', 'WITH OTHER COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0568', 'WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0569', 'RUBELLA WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('057', 'OTHER VIRAL EXANTHEMATA');
INSERT INTO staging.icd9 (code, description) VALUES ('0570', 'ERYTHEMA INFECTIOSUM (FIFTH DISEASE)');
INSERT INTO staging.icd9 (code, description) VALUES ('0578', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('060', 'YELLOW FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0600', 'SYLVATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0601', 'URBAN');
INSERT INTO staging.icd9 (code, description) VALUES ('0609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('061', 'DENGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('062', 'MOSQUITO-BORNE VIRAL ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0620', 'JAPANESE ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0621', 'WESTERN EQUINE ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0622', 'EASTERN EQUINE ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0623', 'ST.LOUIS ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0624', 'AUSTRALIAN ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0625', 'CALIFORNIA VIRUS ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0628', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0629', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('063', 'TICK-BORNE VIRAL ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0630', 'RUSSIAN SPRING-SUMMER (TAIGA) ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0631', 'LOUPING ILL');
INSERT INTO staging.icd9 (code, description) VALUES ('0632', 'CENTRAL EUROPEAN ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0638', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('064', 'VIRAL ENCEPHALITIS TRANSMITTED BY OTHER AND UNSPECIFIED ARTHROPODS');
INSERT INTO staging.icd9 (code, description) VALUES ('065', 'ARTHROPOD-BORNE HAEMORRHAGIC FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0650', 'CRIMEAN HAEMORRHAGIC FEVER (CHF CONGO VIRUS)');
INSERT INTO staging.icd9 (code, description) VALUES ('0651', 'OMSK HAEMORRHAGIC FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0652', 'KYASANUR FOREST DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0653', 'OTHER TICK-BORNE HAEMORRHAGIC FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0654', 'MOSQUITO-BORNE HAEMORRHAGIC FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0658', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0659', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('066', 'OTHER ARTHROPOD-BORNE VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0660', 'PHLEBOTOMUS FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0661', 'TICK-BORNE FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0662', 'VENEZUELAN EQUINE FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0663', 'OTHER MOSQUITO-BORNE FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0668', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0669', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('070', 'VIRAL HEPATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0700', 'VIRAL HEPATITIS ''A'' WITH HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0701', 'VIRAL HEPATITIS ''A'' WITHOUT MENTION OF HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0702', 'VIRAL HEPATITIS ''B'' WITH HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0703', 'VIRAL HEPATITIS ''B'' WITHOUT MENTION OF HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0704', 'OTHER SPECIFIED VIRAL HEPATITIS WITH HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0705', 'OTHER SPECIFIED VIRAL HEPATITIS WITHOUT MENTION OF HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0706', 'UNSPECIFIED VIRAL HEPATITIS WITH HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0709', 'UNSPECIFIED VIRAL HEPATITIS WITHOUT MENTION OF HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('071', 'RABIES');
INSERT INTO staging.icd9 (code, description) VALUES ('072', 'MUMPS');
INSERT INTO staging.icd9 (code, description) VALUES ('0720', 'MUMPS ORCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0721', 'MUMPS MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0722', 'MUMPS ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0723', 'MUMPS PANCREATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0727', 'MUMPS WITH OTHER COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0728', 'MUMPS WITH UNSPECIFIED COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('0729', 'MUMPS WITHOUT MENTION OF  COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('073', 'ORNITHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('074', 'SPECIFIC DISEASES DUE TO COXSACKIE VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0740', 'HERPANGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('0741', 'EPIDEMIC PLEURODYNIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0742', 'COXSACKIE CARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0743', 'HAND, FOOT AND MOUTH DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0748', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('075', 'INFECTIOUS MONONUCLEOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('076', 'TRACHOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('0760', 'INITIAL STAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('0761', 'ACTIVE STAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('0769', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('077', 'OTHER DISEASES OF CONJUNCTIVA DUE TO VIRUSES AND CHLAMYDIAE');
INSERT INTO staging.icd9 (code, description) VALUES ('0770', 'INCLUSION CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0771', 'EPIDEMIC KERATOCONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0772', 'PHARYNGOCONJUNCTIVAL FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0773', 'OTHER ADENOVIRAL CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0774', 'EPIDEMIC HAEMORRHAGIC CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0778', 'OTHER VIRAL CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0779', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('078', 'OTHER DISEASES DUE TO VIRUSES AND CHLAMYDIAE');
INSERT INTO staging.icd9 (code, description) VALUES ('0780', 'MOLLUSCUM CONTAGIOSUM');
INSERT INTO staging.icd9 (code, description) VALUES ('0781', 'VIRAL WARTS');
INSERT INTO staging.icd9 (code, description) VALUES ('0782', 'SWEATING FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0783', 'CAT-SCRATCH DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0784', 'FOOT AND MOUTH DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0785', 'CYTOMEGALIC INCLUSION DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0786', 'HAEMORRHAGIC NEPHROSONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0787', 'ARENAVIRAL HAEMORRHAGIC FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0788', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('079', 'VIRAL INFECTION IN CONDITIONS CLASSIFIED ELSEWHERE AND OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('0790', 'ADENOVIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0791', 'ECHO VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0792', 'COXSACKIE VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0793', 'RHINOVIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0798', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('080', 'LOUSE-BORNE (EPIDEMIC) TYPHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('081', 'OTHER TYPHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0810', 'MURINE (ENDEMIC) TYPHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0811', 'BRILL''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0812', 'SCRUB TYPHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0819', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('082', 'TICK-BORNE RICKETTSIOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('0820', 'SPOTTED FEVERS');
INSERT INTO staging.icd9 (code, description) VALUES ('0821', 'BOUTONNEUSE FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0822', 'NORTH ASIAN TICK FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0823', 'QUEENSLAND TICK TYPHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('0828', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0829', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('083', 'OTHER RICKETTSIOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('0830', 'Q-FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0831', 'TRENCH FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0832', 'RICKETTSIALPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('0838', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0839', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('084', 'MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0840', 'FALCIPARUM MALARIA (MALIGNANT TERTIAN)');
INSERT INTO staging.icd9 (code, description) VALUES ('0841', 'VIVAX MALARIA (BENIGN TERTIAN)');
INSERT INTO staging.icd9 (code, description) VALUES ('0842', 'QUARTAN MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0843', 'OVALE MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0844', 'OTHER MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0845', 'MIXED');
INSERT INTO staging.icd9 (code, description) VALUES ('0846', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0847', 'INDUCED MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('0848', 'BLACKWATER FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0849', 'OTHER PERNICIOUS COMPLICATIONS OF MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('085', 'LEISHMANIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0850', 'VISCERAL (KALA-AZAR)');
INSERT INTO staging.icd9 (code, description) VALUES ('0851', 'CUTANEOUS, URBAN');
INSERT INTO staging.icd9 (code, description) VALUES ('0852', 'CUTANEOUS, ASIAN DESERT');
INSERT INTO staging.icd9 (code, description) VALUES ('0853', 'CUTANEOUS, ETHIOPIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('0854', 'CUTANEOUS, AMERICAN');
INSERT INTO staging.icd9 (code, description) VALUES ('0855', 'MUCOCUTANEOUS (AMERICAN)');
INSERT INTO staging.icd9 (code, description) VALUES ('0859', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('086', 'TRYPANOSOMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0860', 'CHAGA''S DISEASE WITH HEART INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0861', 'CHAGA''S DISEASE WITH OTHER ORGAN INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0862', 'CHAGA''S DISEASE WITHOUT MENTION OF ORGAN INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0863', 'GAMBIAN TRYPANOSOMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0864', 'RHODESIAN TRYPANOSOMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0865', 'AFRICAN TRYPANOSOMIASIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0869', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('087', 'RELAPSING FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('0870', 'LOUSE-BORNE');
INSERT INTO staging.icd9 (code, description) VALUES ('0871', 'TICK-BORNE');
INSERT INTO staging.icd9 (code, description) VALUES ('0879', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('088', 'OTHER ARTHROPOD-BORNE DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0880', 'BARTONELLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0888', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0889', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('090', 'CONGENITAL SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0900', 'EARLY CONGENITAL SYPHILIS, SYMPTOMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0901', 'EARLY CONGENITAL SYPHILIS, LATENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0902', 'EARLY CONGENITAL SYPHILIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0903', 'SYPHILITIC INTERSTITIAL KERATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0904', 'JUVENILE NEUROSYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0905', 'OTHER LATE CONGENITAL SYPHILIS, SYMPTOMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0906', 'LATE CONGENITAL SYPHILIS, LATENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0907', 'LATE CONGENITAL SYPHILIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0909', 'CONGENITAL SYPHILIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('091', 'EARLY SYPHILIS, SYMPTOMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0910', 'GENITAL SYPHILIS (PRIMARY)');
INSERT INTO staging.icd9 (code, description) VALUES ('0911', 'PRIMARY ANAL SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0912', 'OTHER PRIMARY SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0913', 'SECONDARY SYPHILIS OF SKIN OR MUCOUS MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('0914', 'ADENOPATHY DUE TO SECONDARY SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0915', 'UVEITIS DUE TO SECONDARY SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0916', 'SECONDARY SYPHILIS OF VISCERA AND BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('0917', 'SECONDARY SYPHILIS, RELAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('0918', 'OTHER FORMS OF SECONDARY SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0919', 'UNSPECIFIED SECONDARY SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('092', 'EARLY SYPHILIS, LATENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0920', 'EARLY SYPHILIS, LATENT, SEROLOGICAL RELAPSE AFTER TREATMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('0929', 'EARLY SYPHILIS, LATENT, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('093', 'CARDIOVASCULAR SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0930', 'ANEURYSM OF AORTA, SPECIFIED AS SYPHILITIC');
INSERT INTO staging.icd9 (code, description) VALUES ('0931', 'SYPHILITIC AORTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0932', 'SYPHILITIC ENDOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0938', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0939', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('094', 'NEUROSYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0940', 'TABES DORSALIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0941', 'GENERAL PARESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0942', 'SYPHILITIC MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0943', 'ASYMPTOMATIC NEUROSYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0948', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0949', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('095', 'OTHER FORMS OF LATE SYPHILIS, WITH SYMPTOMS');
INSERT INTO staging.icd9 (code, description) VALUES ('096', 'LATE SYPHILIS, LATENT');
INSERT INTO staging.icd9 (code, description) VALUES ('097', 'OTHER AND UNSPECIFIED SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0970', 'LATE SYPHILIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0971', 'LATENT SYPHILIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('0979', 'SYPHILIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('098', 'GONOCOCCAL INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('0980', 'ACUTE, OF LOWER GENITOURINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('0981', 'ACUTE, OF UPPER GENITOURINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('0982', 'CHRONIC, OF LOWER GENITOURINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('0983', 'CHRONIC, OF UPPER GENITOURINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('0984', 'OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('0985', 'OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('0986', 'OF PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('0987', 'OF ANUS AND RECTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('0988', 'OF OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('099', 'OTHER VENEREAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('0990', 'CHANCROID');
INSERT INTO staging.icd9 (code, description) VALUES ('0991', 'LYMPHOGRANULOMA VENEREUM');
INSERT INTO staging.icd9 (code, description) VALUES ('0992', 'GRANULOMA INGUINALE');
INSERT INTO staging.icd9 (code, description) VALUES ('0993', 'REITER''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('0994', 'OTHER NONGONOCOCCAL URETHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('0998', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('0999', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('100', 'LEPTOSPIROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1000', 'LEPTOSPIROSIS ICTEROHAEMORRHAGICA');
INSERT INTO staging.icd9 (code, description) VALUES ('1008', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1009', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('101', 'VINCENT''S ANGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('102', 'YAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('1020', 'INITIAL LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1021', 'MULTIPLE PAPILLOMATA AND WET CRAB YAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('1022', 'OTHER EARLY SKIN LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1023', 'HYPERKERATOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1024', 'GUMMATA AND ULCERS');
INSERT INTO staging.icd9 (code, description) VALUES ('1025', 'GANGOSA');
INSERT INTO staging.icd9 (code, description) VALUES ('1026', 'BONE AND JOINT LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1027', 'OTHER MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1028', 'LATENT YAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('1029', 'YAWS,UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('103', 'PINTA');
INSERT INTO staging.icd9 (code, description) VALUES ('1030', 'PRIMARY LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1031', 'INTERMEDIATE LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1032', 'LATE LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1033', 'MIXED LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1039', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('104', 'OTHER SPIROCHAETAL INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1040', 'NONVENEREAL ENDEMIC SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1048', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1049', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('110', 'DERMATOPHYTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1100', 'OF SCALP AND BEARD');
INSERT INTO staging.icd9 (code, description) VALUES ('1101', 'OF NAIL');
INSERT INTO staging.icd9 (code, description) VALUES ('1102', 'OF HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1103', 'OF GROIN AND PERIANAL AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('1104', 'OF FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('1105', 'OF THE BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('1106', 'DEEP SEATED DERMATOPHYTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1108', 'OF OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1109', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('111', 'DERMATOMYCOSIS, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1110', 'PITYRIASIS VERSICOLOR');
INSERT INTO staging.icd9 (code, description) VALUES ('1111', 'TINEA NIGRA');
INSERT INTO staging.icd9 (code, description) VALUES ('1112', 'TINEA BLANCA');
INSERT INTO staging.icd9 (code, description) VALUES ('1113', 'BLACK PIEDRA');
INSERT INTO staging.icd9 (code, description) VALUES ('1118', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1119', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('112', 'CANDIDIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1120', 'OF MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('1121', 'OF VULVA AND VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('1122', 'OF OTHER UROGENITAL SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1123', 'OF SKIN AND NAILS');
INSERT INTO staging.icd9 (code, description) VALUES ('1124', 'OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1125', 'DISSEMINATED');
INSERT INTO staging.icd9 (code, description) VALUES ('1128', 'OF OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1129', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('114', 'COCCIDIOIDOMYCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('115', 'HISTOPLASMOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1150', 'INFECTION BY HISTOPLASMA CAPSULATUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1151', 'INFECTION BY HISTOPLASMA DUBOISII');
INSERT INTO staging.icd9 (code, description) VALUES ('1159', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('116', 'BLASTOMYCOTIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1160', 'BLASTOMYCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1161', 'PARACOCCIDIOIDOMYCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1162', 'LOBOMYCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('117', 'OTHER MYCOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('1170', 'RHINOSPORIDIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1171', 'SPOROTRICHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1172', 'CHROMOBLASTOMYCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1173', 'ASPERGILLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1174', 'MYCOTIC MYCETOMAS');
INSERT INTO staging.icd9 (code, description) VALUES ('1175', 'CRYPTOCOCCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1176', 'ALLESCHERIOSIS (PETRIELLIDOSIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('1177', 'ZYGOMYCOSIS (PHYCOMYCOSIS OR MUCORMYCOSIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('1178', 'INFECTION BY DEMATIACIOUS FUNGI (PHAEOHYPHOMYCOSIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('1179', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('118', 'OPPORTUNISTIC MYCOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('120', 'SCHISTOSOMIASIS (BILHARZIASIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('1200', 'SCHISTOSOMA HAEMATOBIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1201', 'SCHISTOSOMA MANSONI');
INSERT INTO staging.icd9 (code, description) VALUES ('1202', 'SCHISTOSOMA JAPONICUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1203', 'CUTANEOUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1208', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1209', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('121', 'OTHER TREMATODE INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('1210', 'OPISTHORCHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1211', 'CLONORCHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1212', 'PARAGONIMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1213', 'FASCIOLIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1214', 'FASCIOLOPSIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1215', 'METAGONIMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1216', 'HETEROPHYIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1218', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1219', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('122', 'ECHINOCOCCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1220', 'ECHINOCOCCUS GRANULOSUS INFECTION OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('1221', 'ECHINOCOCCUS GRANULOSUS INFECTION OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1222', 'ECHINOCOCCUS GRANULOSUS INFECTION OF THYROID');
INSERT INTO staging.icd9 (code, description) VALUES ('1223', 'ECHINOCOCCUS GRANULOSUS INFECTION, OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1224', 'ECHINOCOCCUS GRANULOSUS INFECTION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1225', 'ECHINOCOCCUS MULTILOCULARIS INFECTION OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('1226', 'ECHINOCOCCUS MULTILOCULARIS INFECTION, OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1227', 'ECHINOCOCCUS MULTILOCULARIS INFECTION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1228', 'ECHINOCOCCOSIS, UNSPECIFIED, OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('1229', 'ECHINOCOCCOSIS, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('123', 'OTHER CESTODE INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1230', 'TAENIA SOLIUM INFECTION, INTESTINAL FORM');
INSERT INTO staging.icd9 (code, description) VALUES ('1231', 'CYSTICERCOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1232', 'TAENIA SAGINATA INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1233', 'TAENIASIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1234', 'DIPHYLLOBOTHRIASIS, INTESTINAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1235', 'SPARGANOSIS (LARVAL DIPHYLLOBOTHRIASIS)');
INSERT INTO staging.icd9 (code, description) VALUES ('1236', 'HYMENOLEPIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1238', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1239', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('124', 'TRICHINOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('125', 'FILARIAL INFECTION AND DRACONTIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1250', 'BANCROFTIAN FILARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1251', 'MALAYAN FILARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1252', 'LOIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1253', 'ONCHOCERCIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1254', 'DIPETALONEMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1255', 'MANSONELLA OZZARDI INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1256', 'OTHER SPECIFIED FILARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1257', 'DRACONTIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1259', 'UNSPECIFIED FILARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('126', 'ANCYLOSTOMIASIS AND NECATORIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1260', 'ANCYLOSTOMA DUODENALE');
INSERT INTO staging.icd9 (code, description) VALUES ('1261', 'NECATOR AMERICANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1262', 'ANCYLOSTOMA BRAZILIENSE');
INSERT INTO staging.icd9 (code, description) VALUES ('1263', 'ANCYLOSTOMA CEYLANICUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1268', 'OTHER SPECIFIED ANCYLOSTOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('1269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('127', 'OTHER INTESTINAL HELMINTHIASES');
INSERT INTO staging.icd9 (code, description) VALUES ('1270', 'ASCARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1271', 'ANISAKIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1272', 'STRONGYLOIDIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1273', 'TRICHURIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1274', 'ENTEROBIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1275', 'CAPILLARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1276', 'TRICHOSTRONGYLIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1277', 'OTHER INTESTINAL HELMINTHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1278', 'MIXED INTESTINAL HELMINTHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1279', 'INTESTINAL HELMINTHIASIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('128', 'OTHER AND UNSPECIFIED HELMINTHIASES');
INSERT INTO staging.icd9 (code, description) VALUES ('1280', 'TOXOCARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1281', 'GNATHOSTOMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1288', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1289', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('129', 'INTESTINAL PARASITISM, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('130', 'TOXOPLASMOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('131', 'TRICHOMONIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1310', 'UROGENITAL TRICHOMONIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1318', 'OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1319', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('132', 'PEDICULOSIS AND PHTHIRUS INFESTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('1320', 'PEDICULUS CAPITIS (HEAD LOUSE)');
INSERT INTO staging.icd9 (code, description) VALUES ('1321', 'PEDICULUS CORPORIS (BODY LOUSE)');
INSERT INTO staging.icd9 (code, description) VALUES ('1322', 'PHTHIRUS PUBIS (PUBIC LOUSE)');
INSERT INTO staging.icd9 (code, description) VALUES ('1323', 'MIXED');
INSERT INTO staging.icd9 (code, description) VALUES ('1329', 'PEDICULOSIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('133', 'ACARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1330', 'SCABIES');
INSERT INTO staging.icd9 (code, description) VALUES ('1338', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1339', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('134', 'OTHER INFESTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('1340', 'MYIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1341', 'OTHER ARTHROPOD INFESTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('1342', 'HIRUDINIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1348', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1349', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('135', 'SARCOIDOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('136', 'OTHER AND UNSPECIFIED INFECTIOUS AND PARASITIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('1360', 'AINHUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1361', 'BEHCET''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('1362', 'SPECIFIC INFECTIONS BY FREE-LIVING AMOEBAE');
INSERT INTO staging.icd9 (code, description) VALUES ('1363', 'PNEUMOCYSTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1364', 'PSOROSPERMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1365', 'SARCOSPORIDIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1368', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1369', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('137', 'LATE EFFECTS OF TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1370', 'LATE EFFECTS OF RESPIRATORY OR UNSPECIFIED TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1371', 'LATE EFFECTS OF CENTRAL NERVOUS SYSTEM TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1372', 'LATE EFFECTS OF GENITOURINARY TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1373', 'LATE EFFECTS OF TUBERCULOSIS OF BONES AND JOINTS');
INSERT INTO staging.icd9 (code, description) VALUES ('1374', 'LATE EFFECTS OF TUBERCULOSIS OF OTHER SPECIFIED ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('138', 'LATE EFFECTS OF ACUTE POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('139', 'LATE EFFECTS OF OTHER INFECTIOUS AND PARASITIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('1390', 'LATE EFFECTS OF VIRAL ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1391', 'LATE EFFECTS OF TRACHOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('1398', 'LATE EFFECTS OF OTHER AND UNSPECIFIED INFECTIOUS AND PARASITIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('140', 'MALIGNANT NEOPLASM OF LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1400', 'UPPER LIP, VERMILION BORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1401', 'LOWER LIP, VERMILION BORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1403', 'UPPER LIP, INNER ASPECT');
INSERT INTO staging.icd9 (code, description) VALUES ('1404', 'LOWER LIP, INNER ASPECT');
INSERT INTO staging.icd9 (code, description) VALUES ('1405', 'LIP, UNSPECIFIED, INNER ASPECT');
INSERT INTO staging.icd9 (code, description) VALUES ('1406', 'COMMISSURE OF LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1408', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1409', 'LIP, UNSPECIFIED, VERMILION BORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('141', 'MALIGNANT NEOPLASM OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('1410', 'BASE OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('1411', 'DORSAL SURFACE OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('1412', 'TIP AND LATERAL BORDER OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('1413', 'VENTRAL SURFACE OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('1414', 'ANTERIOR TWO-THIRDS OF TONGUE, PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1415', 'JUNCTIONAL ZONE');
INSERT INTO staging.icd9 (code, description) VALUES ('1416', 'LINGUAL TONSIL');
INSERT INTO staging.icd9 (code, description) VALUES ('1418', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1419', 'TONGUE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('142', 'MALIGNANT NEOPLASM OF MAJOR SALIVARY GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('1420', 'PAROTID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1421', 'SUBMANDIBULAR GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1422', 'SUBLINGUAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1428', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1429', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('143', 'MALIGNANT NEOPLASM OF GUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1430', 'UPPER GUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1431', 'LOWER GUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1438', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1439', 'GUM, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('144', 'MALIGNANT NEOPLASM OF FLOOR OF MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('1440', 'ANTERIOR PORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1441', 'LATERAL PORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1448', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1449', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('145', 'MALIGNANT NEOPLASM OF OTHER AND UNSPECIFIED PARTS OF MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('1450', 'CHEEK MUCOSA');
INSERT INTO staging.icd9 (code, description) VALUES ('1451', 'VESTIBULE OF MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('1452', 'HARD PALATE');
INSERT INTO staging.icd9 (code, description) VALUES ('1453', 'SOFT PALATE');
INSERT INTO staging.icd9 (code, description) VALUES ('1454', 'UVULA');
INSERT INTO staging.icd9 (code, description) VALUES ('1455', 'PALATE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1456', 'RETROMOLAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('1458', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1459', 'MOUTH, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('146', 'MALIGNANT NEOPLASM OF OROPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1460', 'TONSIL');
INSERT INTO staging.icd9 (code, description) VALUES ('1461', 'TONSILLAR FOSSA');
INSERT INTO staging.icd9 (code, description) VALUES ('1462', 'TONSILLAR PILLARS (ANTERIOR) (POSTERIOR)');
INSERT INTO staging.icd9 (code, description) VALUES ('1463', 'VALLECULA');
INSERT INTO staging.icd9 (code, description) VALUES ('1464', 'ANTERIOR ASPECT OF EPIGLOTTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1465', 'JUNCTIONAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('1466', 'LATERAL WALL OF OROPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1467', 'POSTERIOR WALL OF OROPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1468', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1469', 'OROPHARYNX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('147', 'MALIGNANT NEOPLASM OF NASOPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1470', 'SUPERIOR WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1471', 'POSTERIOR WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1472', 'LATERAL WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1473', 'ANTERIOR WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1478', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1479', 'NASOPHARYNX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('148', 'MALIGNANT NEOPLASM OF HYPOPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1480', 'POSTCRICOID REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('1481', 'PYRIFORM SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1482', 'ARYEPIGLOTTIC FOLD, HYPOPHARYNGEAL ASPECT');
INSERT INTO staging.icd9 (code, description) VALUES ('1483', 'POSTERIOR HYPOPHARYNGEAL WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1488', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1489', 'HYPOPHARYNX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('149', 'MALIGNANT NEOPLASM OF OTHER AND ILL-DEFINED SITES WITHIN THE LIP, ORAL CAVITY AND PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1490', 'PHARYNX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1491', 'WALDEYER''S RING');
INSERT INTO staging.icd9 (code, description) VALUES ('1498', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1499', 'ILL-DEFINED');
INSERT INTO staging.icd9 (code, description) VALUES ('150', 'MALIGNANT NEOPLASM OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1500', 'CERVICAL PART');
INSERT INTO staging.icd9 (code, description) VALUES ('1501', 'THORACIC PART');
INSERT INTO staging.icd9 (code, description) VALUES ('1502', 'ABDOMINAL PART');
INSERT INTO staging.icd9 (code, description) VALUES ('1503', 'UPPER THIRD');
INSERT INTO staging.icd9 (code, description) VALUES ('1504', 'MIDDLE THIRD');
INSERT INTO staging.icd9 (code, description) VALUES ('1505', 'LOWER THIRD');
INSERT INTO staging.icd9 (code, description) VALUES ('1508', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1509', 'OESOPHAGUS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('151', 'MALIGNANT NEOPLASM OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('1510', 'CARDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('1511', 'PYLORUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1512', 'PYLORIC ANTRUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1513', 'FUNDUS OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('1514', 'BODY OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('1515', 'LESSER CURVATURE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1516', 'GREATER CURVATURE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1518', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1519', 'STOMACH, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('152', 'MALIGNANT NEOPLASM OF SMALL INTESTINE, INCLUDING DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1520', 'DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1521', 'JEJUNUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1522', 'ILEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1523', 'MECKEL''S DIVERTICULUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1528', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1529', 'SMALL INTESTINE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('153', 'MALIGNANT NEOPLASM OF COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('1530', 'HEPATIC FLEXURE');
INSERT INTO staging.icd9 (code, description) VALUES ('1531', 'TRANSVERSE COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('1532', 'DESCENDING COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('1533', 'SIGMOID COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('1534', 'CAECUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1535', 'APPENDIX');
INSERT INTO staging.icd9 (code, description) VALUES ('1536', 'ASCENDING COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('1537', 'SPLENIC FLEXURE');
INSERT INTO staging.icd9 (code, description) VALUES ('1538', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1539', 'COLON, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('154', 'MALIGNANT NEOPLASM OF RECTUM, RECTOSIGMOID JUNCTION AND ANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1540', 'RECTOSIGMOID JUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1541', 'RECTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1542', 'ANAL CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1543', 'ANUS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1548', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('155', 'MALIGNANT NEOPLASM OF LIVER AND INTRAHEPATIC BILE DUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('1550', 'LIVER, PRIMARY');
INSERT INTO staging.icd9 (code, description) VALUES ('1551', 'INTRAHEPATIC BILE DUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('1552', 'LIVER, NOT SPECIFIED AS PRIMARY OR SECONDARY');
INSERT INTO staging.icd9 (code, description) VALUES ('156', 'MALIGNANT NEOPLASM OF GALLBLADDER AND EXTRAHEPATIC BILE DUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('1560', 'GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1561', 'EXTRAHEPATIC BILE DUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('1562', 'AMPULLA OF VATER');
INSERT INTO staging.icd9 (code, description) VALUES ('1568', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1569', 'BILIARY TRACT,PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('157', 'MALIGNANT NEOPLASM OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('1570', 'HEAD OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('1571', 'BODY OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('1572', 'TAIL OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('1573', 'PANCREATIC DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('1574', 'ISLETS OF LANGERHANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1578', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1579', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('158', 'MALIGNANT NEOPLASM OF RETROPERITONEUM AND PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1580', 'RETROPERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1588', 'SPECIFIED PARTS OF PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1589', 'PERITONEUM, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('159', 'MALIGNANT NEOPLASM OF OTHER AND ILL-DEFINED SITES WITHIN THE DIGESTIVE ORGANS AND PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1590', 'INTESTINAL TRACT, PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1591', 'SPLEEN, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1598', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1599', 'ILL-DEFINED');
INSERT INTO staging.icd9 (code, description) VALUES ('160', 'MALIGNANT NEOPLASM OF NASAL CAVITIES, MIDDLE EAR AND ACCESSORY SINUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('1600', 'NASAL CAVITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('1601', 'AUDITORY TUBE, MIDDLE EAR AND MASTOID AIR CELLS');
INSERT INTO staging.icd9 (code, description) VALUES ('1602', 'MAXILLARY SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1603', 'ETHMOIDAL SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1604', 'FRONTAL SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1605', 'SPHENOIDAL SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1608', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1609', 'ACCESSORY SINUS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('161', 'MALIGNANT NEOPLASM OF LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('1610', 'GLOTTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1611', 'SUPRAGLOTTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1612', 'SUBGLOTTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1613', 'LARYNGEAL CARTILAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('1618', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1619', 'LARYNX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('162', 'MALIGNANT NEOPLASM OF TRACHEA, BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1620', 'TRACHEA');
INSERT INTO staging.icd9 (code, description) VALUES ('1622', 'MAIN BRONCHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1623', 'UPPER LOBE, BRONCHUS OR LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1624', 'MIDDLE LOBE, BRONCHUS OR LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1625', 'LOWER LOBE, BRONCHUS OR LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1628', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1629', 'BRONCHUS AND LUNG, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('163', 'MALIGNANT NEOPLASM OF PLEURA');
INSERT INTO staging.icd9 (code, description) VALUES ('1630', 'PARIETAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1631', 'VISCERAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1638', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1639', 'PLEURA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('164', 'MALIGNANT NEOPLASM OF THYMUS, HEART AND MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1640', 'THYMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1641', 'HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('1642', 'ANTERIOR MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1643', 'POSTERIOR MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1648', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1649', 'MEDIASTINUM, PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('165', 'MALIGNANT NEOPLASM OF OTHER AND ILL-DEFINED SITES WITHIN THE RESPIRATORY SYSTEM AND INTRATHORACIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1650', 'UPPER RESPIRATORY TRACT, PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1658', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1659', 'ILL-DEFINED SITES WITHIN THE RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('170', 'MALIGNANT NEOPLASM OF BONE AND ARTICULAR CARTILAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('1700', 'BONES OF SKULL AND FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('1701', 'LOWER JAW BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('1702', 'VERTEBRAL COLUMN, EXCLUDING SACRUM AND COCCYX');
INSERT INTO staging.icd9 (code, description) VALUES ('1703', 'RIBS, STERNUM AND CLAVICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('1704', 'LONG BONES OF UPPER LIMB AND SCAPULA');
INSERT INTO staging.icd9 (code, description) VALUES ('1705', 'UPPER LIMB, SHORT BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('1706', 'PELVIC BONES, SACRUM AND COCCYX');
INSERT INTO staging.icd9 (code, description) VALUES ('1707', 'LOWER LIMB, LONG BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('1708', 'LOWER LIMB, SHORT BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('1709', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('171', 'MALIGNANT NEOPLASM OF CONNECTIVE AND OTHER SOFT TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('1710', 'HEAD, FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('1712', 'UPPER LIMB, INCLUDING SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1713', 'LOWER LIMB, INCLUDING HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1714', 'THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('1715', 'ABDOMEN');
INSERT INTO staging.icd9 (code, description) VALUES ('1716', 'PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1717', 'TRUNK, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1718', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1719', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('172', 'MALIGNANT MELANOMA OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('1720', 'LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1721', 'EYELID, INCLUDING CANTHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1722', 'EAR AND EXTERNAL AURICULAR CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1723', 'OTHER AND UNSPECIFIED PARTS OF FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('1724', 'SCALP AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('1725', 'TRUNK, EXCEPT SCROTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1726', 'UPPER LIMB INCLUDING SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1727', 'LOWER LIMB INCLUDING HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1728', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1729', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('173', 'OTHER MALIGNANT NEOPLASM OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('1730', 'SKIN OF LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1731', 'EYELID, INCLUDING CANTHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1732', 'EAR AND EXTERNAL AURICULAR CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1733', 'SKIN OF OTHER AND UNSPECIFIED PARTS OF FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('1734', 'SCALP AND SKIN OF NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('1735', 'SKIN OF TRUNK, EXCEPT SCROTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1736', 'SKIN OF UPPER LIMB, INCLUDING SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1737', 'SKIN OF LOWER LIMB, INCLUDING HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('1738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1739', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('174', 'MALIGNANT NEOPLASM OF FEMALE BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('1740', 'NIPPLE AND AREOLA');
INSERT INTO staging.icd9 (code, description) VALUES ('1741', 'CENTRAL PORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('1742', 'UPPER-INNER QUADRANT');
INSERT INTO staging.icd9 (code, description) VALUES ('1743', 'LOWER-INNER QUADRANT');
INSERT INTO staging.icd9 (code, description) VALUES ('1744', 'UPPER-OUTER QUADRANT');
INSERT INTO staging.icd9 (code, description) VALUES ('1745', 'LOWER-OUTER QUADRANT');
INSERT INTO staging.icd9 (code, description) VALUES ('1746', 'AXILLARY TAIL');
INSERT INTO staging.icd9 (code, description) VALUES ('1748', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1749', 'BREAST, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('175', 'MALIGNANT NEOPLASM OF MALE BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('179', 'MALIGNANT NEOPLASM OF UTERUS, PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('180', 'MALIGNANT NEOPLASM OF CERVIX UTERI');
INSERT INTO staging.icd9 (code, description) VALUES ('1800', 'ENDOCERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('1801', 'EXOCERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('1808', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1809', 'CERVIX UTERI, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('181', 'MALIGNANT NEOPLASM OF PLACENTA');
INSERT INTO staging.icd9 (code, description) VALUES ('182', 'MALIGNANT NEOPLASM OF BODY OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1820', 'CORPUS UTERI, EXCEPT ISTHMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1821', 'ISTHMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1828', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('183', 'MALIGNANT NEOPLASM OF OVARY AND OTHER UTERINE ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('1830', 'OVARY');
INSERT INTO staging.icd9 (code, description) VALUES ('1832', 'FALLOPIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('1833', 'BROAD LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('1834', 'PARAMETRIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1835', 'ROUND LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('1838', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1839', 'UTERINE ADNEXA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('184', 'MALIGNANT NEOPLASM OF OTHER AND UNSPECIFIED FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1840', 'VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('1841', 'LABIA MAJORA');
INSERT INTO staging.icd9 (code, description) VALUES ('1842', 'LABIA MINORA');
INSERT INTO staging.icd9 (code, description) VALUES ('1843', 'CLITORIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1844', 'VULVA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1848', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1849', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('185', 'MALIGNANT NEOPLASM OF PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('186', 'MALIGNANT NEOPLASM OF TESTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1860', 'UNDESCENDED');
INSERT INTO staging.icd9 (code, description) VALUES ('1869', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('187', 'MALIGNANT NEOPLASM OF PENIS AND OTHER MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1871', 'PREPUCE');
INSERT INTO staging.icd9 (code, description) VALUES ('1872', 'GLANS PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1873', 'BODY OF PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1874', 'PENIS, PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('1875', 'EPIDIDYMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1876', 'SPERMATIC CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('1877', 'SCROTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1878', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1879', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('188', 'MALIGNANT NEOPLASM OF BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('1880', 'TRIGONE');
INSERT INTO staging.icd9 (code, description) VALUES ('1881', 'DOME');
INSERT INTO staging.icd9 (code, description) VALUES ('1882', 'LATERAL WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1883', 'ANTERIOR WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1884', 'POSTERIOR WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('1885', 'BLADDER NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('1886', 'URETERIC ORIFICE');
INSERT INTO staging.icd9 (code, description) VALUES ('1887', 'URACHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('1888', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1889', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2105', 'TONSIL');
INSERT INTO staging.icd9 (code, description) VALUES ('189', 'MALIGNANT NEOPLASM OF KIDNEY AND OTHER AND UNSPECIFIED URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1890', 'KIDNEY, EXCEPT PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1891', 'RENAL PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1892', 'URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('1893', 'URETHRA');
INSERT INTO staging.icd9 (code, description) VALUES ('1894', 'PARAURETHRAL GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('1898', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1899', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('190', 'MALIGNANT NEOPLASM OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('1900', 'EYEBALL, EXCEPT CONJUNCTIVA, CORNEA, RETINA AND CHOROID');
INSERT INTO staging.icd9 (code, description) VALUES ('1901', 'ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('1902', 'LACRIMAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1903', 'CONJUNCTIVA');
INSERT INTO staging.icd9 (code, description) VALUES ('1904', 'CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('1905', 'RETINA');
INSERT INTO staging.icd9 (code, description) VALUES ('1906', 'CHOROID');
INSERT INTO staging.icd9 (code, description) VALUES ('1907', 'LACRIMAL DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('1908', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1909', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('191', 'MALIGNANT NEOPLASM OF BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('1910', 'CEREBRUM, EXCEPT LOBES AND VENTRICLES');
INSERT INTO staging.icd9 (code, description) VALUES ('1911', 'FRONTAL LOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('1912', 'TEMPORAL LOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('1913', 'PARIETAL LOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('1914', 'OCCIPITAL LOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('1915', 'VENTRICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('1916', 'CEREBELLUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1917', 'BRAIN STEM');
INSERT INTO staging.icd9 (code, description) VALUES ('1918', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1919', 'BRAIN, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('192', 'MALIGNANT NEOPLASM OF OTHER AND UNSPECIFIED PARTS OF NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('1920', 'CRANIAL NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('1921', 'CEREBRAL MENINGES');
INSERT INTO staging.icd9 (code, description) VALUES ('1922', 'SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('1923', 'SPINAL MENINGES');
INSERT INTO staging.icd9 (code, description) VALUES ('1928', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1929', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('193', 'MALIGNANT NEOPLASM OF THYROID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('194', 'MALIGNANT NEOPLASM OF OTHER ENDOCRINE GLANDS AND RELATED STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('1940', 'SUPRARENAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1941', 'PARATHYROID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1943', 'PITUITARY GLAND AND CRANIOPHARYNGEAL DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('1944', 'PINEAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1945', 'CAROTID BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('1946', 'AORTIC BODY AND OTHER PARAGANGLIA');
INSERT INTO staging.icd9 (code, description) VALUES ('1948', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('1949', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('195', 'MALIGNANT NEOPLASM OF OTHER AND ILL-DEFINED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1950', 'HEAD, FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('1951', 'THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('1952', 'ABDOMEN');
INSERT INTO staging.icd9 (code, description) VALUES ('1953', 'PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('1954', 'UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('1955', 'LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('1958', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('196', 'SECONDARY AND UNSPECIFIED MALIGNANT NEOPLASM OF LYMPH NODES');
INSERT INTO staging.icd9 (code, description) VALUES ('1960', 'HEAD, FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('1961', 'INTRATHORACIC');
INSERT INTO staging.icd9 (code, description) VALUES ('1962', 'INTRA-ABDOMINAL');
INSERT INTO staging.icd9 (code, description) VALUES ('1963', 'AXILLA AND UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('1965', 'INGUINAL AND LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('1966', 'INTRAPELVIC');
INSERT INTO staging.icd9 (code, description) VALUES ('1968', 'MULTIPLE SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1969', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('197', 'SECONDARY MALIGNANT NEOPLASM OF RESPIRATORY AND DIGESTIVE SYSTEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('1970', 'LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('1971', 'MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1972', 'PLEURA');
INSERT INTO staging.icd9 (code, description) VALUES ('1973', 'OTHER RESPIRATORY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1974', 'SMALL INTESTINE, INCLUDING DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1975', 'LARGE INTESTINE AND RECTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1976', 'RETROPERITONEUM AND PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('1977', 'LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('1978', 'OTHER DIGESTIVE ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('198', 'SECONDARY MALIGNANT NEOPLASM OF OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('1980', 'KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('1981', 'OTHER URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('1982', 'SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('1983', 'BRAIN AND SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('1984', 'OTHER PARTS OF NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('1985', 'BONE AND BONE MARROW');
INSERT INTO staging.icd9 (code, description) VALUES ('1986', 'OVARY');
INSERT INTO staging.icd9 (code, description) VALUES ('1987', 'SUPRARENAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('1988', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('199', 'MALIGNANT NEOPLASM WITHOUT SPECIFICATION OF SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('1990', 'DISSEMINATED');
INSERT INTO staging.icd9 (code, description) VALUES ('1991', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('200', 'LYMPHOSARCOMA AND RETICULOSARCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2000', 'RETICULOSARCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2001', 'LYMPHOSARCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2002', 'BURKITT''S TUMOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('2008', 'OTHER NAMED VARIANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('201', 'HODGKIN''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('2010', 'HODGKIN''S PARAGRANULOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2011', 'HODGKIN''S GRANULOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2012', 'HODGKIN''S SARCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2014', 'LYMPHOCYTIC-HISTIOCYTIC PREDOMINANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('2015', 'NODULAR SCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2016', 'MIXED CELLULARITY');
INSERT INTO staging.icd9 (code, description) VALUES ('2017', 'LYMPHOCYTIC DEPLETION');
INSERT INTO staging.icd9 (code, description) VALUES ('2019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('202', 'OTHER MALIGNANT NEOPLASM OF LYMPHOID AND HISTIOCYTIC TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('2020', 'NODULAR LYMPHOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2021', 'MYCOSIS FUNGOIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('2022', 'SEZARY''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('2023', 'MALIGNANT HISTIOCYTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2024', 'LEUKAEMIC RETICULOENDOTHELIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2025', 'LETTERER-SIWE DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('2026', 'MALIGNANT MAST-CELL TUMOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('2028', 'OTHER LYMPHOMAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2029', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('203', 'MULTIPLE MYELOMA AND IMMUNOPROLIFERATIVE NEOPLASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('2030', 'MULTIPLE MYELOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2031', 'PLASMA CELL LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2038', 'OTHER IMMUNOPROLIFERATIVE NEOPLASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('204', 'LYMPHOID LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2040', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2041', 'CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2042', 'SUBACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2048', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2049', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('205', 'MYELOID LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2050', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2051', 'CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2052', 'SUBACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2053', 'MYELOID SARCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2058', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2059', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('206', 'MONOCYTIC LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2060', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2061', 'CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2062', 'SUBACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2068', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2069', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('207', 'OTHER SPECIFIED LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2070', 'ACUTE ERYTHRAEMIA AND ERYTHROLEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2071', 'CHRONIC ERYTHRAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2072', 'MEGAKARYOCYTIC LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2078', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('208', 'LEUKAEMIA OF UNSPECIFIED CELL TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2080', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2081', 'CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2082', 'SUBACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('2088', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2089', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('210', 'BENIGN NEOPLASM OF LIP, ORAL CAVITY AND PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2100', 'LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('2101', 'TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('2102', 'MAJOR SALIVARY GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('2103', 'FLOOR OF MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('2104', 'OTHER AND UNSPECIFIED PARTS OF MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('2106', 'OTHER PARTS OF OROPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2107', 'NASOPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2108', 'HYPOPHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2109', 'PHARYNX, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('211', 'BENIGN NEOPLASM OF OTHER PARTS OF DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2110', 'OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2111', 'STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('2112', 'SMALL INTESTINE, INCLUDING DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2113', 'COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('2114', 'RECTUM AND ANAL CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('2115', 'LIVER AND BILIARY PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('2116', 'PANCREAS, EXCEPT ISLETS OF LANGERHANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2117', 'ISLETS OF LANGERHANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2118', 'RETROPERITONEUM AND PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2119', 'OTHER AND UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('212', 'BENIGN NEOPLASM OF RESPIRATORY AND INTRATHORACIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2120', 'NASAL CAVITIES, MIDDLE EAR AND ACCESSORY SINUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2121', 'LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2122', 'TRACHEA');
INSERT INTO staging.icd9 (code, description) VALUES ('2123', 'BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('2124', 'PLEURA');
INSERT INTO staging.icd9 (code, description) VALUES ('2125', 'MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2126', 'THYMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2127', 'HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('2128', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2129', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('213', 'BENIGN NEOPLASM OF BONE AND ARTICULAR CARTILAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('2130', 'BONES OF SKULL AND FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('2131', 'LOWER JAW BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('2132', 'VERTEBRAL COLUMN, EXCLUDING SACRUM AND COCCYX');
INSERT INTO staging.icd9 (code, description) VALUES ('2133', 'RIBS, STERNUM AND CLAVICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('2134', 'LONG BONES OF UPPER LIMB AND SCAPULA');
INSERT INTO staging.icd9 (code, description) VALUES ('2135', 'UPPER LIMB, SHORT BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('2136', 'PELVIC BONES, SACRUM AND COCCYX');
INSERT INTO staging.icd9 (code, description) VALUES ('2137', 'LOWER LIMB, LONG BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('2138', 'LOWER LIMB, SHORT BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('2139', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('214', 'LIPOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('215', 'OTHER BENIGN NEOPLASM OF CONNECTIVE AND OTHER SOFT TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('2150', 'HEAD, FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('2152', 'UPPER LIMB, INCLUDING SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2153', 'LOWER LIMB, INCLUDING HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('2154', 'THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('2155', 'ABDOMEN');
INSERT INTO staging.icd9 (code, description) VALUES ('2156', 'PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2157', 'TRUNK, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2158', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2159', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('216', 'BENIGN NEOPLASM OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2160', 'SKIN OF LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('2161', 'EYELID, INCLUDING CANTHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2162', 'EAR AND EXTERNAL AURICULAR CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('2163', 'SKIN OF OTHER AND UNSPECIFIED PARTS OF FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('2164', 'SCALP AND SKIN OF NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('2165', 'SKIN OF TRUNK, EXCEPT SCROTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2166', 'SKIN OF UPPER LIMB, INCLUDING SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2167', 'SKIN OF LOWER LIMB, INCLUDING HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('2168', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2169', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('217', 'BENIGN NEOPLASM OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('218', 'UTERINE LEIOMYOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('219', 'OTHER BENIGN NEOPLASM OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2190', 'CERVIX UTERI');
INSERT INTO staging.icd9 (code, description) VALUES ('2191', 'CORPUS UTERI');
INSERT INTO staging.icd9 (code, description) VALUES ('2198', 'OTHER SPECIFIED PARTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2199', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('220', 'BENIGN NEOPLASM OF OVARY');
INSERT INTO staging.icd9 (code, description) VALUES ('221', 'BENIGN NEOPLASM OF OTHER FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2210', 'UTERINE TUBE AND LIGAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2211', 'VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('2212', 'VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('2218', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2219', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('222', 'BENIGN NEOPLASM OF MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2220', 'TESTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2221', 'PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2222', 'PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('2223', 'EPIDIDYMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2224', 'SCROTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2228', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2229', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('223', 'BENIGN NEOPLASM OF KIDNEY AND OTHER URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2230', 'KIDNEY, EXCEPT PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2231', 'RENAL PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2232', 'URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('2233', 'BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2238', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2239', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('224', 'BENIGN NEOPLASM OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('2240', 'EYEBALL, EXCEPT CONJUNCTIVA, CORNEA, RETINA, AND CHOROID');
INSERT INTO staging.icd9 (code, description) VALUES ('2241', 'ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('2242', 'LACRIMAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2243', 'CONJUNCTIVA');
INSERT INTO staging.icd9 (code, description) VALUES ('2244', 'CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('2245', 'RETINA');
INSERT INTO staging.icd9 (code, description) VALUES ('2246', 'CHOROID');
INSERT INTO staging.icd9 (code, description) VALUES ('2247', 'LACRIMAL DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('2248', 'OTHER SPECIFIED PARTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2249', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('225', 'BENIGN NEOPLASM OF BRAIN AND OTHER PARTS OF NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2250', 'BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2251', 'CRANIAL NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('2252', 'CEREBRAL MENINGES');
INSERT INTO staging.icd9 (code, description) VALUES ('2253', 'SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('2254', 'SPINAL MENINGES');
INSERT INTO staging.icd9 (code, description) VALUES ('2258', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2259', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('226', 'BENIGN NEOPLASM OF THYROID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('227', 'BENIGN NEOPLASM OF OTHER ENDOCRINE GLANDS AND RELATED STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('2270', 'SUPRARENAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2271', 'PARATHYROID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2273', 'PITUITARY GLAND AND CRANIOPHARYNGEAL DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('2274', 'PINEAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2275', 'CAROTID BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('2276', 'AORTIC BODY AND OTHER PARAGANGLIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2278', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2279', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('228', 'HAEMANGIOMA AND LYMPHANGIOMA, ANY SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('2280', 'HAEMANGIOMA, ANY SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('2281', 'LYMPHANGIOMA, ANY SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('229', 'BENIGN NEOPLASM OF OTHER AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2290', 'LYMPH NODES');
INSERT INTO staging.icd9 (code, description) VALUES ('2298', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2299', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('230', 'CARCINOMA IN SITU OF DIGESTIVE ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2300', 'LIP, ORAL CAVITY AND PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2301', 'OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2302', 'STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('2303', 'COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('2304', 'RECTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2305', 'ANAL CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('2306', 'ANUS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2307', 'OTHER AND UNSPECIFIED PARTS OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('2308', 'LIVER AND BILIARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2309', 'OTHER AND UNSPECIFIED DIGESTIVE ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('231', 'CARCINOMA IN SITU OF RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2310', 'LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2311', 'TRACHEA');
INSERT INTO staging.icd9 (code, description) VALUES ('2312', 'BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('2318', 'OTHER SPECIFIED PARTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2319', 'PART UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('232', 'CARCINOMA IN SITU OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2320', 'SKIN OF LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('2321', 'EYELID, INCLUDING CANTHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2322', 'EAR AND EXTERNAL AURICULAR CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('2323', 'SKIN OF OTHER AND UNSPECIFIED PARTS OF FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('2324', 'SCALP AND SKIN OF NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('2325', 'SKIN OF TRUNK, EXCEPT SCROTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2326', 'SKIN OF UPPER LIMB, INCLUDING SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2327', 'SKIN OF LOWER LIMB, INCLUDING HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('2328', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2329', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('233', 'CARCINOMA IN SITU OF BREAST AND GENITOURINARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2330', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('2331', 'CERVIX UTERI');
INSERT INTO staging.icd9 (code, description) VALUES ('2332', 'OTHER AND UNSPECIFIED PARTS OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2333', 'OTHER AND UNSPECIFIED FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2334', 'PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('2335', 'PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2336', 'OTHER AND UNSPECIFIED MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2337', 'BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2339', 'OTHER AND UNSPECIFIED URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('234', 'CARCINOMA IN SITU OF OTHER AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2340', 'EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('2348', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2349', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('235', 'NEOPLASM OF UNCERTAIN BEHAVIOUR OF DIGESTIVE AND RESPIRATORY SYSTEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('2350', 'MAJOR SALIVARY GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('2351', 'LIP, ORAL CAVITY AND PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2352', 'STOMACH, INTESTINES AND RECTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2353', 'LIVER AND BILIARY PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('2354', 'RETROPERITONEUM AND PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2355', 'OTHER AND UNSPECIFIED DIGESTIVE ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2356', 'LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('2357', 'TRACHEA, BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('2358', 'PLEURA, THYMUS AND MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('2359', 'OTHER AND UNSPECIFIED RESPIRATORY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('236', 'NEOPLASM OF UNCERTAIN BEHAVIOUR OF GENITOURINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2360', 'UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2361', 'PLACENTA');
INSERT INTO staging.icd9 (code, description) VALUES ('2362', 'OVARY');
INSERT INTO staging.icd9 (code, description) VALUES ('2363', 'OTHER AND UNSPECIFIED FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2364', 'TESTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2365', 'PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('2366', 'OTHER AND UNSPECIFIED MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2367', 'BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2369', 'OTHER AND UNSPECIFIED URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('237', 'NEOPLASM OF UNCERTAIN BEHAVIOUR OF ENDOCRINE GLANDS AND NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2370', 'PITUITARY GLAND AND CRANIOPHARYNGEAL DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('2371', 'PINEAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2372', 'SUPRARENAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2373', 'PARAGANGLIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2374', 'OTHER AND UNSPECIFIED ENDOCRINE GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('2375', 'BRAIN AND SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('2376', 'MENINGES');
INSERT INTO staging.icd9 (code, description) VALUES ('2377', 'NEUROFIBROMATOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2379', 'OTHER AND UNSPECIFIED PARTS OF THE NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('238', 'NEOPLASM OF UNCERTAIN BEHAVIOUR OF OTHER AND UNSPECIFIED SITES AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('2380', 'BONES AND ARTICULAR CARTILAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('2381', 'CONNECTIVE AND OTHER SOFT TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('2382', 'SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2383', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('2384', 'POLYCYTHAEMIA VERA');
INSERT INTO staging.icd9 (code, description) VALUES ('2385', 'HISTIOCYTIC AND MAST CELLS');
INSERT INTO staging.icd9 (code, description) VALUES ('2386', 'PLASMA CELLS');
INSERT INTO staging.icd9 (code, description) VALUES ('2387', 'OTHER LYMPHATIC AND HAEMATOPOIETIC TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('2388', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2389', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('239', 'NEOPLASM OF UNSPECIFIED NATURE');
INSERT INTO staging.icd9 (code, description) VALUES ('2390', 'DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2391', 'RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2392', 'BONE, SOFT TISSUE AND SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2393', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('2394', 'BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2395', 'OTHER GENITOURINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2396', 'BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2397', 'ENDOCRINE GLANDS, AND OTHER PARTS OF NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('2398', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('2399', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('240', 'SIMPLE AND UNSPECIFIED GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2400', 'GOITRE, SPECIFIED AS SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('2409', 'GOITRE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('241', 'NONTOXIC NODULAR GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2410', 'NONTOXIC UNINODULAR GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2411', 'NONTOXIC MULTINODULAR GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2419', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('242', 'THYROTOXICOSIS WITH OR WITHOUT GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2420', 'TOXIC DIFFUSE GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2421', 'TOXIC UNINODULAR GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2422', 'TOXIC MULTINODULAR GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2423', 'TOXIC NODULAR GOITRE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2424', 'THYROTOXICOSIS FROM ECTOPIC THYROID NODULE');
INSERT INTO staging.icd9 (code, description) VALUES ('2428', 'THYROTOXICOSIS OF OTHER SPECIFIED ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2429', 'THYROTOXICOSIS WITHOUT MENTION OF GOITRE OR OTHER CAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('243', 'CONGENITAL HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('244', 'ACQUIRED HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2440', 'POSTSURGICAL HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2441', 'OTHER POSTABLATIVE HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2442', 'IODINE HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2443', 'OTHER IATROGENIC HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2448', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2449', 'UNSPECIFIED HYPOTHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('245', 'THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2450', 'ACUTE THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2451', 'SUBACUTE THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2452', 'CHRONIC LYMPHOCYTIC THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2453', 'CHRONIC FIBROUS THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2454', 'IATROGENIC THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2458', 'OTHER AND UNSPECIFIED CHRONIC THYROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2459', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('246', 'OTHER DISORDERS OF THE THYROID');
INSERT INTO staging.icd9 (code, description) VALUES ('2460', 'DISORDERS OF THYROCALCITONIN SECRETION');
INSERT INTO staging.icd9 (code, description) VALUES ('2461', 'DYSHORMONOGENIC GOITRE');
INSERT INTO staging.icd9 (code, description) VALUES ('2462', 'CYST OF THYROID');
INSERT INTO staging.icd9 (code, description) VALUES ('2463', 'HAEMORRHAGE AND INFARCTION OF THYROID');
INSERT INTO staging.icd9 (code, description) VALUES ('2468', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2469', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('250', 'DIABETES MELLITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2500', 'DIABETES MELLITUS WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('2501', 'DIABETES WITH KETOACIDOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2502', 'DIABETES WITH COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2503', 'DIABETES WITH RENAL MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2504', 'DIABETES WITH OPHTHALMIC MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2505', 'DIABETES WITH NEUROLOGICAL MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2506', 'DIABETES WITH PERIPHERAL CIRCULATORY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('2507', 'DIABETES WITH OTHER SPECIFIED MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2509', 'DIABETES WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('251', 'OTHER DISORDERS OF PANCREATIC INTERNAL SECRETION');
INSERT INTO staging.icd9 (code, description) VALUES ('2510', 'HYPOGLYCAEMIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('2511', 'OTHER HYPERINSULINISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2512', 'HYPOGLYCAEMIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2513', 'POSTSURGICAL HYPOINSULINAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2514', 'ABNORMALITY OF SECRETION OF GLUCAGON');
INSERT INTO staging.icd9 (code, description) VALUES ('2515', 'ABNORMALITY OF SECRETION OF GASTRIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2518', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2519', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('252', 'DISORDERS OF PARATHYROID GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2520', 'HYPERPARATHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2521', 'HYPOPARATHYROIDISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2528', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2529', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('253', 'DISORDERS OF THE PITUITARY GLAND AND ITS HYPOTHALAMIC CONTROL');
INSERT INTO staging.icd9 (code, description) VALUES ('2530', 'ACROMEGALY AND GIGANTISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2531', 'OTHER ANTERIOR PITUITARY HYPERFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2532', 'PANHYPOPITUITARISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2533', 'PITUITARY DWARFISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2534', 'OTHER ANTERIOR PITUITARY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('2535', 'DIABETES INSIPIDUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2536', 'OTHER DISORDERS OF NEUROHYPOPHYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2537', 'IATROGENIC PITUITARY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('2538', 'OTHER DISORDERS OF THE PITUITARY AND OTHER SYNDROMES OF DIENCEPHALOHYPOPHYSEAL ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('2539', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('254', 'DISEASES OF THYMUS GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('2540', 'PERSISTENT HYPERPLASIA OF THYMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2541', 'ABSCESS OF THYMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('2548', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2549', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('255', 'DISORDERS OF ADRENAL GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('2550', 'CUSHING''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('2551', 'HYPERALDOSTERONISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2552', 'ADRENOGENITAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('2553', 'OTHER CORTICOADRENAL OVERACTIVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('2554', 'CORTICOADRENAL INSUFFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2555', 'OTHER ADRENAL HYPOFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2556', 'MEDULLOADRENAL HYPERFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2558', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2559', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('256', 'OVARIAN DYSFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2560', 'HYPEROESTROGENISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2561', 'OTHER OVARIAN HYPERFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2562', 'POSTABLATIVE OVARIAN FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('2563', 'OTHER OVARIAN FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('2564', 'POLYCYSTIC OVARIES');
INSERT INTO staging.icd9 (code, description) VALUES ('2568', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2569', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('257', 'TESTICULAR DYSFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2570', 'TESTICULAR HYPERFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2571', 'POSTABLATIVE TESTICULAR HYPOFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2572', 'OTHER TESTICULAR HYPOFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2578', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('258', 'POLYGLANDULAR DYSFUNCTION AND RELATED DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('2580', 'POLYGLANDULAR ACTIVITY IN MULTIPLE ENDOCRINE ADENOMATOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2581', 'OTHER COMBINATIONS OF ENDOCRINE DYSFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2588', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2589', 'POLYGLANDULAR DYSFUNCTION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('259', 'OTHER ENDOCRINE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('2590', 'DELAY IN SEXUAL DEVELOPMENT AND PUBERTY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2591', 'PRECOCIOUS SEXUAL DEVELOPMENT AND PUBERTY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2592', 'CARCINOID SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('2593', 'ECTOPIC HORMONE SECRETION, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2594', 'DWARFISM, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2598', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2599', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('260', 'KWASHIORKOR');
INSERT INTO staging.icd9 (code, description) VALUES ('261', 'NUTRITIONAL MARASMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('262', 'OTHER SEVERE PROTEIN-CALORIE MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('263', 'OTHER AND UNSPECIFIED PROTEIN-CALORIE MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('2630', 'MALNUTRITION OF MODERATE DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('2631', 'MALNUTRITION OF MILD DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('2632', 'ARRESTED DEVELOPMENT FOLLOWING PROTEIN-CALORIE MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('2638', 'OTHER PROTEIN-CALORIE MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('2639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('264', 'VITAMIN ''A'' DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2640', 'WITH CONJUNCTIVAL XEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2641', 'WITH BITOT''S SPOT AND CONJUNCTIVAL XEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2642', 'WITH CORNEAL XEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2643', 'WITH CORNEAL ULCERATION AND XEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2644', 'WITH KERATOMALACIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2645', 'WITH NIGHT BLINDNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('2646', 'WITH XEROPHTHALMIC SCARS OF CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('2647', 'OTHER OCULAR MANIFESTATIONS OF VITAMIN ''A'' DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2648', 'OTHER MANIFESTATIONS OF VITAMIN ''A'' DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2649', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('265', 'THIAMINE AND NIACIN DEFICIENCY STATES');
INSERT INTO staging.icd9 (code, description) VALUES ('2650', 'BERIBERI');
INSERT INTO staging.icd9 (code, description) VALUES ('2651', 'OTHER AND UNSPECIFIED MANIFESTATIONS OF THIAMINE DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2652', 'PELLAGRA');
INSERT INTO staging.icd9 (code, description) VALUES ('266', 'DEFICIENCY OF ''B''-COMPLEX COMPONENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2660', 'ARIBOFLAVINOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2661', 'VITAMIN ''B6'' DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2662', 'OTHER ''B''-COMPLEX DEFICIENCIES');
INSERT INTO staging.icd9 (code, description) VALUES ('2669', 'UNSPECIFIED VITAMIN ''B'' DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('267', 'ASCORBIC ACID DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('268', 'VITAMIN ''D'' DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2680', 'RICKETS, ACTIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('2681', 'RICKETS, LATE EFFECT');
INSERT INTO staging.icd9 (code, description) VALUES ('2682', 'OSTEOMALACIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2689', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('269', 'OTHER NUTRITIONAL DEFICIENCIES');
INSERT INTO staging.icd9 (code, description) VALUES ('2690', 'DEFICIENCY OF VITAMIN ''K''');
INSERT INTO staging.icd9 (code, description) VALUES ('2691', 'DEFICIENCY OF OTHER VITAMINS');
INSERT INTO staging.icd9 (code, description) VALUES ('2692', 'UNSPECIFIED VITAMIN DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2693', 'MINERAL DEFICIENCY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2698', 'OTHER NUTRITIONAL DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2699', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('270', 'DISORDERS OF AMINO-ACID TRANSPORT AND METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2700', 'DISTURBANCES OF AMINO-ACID TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('2701', 'PHENYLKETONURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2702', 'OTHER DISTURBANCES OF AROMATIC AMINO-ACID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2703', 'DISTURBANCES OF BRANCHED-CHAIN AMINO-ACID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2704', 'DISTURBANCES OF SULPHUR-BEARING AMINO-ACID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2705', 'DISTURBANCES OF HISTIDINE METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2706', 'DISORDERS OF UREA CYCLE METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2707', 'OTHER DISTURBANCES OF STRAIGHT-CHAIN AMINO-ACID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2708', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2709', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('271', 'DISORDERS OF CARBOHYDRATE TRANSPORT AND METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2710', 'GLYCOGENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2711', 'GALACTOSAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2712', 'HEREDITARY FRUCTOSE INTOLERANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('2713', 'INTESTINAL DISACCHARIDASE DEFICIENCIES AND DISACCHARIDE MALABSORPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2714', 'RENAL GLYCOSURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2718', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('272', 'DISORDERS OF LIPOID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2720', 'PURE HYPERCHOLESTEROLAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2721', 'PURE HYPERGLYCERIDAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2722', 'MIXED HYPERLIPIDAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2723', 'HYPERCHYLOMICRONAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2724', 'OTHER AND UNSPECIFIED HYPERLIPIDAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2725', 'LIPOPROTEIN DEFICIENCIES');
INSERT INTO staging.icd9 (code, description) VALUES ('2726', 'LIPODYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('2727', 'LIPIDOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2728', 'OTHER DISORDERS OF LIPOID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2729', 'UNSPECIFIED DISORDERS OF LIPOID METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('273', 'DISORDERS OF PLASMA PROTEIN METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2730', 'POLYCLONAL HYPERGAMMAGLOBULINAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2731', 'MONOCLONAL PARAPROTEINAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2732', 'OTHER PARAPROTEINAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2733', 'MACROGLOBULINAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('274', 'GOUT');
INSERT INTO staging.icd9 (code, description) VALUES ('2740', 'GOUTY ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('2741', 'GOUTY NEPHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('2748', 'GOUT WITH OTHER MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2749', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('275', 'DISORDERS OF MINERAL METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2750', 'DISORDERS OF IRON METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2751', 'DISORDERS OF COPPER METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2752', 'DISORDERS OF MAGNESIUM METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2753', 'DISORDERS OF PHOSPHORUS METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2754', 'DISORDERS OF CALCIUM METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2758', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2759', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('276', 'DISORDERS OF FLUID, ELECTROLYTE AND ACID-BASE BALANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('2760', 'HYPEROSMOLALITY AND/OR HYPERNATRAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2761', 'HYPOSMOLALITY AND/OR HYPONATRAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2762', 'ACIDOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2763', 'ALKALOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2764', 'MIXED ACID-BASE BALANCE DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2765', 'VOLUME DEPLETION');
INSERT INTO staging.icd9 (code, description) VALUES ('2766', 'FLUID OVERLOAD');
INSERT INTO staging.icd9 (code, description) VALUES ('2767', 'HYPERPOTASSAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2768', 'HYPOPOTASSAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2769', 'ELECTROLYTE AND FLUID DISORDERS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('277', 'OTHER AND UNSPECIFIED DISORDERS OF METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2770', 'CYSTIC FIBROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2771', 'DISORDERS OF PORPHYRIN METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2772', 'OTHER DISORDERS OF PURINE AND PYRIMIDINE METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2773', 'AMYLOIDOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2774', 'DISORDERS OF BILIRUBIN EXCRETION');
INSERT INTO staging.icd9 (code, description) VALUES ('2775', 'MUCOPOLYSACCHARIDOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2776', 'OTHER DEFICIENCIES OF CIRCULATING ENZYMES');
INSERT INTO staging.icd9 (code, description) VALUES ('2778', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2779', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('278', 'OBESITY AND OTHER HYPERALIMENTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('2780', 'OBESITY');
INSERT INTO staging.icd9 (code, description) VALUES ('2781', 'LOCALIZED ADIPOSITY');
INSERT INTO staging.icd9 (code, description) VALUES ('2782', 'HYPERVITAMINOSIS ''A''');
INSERT INTO staging.icd9 (code, description) VALUES ('2783', 'HYPERCAROTINAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2784', 'HYPERVITAMINOSIS ''D''');
INSERT INTO staging.icd9 (code, description) VALUES ('2788', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('279', 'DISORDERS INVOLVING THE IMMUNE MECHANISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2790', 'DEFICIENCY OF HUMORAL IMMUNITY');
INSERT INTO staging.icd9 (code, description) VALUES ('2791', 'DEFICIENCY OF CELL-MEDIATED IMMUNITY');
INSERT INTO staging.icd9 (code, description) VALUES ('2792', 'COMBINED IMMUNITY DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2793', 'UNSPECIFIED IMMUNITY DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2794', 'AUTOIMMUNE DISEASE, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2798', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('280', 'IRON DEFICIENCY ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('281', 'OTHER DEFICIENCY ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2810', 'PERNICIOUS ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2811', 'OTHER VITAMIN-''B12''-DEFICIENCY ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2812', 'FOLATE-DEFICIENCY ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2813', 'OTHER SPECIFIED MEGALOBLASTIC ANAEMIAS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2814', 'PROTEIN-DEFICIENCY ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2818', 'ANAEMIA ASSOCIATED WITH OTHER SPECIFIED NUTRITIONAL DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2819', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('282', 'HEREDITARY HAEMOLYTIC ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2820', 'HEREDITARY SPHEROCYTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2821', 'HEREDITARY ELLIPTOCYTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2822', 'ANAEMIA DUE TO DISORDERS OF GLUTATHIONE METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2823', 'OTHER HAEMOLYTIC ANAEMIAS DUE TO ENZYME DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2824', 'THALASSAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2825', 'SICKLE-CELL TRAIT');
INSERT INTO staging.icd9 (code, description) VALUES ('2826', 'SICKLE-CELL ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2827', 'OTHER HAEMOGLOBINOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('2828', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2829', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('283', 'ACQUIRED HAEMOLYTIC ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2830', 'AUTOIMMUNE HAEMOLYTIC ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2831', 'NON-AUTOIMMUNE HAEMOLYTIC ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2832', 'HAEMOGLOBINURIA DUE TO HAEMOLYSIS FROM EXTERNAL CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2839', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('284', 'APLASTIC ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2840', 'CONSTITUTIONAL APLASTIC ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2848', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2849', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('285', 'OTHER AND UNSPECIFIED ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2850', 'SIDEROBLASTIC ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2851', 'ACUTE POSTHAEMORRHAGIC ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2858', 'OTHER SPECIFIED ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2859', 'ANAEMIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('286', 'COAGULATION DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2860', 'CONGENITAL FACTOR VIII DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2861', 'CONGENITAL FACTOR IX DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('2862', 'CONGENITAL FACTOR XI DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2863', 'CONGENITAL DEFICIENCY OF OTHER CLOTTING FACTORS');
INSERT INTO staging.icd9 (code, description) VALUES ('2864', 'VON WILLEBRAND''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('2865', 'HAEMORRHAGIC DISORDER DUE TO CIRCULATING ANTICOAGULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2866', 'DEFIBRINATION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('2867', 'ACQUIRED COAGULATION FACTOR DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('2869', 'OTHER AND UNSPECIFIED COAGULATION DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('287', 'PURPURA AND OTHER HAEMORRHAGIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2870', 'ALLERGIC PURPURA');
INSERT INTO staging.icd9 (code, description) VALUES ('2871', 'QUALITATIVE PLATELET DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('2872', 'OTHER NONTHROMBOCYTOPENIC PURPURAS');
INSERT INTO staging.icd9 (code, description) VALUES ('2873', 'PRIMARY THROMBOCYTOPENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2874', 'SECONDARY THROMBOCYTOPENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2875', 'THROMBOCYTOPENIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2878', 'OTHER SPECIFIED HAEMORRHAGIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2879', 'UNSPECIFIED HAEMORRHAGIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('288', 'DISEASES OF WHITE BLOOD CELLS');
INSERT INTO staging.icd9 (code, description) VALUES ('2880', 'AGRANULOCYTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2881', 'FUNCTIONAL DISORDERS OF NEUTROPHIL POLYMORPHONUCLEARS');
INSERT INTO staging.icd9 (code, description) VALUES ('2882', 'GENETIC ANOMALIES OF LEUCOCYTES');
INSERT INTO staging.icd9 (code, description) VALUES ('2883', 'EOSINOPHILIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2888', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2889', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('289', 'OTHER DISEASES OF BLOOD AND BLOOD-FORMING ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('2890', 'SECONDARY POLYCYTHAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2891', 'CHRONIC LYMPHADENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2892', 'NONSPECIFIC MESENTERIC LYMPHADENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2893', 'LYMPHADENITIS, UNSPECIFIED, EXCEPT MESENTERIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2894', 'HYPERSPLENISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2895', 'OTHER DISEASES OF SPLEEN');
INSERT INTO staging.icd9 (code, description) VALUES ('2896', 'FAMILIAL POLYCYTHAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2897', 'METHAEMOGLOBINAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2898', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2899', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('290', 'SENILE AND PRESENILE ORGANIC PSYCHOTIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2900', 'SENILE DEMENTIA, SIMPLE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2901', 'PRESENILE DEMENTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2902', 'SENILE DEMENTIA, DEPRESSED OR PARANOID TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2903', 'SENILE DEMENTIA WITH ACUTE CONFUSIONAL STATE');
INSERT INTO staging.icd9 (code, description) VALUES ('2904', 'ARTERIOSCLEROTIC DEMENTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2908', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2909', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('291', 'ALCOHOLIC PSYCHOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2910', 'DELIRIUM TREMENS');
INSERT INTO staging.icd9 (code, description) VALUES ('2911', 'KORSAKOV''S PSYCHOSIS, ALCOHOLIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2912', 'OTHER ALCOHOLIC DEMENTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2913', 'OTHER ALCOHOLIC HALLUCINOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2914', 'PATHOLOGICAL DRUNKENNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('2915', 'ALCOHOLIC JEALOUSY');
INSERT INTO staging.icd9 (code, description) VALUES ('2918', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2919', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('292', 'DRUG PSYCHOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2920', 'DRUG WITHDRAWAL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('2921', 'PARANOID AND/OR HALLUCINATORY STATES INDUCED BY DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('2922', 'PATHOLOGICAL DRUG INTOXICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('2928', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2929', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('293', 'TRANSIENT ORGANIC PSYCHOTIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('2930', 'ACUTE CONFUSIONAL STATE');
INSERT INTO staging.icd9 (code, description) VALUES ('2931', 'SUBACUTE CONFUSIONAL STATE');
INSERT INTO staging.icd9 (code, description) VALUES ('2938', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2939', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('294', 'OTHER ORGANIC PSYCHOTIC CONDITIONS (CHRONIC)');
INSERT INTO staging.icd9 (code, description) VALUES ('2940', 'KORSAKOV''S PSYCHOSIS OR SYNDROME (NONALCOHOLIC)');
INSERT INTO staging.icd9 (code, description) VALUES ('2941', 'DEMENTIA IN CONDITIONS CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('2948', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2949', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('295', 'SCHIZOPHRENIC PSYCHOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2950', 'SIMPLE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2951', 'HEBEPHRENIC TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2952', 'CATATONIC TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2953', 'PARANOID TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2954', 'ACUTE SCHIZOPHRENIC EPISODE');
INSERT INTO staging.icd9 (code, description) VALUES ('2955', 'LATENT SCHIZOPHRENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2956', 'RESIDUAL SCHIZOPHRENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2957', 'SCHIZOAFFECTIVE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2958', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2959', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('296', 'AFFECTIVE PSYCHOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2960', 'MANIC-DEPRESSIVE PSYCHOSIS, MANIC TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2961', 'MANIC-DEPRESSIVE PSYCHOSIS, DEPRESSED TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2962', 'MANIC-DEPRESSIVE PSYCHOSIS, CIRCULAR TYPE BUT CURRENTLY MANIC');
INSERT INTO staging.icd9 (code, description) VALUES ('2963', 'MANIC-DEPRESSIVE PSYCHOSIS, CIRCULAR TYPE BUT CURRENTLY DEPRESSED');
INSERT INTO staging.icd9 (code, description) VALUES ('2964', 'MANIC-DEPRESSIVE PSYCHOSIS, CIRCULAR TYPE, MIXED');
INSERT INTO staging.icd9 (code, description) VALUES ('2965', 'MANIC-DEPRESSIVE PSYCHOSIS, CIRCULAR TYPE, CURRENT CONDITION NOT SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2966', 'MANIC-DEPRESSIVE PSYCHOSIS, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('2968', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2969', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('297', 'PARANOID STATES');
INSERT INTO staging.icd9 (code, description) VALUES ('2970', 'PARANOID STATE, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('2971', 'PARANOIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2972', 'PARAPHRENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('2973', 'INDUCED PSYCHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2978', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2979', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('298', 'OTHER NONORGANIC PSYCHOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('2980', 'DEPRESSIVE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2981', 'EXCITATIVE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('2982', 'REACTIVE CONFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('2983', 'ACUTE PARANOID REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('2984', 'PSYCHOGENIC PARANOID PSYCHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2988', 'OTHER AND UNSPECIFIED REACTIVE PSYCHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2989', 'UNSPECIFIED PSYCHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('299', 'PSYCHOSES WITH ORIGIN SPECIFIC TO CHILDHOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('2990', 'INFANTILE AUTISM');
INSERT INTO staging.icd9 (code, description) VALUES ('2991', 'DISINTEGRATIVE PSYCHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('2998', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('2999', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('300', 'NEUROTIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3000', 'ANXIETY STATES');
INSERT INTO staging.icd9 (code, description) VALUES ('3001', 'HYSTERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3002', 'PHOBIC STATE');
INSERT INTO staging.icd9 (code, description) VALUES ('3003', 'OBSESSIVE-COMPULSIVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3004', 'NEUROTIC DEPRESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('3005', 'NEURASTHENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3006', 'DEPERSONALIZATION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3007', 'HYPOCHONDRIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3008', 'OTHER NEUROTIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3009', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('301', 'PERSONALITY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3010', 'PARANOID PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3011', 'AFFECTIVE PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3012', 'SCHIZOID PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3013', 'EXPLOSIVE PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3014', 'ANANKASTIC PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3015', 'HYSTERICAL PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3016', 'ASTHENIC PERSONALITY DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3017', 'PERSONALITY DISORDER WITH PREDOMINANTLY SOCIOPATHIC OR ASOCIAL MANIFESTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3018', 'OTHER PERSONALITY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('302', 'SEXUAL DEVIATIONS AND DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3020', 'HOMOSEXUALITY');
INSERT INTO staging.icd9 (code, description) VALUES ('3021', 'BESTIALITY');
INSERT INTO staging.icd9 (code, description) VALUES ('3022', 'PAEDOPHILIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3023', 'TRANSVESTISM');
INSERT INTO staging.icd9 (code, description) VALUES ('3024', 'EXHIBITIONISM');
INSERT INTO staging.icd9 (code, description) VALUES ('3025', 'TRANS-SEXUALISM');
INSERT INTO staging.icd9 (code, description) VALUES ('3026', 'DISORDERS OF PSYCHOSEXUAL IDENTITY');
INSERT INTO staging.icd9 (code, description) VALUES ('3027', 'FRIGIDITY AND IMPOTENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('3028', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3029', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('303', 'ALCOHOL DEPENDENCE SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('304', 'DRUG DEPENDENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('3040', 'MORPHINE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('3041', 'BARBITURATE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('3042', 'COCAINE');
INSERT INTO staging.icd9 (code, description) VALUES ('3043', 'CANNABIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3044', 'AMPHETAMINE TYPE AND OTHER PSYCHOSTIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3045', 'HALLUCINOGENS');
INSERT INTO staging.icd9 (code, description) VALUES ('3046', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3047', 'COMBINATIONS OF MORPHINE TYPE DRUG WITH ANY OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3048', 'COMBINATIONS EXCLUDING MORPHINE TYPE DRUG');
INSERT INTO staging.icd9 (code, description) VALUES ('3049', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('305', 'NONDEPENDENT ABUSE OF DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('3050', 'ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('3051', 'TOBACCO');
INSERT INTO staging.icd9 (code, description) VALUES ('3052', 'CANNABIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3053', 'HALLUCINOGENS');
INSERT INTO staging.icd9 (code, description) VALUES ('3054', 'BARBITURATES AND TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3055', 'MORPHINE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('3056', 'COCAINE  TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('3057', 'AMPHETAMINE TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('3058', 'ANTIDEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3059', 'OTHER, MIXED OR UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('306', 'PHYSIOLOGICAL MALFUNCTION ARISING FROM MENTAL FACTORS');
INSERT INTO staging.icd9 (code, description) VALUES ('3060', 'MUSCULOSKELETAL');
INSERT INTO staging.icd9 (code, description) VALUES ('3061', 'RESPIRATORY');
INSERT INTO staging.icd9 (code, description) VALUES ('3062', 'CARDIOVASCULAR');
INSERT INTO staging.icd9 (code, description) VALUES ('3063', 'SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3064', 'GASTROINTESTINAL');
INSERT INTO staging.icd9 (code, description) VALUES ('3065', 'GENITOURINARY');
INSERT INTO staging.icd9 (code, description) VALUES ('3066', 'ENDOCRINE');
INSERT INTO staging.icd9 (code, description) VALUES ('3067', 'ORGANS OF SPECIAL SENSE');
INSERT INTO staging.icd9 (code, description) VALUES ('3068', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3069', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('307', 'SPECIAL SYMPTOMS OR SYNDROMES NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3070', 'STAMMERING AND STUTTERING');
INSERT INTO staging.icd9 (code, description) VALUES ('3071', 'ANOREXIA NERVOSA');
INSERT INTO staging.icd9 (code, description) VALUES ('3072', 'TICS');
INSERT INTO staging.icd9 (code, description) VALUES ('3073', 'STEREOTYPED REPETITIVE MOVEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3074', 'SPECIFIC DISORDERS OF SLEEP');
INSERT INTO staging.icd9 (code, description) VALUES ('3075', 'OTHER AND UNSPECIFIED DISORDERS OF EATING');
INSERT INTO staging.icd9 (code, description) VALUES ('3076', 'ENURESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3077', 'ENCOPRESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3078', 'PSYCHALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3079', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('308', 'ACUTE REACTION TO STRESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3080', 'PREDOMINANT DISTURBANCE OF EMOTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3081', 'PREDOMINANT DISTURBANCE OF CONSCIOUSNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3082', 'PREDOMINANT PSYCHOMOTOR DISTURBANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('3083', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3084', 'MIXED');
INSERT INTO staging.icd9 (code, description) VALUES ('3089', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('309', 'ADJUSTMENT REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3090', 'BRIEF DEPRESSIVE REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3091', 'PROLONGED DEPRESSIVE REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3092', 'WITH PREDOMINANT DISTURBANCE OF OTHER EMOTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3093', 'WITH PREDOMINANT DISTURBANCE OF CONDUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('3094', 'WITH MIXED DISTURBANCE OF EMOTIONS AND CONDUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('3098', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3099', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('310', 'SPECIFIC NONPSYCHOTIC MENTAL DISORDERS FOLLOWING ORGANIC BRAIN DAMAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('3100', 'FRONTAL LOBE SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3101', 'COGNITIVE OR PERSONALITY CHANGE OF OTHER TYPE');
INSERT INTO staging.icd9 (code, description) VALUES ('3102', 'POSTCONCUSSIONAL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3108', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3109', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('311', 'DEPRESSIVE DISORDER, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('312', 'DISTURBANCE OF CONDUCT NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3120', 'UNSOCIALIZED DISTURBANCE OF CONDUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('3121', 'SOCIALIZED DISTURBANCE OF CONDUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('3122', 'COMPULSIVE CONDUCT DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3123', 'MIXED DISTURBANCE OF CONDUCT AND EMOTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3128', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3129', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('313', 'DISTURBANCE OF EMOTIONS SPECIFIC TO CHILDHOOD AND ADOLESCENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('3130', 'WITH ANXIETY AND FEARFULNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3131', 'WITH MISERY AND UNHAPPINESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3132', 'WITH SENSITIVITY, SHYNESS AND SOCIAL WITHDRAWAL');
INSERT INTO staging.icd9 (code, description) VALUES ('3133', 'RELATIONSHIP PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('3138', 'OTHER OR MIXED');
INSERT INTO staging.icd9 (code, description) VALUES ('3139', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('314', 'HYPERKINETIC SYNDROME OF CHILDHOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('3140', 'SIMPLE DISTURBANCE OF ACTIVITY AND ATTENTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3141', 'HYPERKINESIS WITH DEVELOPMENTAL DELAY');
INSERT INTO staging.icd9 (code, description) VALUES ('3142', 'HYPERKINETIC CONDUCT DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3148', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3149', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('315', 'SPECIFIC DELAYS IN DEVELOPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3150', 'SPECIFIC READING RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3151', 'SPECIFIC ARITHMETICAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3152', 'OTHER SPECIFIC LEARNING DIFFICULTIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3153', 'DEVELOPMENTAL SPEECH OR LANGUAGE DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3154', 'SPECIFIC MOTOR RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3155', 'MIXED DEVELOPMENT DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('3158', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3159', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('316', 'PSYCHIC FACTORS ASSOCIATED WITH DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('317', 'MILD MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('318', 'OTHER SPECIFIED MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3180', 'MODERATE MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3181', 'SEVERE MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3182', 'PROFOUND MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('319', 'UNSPECIFIED MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('320', 'BACTERIAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3200', 'HAEMOPHILUS MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3201', 'PNEUMOCOCCAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3202', 'STREPTOCOCCAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3203', 'STAPHYLOCOCCAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3204*', 'TUBERCULOUS MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3205*', 'MENINGOCOCCAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3207*', 'MENINGITIS IN OTHER BACTERIAL DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3208', 'MENINGITIS DUE TO OTHER SPECIFIED BACTERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3209', 'MENINGITIS DUE TO UNSPECIFIED BACTERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('321', 'MENINGITIS DUE TO OTHER ORGANISMS');
INSERT INTO staging.icd9 (code, description) VALUES ('3210*', 'FUNGAL MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3211*', 'MENINGITIS DUE TO COXSACKIE VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3212*', 'MENINGITIS DUE TO ECHO VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3213*', 'MENINGITIS DUE TO HERPES ZOSTER VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3214*', 'MENINGITIS DUE TO HERPES SIMPLEX VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3215*', 'MENINGITIS DUE TO MUMPS VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3216*', 'MENINGITIS DUE TO LYMPHOCYTIC CHORIOMENINGITIS VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3217*', 'MENINGITIS DUE TO OTHER AND UNSPECIFIED VIRUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('3218*', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('322', 'MENINGITIS OF UNSPECIFIED CAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('3220', 'NONPYOGENIC MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3221', 'EOSINOPHILIC MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3222', 'CHRONIC MENINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3229', 'MENINGITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('323', 'ENCEPHALITIS, MYELITIS AND ENCEPHALOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3230*', 'KURU');
INSERT INTO staging.icd9 (code, description) VALUES ('3231*', 'SUBACUTE SCLEROSING PANENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3232*', 'POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3233*', 'ARTHROPOD-BORNE VIRAL ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3234*', 'OTHER ENCEPHALITIS DUE TO INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3235', 'ENCEPHALITIS FOLLOWING IMMUNIZATION PROCEDURES');
INSERT INTO staging.icd9 (code, description) VALUES ('3236*', 'POSTINFECTIOUS ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3237*', 'TOXIC ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3238', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3239', 'UNSPECIFIED CAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('324', 'INTRACRANIAL AND INTRASPINAL ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3240', 'INTRACRANIAL ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3241', 'INTRASPINAL ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3249', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('325', 'PHLEBITIS AND THROMBOPHLEBITIS OF INTRACRANIAL VENOUS SINUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('326', 'LATE EFFECTS OF INTRACRANIAL ABSCESS OR PYOGENIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('330', 'CEREBRAL DEGENERATIONS USUALLY MANIFEST IN CHILDHOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('3300', 'LEUCODYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3301', 'CEREBRAL LIPIDOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('3302*', 'CEREBRAL DEGENERATION IN GENERALIZED LIPIDOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('3303*', 'CEREBRAL DEGENERATION OF CHILDHOOD IN OTHER DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3308', 'OTHER CEREBRAL DEGENERATIONS IN CHILDHOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('3309', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('331', 'OTHER CEREBRAL DEGENERATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3310', 'ALZHEIMER''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3311', 'PICK''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3312', 'SENILE DEGENERATION OF BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3313', 'COMMUNICATING HYDROCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3314', 'OBSTRUCTIVE HYDROCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3315*', 'JAKOB-CREUTZFELDT DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3316*', 'PROGRESSIVE MULTIFOCAL LEUCOENCEPHALOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3317*', 'CEREBRAL DEGENERATION IN OTHER DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3318', 'OTHER CEREBRAL DEGENERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3319', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('332', 'PARKINSON''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3320', 'PARALYSIS AGITANS');
INSERT INTO staging.icd9 (code, description) VALUES ('3321', 'SECONDARY PARKINSONISM');
INSERT INTO staging.icd9 (code, description) VALUES ('333', 'OTHER EXTRAPYRAMIDAL DISEASE AND ABNORMAL MOVEMENT DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3330', 'OTHER DEGENERATIVE DISEASES OF THE BASAL GANGLIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3331', 'ESSENTIAL AND OTHER SPECIFIED FORMS OF TREMOR');
INSERT INTO staging.icd9 (code, description) VALUES ('3332', 'MYOCLONUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3333', 'TICS OF ORGANIC ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3334', 'HUNTINGTON''S CHOREA');
INSERT INTO staging.icd9 (code, description) VALUES ('3335', 'OTHER CHOREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('3336', 'IDIOPATHIC TORSION DYSTONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3337', 'SYMPTOMATIC TORSION DYSTONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3338', 'FRAGMENTS OF TORSION DYSTONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3339', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('334', 'SPINOCEREBELLAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3340', 'FRIEDREICH''S ATAXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3341', 'HEREDITARY SPASTIC PARAPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3342', 'PRIMARY CEREBELLAR DEGENERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3343', 'OTHER CEREBELLAR ATAXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3344*', 'CEREBELLAR ATAXIA IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3348', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3349', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('335', 'ANTERIOR HORN CELL DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3350', 'WERDNIG-HOFFMANN DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3351', 'SPINAL MUSCULAR ATROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3352', 'MOTOR  NEURONE DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3358', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3359', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('336', 'OTHER DISEASES OF SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('3360', 'SYRINGOMYELIA AND SYRINGOBULBIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3361', 'VASCULAR MYELOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3362*', 'SUBACUTE COMBINED DEGENERATION OF SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('3363*', 'MYELOPATHY IN OTHER DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3368', 'OTHER MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3369', 'UNSPECIFIED DISEASES OF SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('337', 'DISORDERS OF THE AUTONOMIC NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('3370', 'IDIOPATHIC PERIPHERAL AUTONOMIC NEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3371*', 'PERIPHERAL AUTONOMIC NEUROPATHY IN DISORDERS CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3379', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('340', 'MULTIPLE SCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('341', 'OTHER DEMYELINATING DISEASES OF CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('3410', 'NEUROMYELITIS OPTICA');
INSERT INTO staging.icd9 (code, description) VALUES ('3411', 'SCHILDER''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3418', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3419', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('342', 'HEMIPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3420', 'FLACCID HEMIPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3421', 'SPASTIC HEMIPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3429', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('343', 'INFANTILE CEREBRAL PALSY');
INSERT INTO staging.icd9 (code, description) VALUES ('3430', 'DIPLEGIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3431', 'HEMIPLEGIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3432', 'QUADRIPLEGIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3433', 'MONOPLEGIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3434', 'INFANTILE HEMIPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3438', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3439', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('344', 'OTHER PARALYTIC SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('3440', 'QUADRIPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3441', 'PARAPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3442', 'DIPLEGIA OF UPPER LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('3443', 'MONOPLEGIA OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('3444', 'MONOPLEGIA OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('3445', 'UNSPECIFIED MONOPLEGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3446', 'CAUDA EQUINA SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3448', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3449', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('345', 'EPILEPSY');
INSERT INTO staging.icd9 (code, description) VALUES ('3450', 'GENERALIZED NONCONVULSIVE EPILEPSY');
INSERT INTO staging.icd9 (code, description) VALUES ('3451', 'GENERALIZED CONVULSIVE EPILEPSY');
INSERT INTO staging.icd9 (code, description) VALUES ('3452', 'PETIT MAL STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3453', 'GRAND MAL STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3454', 'PARTIAL EPILEPSY, WITH IMPAIRMENT OF CONSCIOUSNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3455', 'PARTIAL EPILEPSY, WITHOUT MENTION OF IMPAIRMENT OF CONSCIOUSNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3456', 'INFANTILE SPASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('3457', 'EPILEPSIA PARTIALIS CONTINUA');
INSERT INTO staging.icd9 (code, description) VALUES ('3458', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3459', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('346', 'MIGRAINE');
INSERT INTO staging.icd9 (code, description) VALUES ('3460', 'CLASSICAL MIGRAINE');
INSERT INTO staging.icd9 (code, description) VALUES ('3461', 'COMMON MIGRAINE');
INSERT INTO staging.icd9 (code, description) VALUES ('3462', 'VARIANTS OF MIGRAINE');
INSERT INTO staging.icd9 (code, description) VALUES ('3468', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3469', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('347', 'CATAPLEXY AND NARCOLEPSY');
INSERT INTO staging.icd9 (code, description) VALUES ('348', 'OTHER CONDITIONS OF BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3480', 'CEREBRAL CYSTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3481', 'ANOXIC BRAIN DAMAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('3482', 'BENIGN INTRACRANIAL HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('3483', 'ENCEPHALOPATHY, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3484', 'COMPRESSION OF BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3485', 'CEREBRAL OEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3488', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3489', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('349', 'OTHER AND UNSPECIFIED DISORDERS OF THE NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('3490', 'REACTION TO SPINAL OR LUMBAR PUNCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('3491', 'NERVOUS SYSTEM COMPLICATIONS FROM SURGICALLY IMPLANTED DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('3492', 'DISORDERS OF MENINGES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3498', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3499', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('350', 'TRIGEMINAL NERVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3500*', 'POST-HERPETIC TRIGEMINAL NEURALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3501', 'OTHER TRIGEMINAL NEURALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3502', 'ATYPICAL FACE PAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3508', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3509', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('351', 'FACIAL NERVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3510', 'BELL''S PALSY');
INSERT INTO staging.icd9 (code, description) VALUES ('3511', 'GENICULATE GANGLIONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3518', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3519', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('352', 'DISORDERS OF OTHER CRANIAL NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('3520', 'DISORDERS OF OLFACTORY (1ST) NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3521', 'GLOSSOPHARYNGEAL NEURALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3522', 'OTHER DISORDERS OF GLOSSOPHARYNGEAL (9TH) NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3523', 'DISORDERS OF PNEUMOGASTRIC (10TH) NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3524', 'DISORDERS OF ACCESSORY (11TH) NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3525', 'DISORDERS OF HYPOGLOSSAL (12TH) NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3526', 'MULTIPLE CRANIAL NERVE PALSIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3529', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('353', 'NERVE ROOT AND PLEXUS DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3530', 'BRACHIAL PLEXUS LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3531', 'LUMBOSACRAL PLEXUS LESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3532', 'CERVICAL ROOT LESIONS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3533', 'THORACIC ROOT LESIONS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3534', 'LUMBOSACRAL ROOT LESIONS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3535', 'NEURALGIC AMYOTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3536', 'PHANTOM LIMB SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3538', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3539', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('354', 'MONONEURITIS OF UPPER LIMB AND MONONEURITIS MULTIPLEX');
INSERT INTO staging.icd9 (code, description) VALUES ('3540', 'CARPAL TUNNEL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3541', 'OTHER LESION OF MEDIAN NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3542', 'LESION OF ULNAR NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3543', 'LESION OF RADIAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3544', 'CAUSALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3545', 'MONONEURITIS MULTIPLEX');
INSERT INTO staging.icd9 (code, description) VALUES ('3548', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3549', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('355', 'MONONEURITIS OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('3550', 'LESION OF SCIATIC NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3551', 'MERALGIA PARAESTHETICA');
INSERT INTO staging.icd9 (code, description) VALUES ('3552', 'LESION OF FEMORAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3553', 'LESION OF LATERAL POPLITEAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3554', 'LESION OF MEDIAL POPLITEAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3555', 'TARSAL TUNNEL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('3556', 'LESION OF PLANTAR NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3557', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3558', 'UNSPECIFIED MONONEURITIS OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('3559', 'MONONEURITIS OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('356', 'HEREDITARY AND IDIOPATHIC PERIPHERAL NEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3560', 'HEREDITARY PERIPHERAL NEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3561', 'PERONEAL MUSCULAR ATROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3562', 'HEREDITARY SENSORY NEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3563', 'REFSUM''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3564', 'IDIOPATHIC PROGRESSIVE POLYNEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3568', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3569', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('357', 'INFLAMMATORY AND TOXIC NEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3570', 'ACUTE INFECTIVE POLYNEURITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3571*', 'POLYNEUROPATHY IN COLLAGEN VASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3572*', 'POLYNEUROPATHY IN DIABETES');
INSERT INTO staging.icd9 (code, description) VALUES ('3573*', 'POLYNEUROPATHY IN MALIGNANT DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3574*', 'POLYNEUROPATHY IN OTHER DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3575', 'ALCOHOLIC POLYNEUROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3576', 'POLYNEUROPATHY DUE TO DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('3577', 'POLYNEUROPATHY DUE TO OTHER TOXIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3578', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('358', 'MYONEURAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3580', 'MYASTHENIA GRAVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3581*', 'MYASTHENIC SYNDROMES IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('3582', 'TOXIC MYONEURAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3588', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3589', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('359', 'MUSCULAR DYSTROPHIES AND OTHER MYOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3590', 'COGENITAL HEREDITARY MUSCULAR DYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3591', 'HEREDITARY PROGRESSIVE MUSCULAR DYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3592', 'MYOTONIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3593', 'FAMILIAL PERIODIC PARALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3594', 'TOXIC MYOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3595*', 'ENDOCRINE MYOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3596*', 'SYMPTOMATIC INFLAMMATORY MYOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3598', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3599', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('360', 'DISORDERS OF THE GLOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3600', 'PURULENT ENDOPHTHALMITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3601', 'OTHER ENDOPHTHALMITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3602', 'DEGENERATIVE DISORDERS OF GLOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3603', 'HYPOTONY OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('3604', 'DEGENERATED CONDITIONS OF GLOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3605', 'RETAINED (OLD) INTRAOCULAR FOREIGN BODY, MAGNETIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3606', 'RETAINED (OLD) INTRAOCULAR FOREIGN BODY, NONMAGNETIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3608', 'OTHER DISORDERS OF GLOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('361', 'RETINAL DETACHMENTS AND DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3610', 'RETINAL DETACHMENT WITH RETINAL DEFECT');
INSERT INTO staging.icd9 (code, description) VALUES ('3611', 'RETINOSCHISIS AND RETINAL CYSTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3612', 'SEROUS RETINAL DETACHMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3613', 'RETINAL DEFECTS WITHOUT DETACHMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3618', 'OTHER FORMS OF RETINAL DETACHMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3619', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('362', 'OTHER RETINAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3620*', 'DIABETIC RETINOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3621', 'OTHER BACKGROUND RETINOPATHY AND RETINAL VASCULAR CHANGES');
INSERT INTO staging.icd9 (code, description) VALUES ('3622', 'OTHER PROLIFERATIVE RETINOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3623', 'RETINAL VASCULAR OCCLUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('3624', 'SEPARATION OF RETINAL LAYERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3625', 'DEGENERATION OF MACULA AND POSTERIOR POLE');
INSERT INTO staging.icd9 (code, description) VALUES ('3626', 'PERIPHERAL RETINAL DEGENERATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3627', 'HEREDITARY RETINAL DYSTROPHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3628', 'OTHER RETINAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3629', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('363', 'CHORIORETINAL INFLAMMATIONS AND SCARS AND OTHER DISORDERS OF CHOROID');
INSERT INTO staging.icd9 (code, description) VALUES ('3630', 'FOCAL CHORIORETINITIS AND FOCAL RETINOCHOROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3631', 'DISSEMINATED CHORIORETINITIS AND DISSEMINATED RETINOCHOROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3632', 'OTHER AND UNSPECIFIED FORMS OF CHORIORETINITIS AND RETINOCHOROIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3633', 'CHORIORETINAL SCARS');
INSERT INTO staging.icd9 (code, description) VALUES ('3634', 'CHOROIDAL DEGENERATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3635', 'HEREDITARY CHOROIDAL DYSTROPHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3636', 'CHOROIDAL  HAEMORRHAGE AND RUPTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('3637', 'CHOROIDAL  DETACHMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3638', 'OTHER DISORDERS OF CHOROID');
INSERT INTO staging.icd9 (code, description) VALUES ('3639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('364', 'DISORDERS OF IRIS AND CILIARY BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('3640', 'ACUTE AND SUBACUTE IRIDOCYCLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3641', 'CHRONIC IRIDOCYCLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3642', 'CERTAIN TYPES OF IRIDOCYCLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3643', 'UNSPECIFIED IRIDOCYCLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3644', 'VASCULAR DISORDERS OF IRIS AND CILIARY BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('3645', 'DEGENERATIONS OF IRIS AND CILIARY BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('3646', 'CYSTS OF IRIS, CILIARY BODY AND ANTERIOR CHAMBER');
INSERT INTO staging.icd9 (code, description) VALUES ('3647', 'ADHESIONS AND DISRUPTIONS OF IRIS AND CILIARY BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('3648', 'OTHER DISORDERS OF IRIS AND CILIARY BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('3649', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('365', 'GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3650', 'BORDERLINE GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3651', 'OPEN-ANGLE GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3652', 'PRIMARY ANGLE-CLOSURE GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3653', 'CORTICOSTEROID-INDUCED GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3654', 'GLAUCOMA ASSOCIATED WITH CONGENITAL ANOMALIES, WITH DYSTROPHIES AND WITH SYSTEMIC SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('3655', 'GLAUCOMA ASSOCIATED WITH DISORDERS OF THE LENS');
INSERT INTO staging.icd9 (code, description) VALUES ('3656', 'GLAUCOMA ASSOCIATED WITH OTHER OCULAR DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3658', 'OTHER GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3659', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('366', 'CATARACT');
INSERT INTO staging.icd9 (code, description) VALUES ('3660', 'INFANTILE, JUVENILE AND PRESENILE CATARACT');
INSERT INTO staging.icd9 (code, description) VALUES ('3661', 'SENILE CATARACT');
INSERT INTO staging.icd9 (code, description) VALUES ('3662', 'TRAUMATIC CATARACT');
INSERT INTO staging.icd9 (code, description) VALUES ('3663', 'CATARACT SECONDARY TO OCULAR DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3664', 'CATARACT ASSOCIATED WITH OTHER DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3665', 'AFTER-CATARACT');
INSERT INTO staging.icd9 (code, description) VALUES ('3668', 'OTHER CATARACT');
INSERT INTO staging.icd9 (code, description) VALUES ('3669', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('367', 'DISORDERS OF REFRACTION AND ACCOMMODATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3670', 'HYPERMETROPIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3671', 'MYOPIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3672', 'ASTIGMATISM');
INSERT INTO staging.icd9 (code, description) VALUES ('3673', 'ANISOMETROPIA AND ANISEIKONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3674', 'PRESBYOPIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3675', 'DISORDERS OF ACCOMMODATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3678', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3679', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('368', 'VISUAL DISTURBANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('3680', 'AMBLYOPIA EX ANOPSIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3681', 'SUBJECTIVE VISUAL DISTURBANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('3682', 'DIPLOPIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3683', 'OTHER DISORDERS OF BINOCULAR VISION');
INSERT INTO staging.icd9 (code, description) VALUES ('3684', 'VISUAL FIELD DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3685', 'COLOUR VISION DEFICIENCIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3686', 'NIGHT BLINDNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3688', 'OTHER VISUAL DISTURBANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('3689', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('369', 'BLINDNESS AND LOW VISION');
INSERT INTO staging.icd9 (code, description) VALUES ('3690', 'BLINDNESS, BOTH EYES');
INSERT INTO staging.icd9 (code, description) VALUES ('4783', 'PARALYSIS OF VOCAL CORDS OR LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('3691', 'BLINDNESS, ONE EYE, LOW VISION OTHER EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('3692', 'LOW VISION, BOTH EYES');
INSERT INTO staging.icd9 (code, description) VALUES ('3693', 'UNQUALIFIED VISUAL LOSS, BOTH EYES');
INSERT INTO staging.icd9 (code, description) VALUES ('3696', 'BLINDNESS, ONE EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('3697', 'LOW VISION, ONE EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('3698', 'UNQUALIFIED VISUAL LOSS, ONE EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('3699', 'UNSPECIFIED VISUAL LOSS');
INSERT INTO staging.icd9 (code, description) VALUES ('370', 'KERATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3700', 'CORNEAL ULCER');
INSERT INTO staging.icd9 (code, description) VALUES ('3701*', 'DENDRITIC KERATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3702', 'OTHER SUPERFICIAL KERATITIS WITHOUT CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3703', 'CERTAIN TYPES KERATOCONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3704', 'OTHER AND UNSPECIFIED KERATOCONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3705', 'INTERSTITIAL AND DEEP KERATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3706', 'CORNEAL NEOVASCULARIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('3708', 'OTHER FORMS OF KERATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3709', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('371', 'CORNEAL OPACITY AND OTHER DISORDERS OF CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('3710', 'CORNEAL SCARS AND OPACITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3711', 'CORNEAL PIGMENTATIONS AND DEPOSITS');
INSERT INTO staging.icd9 (code, description) VALUES ('3712', 'CORNEAL OEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3713', 'CHANGES OF CORNEAL MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('3714', 'CORNEAL DEGENERATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3715', 'HEREDITARY CORNEAL DYSTROPHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3716', 'KERATOCONUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3717', 'OTHER CORNEAL DEFORMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('3718', 'OTHER CORNEAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('372', 'DISORDERS OF CONJUNCTIVA');
INSERT INTO staging.icd9 (code, description) VALUES ('3720', 'ACUTE CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3721', 'CHRONIC CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3722', 'BLEPHAROCONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3723', 'OTHER AND UNSPECIFIED CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3724', 'PTERYGIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('3725', 'CONJUNCTIVAL DEGENERATIONS AND DEPOSITS');
INSERT INTO staging.icd9 (code, description) VALUES ('3726', 'CONJUNCTIVAL SCARS');
INSERT INTO staging.icd9 (code, description) VALUES ('3727', 'CONJUNCTIVAL VASCULAR DISORDERS AND CYSTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3728', 'OTHER DISORDERS OF CONJUNCTIVA');
INSERT INTO staging.icd9 (code, description) VALUES ('3729', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('373', 'INFLAMMATION OF EYELIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('3730', 'BLEPHARITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3731', 'HORDEOLUM AND OTHER DEEP INFLAMMATION OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3732', 'CHALAZION');
INSERT INTO staging.icd9 (code, description) VALUES ('3733', 'NONINFECTIOUS DERMATOSES OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3734*', 'INFECTIVE DERMATITIS OF EYELID OF TYPES RESULTING IN DEFORMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('3735*', 'OTHER INFECTIVE DERMATITIS OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3736*', 'PARASITIC INFESTATION OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('374', 'OTHER DISORDERS OF EYELIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('3740', 'ENTROPION AND TRICHIASIS OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3741', 'ECTROPION');
INSERT INTO staging.icd9 (code, description) VALUES ('3742', 'LAGOPHTHALMOS');
INSERT INTO staging.icd9 (code, description) VALUES ('3743', 'PTOSIS OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3744', 'OTHER DISORDERS AFFECTING EYELID FUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3745', 'DEGENERATIVE DISORDERS OF EYELIDS AND PERIOCULAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('3748', 'OTHER DISORDERS OF EYELID');
INSERT INTO staging.icd9 (code, description) VALUES ('3749', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('375', 'DISORDERS OF LACRIMAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('3750', 'DACRYOADENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3751', 'OTHER DISORDERS OF LACRIMAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('3752', 'EPIPHORA');
INSERT INTO staging.icd9 (code, description) VALUES ('3753', 'ACUTE AND UNSPECIFIED INFLAMMATION OF LACRIMAL PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('3754', 'CHRONIC INFLAMMATION OF LACRIMAL PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('3755', 'STENOSIS AND INSUFFICIENCY OF LACRIMAL PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('3756', 'OTHER CHANGES OF LACRIMAL PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('3758', 'OTHER DISORDERS OF LACRIMAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('3759', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('376', 'DISORDERS OF THE ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('3760', 'ACUTE INFLAMMATION OF ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('3761', 'CHRONIC INFLAMMATORY DISORDERS OF ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('3762*', 'ENDOCRINE EXOPHTHALMOS');
INSERT INTO staging.icd9 (code, description) VALUES ('3763', 'OTHER EXOPHTHALMIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3764', 'DEFORMITY OF ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('3765', 'ENOPHTHALMOS');
INSERT INTO staging.icd9 (code, description) VALUES ('3766', 'RETAINED (OLD) FOREIGN BODY FOLLOWING PENETRATING WOUND OF ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('3768', 'OTHER DISORDERS OF ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('3769', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('377', 'DISORDERS OF OPTIC NERVE AND VISUAL PATHWAYS');
INSERT INTO staging.icd9 (code, description) VALUES ('3770', 'PAPILLOEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('3771', 'OPTIC ATROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('3772', 'OTHER DISORDERS OF OPTIC DISC');
INSERT INTO staging.icd9 (code, description) VALUES ('3773', 'OPTIC NEURITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3774', 'OTHER DISORDERS OF OPTIC NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3775', 'DISORDERS OF OPTIC CHIASM');
INSERT INTO staging.icd9 (code, description) VALUES ('3776', 'DISORDERS OF OTHER VISUAL PATHWAYS');
INSERT INTO staging.icd9 (code, description) VALUES ('3777', 'DISORDERS OF VISUAL CORTEX');
INSERT INTO staging.icd9 (code, description) VALUES ('3779', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('378', 'STRABISMUS AND OTHER DISORDERS OF BINOCULAR EYE MOVEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3780', 'CONVERGENT CONCOMITANT STRABISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3781', 'DIVERGENT CONCOMITANT STRABISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3782', 'INTERMITTENT HETEROTROPIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3783', 'OTHER AND UNSPECIFIED HETEROTROPIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3784', 'HETEROPHORIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3785', 'PARALYTIC STRABISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3786', 'MECHANICAL STRABISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3787', 'OTHER STRABISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3788', 'OTHER DISORDERS OF BINOCULAR EYE MOVEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3789', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('379', 'OTHER DISORDERS OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('3790', 'SCLERITIS AND EPISCLERITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3791', 'OTHER DISORDERS OF SCLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('3792', 'DISORDERS OF VITREOUS BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('3793', 'APHAKIA AND OTHER DISORDERS OF LENS');
INSERT INTO staging.icd9 (code, description) VALUES ('3794', 'ANOMALIES OF PUPILLARY FUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3795', 'NYSTAGMUS AND OTHER IRREGULAR EYE MOVEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('3798', 'OTHER DISORDERS OF EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('3799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('380', 'DISORDERS OF EXTERNAL EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('3800', 'PERICHONDRITIS OF PINNA');
INSERT INTO staging.icd9 (code, description) VALUES ('3801', 'INFECTIVE OTITIS EXTERNA');
INSERT INTO staging.icd9 (code, description) VALUES ('3802', 'OTHER OTITIS EXTERNA');
INSERT INTO staging.icd9 (code, description) VALUES ('3803', 'NONINFECTIVE DISORDERS OF PINNA');
INSERT INTO staging.icd9 (code, description) VALUES ('3804', 'IMPACTED CERUMEN');
INSERT INTO staging.icd9 (code, description) VALUES ('3805', 'ACQUIRED STENOSIS OF EXTERNAL EAR CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('3808', 'OTHER DISORDERS OF EXTERNAL EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('3809', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('381', 'NONSUPPURATIVE OTITIS MEDIA AND EUSTACHIAN TUBE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('3810', 'ACUTE NONSUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3811', 'CHRONIC SEROUS OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3812', 'CHRONIC MUCOID OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3813', 'OTHER AND UNSPECIFIED CHRONIC NONSUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3814', 'NONSUPPURATIVE OTITIS MEDIA, NOT SPECIFIED AS ACUTE OR CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('3815', 'EUSTACHIAN SALPINGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3816', 'OBSTRUCTION OF EUSTACHIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3817', 'PATULOUS EUSTACHIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3818', 'OTHER DISORDERS OF EUSTACHIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('3819', 'UNSPECIFIED EUSTACHIAN TUBE DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('382', 'SUPPURATIVE AND UNSPECIFIED OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3820', 'ACUTE SUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3821', 'CHRONIC TUBOTYMPANIC SUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3822', 'CHRONIC ATTICOANTRAL SUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3823', 'UNSPECIFIED CHRONIC SUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3824', 'UNSPECIFIED SUPPURATIVE OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3829', 'UNSPECIFIED OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('383', 'MASTOIDITIS AND RELATED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('3830', 'ACUTE MASTOIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3831', 'CHRONIC MASTOIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3832', 'PETROSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3833', 'COMPLICATIONS FOLLOWING MASTOIDECTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('3838', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3839', 'UNSPECIFIED MASTOIDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('384', 'OTHER DISORDERS OF TYMPANIC MEMBRANE');
INSERT INTO staging.icd9 (code, description) VALUES ('3840', 'ACUTE MYRINGITIS WITHOUT MENTION OF OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3841', 'CHRONIC MYRINGITIS WITHOUT MENTION OF OTITIS MEDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3842', 'PERFORATION OF TYMPANIC MEMBRANE');
INSERT INTO staging.icd9 (code, description) VALUES ('3848', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3849', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('385', 'OTHER DISORDERS OF MIDDLE EAR AND MASTOID');
INSERT INTO staging.icd9 (code, description) VALUES ('3850', 'TYMPANOSCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3851', 'ADHESIVE MIDDLE EAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3852', 'OTHER ACQUIRED ABNORMALITY OF EAR OSSICLES');
INSERT INTO staging.icd9 (code, description) VALUES ('3853', 'CHOLESTEATOMA OF MIDDLE EAR AND MASTOID');
INSERT INTO staging.icd9 (code, description) VALUES ('3858', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3859', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('386', 'VERTIGINOUS SYNDROMES AND OTHER DISORDERS OF VESTIBULAR SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('3860', 'MENIERE''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3861', 'OTHER AND UNSPECIFIED PERIPHERAL VERTIGO');
INSERT INTO staging.icd9 (code, description) VALUES ('3862', 'VERTIGO OF CENTRAL ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('3863', 'LABYRINTHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3864', 'LABYRINTHINE FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('3865', 'LABYRINTHINE DYSFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3868', 'OTHER DISORDERS OF LABYRINTH');
INSERT INTO staging.icd9 (code, description) VALUES ('3869', 'UNSPECIFIED VERTIGINOUS SYNDROMES AND LABYRINTHINE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('387', 'OTOSCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3870', 'OTOSCLEROSIS INVOLVING OVAL WINDOW, NONOBLITERATIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3871', 'OTOSCLEROSIS INVOLVING OVAL WINDOW, OBLITERATIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3872', 'COCHLEAR OTOSCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3878', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3879', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('388', 'OTHER DISORDERS OF EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('3880', 'DEGENERATIVE AND VASCULAR DISORDERS OF EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('3881', 'NOISE EFFECTS ON INNER EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('3882', 'SUDDEN HEARING LOSS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('3883', 'TINNITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('3884', 'OTHER ABNORMAL AUDITORY PERCEPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('3885', 'DISORDERS OF ACOUSTIC NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3886', 'OTORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('3887', 'OTALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('3888', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('3889', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('389', 'DEAFNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3890', 'CONDUCTIVE DEAFNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3891', 'SENSORINEURAL DEAFNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3892', 'MIXED CONDUCTIVE AND SENSORINEURAL DEAFNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3897', 'DEAF MUTISM, NOT ELSEWHERE CLASSIFIABLE');
INSERT INTO staging.icd9 (code, description) VALUES ('3898', 'OTHER SPECIFIED FORMS OF DEAFNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('3899', 'UNSPECIFIED DEAFNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('390', 'RHEUMATIC FEVER WITHOUT MENTION OF HEART INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('391', 'RHEUMATIC FEVER WITH HEART INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3910', 'ACUTE RHEUMATIC PERICARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3911', 'ACUTE RHEUMATIC ENDOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3912', 'ACUTE RHEUMATIC MYOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3918', 'OTHER ACUTE RHEUMATIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3919', 'ACUTE RHEUMATIC HEART DISEASE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('392', 'RHEUMATIC CHOREA');
INSERT INTO staging.icd9 (code, description) VALUES ('3920', 'WITH HEART INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('3929', 'WITHOUT MENTION OF HEART INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('393', 'CHRONIC RHEUMATIC PERICARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('394', 'DISEASES OF MITRAL VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3940', 'MITRAL STENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3941', 'RHEUMATIC MITRAL INSUFFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('3942', 'MITRAL STENOSIS WITH INSUFFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('3949', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('395', 'DISEASES OF AORTIC VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3950', 'RHEUMATIC AORTIC STENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3951', 'RHEUMATIC AORTIC INSUFFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('3952', 'RHEUMATIC AORTIC STENOSIS WITH INSUFFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('3959', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('396', 'DISEASES OF MITRAL AND AORTIC VALVES');
INSERT INTO staging.icd9 (code, description) VALUES ('397', 'DISEASES OF OTHER ENDOCARDIAL STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('3970', 'DISEASES OF TRICUSPID VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3971', 'RHEUMATIC DISEASES OF PULMONARY VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('3979', 'RHEUMATIC DISEASES OF ENDOCARDIUM, VALVE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('398', 'OTHER RHEUMATIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('3980', 'RHEUMATIC MYOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('3989', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('401', 'ESSENTIAL HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('4010', 'SPECIFIED AS MALIGNANT');
INSERT INTO staging.icd9 (code, description) VALUES ('4011', 'SPECIFIED AS BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('4019', 'NOT SPECIFIED AS MALIGNANT OR BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('402', 'HYPERTENSIVE HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4020', 'SPECIFIED AS MALIGNANT');
INSERT INTO staging.icd9 (code, description) VALUES ('4021', 'SPECIFIED AS BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('4029', 'NOT SPECIFIED AS MALIGNANT OR BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('403', 'HYPERTENSIVE RENAL DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4030', 'SPECIFIED AS MALIGNANT');
INSERT INTO staging.icd9 (code, description) VALUES ('4031', 'SPECIFIED AS BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('4039', 'NOT SPECIFIED AS MALIGNANT OR BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('404', 'HYPERTENSIVE HEART AND RENAL DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4040', 'SPECIFIED AS MALIGNANT');
INSERT INTO staging.icd9 (code, description) VALUES ('4041', 'SPECIFIED AS BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('4049', 'NOT SPECIFIED AS MALIGNANT OR BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('405', 'SECONDARY HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('4050', 'SPECIFIED AS MALIGNANT');
INSERT INTO staging.icd9 (code, description) VALUES ('4051', 'SPECIFIED AS BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('4059', 'NOT SPECIFIED AS MALIGNANT OR BENIGN');
INSERT INTO staging.icd9 (code, description) VALUES ('410', 'ACUTE MYOCARDIAL INFARCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('411', 'OTHER ACUTE AND SUBACUTE FORMS OF ISCHAEMIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('412', 'OLD MYOCARDIAL INFARCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('413', 'ANGINA PECTORIS');
INSERT INTO staging.icd9 (code, description) VALUES ('414', 'OTHER FORMS OF CHRONIC ISCHAEMIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4140', 'CORONARY ATHEROSCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4141', 'ANEURYSM OF HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('4148', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4149', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('415', 'ACUTE PULMONARY HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4150', 'ACUTE COR PULMONALE');
INSERT INTO staging.icd9 (code, description) VALUES ('4151', 'PULMONARY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('416', 'CHRONIC PULMONARY HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4160', 'PRIMARY PULMONARY HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('4161', 'KYPHOSCOLIOTIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4168', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4169', 'PULMONARY HEART DISEASE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('417', 'OTHER DISEASES OF PULMONARY CIRCULATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4170', 'ARTERIOVENOUS FISTULA OF PULMONARY VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('4171', 'ANEURYSM OF PULMONARY ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4178', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4179', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('420', 'ACUTE PERICARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4200*', 'PERICARDITIS IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('4209', 'OTHER AND UNSPECIFIED ACUTE PERICARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('421', 'ACUTE AND SUBACUTE ENDOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4210', 'ACUTE AND SUBACUTE BACTERIAL ENDOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4211*', 'ACUTE AND SUBACUTE INFECTIVE ENDOCARDITIS IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('4219', 'ACUTE ENDOCARDITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('422', 'ACUTE MYOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4220*', 'ACUTE MYOCARDITIS IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('4229', 'OTHER AND UNSPECIFIED ACUTE MYOCARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('423', 'OTHER DISEASES OF PERICARDIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('4230', 'HAEMOPERICARDIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('4231', 'ADHESIVE PERICARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4232', 'CONSTRICTIVE PERICARDITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4238', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4239', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('424', 'OTHER DISEASES OF ENDOCARDIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('4240', 'MITRAL VALVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('4241', 'AORTIC VALVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('4242', 'TRICUSPID VALVE DISORDERS, SPECIFIED AS NONRHEUMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('4243', 'PULMONARY VALVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('4249', 'ENDOCARDITIS, VALVE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('425', 'CARDIOMYOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('4250', 'ENDOMYOCARDIAL FIBROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4251', 'HYPERTROPHIC OBSTRUCTIVE CARDIOMYOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('4252', 'OBSCURE CARDIOMYOPATHY OF AFRICA');
INSERT INTO staging.icd9 (code, description) VALUES ('4253', 'ENDOCARDIAL FIBROELASTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4254', 'OTHER PRIMARY CARDIOMYOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4255', 'ALCOHOLIC CARDIOMYOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('4256*', 'CARDIOMYOPATHY IN CHAGAS''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4257*', 'NUTRITIONAL AND METABOLIC CARDIOMYOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4258*', 'CARDIOMYOPATHY IN OTHER DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('4259', 'SECONDARY CARDIOMYOPATHY, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('426', 'CONDUCTION DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('4260', 'ATRIOVENTRICULAR BLOCK, COMPLETE');
INSERT INTO staging.icd9 (code, description) VALUES ('4261', 'ATRIOVENTRICULAR BLOCK, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4262', 'LEFT BUNDLE BRANCH HEMIBLOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('4263', 'OTHER LEFT BUNDLE BRANCH BLOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('4264', 'RIGHT BUNDLE BRANCH BLOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('4265', 'BUNDLE BRANCH BLOCK, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4266', 'OTHER HEART BLOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('4267', 'ANOMALOUS ATRIOVENTRICULAR EXCITATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4268', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('427', 'CARDIAC DYSRHYTHMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('4270', 'PAROXYSMAL SUPRAVENTRICULAR TACHYCARDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4271', 'PAROXYSMAL VENTRICULAR TACHYCARDIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4272', 'PAROXYSMAL TACHYCARDIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4273', 'ATRIAL FIBRILLATION AND FLUTTER');
INSERT INTO staging.icd9 (code, description) VALUES ('4274', 'VENTRICULAR FIBRILLATION AND FLUTTER');
INSERT INTO staging.icd9 (code, description) VALUES ('4275', 'CARDIAC ARREST');
INSERT INTO staging.icd9 (code, description) VALUES ('4276', 'PREMATURE BEATS');
INSERT INTO staging.icd9 (code, description) VALUES ('4278', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4279', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('428', 'HEART FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('4280', 'CONGESTIVE HEART FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('4281', 'LEFT HEART FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('4289', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('429', 'ILL-DEFINED DESCRIPTIONS AND COMPLICATIONS OF HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4290', 'MYOCARDITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4291', 'MYOCARDIAL DEGENERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4292', 'CARDIOVASCULAR DISEASE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4293', 'CARDIOMEGALY');
INSERT INTO staging.icd9 (code, description) VALUES ('4294', 'FUNCTIONAL DISTURBANCES FOLLOWING CARDIAC SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4295', 'RUPTURE OF CHORDAE TENDINAE');
INSERT INTO staging.icd9 (code, description) VALUES ('4296', 'RUPTURE OF PAPILLARY MUSCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('4298', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4299', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('430', 'SUBARACHNOID HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('431', 'INTRACEREBRAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('432', 'OTHER AND UNSPECIFIED INTRACRANIAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('4320', 'NONTRAUMATIC EXTRADURAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('4321', 'SUBDURAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('4329', 'UNSPECIFIED INTRACRANIAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('433', 'OCCLUSION AND STENOSIS OF PRECEREBRAL ARTERIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4330', 'BASILAR ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4331', 'CAROTID ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4332', 'VERTEBRAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4333', 'MULTIPLE AND BILATERAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4338', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4339', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('434', 'OCCLUSION OF CEREBRAL ARTERIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4340', 'CEREBRAL THROMBOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4341', 'CEREBRAL EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('4349', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('435', 'TRANSIENT CEREBRAL ISCHAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('436', 'ACUTE BUT ILL-DEFINED CEREBROVASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('437', 'OTHER AND ILL-DEFINED CEREBROVASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4370', 'CEREBRAL ATHEROSCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4371', 'OTHER GENERALIZED ISCHAEMIC CEREBROVASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4372', 'HYPERTENSIVE ENCEPHALOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('4373', 'CEREBRAL ANEURYSM, NONRUPTURED');
INSERT INTO staging.icd9 (code, description) VALUES ('4374', 'CEREBRAL ARTERITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4375', 'MOYAMOYA DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4376', 'NONPYOGENIC THROMBOSIS OF INTRACRANIAL VENOUS SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4378', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4379', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('438', 'LATE EFFECTS OF CEREBROVASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('440', 'ATHEROSCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4400', 'OF AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('4401', 'OF RENAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4402', 'OF ARTERIES OF THE EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4408', 'OF OTHER SPECIFIED ARTERIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4409', 'GENERALIZED AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('441', 'AORTIC ANEURYSM');
INSERT INTO staging.icd9 (code, description) VALUES ('4410', 'DISSECTING ANEURYSM (ANY PART)');
INSERT INTO staging.icd9 (code, description) VALUES ('4411', 'THORACIC ANEURYSM, RUPTURED');
INSERT INTO staging.icd9 (code, description) VALUES ('4412', 'THORACIC ANEURYSM WITHOUT MENTION OF RUPTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('4413', 'ABDOMINAL ANEURYSM, RUPTURED');
INSERT INTO staging.icd9 (code, description) VALUES ('4414', 'ABDOMINAL ANEURYSM WITHOUT MENTION OF RUPTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('4415', 'AORTIC ANEURYSM OF UNSPECIFIED SITE, RUPTURED');
INSERT INTO staging.icd9 (code, description) VALUES ('4416', 'AORTIC ANEURYSM OF UNSPECIFIED SITE WITHOUT MENTION OF RUPTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('4417*', 'SYPHILITIC ANEURYSM OF AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('442', 'OTHER ANEURYSM');
INSERT INTO staging.icd9 (code, description) VALUES ('4420', 'OF ARTERY OF UPPER EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('4421', 'OF RENAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4422', 'OF ILIAC ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4423', 'OF ARTERY OF LOWER EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('4428', 'OF OTHER SPECIFIED ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4429', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('443', 'OTHER PERIPHERAL VASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4430', 'RAYNAUD''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('4431', 'THROMBOANGIITIS OBLITERANS (BUERGER''S DISEASE)');
INSERT INTO staging.icd9 (code, description) VALUES ('4438', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4439', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('444', 'ARTERIAL EMBOLISM AND THROMBOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4440', 'OF ABDOMINAL AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('4441', 'OF OTHER AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('4442', 'OF ARTERIES OF THE EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4448', 'OF OTHER SPECIFIED ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4449', 'OF UNSPECIFIED ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('446', 'POLYARTERITIS NODOSA AND ALLIED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('4460', 'POLYARTERITIS NODOSA');
INSERT INTO staging.icd9 (code, description) VALUES ('4461', 'ACUTE FEBRILE MUCOCUTANEOUS LYMPHNODE SYNDROME (MCLS)');
INSERT INTO staging.icd9 (code, description) VALUES ('4462', 'HYPERSENSITIVITY ANGIITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4463', 'LETHAL MIDLINE GRANULOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('4464', 'WEGENER''S GRANULOMATOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4465', 'GIANT CELL ARTERITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4466', 'THROMBOTIC MICROANGIOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('4467', 'TAKAYASU DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('447', 'OTHER DISORDERS OF ARTERIES AND ARTERIOLES');
INSERT INTO staging.icd9 (code, description) VALUES ('4470', 'ARTERIOVENOUS FISTULA, ACQUIRED');
INSERT INTO staging.icd9 (code, description) VALUES ('4471', 'STRICTURE OF ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4472', 'RUPTURE OF ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4473', 'HYPERPLASIA OF RENAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4474', 'COELIAC ARTERY COMPRESSION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('4475', 'NECROSIS OF ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('4476', 'ARTERITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4477*', 'SYPHILITIC AORTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4478', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4479', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('448', 'DISEASES OF CAPILLARIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4480', 'HEREDITARY HAEMORRHAGIC TELANGIECTASIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4481', 'NAEVUS, NON-NEOPLASTIC');
INSERT INTO staging.icd9 (code, description) VALUES ('4489', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('451', 'PHLEBITIS AND THROMBOPHLEBITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4510', 'OF SUPERFICIAL VESSELS OF LOWER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4511', 'OF DEEP VESSELS OF LOWER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4512', 'OF LOWER EXTREMITIES, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4518', 'OF OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('4519', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('452', 'PORTAL VEIN THROMBOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('453', 'OTHER VENOUS EMBOLISM AND THROMBOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4530', 'BUDD-CHIARI SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('4531', 'THROMBOPHLEBITIS MIGRANS');
INSERT INTO staging.icd9 (code, description) VALUES ('4532', 'OF VENA CAVA');
INSERT INTO staging.icd9 (code, description) VALUES ('4533', 'OF RENAL VEIN');
INSERT INTO staging.icd9 (code, description) VALUES ('4538', 'OF OTHER SPECIFIED VEINS');
INSERT INTO staging.icd9 (code, description) VALUES ('4539', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('454', 'VARICOSE VEINS OF LOWER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('4540', 'WITH ULCER');
INSERT INTO staging.icd9 (code, description) VALUES ('4541', 'WITH INFLAMMATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4542', 'WITH ULCER AND INFLAMMATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4549', 'WITHOUT MENTION OF ULCER OR INFLAMMATION');
INSERT INTO staging.icd9 (code, description) VALUES ('455', 'HAEMORRHOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4550', 'INTERNAL HAEMORRHOIDS, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4551', 'INTERNAL THROMBOSED HAEMORRHOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4552', 'INTERNAL HAEMORRHOIDS WITH OTHER COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4553', 'EXTERNAL HAEMORRHOIDS WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4554', 'EXTERNAL THROMBOSED HAEMORRHOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4555', 'EXTERNAL HAEMORRHOIDS WITH OTHER COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4556', 'UNSPECIFIED HAEMORRHOIDS, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4557', 'UNSPECIFIED THROMBOSED HAEMORRHOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4558', 'UNSPECIFIED HAEMORRHOIDS WITH OTHER COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4559', 'RESIDUAL HAEMORRHOIDAL SKIN TAGS');
INSERT INTO staging.icd9 (code, description) VALUES ('456', 'VARICOSE VEINS OF OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('4560', 'OESOPHAGEAL VARICES WITH BLEEDING');
INSERT INTO staging.icd9 (code, description) VALUES ('4561', 'OESOPHAGEAL VARICES WITHOUT MENTION OF BLEEDING');
INSERT INTO staging.icd9 (code, description) VALUES ('4562*', 'OESOPHAGEAL VARICES IN CIRRHOSIS OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('4563', 'SUBLINGUAL VARICES');
INSERT INTO staging.icd9 (code, description) VALUES ('4564', 'SCROTAL VARICES');
INSERT INTO staging.icd9 (code, description) VALUES ('4565', 'PELVIC VARICES');
INSERT INTO staging.icd9 (code, description) VALUES ('4566', 'VULVAL VARICES');
INSERT INTO staging.icd9 (code, description) VALUES ('4568', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('457', 'NONINFECTIVE DISORDERS OF LYMPHATIC CHANNELS');
INSERT INTO staging.icd9 (code, description) VALUES ('4570', 'POSTMASTECTOMY LYMPHOEDEMA SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('4571', 'OTHER LYMPHOEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('4572', 'LYMPHANGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4578', 'OTHER NONINFECTIVE DISORDERS OF LYMPHATIC CHANNELS');
INSERT INTO staging.icd9 (code, description) VALUES ('4579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('458', 'HYPOTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('4580', 'ORTHOSTATIC HYPOTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('4581', 'CHRONIC HYPOTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('4589', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('459', 'OTHER DISORDERS OF CIRCULATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('4590', 'HAEMORRHAGE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4591', 'POST-PHLEBITIC SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('4592', 'COMPRESSION OF VEIN');
INSERT INTO staging.icd9 (code, description) VALUES ('4598', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4599', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('460', 'ACUTE NASOPHARYNGITIS (COMMON COLD)');
INSERT INTO staging.icd9 (code, description) VALUES ('461', 'ACUTE SINUSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4610', 'MAXILLARY');
INSERT INTO staging.icd9 (code, description) VALUES ('4611', 'FRONTAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4612', 'ETHMOIDAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4613', 'SPHENOIDAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4618', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4619', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('462', 'ACUTE PHARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('463', 'ACUTE TONSILLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('464', 'ACUTE LARYNGITIS AND TRACHEITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4640', 'ACUTE LARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4641', 'ACUTE TRACHEITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4642', 'ACUTE LARYNGOTRACHEITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4643', 'ACUTE EPIGLOTTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4644', 'CROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('465', 'ACUTE UPPER RESPIRATORY INFECTIONS OF MULTIPLE OR UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('4650', 'ACUTE LARYNGOPHARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4658', 'OTHER MULTIPLE SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('4659', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('466', 'ACUTE BRONCHITIS AND BRONCHIOLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4660', 'ACUTE BRONCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4661', 'ACUTE BRONCHIOLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('470', 'DEFLECTED NASAL SEPTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('471', 'NASAL POLYPS');
INSERT INTO staging.icd9 (code, description) VALUES ('4710', 'POLYP OF NASAL CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('4711', 'POLYPOID SINUS DEGENERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('4718', 'OTHER POLYP OF SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('472', 'CHRONIC PHARYNGITIS AND NASOPHARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4720', 'CHRONIC RHINITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4721', 'CHRONIC PHARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4722', 'CHRONIC NASOPHARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('473', 'CHRONIC SINUSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4730', 'MAXILLARY');
INSERT INTO staging.icd9 (code, description) VALUES ('4731', 'FRONTAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4732', 'ETHMOIDAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4733', 'SPHENOIDAL');
INSERT INTO staging.icd9 (code, description) VALUES ('4738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('4739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('474', 'CHRONIC DISEASE OF TONSILS AND ADENOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4740', 'CHRONIC TONSILLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4741', 'HYPERTROPHY OF TONSILS AND ADENOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4742', 'ADENOID VEGETATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('4748', 'OTHER CHRONIC DISEASE OF TONSILS AND ADENOIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4749', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('475', 'PERITONSILLAR ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('476', 'CHRONIC LARYNGITIS AND LARYNGOTRACHEITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4760', 'CHRONIC LARYNGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4761', 'CHRONIC LARYNGOTRACHEITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('477', 'ALLERGIC RHINITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4770', 'DUE TO POLLEN');
INSERT INTO staging.icd9 (code, description) VALUES ('4778', 'DUE TO OTHER ALLERGEN');
INSERT INTO staging.icd9 (code, description) VALUES ('4779', 'CAUSE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('478', 'OTHER DISEASES OF UPPER RESPIRATORY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('4780', 'HYPERTROPHY OF NASAL TURBINATES');
INSERT INTO staging.icd9 (code, description) VALUES ('4781', 'OTHER DISEASES OF NASAL CAVITY AND SINUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('4782', 'OTHER DISEASES OF PHARYNX, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4784', 'POLYP OF VOCAL CORD OR LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('4785', 'OTHER DISEASES OF VOCAL CORDS');
INSERT INTO staging.icd9 (code, description) VALUES ('4786', 'OEDEMA OF LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('4787', 'OTHER DISEASES OF LARYNX, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4788', 'UPPER RESPIRATORY TRACT HYPERSENSITIVITY REACTION, SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4789', 'OTHER AND UNSPECIFIED DISEASES OF UPPER RESPIRATORY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('480', 'VIRAL PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4800', 'PNEUMONIA DUE TO ADENOVIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4801', 'PNEUMONIA DUE TO RESPIRATORY SYNCYTIAL VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4802', 'PNEUMONIA DUE TO PARAINFLUENZA VIRUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4808', 'PNEUMONIA DUE TO OTHER VIRUS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('4809', 'VIRAL PNEUMONIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('481', 'PNEUMOCOCCAL PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('482', 'OTHER BACTERIAL PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4820', 'PNEUMONIA DUE TO KLEBSIELLA PNEUMONIAE');
INSERT INTO staging.icd9 (code, description) VALUES ('4821', 'PNEUMONIA DUE TO PSEUDOMONAS');
INSERT INTO staging.icd9 (code, description) VALUES ('4822', 'PNEUMONIA DUE TO HAEMOPHILUS INFLUENZAE (H.INFLUENZAE)');
INSERT INTO staging.icd9 (code, description) VALUES ('4823', 'PNEUMONIA DUE TO STREPTOCOCCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4824', 'PNEUMONIA DUE TO STAPHYLOCOCCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('4828', 'PNEUMONIA DUE TO OTHER SPECIFIED BACTERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4829', 'BACTERIAL PNEUMONIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('483', 'PNEUMONIA DUE TO OTHER SPECIFIED ORGANISM');
INSERT INTO staging.icd9 (code, description) VALUES ('484', 'PNEUMONIA IN INFECTIOUS DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('4840*', 'MEASLES');
INSERT INTO staging.icd9 (code, description) VALUES ('4841*', 'CYTOMEGALIC INCLUSION DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('4842*', 'ORNITHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4843*', 'WHOOPING COUGH');
INSERT INTO staging.icd9 (code, description) VALUES ('4844*', 'TULARAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4845*', 'ANTHRAX');
INSERT INTO staging.icd9 (code, description) VALUES ('4846*', 'ASPERGILLOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4847*', 'PNEUMONIA IN OTHER SYSTEMIC MYCOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('4848*', 'PNEUMONIA IN OTHER INFECTIOUS DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('485', 'BRONCHOPNEUMONIA, ORGANISM UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('486', 'PNEUMONIA, ORGANISM UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('487', 'INFLUENZA');
INSERT INTO staging.icd9 (code, description) VALUES ('4870', 'WITH PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('4871', 'WITH OTHER RESPIRATORY MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('4878', 'WITH OTHER MANIFESTATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('490', 'BRONCHITIS, NOT SPECIFIED AS ACUTE OR CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('491', 'CHRONIC BRONCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4910', 'SIMPLE CHRONIC BRONCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4911', 'MUCOPURULENT CHRONIC BRONCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4912', 'OBSTRUCTIVE CHRONIC BRONCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4918', 'OTHER CHRONIC BRONCHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4919', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('492', 'EMPHYSEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('493', 'ASTHMA');
INSERT INTO staging.icd9 (code, description) VALUES ('4930', 'EXTRINSIC ASTHMA');
INSERT INTO staging.icd9 (code, description) VALUES ('4931', 'INTRINSIC ASTHMA');
INSERT INTO staging.icd9 (code, description) VALUES ('4939', 'ASTHMA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('494', 'BRONCHIECTASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('495', 'EXTRINSIC ALLERGIC ALVEOLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4950', 'FARMERS'' LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('4951', 'BAGASSOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4952', 'BIRD FANCIERS'' LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('4953', 'SUBEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4954', 'MALTWORKERS'' LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('4955', 'MUSHROOM-WORKERS'' LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('4956', 'MAPLE-BARK-STRIPPERS'' LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('4957', '"VENTILATION" PNEUMONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4958', 'OTHER ALLERGIC PNEUMONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('4959', 'UNSPECIFIED ALLERGIC ALVEOLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('496', 'CHRONIC AIRWAYS OBSTRUCTION, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('500', 'COALWORKERS'' PNEUMOCONIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('501', 'ASBESTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('502', 'PNEUMOCONIOSIS DUE TO OTHER SILICA OR SILICATES');
INSERT INTO staging.icd9 (code, description) VALUES ('503', 'PNEUMOCONIOSIS DUE TO OTHER INORGANIC DUST');
INSERT INTO staging.icd9 (code, description) VALUES ('504', 'PNEUMOPATHY DUE TO INHALATION OF OTHER DUST');
INSERT INTO staging.icd9 (code, description) VALUES ('505', 'PNEUMOCONIOSIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('506', 'RESPIRATORY CONDITIONS DUE TO CHEMICAL FUMES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('5060', 'BRONCHITIS AND PNEUMONITIS DUE TO FUMES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('5061', 'ACUTE PULMONARY OEDEMA DUE TO FUMES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('5062', 'UPPER RESPIRATORY INFLAMMATION DUE TO FUMES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('5063', 'OTHER ACUTE AND SUBACUTE RESPIRATORY CONDITIONS DUE TO FUMES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('5064', 'CHRONIC RESPIRATORY CONDITIONS DUE TO FUMES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('5069', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('507', 'PNEUMONITIS DUE TO SOLIDS AND LIQUIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('5070', 'DUE TO INHALATION OF FOOD OR VOMIT');
INSERT INTO staging.icd9 (code, description) VALUES ('5071', 'DUE TO INHALATION OF OILS AND ESSENCES');
INSERT INTO staging.icd9 (code, description) VALUES ('5078', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('508', 'RESPIRATORY CONDITIONS DUE TO OTHER AND UNSPECIFIED EXTERNAL AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('5080', 'ACUTE PULMONARY MANIFESTATIONS DUE TO RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5081', 'CHRONIC AND OTHER PULMONARY MANIFESTATIONS DUE TO RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5088', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5089', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('510', 'EMPYEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('5100', 'WITH FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('5109', 'WITHOUT MENTION OF FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('511', 'PLEURISY');
INSERT INTO staging.icd9 (code, description) VALUES ('5110', 'WITHOUT MENTION OF EFFUSION OR CURRENT TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5111', 'WITH EFFUSION, WITH MENTION OF A BACTERIAL CAUSE OTHER THAN TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5118', 'OTHER SPECIFIED FORMS OF EFFUSION, EXCEPT TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5119', 'UNSPECIFIED PLEURAL EFFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('512', 'PNEUMOTHORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('513', 'ABSCESS OF LUNG AND MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5130', 'ABSCESS OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('5131', 'ABSCESS OF MEDIASTINUM');
INSERT INTO staging.icd9 (code, description) VALUES ('514', 'PULMONARY CONGESTION AND HYPOSTASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('515', 'POSTINFLAMMATORY PULMONARY FIBROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('516', 'OTHER ALVEOLAR AND PARIETOALVEOLAR PNEUMOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('5160', 'PULMONARY ALVEOLAR PROTEINOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5161*', 'IDIOPATHIC PULMONARY HAEMOSIDEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5162', 'PULMONARY ALVEOLAR MICROLITHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5163', 'IDIOPATHIC FIBROSING ALVEOLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5168', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5169', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('517', 'LUNG INVOLVEMENT IN CONDITIONS CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('5170*', 'RHEUMATOID LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('5171*', 'RHEUMATIC PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5172*', 'LUNG INVOLVEMENT IN SYSTEMIC SCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5178*', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('518', 'OTHER DISEASES OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('5180', 'PULMONARY COLLAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('5181', 'INTERSTITIAL EMPHYSEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('5182', 'COMPENSATORY EMPHYSEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('5183', 'PULMONARY EOSINOPHILIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5184', 'ACUTE OEDEMA OF LUNG, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5185', 'PULMONARY INSUFFICIENCY FOLLOWING TRAUMA AND SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('5188', 'OTHER DISEASES OF LUNG, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('519', 'OTHER DISEASES OF RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('5190', 'TRACHEOSTOMY MALFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5191', 'OTHER DISEASES OF TRACHEA AND BRONCHUS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5192', 'MEDIASTINITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5193', 'OTHER DISEASES OF MEDIASTINUM, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5194', 'DISORDERS OF DIAPHRAGM');
INSERT INTO staging.icd9 (code, description) VALUES ('5198', 'OTHER DISEASES OF RESPIRATORY SYSTEM, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5199', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('520', 'DISORDERS OF TOOTH DEVELOPMENT AND ERUPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5200', 'ANODONTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5201', 'SUPERNUMERARY TEETH');
INSERT INTO staging.icd9 (code, description) VALUES ('5202', 'ABNORMALITIES OF SIZE AND FORM');
INSERT INTO staging.icd9 (code, description) VALUES ('5203', 'MOTTLED TEETH');
INSERT INTO staging.icd9 (code, description) VALUES ('5204', 'DISTURBANCES OF TOOTH FORMATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5205', 'HEREDITARY DISTURBANCES IN TOOTH STRUCTURE, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5206', 'DISTURBANCES IN TOOTH ERUPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5207', 'TEETHING SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5208', 'OTHER DISORDERS OF TOOTH DEVELOPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('5209', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('521', 'DISEASES OF HARD TISSUES OF TEETH');
INSERT INTO staging.icd9 (code, description) VALUES ('5210', 'DENTAL  CARIES');
INSERT INTO staging.icd9 (code, description) VALUES ('5211', 'EXCESSIVE ATTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('5212', 'ABRASION');
INSERT INTO staging.icd9 (code, description) VALUES ('5213', 'EROSION');
INSERT INTO staging.icd9 (code, description) VALUES ('5214', 'PATHOLOGICAL RESORPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5215', 'HYPERCEMENTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5216', 'ANKYLOSIS OF TEETH');
INSERT INTO staging.icd9 (code, description) VALUES ('5217', 'POSTERUPTIVE COLOUR CHANGES');
INSERT INTO staging.icd9 (code, description) VALUES ('5218', 'OTHER DISEASES OF HARD TISSUES OF TEETH');
INSERT INTO staging.icd9 (code, description) VALUES ('5219', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('522', 'DISEASES OF PULP AND PERIAPICAL TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('5220', 'PULPITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5221', 'NECROSIS OF THE PULP');
INSERT INTO staging.icd9 (code, description) VALUES ('5222', 'PULP DEGENERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5223', 'ABNORMAL HARD TISSUE FORMATION IN PULP');
INSERT INTO staging.icd9 (code, description) VALUES ('5224', 'ACUTE APICAL PERIODONTITIS OF PULPAL ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('5225', 'PERIAPICAL ABSCESS WITHOUT SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5226', 'CHRONIC APICAL PERIODONTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5227', 'PERIAPICAL ABSCESS WITH SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5228', 'RADICULAR CYST');
INSERT INTO staging.icd9 (code, description) VALUES ('5229', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('523', 'GINGIVAL AND PERIODONTAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('5230', 'ACUTE GINGIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5231', 'CHRONIC GINGIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5232', 'GINGIVAL RECESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('5233', 'ACUTE PERIODONTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5234', 'CHRONIC PERIODONTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5235', 'PERIODONTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5236', 'ACCRETIONS ON TEETH');
INSERT INTO staging.icd9 (code, description) VALUES ('5238', 'OTHER PERIODONTAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('5239', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('524', 'DENTOFACIAL ANOMALIES, INCLUDING MALOCCLUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('5240', 'MAJOR ANOMALIES OF JAW SIZE');
INSERT INTO staging.icd9 (code, description) VALUES ('5241', 'ANOMALIES OF RELATIONSHIP OF JAW TO CRANIAL BASE');
INSERT INTO staging.icd9 (code, description) VALUES ('5242', 'ANOMALIES OF DENTAL ARCH RELATIONSHIP');
INSERT INTO staging.icd9 (code, description) VALUES ('5243', 'ANOMALIES OF TOOTH POSITION');
INSERT INTO staging.icd9 (code, description) VALUES ('5244', 'MALOCCLUSION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5245', 'DENTOFACIAL FUNCTIONAL ABNORMALITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('5246', 'TEMPOROMANDIBULAR JOINT DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('5248', 'OTHER DENTOFACIAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('5249', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('525', 'OTHER DISEASES AND CONDITIONS OF THE TEETH AND SUPPORTING STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('5250', 'EXFOLIATION OF TEETH DUE TO SYSTEMIC CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('5251', 'LOSS OF TEETH DUE TO ACCIDENT, EXTRACTION OR LOCAL PERIODONTAL DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('5252', 'ATROPHY OF EDENTULOUS ALVEOLAR RIDGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5253', 'RETAINED DENTAL ROOT');
INSERT INTO staging.icd9 (code, description) VALUES ('5258', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5259', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('526', 'DISEASES OF THE JAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('5260', 'DEVELOPMENTAL ODONTOGENIC CYSTS');
INSERT INTO staging.icd9 (code, description) VALUES ('5261', 'FISSURAL CYSTS OF JAW');
INSERT INTO staging.icd9 (code, description) VALUES ('5262', 'OTHER CYSTS OF JAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('5263', 'CENTRAL GIANT CELL (REPARATIVE) GRANULOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('5264', 'INFLAMMATORY CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('5265', 'ALVEOLITIS OF JAW');
INSERT INTO staging.icd9 (code, description) VALUES ('5268', 'OTHER DISEASES OF THE JAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('5269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('527', 'DISEASES OF THE SALIVARY GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('5270', 'ATROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('5271', 'HYPERTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('5272', 'SIALOADENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5273', 'ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('5274', 'FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('5275', 'SIALOLITHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5276', 'MUCOCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('5277', 'DISTURBANCE OF SALIVARY SECRETION');
INSERT INTO staging.icd9 (code, description) VALUES ('5278', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5279', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('528', 'DISEASES OF THE ORAL SOFT TISSUES, EXCLUDING LESIONS SPECIFIC FOR GINGIVA AND TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5280', 'STOMATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5281', 'CANCRUM ORIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5282', 'ORAL APHTHAE');
INSERT INTO staging.icd9 (code, description) VALUES ('5283', 'CELLULITIS AND ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('5284', 'CYSTS');
INSERT INTO staging.icd9 (code, description) VALUES ('5285', 'DISEASES OF LIPS');
INSERT INTO staging.icd9 (code, description) VALUES ('5286', 'LEUKOPLAKIA OF ORAL MUCOSA, INCLUDING TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5287', 'OTHER DISTURBANCES OF ORAL EPITHELIUM, INCLUDING TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5288', 'ORAL SUBMUCOUS FIBROSIS, INCLUDING OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5289', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('529', 'DISEASES AND OTHER CONDITIONS OF THE TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5290', 'GLOSSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5291', 'GEOGRAPHIC TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5292', 'MEDIAN RHOMBOID GLOSSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5293', 'HYPERTROPHY OF TONGUE PAPILLAE');
INSERT INTO staging.icd9 (code, description) VALUES ('5294', 'ATROPHY OF TONGUE PAPILLAE');
INSERT INTO staging.icd9 (code, description) VALUES ('5295', 'PLICATED TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5296', 'GLOSSODYNIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5298', 'OTHER CONDITIONS OF THE TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5299', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('530', 'DISEASES OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5300', 'ACHALASIA AND CARDIOSPASM');
INSERT INTO staging.icd9 (code, description) VALUES ('5301', 'OESOPHAGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5302', 'ULCER OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5303', 'STRICTURE AND STENOSIS OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5304', 'PERFORATION OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5305', 'DYSKINESIA OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5306', 'DIVERTICULUM OF OESOPHAGUS, ACQUIRED');
INSERT INTO staging.icd9 (code, description) VALUES ('5307', 'GASTRO-OESOPHAGEAL LACERATION-HAEMORRHAGE SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5308', 'OTHER DISORDERS OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5309', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('531', 'GASTRIC ULCER');
INSERT INTO staging.icd9 (code, description) VALUES ('5310', 'ACUTE WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5311', 'ACUTE WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5312', 'ACUTE WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5313', 'ACUTE WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5314', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5315', 'CHRONIC OR UNSPECIFIED WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5316', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5317', 'CHRONIC WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5319', 'UNSPECIFIED AS ACUTE OR CHRONIC, WITHOUT MENTION OF HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('532', 'DUODENAL ULCER');
INSERT INTO staging.icd9 (code, description) VALUES ('5320', 'ACUTE WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5321', 'ACUTE WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5322', 'ACUTE WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5323', 'ACUTE WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5324', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5325', 'CHRONIC OR UNSPECIFIED WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5326', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5327', 'CHRONIC WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5329', 'UNSPECIFIED AS ACUTE OR CHRONIC, WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('533', 'PEPTIC ULCER, SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5330', 'ACUTE WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5331', 'ACUTE WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5332', 'ACUTE WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5333', 'ACUTE WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5334', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5335', 'CHRONIC OR UNSPECIFIED WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5336', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5337', 'CHRONIC WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5339', 'UNSPECIFIED AS ACUTE OR CHRONIC, WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('534', 'GASTROJEJUNAL ULCER');
INSERT INTO staging.icd9 (code, description) VALUES ('5340', 'ACUTE WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5341', 'ACUTE WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5342', 'ACUTE WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5343', 'ACUTE WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5344', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5345', 'CHRONIC OR UNSPECIFIED WITH PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5346', 'CHRONIC OR UNSPECIFIED WITH HAEMORRHAGE AND PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5347', 'CHRONIC WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5349', 'UNSPECIFIED AS ACUTE OR CHRONIC, WITHOUT MENTION OF HAEMORRHAGE OR PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('535', 'GASTRITIS AND DUODENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5350', 'ACUTE GASTRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5351', 'ATROPHIC GASTRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5352', 'GASTRIC MUCOSAL HYPERTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('5353', 'ALCOHOLIC GASTRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5354', 'OTHER GASTRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5355', 'UNSPECIFIED GASTRITIS AND GASTRODUODENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5356', 'DUODENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('536', 'DISORDERS OF FUNCTION OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('5360', 'ACHLORHYDRIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5361', 'ACUTE DILATATION OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('5362', 'HABIT VOMITING');
INSERT INTO staging.icd9 (code, description) VALUES ('5368', 'DYSPEPSIA AND OTHER DISORDERS OF FUNCTION OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('5369', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('537', 'OTHER DISORDERS OF STOMACH AND DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5370', 'ADULT HYPERTROPHIC PYLORIC STENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5371', 'GASTRIC DIVERTICULUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5372', 'CHRONIC DUODENAL ILEUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5373', 'OTHER OBSTRUCTION OF DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5374', 'FISTULA OF STOMACH OR DUODENUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5375', 'GASTROPTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5376', 'HOURGLASS STRICTURE OR STENOSIS OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('5378', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5379', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('540', 'ACUTE APPENDICITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5400', 'WITH GENERALIZED PERITONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5401', 'WITH PERITONEAL ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('5409', 'WITHOUT MENTION OF PERITONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('541', 'APPENDICITIS, UNQUALIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('542', 'OTHER APPENDICITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('543', 'OTHER DISEASES OF APPENDIX');
INSERT INTO staging.icd9 (code, description) VALUES ('550', 'INGUINAL HERNIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5500', 'INGUINAL HERNIA, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5501', 'INGUINAL HERNIA, WITH OBSTRUCTION, WITHOUT MENTION OF GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5509', 'INGUINAL HERNIA, WITHOUT MENTION OF OBSTRUCTION OR GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('551', 'OTHER HERNIA OF ABDOMINAL CAVITY, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5510', 'FEMORAL, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5511', 'UMBILICAL, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5512', 'VENTRAL (INCISIONAL), WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5513', 'DIAPHRAGMATIC, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5518', 'OF OTHER SPECIFIED SITES, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5519', 'OF UNSPECIFIED SITE, WITH GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('552', 'OTHER HERNIA OF ABDOMINAL CAVITY WITH OBSTRUCTION, WITHOUT MENTION OF GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5520', 'FEMORAL, WITH OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5521', 'UMBILICAL, WITH OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5522', 'VENTRAL (INCISIONAL), WITH OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5523', 'DIAPHRAGMATIC, WITH OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5528', 'OF OTHER SPECIFIED SITES, WITH OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5529', 'OF UNSPECIFIED SITE, WITH OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('553', 'OTHER HERNIA OF ABDOMINAL CAVITY WITHOUT MENTION OF OBSTRUCTION OR GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('5530', 'FEMORAL');
INSERT INTO staging.icd9 (code, description) VALUES ('5531', 'UMBILICAL');
INSERT INTO staging.icd9 (code, description) VALUES ('5532', 'VENTRAL (INCISIONAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('5533', 'DIAPHRAGMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('5538', 'OF OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('5539', 'OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('555', 'REGIONAL ENTERITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5550', 'SMALL INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5551', 'LARGE INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5552', 'SMALL INTESTINE WITH LARGE INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5559', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('556', 'IDIOPATHIC PROCTOCOLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('557', 'VASCULAR INSUFFICIENCY OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5570', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('5571', 'CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('5579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('558', 'OTHER NONINFECTIVE GASTROENTERITIS AND COLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('560', 'INTESTINAL OBSTRUCTION WITHOUT MENTION OF HERNIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5600', 'INTUSSUSCEPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5601', 'PARALYTIC ILEUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5602', 'VOLVULUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5603', 'IMPACTION OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5608', 'OTHER INTESTINAL OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5609', 'UNSPECIFIED INTESTINAL OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('562', 'DIVERTICULA OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5620', 'SMALL INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5621', 'COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('564', 'FUNCTIONAL DIGESTIVE DISORDERS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5640', 'CONSTIPATION');
INSERT INTO staging.icd9 (code, description) VALUES ('5641', 'IRRITABLE COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('5642', 'POSTGASTRIC SURGERY SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('5643', 'VOMITING FOLLOWING GASTROINTESTINAL SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('5644', 'OTHER POSTOPERATIVE FUNCTIONAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('5645', 'FUNCTIONAL DIARRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('5646', 'ANAL SPASM');
INSERT INTO staging.icd9 (code, description) VALUES ('5647', 'MEGACOLON, OTHER THAN HIRSCHSPRUNG''S');
INSERT INTO staging.icd9 (code, description) VALUES ('5648', 'OTHER FUNCTIONAL DISORDERS OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5649', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('565', 'ANAL FISSURE AND FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('5650', 'ANAL FISSURE');
INSERT INTO staging.icd9 (code, description) VALUES ('5651', 'ANAL FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('566', 'ABSCESS OF ANAL AND RECTAL REGIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('567', 'PERITONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5670*', 'PERITONITIS IN INFECTIOUS DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('5671', 'PNEUMOCOCCAL PERITONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5672', 'OTHER SUPPURATIVE PERITONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5678', 'OTHER PERITONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5679', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('568', 'OTHER DISORDERS OF PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5680', 'PERITONEAL ADHESIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('5688', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5689', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('569', 'OTHER DISORDERS OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5690', 'ANAL AND RECTAL POLYP');
INSERT INTO staging.icd9 (code, description) VALUES ('5691', 'RECTAL PROLAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('5692', 'STENOSIS OF RECTUM AND ANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5693', 'HAEMORRHAGE OF RECTUM AND ANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5694', 'OTHER DISORDERS OF RECTUM AND ANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5695', 'ABSCESS OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('5696', 'COLOSTOMY OR ENTEROSTOMY MALFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5698', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5699', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('570', 'ACUTE AND SUBACUTE NECROSIS OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('571', 'CHRONIC LIVER DISEASE AND CIRRHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5710', 'ALCOHOLIC FATTY LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('5711', 'ACUTE ALCOHOLIC HEPATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5712', 'ALCOHOLIC CIRRHOSIS OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('5713', 'ALCOHOLIC LIVER DAMAGE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5714', 'CHRONIC HEPATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5715', 'CIRRHOSIS OF LIVER WITHOUT MENTION OF ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('5716', 'BILIARY CIRRHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5718', 'OTHER CHRONIC NONALCOHOLIC LIVER DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('5719', 'UNSPECIFIED CHRONIC LIVER DISEASE WITHOUT MENTION OF ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('572', 'LIVER ABSCESS AND SEQUELAE OF CHRONIC LIVER DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('5720', 'ABSCESS OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('5721', 'PORTAL PYAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5722', 'HEPATIC COMA');
INSERT INTO staging.icd9 (code, description) VALUES ('5723', 'PORTAL HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('5724', 'HEPATORENAL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5728', 'OTHER SEQUELAE OF CHRONIC LIVER DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('573', 'OTHER DISORDERS OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('5730', 'CHRONIC PASSIVE CONGESTION OF LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('5731*', 'HEPATITIS IN VIRAL DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('5732*', 'HEPATITIS IN OTHER INFECTIOUS DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('5733', 'HEPATITIS UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5734', 'HEPATIC INFARCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('574', 'CHOLELITHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5740', 'CALCULUS OF GALLBLADDER WITH ACUTE CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5741', 'CALCULUS OF GALLBLADDER WITH OTHER CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5742', 'CALCULUS OF GALLBLADDER WITHOUT MENTION OF CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5743', 'CALCULUS OF BILE DUCT WITH ACUTE CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5744', 'CALCULUS OF BILE DUCT WITH OTHER CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5745', 'CALCULUS OF BILE DUCT WITHOUT MENTION OF CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('575', 'OTHER DISORDERS OF GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5750', 'ACUTE CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5751', 'OTHER CHOLECYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5752', 'OBSTRUCTION OF GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5753', 'HYDROPS OF GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5754', 'PERFORATION OF GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5755', 'FISTULA OF GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5756', 'CHOLESTEROLOSIS OF GALLBLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5758', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5759', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('576', 'OTHER DISORDERS OF BILIARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('5760', 'POSTCHOLECYSTECTOMY SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5761', 'CHOLANGITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5762', 'OBSTRUCTION OF BILE DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('5763', 'PERFORATION OF BILE DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('5764', 'FISTULA OF BILE DUCT');
INSERT INTO staging.icd9 (code, description) VALUES ('5765', 'SPASM OF SPHINCTER OF ODDI');
INSERT INTO staging.icd9 (code, description) VALUES ('5768', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5769', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('577', 'DISEASES OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('5770', 'ACUTE PANCREATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5771', 'CHRONIC PANCREATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5772', 'CYST AND PSEUDOCYST OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('5778', 'OTHER DISEASES OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('5779', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('578', 'GASTROINTESTINAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5780', 'HAEMATEMESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5781', 'MELAENA');
INSERT INTO staging.icd9 (code, description) VALUES ('5789', 'HAEMORRHAGE OF GASTROINTESTINAL TRACT, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('579', 'INTESTINAL MALABSORPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5790', 'COELIAC DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('5791', 'TROPICAL SPRUE');
INSERT INTO staging.icd9 (code, description) VALUES ('5792', 'BLIND LOOP SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5793', 'OTHER AND UNSPECIFIED POSTSURGICAL NONABSORPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5794', 'PANCREATIC STEATORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('5798', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('580', 'ACUTE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5800', 'WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5804', 'WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5808', 'WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5809', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('581', 'NEPHROTIC SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5810', 'WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5811', 'WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5812', 'WITH LESION OF MEMBRANOPROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5813', 'WITH LESION OF MINIMAL CHANGE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5818', 'WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5819', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('582', 'CHRONIC GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5820', 'WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5821', 'WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5822', 'WITH LESION OF MEMBRANOPROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5824', 'WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5828', 'WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5829', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('583', 'NEPHRITIS AND NEPHROPATHY, NOT SPECIFIED AS ACUTE OR CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('5830', 'WITH LESION OF PROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5831', 'WITH LESION OF MEMBRANOUS GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5832', 'WITH LESION OF MEMBRANOPROLIFERATIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5834', 'WITH LESION OF RAPIDLY PROGRESSIVE GLOMERULONEPHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5836', 'WITH LESION OF RENAL CORTICAL NECROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5837', 'WITH LESION OF RENAL MEDULLARY NECROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5838', 'WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5839', 'WITH UNSPECIFIED PATHOLOGICAL LESION IN KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('584', 'ACUTE RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('5845', 'WITH LESION OF TUBULAR NECROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5846', 'WITH LESION OF RENAL CORTICAL NECROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5847', 'WITH LESION OF RENAL MEDULLARY (PAPILLARY) NECROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5848', 'WITH OTHER SPECIFIED PATHOLOGICAL LESION IN KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5849', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('585', 'CHRONIC RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('586', 'RENAL FAILURE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('587', 'RENAL SCLEROSIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('588', 'DISORDERS RESULTING FROM IMPAIRED RENAL FUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5880', 'RENAL OSTEODYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('5881', 'NEPHROGENIC DIABETES INSIPIDUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5888', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5889', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('589', 'SMALL KIDNEY OF UNKNOWN CAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('5890', 'UNILATERAL');
INSERT INTO staging.icd9 (code, description) VALUES ('5891', 'BILATERAL');
INSERT INTO staging.icd9 (code, description) VALUES ('5899', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('590', 'INFECTIONS OF KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5900', 'CHRONIC PYELONEPHRITIS AND CHRONIC PYONEPHROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5901', 'ACUTE PYELONEPHRITIS AND ACUTE PYONEPHROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5902', 'RENAL AND PERINEPHRIC ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('5903', 'PYELOURETERITIS CYSTICA');
INSERT INTO staging.icd9 (code, description) VALUES ('5908', 'PYELONEPHRITIS OR PYONEPHROSIS, NOT SPECIFIED AS ACUTE OR CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('5909', 'INFECTION OF KIDNEY, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('591', 'HYDRONEPHROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('592', 'CALCULUS OF KIDNEY AND URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('5920', 'CALCULUS OF KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5921', 'CALCULUS OF URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('5929', 'URINARY CALCULUS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('593', 'OTHER DISORDERS OF KIDNEY AND URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('5930', 'NEPHROPTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5931', 'HYPERTROPHY OF KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('5932', 'CYST OF KIDNEY, ACQUIRED');
INSERT INTO staging.icd9 (code, description) VALUES ('5933', 'STRICTURE OR KINKING OF URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('5934', 'OTHER URETERIC OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5935', 'HYDROURETER');
INSERT INTO staging.icd9 (code, description) VALUES ('5936', 'POSTURAL PROTEINURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5937', 'VESICOURETERIC REFLUX');
INSERT INTO staging.icd9 (code, description) VALUES ('5938', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5939', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('594', 'CALCULUS OF LOWER URINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('5940', 'CALCULUS IN DIVERTICULUM OF BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5941', 'OTHER CALCULUS IN BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5942', 'CALCULUS IN URETHRA');
INSERT INTO staging.icd9 (code, description) VALUES ('5948', 'OTHER LOWER URINARY TRACT CALCULUS');
INSERT INTO staging.icd9 (code, description) VALUES ('5949', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('595', 'CYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5950', 'ACUTE CYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5951', 'CHRONIC INTERSTITIAL CYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5952', 'OTHER CHRONIC CYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5953', 'TRIGONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('5954*', 'CYSTITIS IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('5958', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5959', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('596', 'OTHER DISORDERS OF BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5960', 'BLADDER-NECK OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('5961', 'INTESTINOVESICAL FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('5962', 'VESICAL FISTULA, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5963', 'DIVERTICULUM OF BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5964', 'ATONY OF BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5965', 'OTHER FUNCTIONAL DISORDERS OF BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('5966', 'RUPTURE OF BLADDER, NONTRAUMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('5967', 'HAEMORRHAGE INTO BLADDER WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('5968', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5969', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('597', 'URETHRITIS, NOT SEXUALLY TRANSMITTED, AND URETHRAL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('5970', 'URETHRAL ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('5978', 'OTHER URETHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('598', 'URETHRAL STRICTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('5980', 'INFECTIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('5981', 'TRAUMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('5982', 'POSTOPERATIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('5988', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5989', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('599', 'OTHER DISORDERS OF URETHRA AND URINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('5990', 'URINARY TRACT INFECTION, SITE NOT SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5991', 'URETHRAL FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('5992', 'URETHRAL DIVERTICULUM');
INSERT INTO staging.icd9 (code, description) VALUES ('5993', 'URETHRAL CARUNCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('5994', 'URETHRAL FALSE PASSAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('5995', 'PROLAPSED URETHRAL MUCOSA');
INSERT INTO staging.icd9 (code, description) VALUES ('5996', 'URINARY OBSTRUCTION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('5997', 'HAEMATURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('5998', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('5999', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('600', 'HYPERPLASIA OF PROSTRATE');
INSERT INTO staging.icd9 (code, description) VALUES ('601', 'INFLAMMATORY DISEASES OF PROSTRATE');
INSERT INTO staging.icd9 (code, description) VALUES ('6010', 'ACUTE PROSTATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6011', 'CHRONIC PROSTATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6012', 'ABSCESS OF PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('6013', 'PROSTATOCYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6014*', 'PROSTATITIS IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('6018', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('602', 'OTHER DISORDERS OF PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('6020', 'CALCULUS OF PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('6021', 'CONGESTION OR HAEMORRHAGE OF PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('6022', 'ATROPHY OF PROSTATE');
INSERT INTO staging.icd9 (code, description) VALUES ('6028', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6029', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('603', 'HYDROCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('6030', 'ENCYSTED HYDROCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('6031', 'INFECTED HYDROCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('6038', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6039', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('604', 'ORCHITIS AND EPIDIDYMITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6040', 'ORCHITIS, EPIDIDYMITIS AND EPIDIDYMO-ORCHITIS, WITH ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('6049', 'ORCHITIS, EPIDIDYMITIS AND EPIDIDYMO-ORCHITIS, WITHOUT MENTION OF ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('605', 'REDUNDANT PREPUCE AND PHIMOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('606', 'INFERTILITY, MALE');
INSERT INTO staging.icd9 (code, description) VALUES ('607', 'DISORDERS OF PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6070', 'LEUKOPLAKIA OF PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6071', 'BALANOPOSTHITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6072', 'OTHER INFLAMMATORY DISORDERS OF PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6073', 'PRIAPISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6078', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6079', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('608', 'OTHER DISORDERS OF MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('6080', 'SEMINAL VESICULITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6081', 'SPERMATOCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('6082', 'TORSION OF TESTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6083', 'ATROPHY OF TESTIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6084', 'OTHER INFLAMMATORY DISORDERS OF MALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('6088', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6089', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('610', 'BENIGN MAMMARY DYSPLASIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('6100', 'SOLITARY CYST OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6101', 'DIFFUSE CYSTIC MASTOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('6102', 'FIBROADENOSIS OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6103', 'FIBROSCLEROSIS OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6104', 'MAMMARY DUCT ECTASIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6108', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6109', 'MAMMARY DYSPLASIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('611', 'OTHER DISORDERS OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6110', 'INFLAMMATORY DISEASE OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6111', 'HYPERTROPHY OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6112', 'FISSURE OF NIPPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('6113', 'FAT NECROSIS OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6114', 'ATROPHY OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6115', 'GALACTOCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('6116', 'GALACTORRHOEA NOT ASSOCIATED WITH CHILDBIRTH');
INSERT INTO staging.icd9 (code, description) VALUES ('6117', 'SIGNS AND SYMPTOMS IN BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6118', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6119', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('614', 'INFLAMMATORY DISEASE OF OVARY, FALLOPIAN TUBE, PELVIC CELLULAR TISSUE AND PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6140', 'ACUTE SALPINGITIS AND OOPHORITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6141', 'CHRONIC SALPINGITIS AND OOPHORITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6142', 'SALPINGITIS AND OOPHORITIS, NOT SPECIFIED AS ACUTE, SUBACUTE OR CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('6143', 'ACUTE PARAMETRITIS AND PELVIC CELLULITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6144', 'CHRONIC OR UNSPECIFIED PARAMETRITIS AND PELVIC CELLULITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6145', 'ACUTE OR UNSPECIFIED PELVIC PERITONITIS, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6146', 'PELVIC PERITONEAL ADHESIONS, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6147', 'OTHER CHRONIC PELVIC PERITONITIS, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6148', 'OTHER SPECIFIED INFLAMMATORY DISEASE OF FEMALE PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6149', 'UNSPECIFIED INFLAMMATORY DISEASE OF FEMALE PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('615', 'INFLAMMATORY DISEASES OF UTERUS, EXCEPT CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6150', 'ACUTE');
INSERT INTO staging.icd9 (code, description) VALUES ('6151', 'CHRONIC');
INSERT INTO staging.icd9 (code, description) VALUES ('6159', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('616', 'INFLAMMATORY DISEASE OF CERVIX, VAGINA AND VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6160', 'CERVICITIS AND ENDOCERVICITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6161', 'VAGINITIS AND VULVOVAGINITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6162', 'CYST OF BARTHOLIN''S GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('6163', 'ABSCESS OF BARTHOLIN''S GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('6164', 'OTHER ABSCESS OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6165', 'ULCERATION OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6168', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6169', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('617', 'ENDOMETRIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6170', 'UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6171', 'OVARY');
INSERT INTO staging.icd9 (code, description) VALUES ('6172', 'FALLOPIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('6173', 'PELVIC PERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6174', 'RECTOVAGINAL SEPTUM AND VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6175', 'INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('6176', 'ENDOMETRIOSIS IN SCAR OR SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6178', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('6179', 'SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('618', 'GENITAL PROLAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('6180', 'PROLAPSE OF VAGINAL WALLS, WITHOUT MENTION OF UTERINE PROLAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('6181', 'UTERINE PROLAPSE WITHOUT MENTION OF VAGINAL WALL PROLAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('6182', 'UTEROVAGINAL PROLAPSE, INCOMPLETE');
INSERT INTO staging.icd9 (code, description) VALUES ('6183', 'UTEROVAGINAL PROLAPSE, COMPLETE');
INSERT INTO staging.icd9 (code, description) VALUES ('6184', 'UTEROVAGINAL PROLAPSE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6185', 'PROLAPSE OF VAGINAL VAULT AFTER HYSTERECTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('6186', 'VAGINAL ENTEROCELE, CONGENITAL OR ACQUIRED');
INSERT INTO staging.icd9 (code, description) VALUES ('6187', 'OLD LACERATION OF MUSCLES OF PELVIC FLOOR');
INSERT INTO staging.icd9 (code, description) VALUES ('6188', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6189', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('619', 'FISTULAE INVOLVING FEMALE GENITAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('6190', 'URINARY - GENITAL TRACT FISTULAE, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6191', 'DIGESTIVE - GENITAL TRACT FISTULAE, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6192', 'GENITAL TRACT - SKIN FISTULAE, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6198', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6199', 'UNSPECIFIED FISTULA INVOLVING FEMALE GENITAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('620', 'NONINFLAMMATORY DISORDERS OF OVARY, FALLOPIAN TUBE AND BROAD LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('6200', 'FOLLICULAR CYST OF OVARY');
INSERT INTO staging.icd9 (code, description) VALUES ('6201', 'CORPUS LUTEUM CYST OR HAEMATOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6202', 'OTHER AND UNSPECIFIED OVARIAN CYST');
INSERT INTO staging.icd9 (code, description) VALUES ('6203', 'ACQUIRED ATROPHY OF OVARY AND FALLOPIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('6204', 'PROLAPSE OR HERNIA OF OVARY AND FALLOPIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('6205', 'TORSION OF OVARY, OVARIAN PEDICLE OR FALLOPIAN TUBE');
INSERT INTO staging.icd9 (code, description) VALUES ('6206', 'BROAD LIGAMENT LACERATION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('6207', 'HAEMATOMA OF BROAD LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('6208', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6209', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('621', 'DISORDERS OF UTERUS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6210', 'POLYP OF CORPUS UTERI');
INSERT INTO staging.icd9 (code, description) VALUES ('6211', 'CHRONIC SUBINVOLUTION OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6212', 'HYPERTROPHY OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6213', 'ENDOMETRIAL CYSTIC HYPERPLASIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6214', 'HAEMATOMETRA');
INSERT INTO staging.icd9 (code, description) VALUES ('6215', 'INTRAUTERINE SYNECHIAE');
INSERT INTO staging.icd9 (code, description) VALUES ('6216', 'MALPOSITION OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6217', 'CHRONIC INVERSION OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6218', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6219', 'UNSPECIFIED DISORDERS OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('622', 'NONINFLAMMATORY DISORDERS OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6220', 'EROSION AND ECTROPION OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6221', 'DYSPLASIA OF CERVIX (UTERI)');
INSERT INTO staging.icd9 (code, description) VALUES ('6222', 'LEUKOPLAKIA OF CERVIX (UTERI)');
INSERT INTO staging.icd9 (code, description) VALUES ('6223', 'OLD LACERATION OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6224', 'STRICTURE AND STENOSIS OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6225', 'INCOMPETENCE OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6226', 'HYPERTROPHIC ELONGATION OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6227', 'MUCOUS POLYP OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6228', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6229', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('623', 'NONINFLAMMATORY DISORDERS OF VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6230', 'DYSPLASIA OF VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6231', 'LEUKOPLAKIA OF VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6232', 'STRICTURE OR ATRESIA OF VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6233', 'TIGHT HYMENAL RING');
INSERT INTO staging.icd9 (code, description) VALUES ('6234', 'OLD VAGINAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6235', 'LEUKORRHOEA, NOT SPECIFIED AS INFECTIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('6236', 'VAGINAL HAEMATOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6237', 'POLYP OF VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6238', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6239', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('624', 'NONINFLAMMATORY DISORDERS OF VULVA AND PERINEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6240', 'DYSTROPHY OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6241', 'ATROPHY OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6242', 'HYPERTROPHY OF CLITORIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6243', 'HYPERTROPHY OF LABIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6244', 'OLD LACERATION OR SCARRING OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6245', 'HAEMATOMA OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6246', 'POLYP OF LABIA AND VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6248', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6249', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('625', 'PAIN AND OTHER SYMPTOMS ASSOCIATED WITH FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('6250', 'DYSPAREUNIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6251', 'VAGINISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6252', 'MITTELSCHMERZ');
INSERT INTO staging.icd9 (code, description) VALUES ('6253', 'DYSMENORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('6254', 'PREMENSTRUAL TENSION SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('6255', 'PELVIC CONGESTION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('6256', 'STRESS INCONTINENCE, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6258', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6259', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('626', 'DISORDERS OF MENSTRUATION AND OTHER ABNORMAL BLEEDING FROM FEMALE GENITAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('6260', 'ABSENCE OF MENSTRUATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6261', 'SCANTY OR INFREQUENT MENSTRUATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6262', 'EXCESSIVE OR FREQUENT MENSTRUATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6263', 'PUBERTY BLEEDING');
INSERT INTO staging.icd9 (code, description) VALUES ('6264', 'IRREGULAR MENSTRUAL CYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('6265', 'OVULATION BLEEDING');
INSERT INTO staging.icd9 (code, description) VALUES ('6266', 'METRORRHAGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6267', 'POSTCOITAL BLEEDING');
INSERT INTO staging.icd9 (code, description) VALUES ('6268', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('627', 'MENOPAUSAL AND POSTMENOPAUSAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('6270', 'PREMENOPAUSAL MENORRHAGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6271', 'POSTMENOPAUSAL BLEEDING');
INSERT INTO staging.icd9 (code, description) VALUES ('6272', 'MENOPAUSAL OR FEMALE CLIMACTERIC STATES');
INSERT INTO staging.icd9 (code, description) VALUES ('6273', 'POSTMENOPAUSAL ATROPHIC VAGINITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6274', 'STATES ASSOCIATED WITH ARTIFICIAL MENOPAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('6278', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6279', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('628', 'INFERTILITY, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6280', 'ASSOCIATED WITH ANOVULATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6281*', 'OF PITUITARY-HYPOTHALAMIC ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6282', 'OF TUBAL ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6283', 'OF UTERINE ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6284', 'OF CERVICAL OR VAGINAL ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6288', 'OF OTHER SPECIFIED ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6289', 'OF UNSPECIFIED ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('629', 'OTHER DISORDERS OF FEMALE GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('6290', 'HAEMATOCELE, FEMALE');
INSERT INTO staging.icd9 (code, description) VALUES ('6291', 'HYDROCELE, CANAL OF NUCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6298', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6299', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('630', 'HYDATIDIFORM MOLE');
INSERT INTO staging.icd9 (code, description) VALUES ('631', 'OTHER ABNORMAL PRODUCT OF CONCEPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('632', 'MISSED ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('633', 'ECTOPIC PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6330', 'ABDOMINAL PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6331', 'TUBAL PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6332', 'OVARIAN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6338', 'OTHER ECTOPIC PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6339', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('634', 'SPONTANEOUS ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6340', 'COMPLICATED BY GENITAL TRACT AND PELVIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6341', 'COMPLICATED BY DELAYED OR EXCESSIVE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6342', 'COMPLICATED BY DAMAGE TO PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6343', 'COMPLICATED BY RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('6344', 'COMPLICATED BY METABOLIC DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('6345', 'COMPLICATED BY SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6346', 'COMPLICATED BY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6347', 'WITH OTHER SPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6348', 'WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6349', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('635', 'LEGALLY INDUCED ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6350', 'COMPLICATED BY GENITAL TRACT AND PELVIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6351', 'COMPLICATED BY DELAYED OR EXCESSIVE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6352', 'COMPLICATED BY DAMAGE TO PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6353', 'COMPLICATED BY RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('6354', 'COMPLICATED BY METABOLIC DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('6355', 'COMPLICATED BY SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6356', 'COMPLICATED BY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6357', 'WITH OTHER SPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6358', 'WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6359', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('636', 'ILLEGALLY INDUCED ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6360', 'COMPLICATED BY GENITAL TRACT AND PELVIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6361', 'COMPLICATED BY DELAYED OR EXCESSIVE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6362', 'COMPLICATED BY DAMAGE TO PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6363', 'COMPLICATED BY RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('6364', 'COMPLICATED BY METABOLIC DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('6365', 'COMPLICATED BY SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6366', 'COMPLICATED BY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6367', 'WITH OTHER SPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6368', 'WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6369', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('637', 'UNSPECIFIED ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6370', 'COMPLICATED BY GENITAL TRACT AND PELVIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6371', 'COMPLICATED BY DELAYED OR EXCESSIVE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6372', 'COMPLICATED BY DAMAGE TO PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6373', 'COMPLICATED BY RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('6374', 'COMPLICATED BY METABOLIC DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('6375', 'COMPLICATED BY SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6376', 'COMPLICATED BY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6377', 'WITH OTHER SPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6378', 'WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6379', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('638', 'FAILED ATTEMPTED ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6380', 'COMPLICATED BY GENITAL TRACT AND PELVIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6381', 'COMPLICATED BY DELAYED OR EXCESSIVE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6382', 'COMPLICATED BY DAMAGE TO PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6383', 'COMPLICATED BY RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('6384', 'COMPLICATED BY METABOLIC DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('6385', 'COMPLICATED BY SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6386', 'COMPLICATED BY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6387', 'WITH OTHER SPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6388', 'WITH UNSPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6389', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('639', 'COMPLICATIONS FOLLOWING ABORTION AND ECTOPIC AND MOLAR PREGNANCIES');
INSERT INTO staging.icd9 (code, description) VALUES ('6390', 'GENITAL TRACT AND PELVIC INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6391', 'DELAYED OR EXCESSIVE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6392', 'DAMAGE TO PELVIC ORGANS AND TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6393', 'RENAL FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('6394', 'METABOLIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('6395', 'SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6396', 'EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6398', 'OTHER SPECIFIED COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6399', 'UNSPECIFIED COMPLICATIONS FOLLOWING CONDITIONS CLASSIFIABLE TO 630-638');
INSERT INTO staging.icd9 (code, description) VALUES ('640', 'HAEMORRHAGE IN EARLY PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6400', 'THREATENED ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6408', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6409', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('641', 'ANTEPARTUM HAEMORRHAGE, ABRUPTIO PLACENTAE, AND PLACENTA PRAEVIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6410', 'PLACENTA PRAEVIA WITHOUT HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6411', 'HAEMORRHAGE FROM PLACENTA PRAEVIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6412', 'PREMATURE SEPARATION OF PLACENTA');
INSERT INTO staging.icd9 (code, description) VALUES ('6413', 'ANTEPARTUM HAEMORRHAGE ASSOCIATED WITH COAGULATION DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6418', 'OTHER ANTEPARTUM HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6419', 'UNSPECIFIED ANTEPARTUM HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('642', 'HYPERTENSION COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6420', 'BENIGN ESSENTIAL HYPERTENSION COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6421', 'HYPERTENSION SECONDARY TO RENAL DISEASE, COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6422', 'OTHER PRE-EXISTING HYPERTENSION COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6423', 'TRANSIENT HYPERTENSION OF PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6424', 'MILD OR UNSPECIFIED PRE-ECLAMPSIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6425', 'SEVERE PRE-ECLAMPSIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6426', 'ECLAMPSIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6427', 'PRE-ECLAMPSIA OR ECLAMPSIA SUPERIMPOSED ON PRE-EXISTING HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6429', 'UNSPECIFIED HYPERTENSION COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('643', 'EXCESSIVE VOMITING IN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6430', 'MILD HYPEREMESIS GRAVIDARUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6431', 'HYPEREMESIS GRAVIDARUM WITH METABOLIC DISTURBANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('6432', 'LATE VOMITING OF PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6438', 'OTHER VOMITING COMPLICATING PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6439', 'UNSPECIFIED VOMITING OF PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('644', 'EARLY OR THREATENED LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6440', 'THREATENED LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6441', 'EARLY ONSET OF DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('645', 'PROLONGED PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('646', 'OTHER COMPLICATIONS OF PREGNANCY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6460', 'PAPYRACEOUS FETUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6461', 'OEDEMA OR EXCESSIVE WEIGHT GAIN IN PREGNANCY, WITHOUT MENTION OF HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6462', 'UNSPECIFIED RENAL DISEASE IN PREGNANCY, WITHOUT MENTION OF HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6463', 'HABITUAL ABORTER');
INSERT INTO staging.icd9 (code, description) VALUES ('6464', 'PERIPHERAL NEURITIS IN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6465', 'ASYMPTOMATIC BACTERIURIA IN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6466', 'INFECTIONS OF GENITOURINARY TRACT IN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6467', 'LIVER DISORDERS IN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('662', 'LONG LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6468', 'OTHER SPECIFIED COMPLICATIONS OF PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6469', 'UNSPECIFIED COMPLICATION OF PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('647', 'INFECTIVE AND PARASITIC CONDITIONS IN THE MOTHER CLASSIFIABLE ELSEWHERE BUT COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6470', 'SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6471', 'GONORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('6472', 'OTHER VENEREAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('6473', 'TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6474', 'MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6475', 'RUBELLA');
INSERT INTO staging.icd9 (code, description) VALUES ('6476', 'OTHER VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('6478', 'OTHER SPECIFIED INFECTIVE AND PARASITIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('6479', 'UNSPECIFIED INFECTION OR INFESTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('648', 'OTHER CURRENT CONDITIONS IN THE MOTHER CLASSIFIABLE ELSEWHERE BUT COMPLICATING PREGNANCY, CHILDBIRTH AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6480', 'DIABETES MELLITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6481', 'THYROID DYSFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6482', 'ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6483', 'DRUG DEPENDENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('6484', 'MENTAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('6485', 'CONGENITAL CARDIOVASCULAR DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('6486', 'OTHER CARDIOVASCULAR DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('6487', 'BONE AND JOINT DISORDERS OF BACK, PELVIS AND LOWER LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('6488', 'ABNORMAL GLUCOSE TOLERANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('6489', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('650', 'DELIVERY IN A COMPLETELY NORMAL CASE');
INSERT INTO staging.icd9 (code, description) VALUES ('651', 'MULTIPLE GESTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6510', 'TWIN PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6511', 'TRIPLET PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6512', 'QUADRUPLET PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('6518', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6519', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('652', 'MALPOSITION AND MALPRESENTATION OF FETUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6520', 'UNSTABLE LIE');
INSERT INTO staging.icd9 (code, description) VALUES ('6521', 'BREECH OR OTHER MALPRESENTATION SUCCESSFULLY CONVERTED TO CEPHALIC PRESENTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6522', 'BREECH PRESENTATION WITHOUT MENTION OF VERSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6523', 'TRANSVERSE OR OBLIQUE PRESENTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6524', 'FACE OR BROW PRESENTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6525', 'HIGH HEAD AT TERM');
INSERT INTO staging.icd9 (code, description) VALUES ('6526', 'MULTIPLE GESTATION WITH MALPRESENTATION OF ONE FETUS OR MORE');
INSERT INTO staging.icd9 (code, description) VALUES ('6527', 'PROLAPSED ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('6528', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6529', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('653', 'DISPROPORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6530', 'MAJOR ABNORMALITY OF BONY PELVIS, NOT FURTHER SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6531', 'GENERALLY CONTRACTED PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6532', 'INLET CONTRACTION OF PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6533', 'OUTLET CONTRACTION OF PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6534', 'FETOPELVIC DISPROPORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6535', 'UNUSUALLY LARGE FETUS CAUSING DISPROPORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6536', 'HYDROCEPHALIC FETUS CAUSING DISPROPORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6537', 'OTHER FETAL ABNORMALITY CAUSING DISPROPORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6538', 'DISPROPORTION OF OTHER ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6539', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('654', 'ABNORMALITY OF ORGANS AND SOFT TISSUES OF PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6540', 'CONGENITAL ABNORMALITIES OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6541', 'TUMOURS OF BODY OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6542', 'UTERINE SCAR FROM PREVIOUS SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('6543', 'RETROVERTED AND INCARCERATED GRAVID UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6544', 'OTHER ABNORMALITIES IN SHAPE OR POSITION OF GRAVID UTERUS AND OF NEIGHBOURING STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('6545', 'CERVICAL INCOMPETENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('6546', 'OTHER CONGENITAL OR ACQUIRED ABNORMALITY OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6547', 'CONGENITAL OR ACQUIRED ABNORMALITY OF VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('6548', 'CONGENITAL OR ACQUIRED ABNORMALITY OF VULVA');
INSERT INTO staging.icd9 (code, description) VALUES ('6549', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('655', 'KNOWN OR SUSPECTED FETAL ABNORMALITY AFFECTING MANAGEMENT OF MOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6550', 'CENTRAL NERVOUS SYSTEM MALFORMATION IN FETUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6551', 'CHROMOSOMAL ABNORMALITY IN FETUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6552', 'HEREDITARY DISEASE IN FAMILY POSSIBLY AFFECTING FETUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6553', 'SUSPECTED DAMAGE TO FETUS FROM VIRAL DISEASE IN THE MOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6554', 'SUSPECTED DAMAGE TO FETUS FROM OTHER DISEASE IN THE MOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6555', 'SUSPECTED DAMAGE TO FETUS FROM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('6556', 'SUSPECTED DAMAGE TO FETUS FROM RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6558', 'OTHER KNOWN OR SUSPECTED FETAL ABNORMALITY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6559', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('656', 'OTHER FETAL AND PLACENTAL PROBLEMS AFFECTING MANAGEMENT OF MOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6560', 'FETAL-MATERNAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6561', 'RHESUS ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6562', 'ISOIMMUNIZATION FROM OTHER AND UNSPECIFIED BLOOD-GROUP INCOMPATIBILITY');
INSERT INTO staging.icd9 (code, description) VALUES ('6563', 'FETAL DISTRESS');
INSERT INTO staging.icd9 (code, description) VALUES ('6564', 'INTRAUTERINE DEATH');
INSERT INTO staging.icd9 (code, description) VALUES ('6565', 'POOR FETAL GROWTH');
INSERT INTO staging.icd9 (code, description) VALUES ('6566', 'EXCESSIVE FETAL GROWTH');
INSERT INTO staging.icd9 (code, description) VALUES ('6567', 'OTHER PLACENTAL CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6568', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6569', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('657', 'POLYHYDRAMNIOS');
INSERT INTO staging.icd9 (code, description) VALUES ('658', 'OTHER PROBLEMS ASSOCIATED WITH AMNIOTIC CAVITY AND MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('6580', 'OLIGOHYDRAMNIOS');
INSERT INTO staging.icd9 (code, description) VALUES ('6581', 'PREMATURE RUPTURE OF MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('6582', 'DELAYED DELIVERY AFTER SPONTANEOUS OR UNSPECIFIED RUPTURE OF MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('6583', 'DELAYED DELIVERY AFTER ARTIFICIAL RUPTURE OF MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('6584', 'INFECTION OF AMNIOTIC CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('6588', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6589', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('659', 'OTHER INDICATIONS FOR CARE OR INTERVENTION RELATED TO LABOUR AND DELIVERY AND NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6590', 'FAILED MECHANICAL INDUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6591', 'FAILED MEDICAL OR UNSPECIFIED INDUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('6592', 'MATERNAL PYREXIA DURING LABOUR, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6593', 'GENERALIZED INFECTION DURING LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6594', 'GRAND MULTIPARITY');
INSERT INTO staging.icd9 (code, description) VALUES ('6595', 'ELDERLY PRIMIGRAVIDA');
INSERT INTO staging.icd9 (code, description) VALUES ('6598', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6599', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('660', 'OBSTRUCTED LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6600', 'OBSTRUCTION CAUSED BY MALPOSITION OF FETUS AT ONSET OF LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6601', 'OBSTRUCTION BY BONY PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6602', 'OBSTRUCTION BY ABNORMAL PELVIC SOFT TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('6603', 'DEEP TRANSVERSE ARREST AND PERSISTENT OCCIPITOPOSTERIOR OR OCCIPITOANTERIOR POSITION');
INSERT INTO staging.icd9 (code, description) VALUES ('6604', 'SHOULDER DYSTOCIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6605', 'LOCKED TWINS');
INSERT INTO staging.icd9 (code, description) VALUES ('6606', 'FAILED TRIAL OF LABOUR, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6607', 'FAILED FORCEPS OR VENTOUSE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6608', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('661', 'ABNORMALITY OF FORCES OF LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6610', 'PRIMARY UTERINE INERTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6611', 'SECONDARY UTERINE INERTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6612', 'OTHER AND UNSPECIFIED UTERINE INERTIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6613', 'PRECIPITATE LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6614', 'HYPERTONIC, INCOORDINATE, OR PROLONGED UTERINE CONTRACTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6619', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6620', 'PROLONGED FIRST STAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6621', 'PROLONGED LABOUR, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6622', 'PROLONGED SECOND STAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6623', 'DELAYED DELIVERY OF SECOND TWIN, TRIPLET, ETC.');
INSERT INTO staging.icd9 (code, description) VALUES ('663', 'UMBILICAL CORD COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6630', 'PROLAPSE OF CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('6631', 'CORD AROUND NECK, WITH COMPRESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6632', 'OTHER AND UNSPECIFIED CORD ENTANGLEMENT, WITH COMPRESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6633', 'OTHER AND UNSPECIFIED CORD ENTANGLEMENT, WITHOUT MENTION OF COMPRESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('6634', 'SHORT CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('6635', 'VASA PRAEVIA');
INSERT INTO staging.icd9 (code, description) VALUES ('6636', 'VASCULAR LESIONS OF CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('6638', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('664', 'TRAUMA TO PERINEUM AND VULVA DURING DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('6640', 'FIRST-DEGREE PERINEAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6641', 'SECOND-DEGREE PERINEAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6642', 'THIRD-DEGREE PERINEAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6643', 'FOURTH-DEGREE PERINEAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6644', 'UNSPECIFIED PERINEAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6645', 'VULVAL AND PERINEAL HAEMATOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6648', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6649', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('665', 'OTHER OBSTETRICAL TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6650', 'RUPTURE OF UTERUS BEFORE ONSET OF LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6651', 'RUPTURE OF UTERUS DURING AND AFTER LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('6652', 'INVERSION OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6653', 'LACERATION OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('6654', 'HIGH VAGINAL LACERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6655', 'OTHER INJURY TO PELVIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('6656', 'DAMAGE TO PELVIC JOINTS AND LIGAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6657', 'PELVIC HAEMATOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6658', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6659', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('666', 'POSTPARTUM HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6660', 'THIRD-STAGE HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6661', 'OTHER IMMEDIATE POSTPARTUM HAEMMORHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6662', 'DELAYED AND SECONDARY POSTPARTUM HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6663', 'POSTPARTUM COAGULATION DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('667', 'RETAINED PLACENTA OR MEMBRANES, WITHOUT HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6670', 'RETAINED PLACENTA WITHOUT HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('6671', 'RETAINED PORTIONS OF PLACENTA OR MEMBRANES, WITHOUT HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('668', 'COMPLICATIONS OF THE ADMINISTRATION OF ANAESTHETIC OR OTHER SEDATION IN LABOUR AND DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('6680', 'PULMONARY COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6681', 'CARDIAC COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6682', 'CENTRAL NERVOUS SYSTEM COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6688', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6689', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('669', 'OTHER COMPLICATIONS OF LABOUR AND DELIVERY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6690', 'MATERNAL DISTRESS');
INSERT INTO staging.icd9 (code, description) VALUES ('6691', 'SHOCK DURING OR FOLLOWING LABOUR AND DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('6692', 'MATERNAL HYPOTENSION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('6693', 'ACUTE RENAL FAILURE FOLLOWING LABOUR AND DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('6694', 'OTHER COMPLICATIONS OF OBSTETRICAL SURGERY AND PROCEDURES');
INSERT INTO staging.icd9 (code, description) VALUES ('6695', 'FORCEPS OR VENTOUSE DELIVERY WITHOUT MENTION OF INDICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6696', 'BREECH EXTRACTION, WITHOUT MENTION OF INDICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6697', 'CAESAREAN DELIVERY, WITHOUT MENTION OF INDICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6698', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6699', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('670', 'MAJOR PUERPERAL INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('671', 'VENOUS COMPLICATIONS IN PREGNANCY AND THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6710', 'VARICOSE VEINS OF LEGS');
INSERT INTO staging.icd9 (code, description) VALUES ('6711', 'VARICOSE VEINS OF VULVA AND PERINEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6712', 'SUPERFICIAL THROMBOPHLEBITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6713', 'DEEP PHLEBOTHROMBOSIS, ANTEPARTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6714', 'DEEP PHLEBOTHROMBOSIS, POSTPARTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6715', 'OTHER PHLEBITIS AND THROMBOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6718', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('672', 'PYREXIA OF UNKNOWN ORIGIN DURING THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('673', 'OBSTETRICAL PULMONARY EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6730', 'OBSTETRICAL AIR EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6731', 'AMNIOTIC FLUID EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6732', 'OBSTETRICAL BLOOD-CLOT EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6733', 'OBSTETRICAL PYAEMIC AND SEPTIC EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('6738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('674', 'OTHER AND UNSPECIFIED COMPLICATIONS OF THE PUERPERIUM, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6740', 'CEREBROVASCULAR DISORDERS IN THE PUERPERIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6741', 'DISRUPTION OF CAESAREAN WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('6742', 'DISRUPTION OF PERINEAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('6743', 'OTHER COMPLICATIONS OF OBSTETRICAL SURGICAL WOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('6744', 'PLACENTAL POLYP');
INSERT INTO staging.icd9 (code, description) VALUES ('6748', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6749', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('675', 'INFECTIONS OF THE BREAST AND NIPPLE ASSOCIATED WITH CHILDBIRTH');
INSERT INTO staging.icd9 (code, description) VALUES ('6750', 'INFECTIONS OF NIPPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('6751', 'ABSCESS OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6752', 'NONPURULENT MASTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6758', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('6759', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('676', 'OTHER DISORDERS OF THE BREAST ASSOCIATED WITH CHILDBIRTH, AND DISORDERS OF LACTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6760', 'RETRACTED NIPPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('6761', 'CRACKED NIPPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('6762', 'ENGORGEMENT OF BREASTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6763', 'OTHER AND UNSPECIFIED DISORDER OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('6764', 'FAILURE OF LACTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6765', 'SUPPRESSED LACTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6766', 'GALACTORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('6768', 'OTHER DISORDERS OF LACTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6769', 'UNSPECIFIED DISORDER OF LACTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('680', 'CARBUNCLE AND FURUNCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('6800', 'FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('6801', 'NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('6802', 'TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('6803', 'UPPER ARM AND FOREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('6804', 'HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('6805', 'BUTTOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6806', 'LEG, EXCEPT FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('6807', 'FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('6808', 'OTHER SPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('6809', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('681', 'CELLULITIS AND ABSCESS OF FINGER AND TOE');
INSERT INTO staging.icd9 (code, description) VALUES ('6810', 'FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('6811', 'TOE');
INSERT INTO staging.icd9 (code, description) VALUES ('6819', 'UNSPECIFIED DIGIT');
INSERT INTO staging.icd9 (code, description) VALUES ('682', 'OTHER CELLULITIS AND ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('6820', 'FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('6821', 'NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('6822', 'TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('6823', 'UPPER ARM AND FOREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('6824', 'HAND, EXCEPT FINGERS');
INSERT INTO staging.icd9 (code, description) VALUES ('6825', 'BUTTOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('6826', 'LEG, EXCEPT FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('6827', 'FOOT, EXCEPT TOES');
INSERT INTO staging.icd9 (code, description) VALUES ('6828', 'OTHER SPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('6829', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('683', 'ACUTE LYMPHADENITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('684', 'IMPETIGO');
INSERT INTO staging.icd9 (code, description) VALUES ('685', 'PILONIDAL CYST');
INSERT INTO staging.icd9 (code, description) VALUES ('6850', 'WITH ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('6851', 'WITHOUT MENTION OF ABSCESS');
INSERT INTO staging.icd9 (code, description) VALUES ('686', 'OTHER LOCAL INFECTIONS OF SKIN AND SUBCUTANEOUS TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('6860', 'PYODERMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6861', 'PYOGENIC GRANULOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6868', 'OTHER LOCAL INFECTIONS OF SKIN AND SUBCUTANEOUS TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('6869', 'UNSPECIFIED LOCAL INFECTIONS OF SKIN AND SUBCUTANEOUS TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('690', 'ERYTHEMATOSQUAMOUS DERMATOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('691', 'ATOPIC DERMATITIS AND RELATED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6910', 'DIAPER OR NAPKIN RASH');
INSERT INTO staging.icd9 (code, description) VALUES ('6918', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('692', 'CONTACT DERMATITIS AND OTHER ECZEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6920', 'DUE TO DETERGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6921', 'DUE TO OILS AND GREASES');
INSERT INTO staging.icd9 (code, description) VALUES ('6922', 'DUE TO SOLVENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6923', 'DUE TO DRUGS AND MEDICAMENTS IN CONTACT WITH SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6924', 'DUE TO OTHER CHEMICAL PRODUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6925', 'DUE TO FOOD IN CONTACT WITH SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('6926', 'DUE TO PLANTS (EXCEPT FOOD)');
INSERT INTO staging.icd9 (code, description) VALUES ('6927', 'DUE TO SOLAR RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('6928', 'DUE TO OTHER SPECIFIED AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6929', 'UNSPECIFIED CAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('693', 'DERMATITIS DUE TO SUBSTANCES TAKEN INTERNALLY');
INSERT INTO staging.icd9 (code, description) VALUES ('6930', 'DUE TO DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('6931', 'DUE TO FOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('6938', 'DUE TO OTHER SPECIFIED SUBSTANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('6939', 'DUE TO UNSPECIFIED SUBSTANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('694', 'BULLOUS DERMATOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('6940', 'DERMATITIS HERPETIFORMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6941', 'SUBCORNEAL PUSTULAR DERMATOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6942', 'JUVENILE DERMATITIS HERPETIFORMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6943', 'IMPETIGO HERPETIFORMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6944', 'PEMPHIGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6945', 'PEMPHIGOID');
INSERT INTO staging.icd9 (code, description) VALUES ('6946', 'BENIGN MUCOUS MEMBRANE PEMPHIGOID');
INSERT INTO staging.icd9 (code, description) VALUES ('6948', 'OTHER BULLOUS DERMATOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('6949', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('695', 'ERYTHEMATOUS CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6950', 'TOXIC ERYTHEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('6951', 'ERYTHEMA MULTIFORME');
INSERT INTO staging.icd9 (code, description) VALUES ('6952', 'ERYTHEMA NODOSUM');
INSERT INTO staging.icd9 (code, description) VALUES ('6953', 'ROSACEA');
INSERT INTO staging.icd9 (code, description) VALUES ('6954', 'LUPUS ERYTHEMATOSUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6958', 'OTHER ERYTHEMATOUS CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6959', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('696', 'PSORIASIS AND SIMILAR DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('6960', 'PSORIATIC ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('6961', 'OTHER PSORIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6962', 'PARAPSORIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6963', 'PITYRIASIS ROSEA');
INSERT INTO staging.icd9 (code, description) VALUES ('6964', 'PITYRIASIS RUBRA PILARIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6965', 'OTHER AND UNSPECIFIED PITYRIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('6968', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('697', 'LICHEN');
INSERT INTO staging.icd9 (code, description) VALUES ('6970', 'LICHEN PLANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6971', 'LICHEN NITIDUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6978', 'OTHER LICHEN, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('6979', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('698', 'PRURITIS AND RELATED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6980', 'PRURITIS ANI');
INSERT INTO staging.icd9 (code, description) VALUES ('6981', 'PRURITIS OF GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('6982', 'PRURIGO');
INSERT INTO staging.icd9 (code, description) VALUES ('6983', 'LICHENIFICATION AND LICHEN SIMPLEX CHRONICUS');
INSERT INTO staging.icd9 (code, description) VALUES ('6984', 'DERMATITIS FACTITIA (ARTEFACTA)');
INSERT INTO staging.icd9 (code, description) VALUES ('6988', 'OTHER PRURITIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('6989', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('700', 'CORNS AND CALLOSITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('701', 'OTHER HYPERTROPHIC AND ATROPHIC CONDITIONS OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7010', 'CIRCUMSCRIBED SCLERODERMA');
INSERT INTO staging.icd9 (code, description) VALUES ('7011', 'KERATODERMA, ACQUIRED');
INSERT INTO staging.icd9 (code, description) VALUES ('7012', 'ACQUIRED ACANTHOSIS NIGRICANS');
INSERT INTO staging.icd9 (code, description) VALUES ('7013', 'STRIAE ATROPHICAE');
INSERT INTO staging.icd9 (code, description) VALUES ('7014', 'KELOID SCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('7015', 'OTHER ABNORMAL GRANULATION TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7018', 'OTHER HYPERTROPHIC AND ATROPHIC CONDITIONS OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('702', 'OTHER DERMATOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('703', 'DISEASES OF NAIL');
INSERT INTO staging.icd9 (code, description) VALUES ('7030', 'INGROWING NAIL');
INSERT INTO staging.icd9 (code, description) VALUES ('7038', 'OTHER DISEASES OF NAIL');
INSERT INTO staging.icd9 (code, description) VALUES ('7039', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('704', 'DISEASES OF HAIR AND HAIR FOLLICLES');
INSERT INTO staging.icd9 (code, description) VALUES ('7040', 'ALOPECIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7041', 'HIRSUTISM');
INSERT INTO staging.icd9 (code, description) VALUES ('7042', 'ABNORMALITIES OF THE HAIR');
INSERT INTO staging.icd9 (code, description) VALUES ('7043', 'VARIATIONS IN HAIR COLOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('7048', 'OTHER DISEASES OF HAIR AND HAIR FOLLICLES');
INSERT INTO staging.icd9 (code, description) VALUES ('7049', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('705', 'DISORDERS OF SWEAT GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7050', 'ANHIDROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7051', 'PRICKLY HEAT');
INSERT INTO staging.icd9 (code, description) VALUES ('7058', 'OTHER DISORDERS OF SWEAT GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7059', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('706', 'DISEASES OF SEBACEOUS GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7060', 'ACNE VARIOLIFORMIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7061', 'OTHER ACNE');
INSERT INTO staging.icd9 (code, description) VALUES ('7062', 'SEBACEOUS CYST');
INSERT INTO staging.icd9 (code, description) VALUES ('7063', 'SEBORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('7068', 'OTHER DISORDERS OF SEBACEOUS GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7069', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('707', 'CHRONIC ULCER OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7070', 'DECUBITUS ULCER');
INSERT INTO staging.icd9 (code, description) VALUES ('7071', 'ULCER OF LOWER LIMBS, EXCEPT DECUBITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7078', 'CHRONIC ULCER OF OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('7079', 'CHRONIC ULCER OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('708', 'URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7080', 'ALLERGIC URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7081', 'IDIOPATHIC URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7082', 'URTICARIA DUE TO COLD AND HEAT');
INSERT INTO staging.icd9 (code, description) VALUES ('7083', 'DERMATOGRAPHIC URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7084', 'VIBRATORY URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7085', 'CHOLINERGIC URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7088', 'OTHER SPECIFIED URTICARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7089', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('709', 'OTHER DISORDERS OF SKIN AND SUBCUTANEOUS TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7090', 'DYSCHROMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7091', 'VASCULAR DISORDERS OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7092', 'SCAR CONDITIONS AND FIBROSIS OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7093', 'DEGENERATIVE SKIN DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7094', 'FOREIGN BODY GRANULOMA OF SKIN AND SUBCUTANEOUS TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7098', 'OTHER DISEASES OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7099', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('710', 'DIFFUSE DISEASES OF CONNECTIVE TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7100', 'SYSTEMIC LUPUS ERYTHEMATOSUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7101', 'SYSTEMIC SCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7102', 'SICCA SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7103', 'DERMATOMYOSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7104', 'POLYMYOSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7108', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7109', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('711', 'ARTHROPATHY ASSOCIATED WITH INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7110', 'PYOGENIC ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7111*', 'ARTHROPATHY IN REITER''S DISEASE AND ALLIED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7112*', 'ARTHROPATHY IN BEHCET''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7113*', 'POSTDYSENTERIC ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7114*', 'ARTHROPATHY ASSOCIATED WITH OTHER BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('7115*', 'ARTHROPATHY ASSOCIATED WITH OTHER VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('7116*', 'ARTHROPATHY ASSOCIATED WITH MYCOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('7117*', 'ARTHROPATHY ASSOCIATED WITH HELMINTHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7118*', 'ARTHROPATHY ASSOCIATED WITH OTHER INFECTIOUS AND PARASITIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('7119', 'UNSPECIFIED INFECTIVE ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('712', 'CRYSTAL ARTHROPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7120*', 'GOUTY ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7121*', 'CHONDROCALCINOSIS DUE TO DICALCIUM PHOSPHATE CRYSTALS');
INSERT INTO staging.icd9 (code, description) VALUES ('7122*', 'CHONDROCALCINOSIS DUE TO PYROPHOSPHATE CRYSTALS');
INSERT INTO staging.icd9 (code, description) VALUES ('7123*', 'CHONDROCALCINOSIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7128', 'OTHER CRYSTAL ARTHROPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7129', 'UNSPECIFIED CRYSTAL ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('713', 'ARTHROPATHY ASSOCIATED WITH OTHER DISORDERS CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('7130*', 'ARTHROPATHY ASSOCIATED WITH OTHER ENDOCRINE AND METABOLIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7131*', 'ARTHROPATHY ASSOCIATED WITH GASTROINTESTINAL CONDITIONS OTHER THAN INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7132*', 'ARTHROPATHY ASSOCIATED WITH HAEMATOLOGICAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7133*', 'ARTHROPATHY ASSOCIATED WITH DERMATOLOGICAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7134*', 'ARTHROPATHY ASSOCIATED WITH RESPIRATORY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7135*', 'ARTHROPATHY ASSOCIATED WITH NEUROLOGICAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7136*', 'ARTHROPATHY ASSOCIATED WITH HYPERSENSITIVITY REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7137*', 'OTHER GENERAL DISEASES WITH ARTICULAR INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7138*', 'ARTHROPATHY ASSOCIATED WITH OTHER CONDITIONS CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('714', 'RHEUMATOID ARTHRITIS AND OTHER INFLAMMATORY POLYARTHROPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7140', 'RHEUMATOID ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7141', 'FELTY''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7142', 'OTHER RHEUMATOID ARTHRITIS WITH VISCERAL OR SYSTEMIC INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7143', 'JUVENILE CHRONIC POLYARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7144', 'CHRONIC POSTRHEUMATIC ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7148', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7149', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('715', 'OSTEOARTHROSIS AND ALLIED DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7150', 'GENERALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('7151', 'LOCALIZED, PRIMARY');
INSERT INTO staging.icd9 (code, description) VALUES ('7152', 'LOCALIZED, SECONDARY');
INSERT INTO staging.icd9 (code, description) VALUES ('7153', 'LOCALIZED, NOT SPECIFIED WHETHER PRIMARY OR SECONDARY');
INSERT INTO staging.icd9 (code, description) VALUES ('7158', 'INVOLVING OR WITH MENTION OF MORE THAN ONE SITE BUT NOT SPECIFIED AS GENERALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('7159', 'UNSPECIFIED WHETHER GENERALIZED OR LOCALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('716', 'OTHER AND UNSPECIFIED ARTHROPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7160', 'KASCHIN-BECK DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('7161', 'TRAUMATIC ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7162', 'ALLERGIC ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7163', 'CLIMACTERIC ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7164', 'TRANSIENT ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7165', 'UNSPECIFIED POLYARTHROPATHY OR POLYARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7166', 'UNSPECIFIED MONOARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7168', 'OTHER SPECIFIED ARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7169', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('717', 'INTERNAL DERANGEMENT OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('7170', 'OLD BUCKET HANDLE TEAR OF MEDIAL MENISCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7171', 'DERANGEMENT OF ANTERIOR HORN OF MEDIAL MENISCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7172', 'DERANGEMENT OF POSTERIOR HORN OF MEDIAL MENISCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7173', 'OTHER AND UNSPECIFIED DERANGEMENT OF MEDIAL MENISCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7174', 'DERANGEMENT OF LATERAL MENISCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7175', 'DERANGEMENT OF MENISCUS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7176', 'LOOSE BODY IN KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('7177', 'CHONDROMALACIA PATELLAE');
INSERT INTO staging.icd9 (code, description) VALUES ('7178', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7179', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('718', 'OTHER DERANGEMENT OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7180', 'ARTICULAR CARTILAGE DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('7181', 'LOOSE BODY IN JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7182', 'PATHOLOGICAL DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7183', 'RECURRENT DISLOCATION OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7184', 'CONTRACTURE OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7185', 'ANKYLOSIS OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7186', 'UNSPECIFIED PROTRUSIO ACETABULI');
INSERT INTO staging.icd9 (code, description) VALUES ('7188', 'OTHER JOINT DERANGEMENT NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7189', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('719', 'OTHER AND UNSPECIFIED DISORDER OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7190', 'EFFUSION OF JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7191', 'HAEMARTHROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7192', 'VILLONODULAR SYNOVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7193', 'PALINDROMIC RHEUMATISM');
INSERT INTO staging.icd9 (code, description) VALUES ('7194', 'PAIN IN JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7195', 'STIFFNESS OF JOINT, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7196', 'OTHER SYMPTOMS REFERABLE TO JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('7197', 'DIFFICULTY IN WALKING');
INSERT INTO staging.icd9 (code, description) VALUES ('7198', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7199', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('720', 'ANKYLOSING SPONDYLITIS AND OTHER INFLAMMATORY SPONDYLOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7200', 'ANKYLOSING SPONDYLITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7201', 'SPINAL ENTHESOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7202', 'SACROILIITIS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7208', 'OTHER INFLAMMATORY SPONDYLOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7209', 'UNSPECIFIED INFLAMMATORY SPONDYLOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('721', 'SPONDYLOSIS AND ALLIED DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7210', 'CERVICAL SPONDYLOSIS WITHOUT MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7211', 'CERVICAL SPONDYLOSIS WITH MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7212', 'THORACIC SPONDYLOSIS WITHOUT MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7213', 'LUMBOSACRAL SPONDYLOSIS WITHOUT MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7214', 'THORACIC OR LUMBAR SPONDYLOSIS WITH MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7215', 'KISSING SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7216', 'ANKYLOSING VERTEBRAL HYPEROSTOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7217', 'TRAUMATIC SPONDYLOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7218', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7219', 'SPONDYLOSIS OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('722', 'INTERVERTEBRAL DISC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7220', 'DISPLACEMENT OF CERVICAL INTERVERTEBRAL DISC WITHOUT MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7221', 'DISPLACEMENT OF THORACIC OR LUMBAR INTERVERTEBRAL DISC WITHOUT MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7222', 'DISPLACEMENT OF INTERVERTEBRAL DISC, SITE UNSPECIFIED, WITHOUT MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7223', 'SCHMORL''S NODES');
INSERT INTO staging.icd9 (code, description) VALUES ('7224', 'DEGENERATION OF CERVICAL INTERVERTEBRAL DISC');
INSERT INTO staging.icd9 (code, description) VALUES ('7225', 'DEGENERATION OF THORACIC OR LUMBAR INTERVERTEBRAL DISC');
INSERT INTO staging.icd9 (code, description) VALUES ('7226', 'DEGENERATION OF INTERVERTEBRAL DISC, SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7227', 'INTERVERTEBRAL DISC DISORDER WITH MYELOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7228', 'POSTLAMINECTOMY SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7229', 'OTHER AND UNSPECIFIED DISC DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('723', 'OTHER DISORDERS OF CERVICAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7230', 'SPINAL STENOSIS IN CERVICAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7231', 'CERVICALGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7232', 'CERVICOCRANIAL SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7233', 'CERVICOBRACHIAL SYNDROME (DIFFUSE)');
INSERT INTO staging.icd9 (code, description) VALUES ('7234', 'BRACHIAL NEURITIS OR RADICULITIS NOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7235', 'TORTICOLLIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7236', 'PANNICULITIS SPECIFIED AS AFFECTING NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7237', 'OSSIFICATION OF POSTERIOR LONGITUDINAL LIGAMENT IN CERVICAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7238', 'OTHER SYNDROMES AFFECTING CERVICAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7239', 'UNSPECIFIED DISORDERS AND SYMPTOMS REFERABLE TO NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('724', 'OTHER AND UNSPECIFIED DISORDERS OF BACK');
INSERT INTO staging.icd9 (code, description) VALUES ('7240', 'SPINAL STENOSIS, OTHER THAN CERVICAL');
INSERT INTO staging.icd9 (code, description) VALUES ('7241', 'PAIN IN THORACIC SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7242', 'LUMBAGO');
INSERT INTO staging.icd9 (code, description) VALUES ('7243', 'SCIATICA');
INSERT INTO staging.icd9 (code, description) VALUES ('7244', 'THORACIC OR LUMBOSACRAL NEURITIS OR RADICULITIS NOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7245', 'BACKACHE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7246', 'DISORDERS OF SACRUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7247', 'DISORDERS OF COCCYX');
INSERT INTO staging.icd9 (code, description) VALUES ('7248', 'OTHER SYMPTOMS REFERABLE TO BACK');
INSERT INTO staging.icd9 (code, description) VALUES ('7249', 'UNSPECIFIED BACK DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('725', 'POLYMYALGIA RHEUMATICA');
INSERT INTO staging.icd9 (code, description) VALUES ('726', 'PERIPHERAL ENTHESOPATHIES AND ALLIED SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('7260', 'ADHESIVE CAPSULITIS OF SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('7261', 'ROTATOR CUFF SYNDROME OF SHOULDER, AND ALLIED DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7262', 'OTHER AFFECTIONS OF SHOULDER REGION, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7263', 'ENTHESOPATHY OF ELBOW REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7264', 'ENTHESOPATHY OF WRIST AND CARPUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7265', 'ENTHESOPATHY OF HIP REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7266', 'ENTHESOPATHY OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('7267', 'ENTHESOPATHY OF ANKLE AND TARSUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7268', 'OTHER PERIPHERAL ENTHESOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7269', 'UNSPECIFIED ENTHESOPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('727', 'OTHER DISORDERS OF SYNOVIUM, TENDON AND BURSA');
INSERT INTO staging.icd9 (code, description) VALUES ('7270', 'SYNOVITIS AND TENOSYNOVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7271', 'BUNION');
INSERT INTO staging.icd9 (code, description) VALUES ('7272', 'SPECIFIC BURSITIDES OFTEN OF OCCUPATIONAL ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7273', 'OTHER BURSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7274', 'GANGLION AND CYST OF SYNOVIUM, TENDON AND BURSA');
INSERT INTO staging.icd9 (code, description) VALUES ('7275', 'RUPTURE OF SYNOVIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7276', 'RUPTURE OF TENDON, NONTRAUMATIC');
INSERT INTO staging.icd9 (code, description) VALUES ('7278', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7279', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('728', 'DISORDERS OF MUSCLE, LIGAMENT AND FASCIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7280', 'INFECTIVE MYOSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7281', 'MUSCULAR CALCIFICATION AND OSSIFICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7282', 'MUSCULAR WASTING AND DISUSE ATROPHY, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7283', 'OTHER SPECIFIC MUSCLE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7284', 'LAXITY OF LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7285', 'HYPERMOBILITY SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7286', 'CONTRACTURE OF PALMAR FASCIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7287', 'OTHER FIBROMATOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('7288', 'OTHER DISORDERS OF MUSCLE, LIGAMENT AND FASCIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7289', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('729', 'OTHER DISORDERS OF SOFT TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('7290', 'RHEUMATISM, UNSPECIFIED, AND FIBROSITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7291', 'MYALGIA AND MYOSITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7292', 'NEURALGIA, NEURITIS AND RADICULITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7293', 'PANNICULITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7294', 'FASCIITIS, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7295', 'PAIN IN LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('7296', 'RESIDUAL FOREIGN BODY IN SOFT TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7298', 'OTHER SYMPTOMS REFERABLE TO LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('7299', 'OTHER AND UNSPECIFIED DISORDERS OF SOFT TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('730', 'OSTEOMYELITIS, PERIOSTITIS AND OTHER INFECTIONS INVOLVING BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('7300', 'ACUTE OSTEOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7301', 'CHRONIC OSTEOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7302', 'UNSPECIFIED OSTEOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7303', 'PERIOSTITIS WITHOUT MENTION OF OSTEOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7304*', 'TUBERCULOSIS OF SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7305*', 'TUBERCULOSIS OF LIMB BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('7306*', 'TUBERCULOSIS OF OTHER BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('7307*', 'OSTEOPATHY RESULTING FROM POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7308*', 'OTHER INFECTIONS INVOLVING BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('7309', 'UNSPECIFIED INFECTION OF BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('731', 'OSTEITIS DEFORMANS AND OSTEOPATHIES ASSOCIATED WITH OTHER DISORDERS CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('7310', 'OSTEITIS DEFORMANS WITHOUT MENTION OF BONE TUMOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('7311*', 'OSTEITIS DEFORMANS IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('7312', 'HYPERTROPHIC PULMONARY OSTEOARTHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7318*', 'OTHER BONE INVOLVEMENT IN DISEASES CLASSIFIED ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('732', 'OSTEOCHONDROPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7320', 'JUVENILE OSTEOCHONDROSIS OF SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7321', 'JUVENILE OSTEOCHONDROSIS OF HIP AND PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7322', 'NONTRAUMATIC SLIPPED UPPER FEMORAL EPIPHYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7323', 'JUVENILE OSTEOCHONDROSIS OF UPPER EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('7324', 'JUVENILE OSTEOCHONDROSIS OF LOWER EXTREMITY, EXCLUDING FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('7325', 'JUVENILE OSTEOCHONDROSIS OF FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('7326', 'OTHER JUVENILE OSTEOCHONDROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7327', 'OSTEOCHONDRITIS DISSECANS');
INSERT INTO staging.icd9 (code, description) VALUES ('7328', 'OTHER SPECIFIED FORMS OF OSTEOCHONDROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7329', 'UNSPECIFIED OSTEOCHONDROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('733', 'OTHER DISORDERS OF BONE AND CARTILAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7330', 'OSTEOPOROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7331', 'PATHOLOGICAL FRACTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('7332', 'CYST OF BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('7333', 'HYPEROSTOSIS OF SKULL');
INSERT INTO staging.icd9 (code, description) VALUES ('7334', 'ASEPTIC NECROSIS OF BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('7335', 'OSTEITIS CONDENSANS');
INSERT INTO staging.icd9 (code, description) VALUES ('7336', 'TIETZE''S DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('7337', 'ALGONEURODYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7338', 'MALUNION AND NONUNION OF FRACTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('7339', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('734', 'FLAT FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('735', 'ACQUIRED DEFORMITIES OF TOE');
INSERT INTO staging.icd9 (code, description) VALUES ('7350', 'HALLUX VALGUS (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7351', 'HALLUX VARUS (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7352', 'HALLUX RIGIDUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7353', 'HALLUX MALLEUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7354', 'OTHER HAMMER TOE (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7355', 'CLAWTOE (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7358', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7359', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('736', 'OTHER ACQUIRED DEFORMITIES OF LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('7360', 'ACQUIRED DEFORMITIES OF FOREARM, EXCLUDING FINGERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7361', 'MALLET FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('7362', 'OTHER ACQUIRED DEFORMITIES OF FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('7363', 'ACQUIRED DEFORMITIES OF HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('7364', 'GENU VALGUM OR VARUM (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7365', 'GENU RECURVATUM (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7366', 'OTHER ACQUIRED DEFORMITIES OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('7367', 'OTHER ACQUIRED DEFORMITIES OF ANKLE AND FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('7368', 'ACQUIRED DEFORMITIES OF OTHER PARTS OF LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('7369', 'ACQUIRED DEFORMITY OF LIMB, SITE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('737', 'CURVATURE OF SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7370', 'ADOLESCENT POSTURAL KYPHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7371', 'KYPHOSIS (ACQUIRED)');
INSERT INTO staging.icd9 (code, description) VALUES ('7372', 'LORDOSIS (ACQUIRED) (POSTURAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('7373', 'KYPHOSCOLIOSIS AND SCOLIOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7374*', 'CURVATURE OF SPINE ASSOCIATED WITH OTHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7378', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7379', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('738', 'OTHER ACQUIRED DEFORMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('7380', 'ACQUIRED DEFORMITY OF NOSE');
INSERT INTO staging.icd9 (code, description) VALUES ('7381', 'OTHER ACQUIRED DEFORMITY OF HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('7382', 'ACQUIRED DEFORMITY OF NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7383', 'ACQUIRED DEFORMITY OF CHEST AND RIB');
INSERT INTO staging.icd9 (code, description) VALUES ('7384', 'ACQUIRED SPONDYLOLISTHESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7385', 'OTHER ACQUIRED DEFORMITY OF BACK OR SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7386', 'ACQUIRED DEFORMITY OF PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7387', 'CAULIFLOWER EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('7388', 'ACQUIRED DEFORMITY OF OTHER SPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('7389', 'ACQUIRED DEFORMITY OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('739', 'NONALLOPATHIC LESIONS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7390', 'HEAD REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7391', 'CERVICAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7392', 'THORACIC REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7393', 'LUMBAR REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7394', 'SACRAL REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7395', 'PELVIC REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('7396', 'LOWER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7397', 'UPPER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7398', 'RIB CAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7399', 'ABDOMEN AND OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('740', 'ANENCEPHALUS AND SIMILAR ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7400', 'ANENCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7401', 'CRANIORACHISCHISIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7402', 'INIENCEPHALY');
INSERT INTO staging.icd9 (code, description) VALUES ('741', 'SPINA BIFIDA');
INSERT INTO staging.icd9 (code, description) VALUES ('7410', 'WITH HYDROCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7419', 'WITHOUT MENTION OF HYDROCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('742', 'OTHER CONGENITAL ANOMALIES OF NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7420', 'ENCEPHALOCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('7421', 'MICROCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7422', 'REDUCTION DEFORMITIES OF BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7423', 'CONGENITAL HYDROCEPHALUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7424', 'OTHER SPECIFIED ANOMALIES OF BRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7425', 'OTHER SPECIFIED ANOMALIES OF SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('7428', 'OTHER SPECIFIED ANOMALIES OF NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7429', 'UNSPECIFIED ANOMALIES OF BRAIN, SPINAL CORD AND NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('743', 'CONGENITAL ANOMALIES OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('7430', 'ANOPHTHALMOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7431', 'MICROPHTHALMOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7432', 'BUPHTHALMOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7433', 'CONGENITAL CATARACT AND LENS ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7434', 'COLOBOMA AND OTHER ANOMALIES OF ANTERIOR SEGMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('7435', 'CONGENITAL ANOMALIES OF POSTERIOR SEGMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7436', 'CONGENITAL ANOMALIES OF EYELIDS, LACRIMAL SYSTEM AND ORBIT');
INSERT INTO staging.icd9 (code, description) VALUES ('7438', 'OTHER SPECIFIED ANOMALIES OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('7439', 'UNSPECIFIED ANOMALIES OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('744', 'CONGENITAL ANOMALIES OF EAR, FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7440', 'ANOMALIES OF EAR CAUSING IMPAIRMENT OF HEARING');
INSERT INTO staging.icd9 (code, description) VALUES ('7441', 'ACCESSORY AURICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7442', 'OTHER SPECIFIED ANOMALIES OF EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('7443', 'UNSPECIFIED ANOMALIES OF EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('7444', 'BRANCHIAL CLEFT, CYST OR FISTULA; PREAURICULAR SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7445', 'WEBBING OF NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7448', 'OTHER SPECIFIED ANOMALIES OF FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7449', 'UNSPECIFIED ANOMALIES OF FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('745', 'BULBUS CORDIS ANOMALIES AND ANOMALIES OF CARDIAC SEPTAL CLOSURE');
INSERT INTO staging.icd9 (code, description) VALUES ('7450', 'COMMON TRUNCUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7451', 'TRANSPOSITION OF GREAT VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('7452', 'TETRALOGY OF FALLOT');
INSERT INTO staging.icd9 (code, description) VALUES ('7453', 'COMMON VENTRICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7454', 'VENTRICULAR SEPTAL DEFECT');
INSERT INTO staging.icd9 (code, description) VALUES ('7455', 'OSTIUM SECUNDUM TYPE ATRIAL SEPTAL DEFECT');
INSERT INTO staging.icd9 (code, description) VALUES ('7456', 'ENDOCARDIAL CUSHION DEFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('7457', 'COR BILOCULARE');
INSERT INTO staging.icd9 (code, description) VALUES ('7458', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7459', 'UNSPECIFIED DEFECT OF SEPTAL CLOSURE');
INSERT INTO staging.icd9 (code, description) VALUES ('746', 'OTHER CONGENITAL ANOMALIES OF HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('7460', 'ANOMALIES OF PULMONARY VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('7461', 'TRICUSPID ATRESIA AND STENOSIS, CONGENITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('7462', 'EBSTEIN''S ANOMALY');
INSERT INTO staging.icd9 (code, description) VALUES ('7463', 'CONGENITAL STENOSIS OF AORTIC VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('7464', 'CONGENITAL INSUFFICIENCY OF AORTIC VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('7465', 'CONGENITAL MITRAL STENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7466', 'CONGENITAL MITRAL INSUFFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('7467', 'HYPOPLASTIC LEFT HEART SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7468', 'OTHER SPECIFIED ANOMALIES OF HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('7469', 'UNSPECIFIED ANOMALIES OF HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('747', 'OTHER CONGENITAL ANOMALIES OF CIRCULATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7470', 'PATENT DUCTUS ARTERIOSUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7471', 'COARCTATION OF AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('7472', 'OTHER ANOMALIES OF AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('7473', 'ANOMALIES OF PULMONARY ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7474', 'ANOMALIES OF GREAT VEINS');
INSERT INTO staging.icd9 (code, description) VALUES ('7475', 'ABSENCE OR HYPOPLASIA OF UMBILICAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7476', 'OTHER ANOMALIES OF PERIPHERAL VASCULAR SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7478', 'OTHER SPECIFIED ANOMALIES OF CIRCULATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7479', 'UNSPECIFIED ANOMALIES OF CIRCULATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('748', 'CONGENITAL ANOMALIES OF RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7480', 'CHOANAL ATRESIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7481', 'OTHER ANOMALIES OF NOSE');
INSERT INTO staging.icd9 (code, description) VALUES ('7482', 'WEB OF LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('7483', 'OTHER ANOMALIES OF LARYNX, TRACHEA AND BRONCHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7484', 'CONGENITAL CYSTIC LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('7485', 'AGENESIS, HYPOPLASIA AND DYSPLASIA OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('7486', 'OTHER ANOMALIES OF LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('7488', 'OTHER SPECIFIED ANOMALIES OF RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7489', 'UNSPECIFIED ANOMALIES OF RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('749', 'CLEFT PALATE AND CLEFT LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('7490', 'CLEFT PALATE');
INSERT INTO staging.icd9 (code, description) VALUES ('7491', 'CLEFT LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('7492', 'CLEFT PALATE WITH CLEFT LIP');
INSERT INTO staging.icd9 (code, description) VALUES ('750', 'OTHER CONGENITAL ANOMALIES OF UPPER ALIMENTARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('7500', 'TONGUE TIE');
INSERT INTO staging.icd9 (code, description) VALUES ('7501', 'OTHER ANOMALIES OF TONGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7502', 'OTHER SPECIFIED ANOMALIES OF MOUTH AND PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('7503', 'TRACHEO-OESOPHAGEAL FISTULA, OESOPHAGEAL ATRESIA AND STENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7504', 'OTHER SPECIFIED ANOMALIES OF OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7505', 'CONGENITAL HYPERTROPHIC PYLORIC STENOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7506', 'CONGENITAL HIATUS HERNIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7507', 'OTHER SPECIFIED ANOMALIES OF STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('7508', 'OTHER SPECIFIED ANOMALIES OF UPPER ALIMENTARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('7509', 'UNSPECIFIED ANOMALIES OF UPPER ALIMENTARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('751', 'OTHER CONGENITAL ANOMALIES OF DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7510', 'MECKEL''S DIVERTICULUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7511', 'ATRESIA AND STENOSIS OF SMALL INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7512', 'ATRESIA AND STENOSIS OF LARGE INTESTINE, RECTUM AND ANAL CANAL');
INSERT INTO staging.icd9 (code, description) VALUES ('7513', 'HIRSCHSPRUNG''S DISEASE AND OTHER CONGENITAL FUNCTIONAL DISORDERS OF COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('7514', 'ANOMALIES OF INTESTINAL FIXATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7515', 'OTHER ANOMALIES OF INTESTINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7516', 'ANOMALIES OF GALLBLADDER, BILE DUCTS AND LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('7517', 'ANOMALIES OF PANCREAS');
INSERT INTO staging.icd9 (code, description) VALUES ('7518', 'OTHER SPECIFIED ANOMALIES OF DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7519', 'UNSPECIFIED ANOMALIES OF DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('752', 'CONGENITAL ANOMALIES OF GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('7520', 'ANOMALIES OF OVARIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7521', 'ANOMALIES OF FALLOPIAN TUBES AND BROAD LIGAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('7522', 'DOUBLING OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7523', 'OTHER ANOMALIES OF UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7524', 'ANOMALIES OF CERVIX, VAGINA AND EXTERNAL FEMALE GENITALIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7525', 'UNDESCENDED TESTICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7526', 'HYPOSPADIAS AND EPISPADIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('7527', 'INDETERMINATE SEX AND PSEUDOHERMAPHRODITISM');
INSERT INTO staging.icd9 (code, description) VALUES ('7528', 'OTHER SPECIFIED ANOMALIES OF GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('7529', 'UNSPECIFIED ANOMALIES OF GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('753', 'CONGENITAL ANOMALIES OF URINARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7530', 'RENAL AGENESIS AND DYSGENESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7531', 'CYSTIC KIDNEY DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('7532', 'OBSTRUCTIVE DEFECTS OF RENAL PELVIS AND URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('7533', 'OTHER SPECIFIED ANOMALIES OF KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('7534', 'OTHER SPECIFIED ANOMALIES OF URETER');
INSERT INTO staging.icd9 (code, description) VALUES ('7535', 'EXSTROPHY OF URINARY BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('7536', 'ATRESIA AND STENOSIS OF URETHRA AND BLADDER NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7537', 'ANOMALIES OF URACHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7538', 'OTHER SPECIFIED ANOMALIES OF BLADDER AND URETHRA');
INSERT INTO staging.icd9 (code, description) VALUES ('7539', 'UNSPECIFIED ANOMALIES OF URINARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('754', 'CERTAIN CONGENITAL MUSCULOSKELETAL DEFORMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7540', 'OF SKULL, FACE AND JAW');
INSERT INTO staging.icd9 (code, description) VALUES ('7541', 'OF STERNOCLEIDOMASTOID MUSCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7542', 'OF SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7543', 'CONGENITAL DISLOCATION OF HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('7544', 'CONGENITAL GENU RECURVATUM AND BOWING OF LONG BONES OF LEG');
INSERT INTO staging.icd9 (code, description) VALUES ('7545', 'VARUS DEFORMITIES OF FEET');
INSERT INTO staging.icd9 (code, description) VALUES ('7546', 'VALGUS DEFORMITIES OF FEET');
INSERT INTO staging.icd9 (code, description) VALUES ('7547', 'OTHER DEFORMITIES OF FEET');
INSERT INTO staging.icd9 (code, description) VALUES ('7548', 'OTHER SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('755', 'OTHER CONGENITAL ANOMALIES OF LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('7550', 'POLYDACTYLY');
INSERT INTO staging.icd9 (code, description) VALUES ('7551', 'SYNDACTYLY');
INSERT INTO staging.icd9 (code, description) VALUES ('7552', 'REDUCTION DEFORMITIES OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('7553', 'REDUCTION DEFORMITIES OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('7554', 'REDUCTION DEFORMITIES, UNSPECIFIED LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('7555', 'OTHER ANOMALIES OF UPPER LIMB, INCLUDING SHOULDER GIRDLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7556', 'OTHER ANOMALIES OF LOWER LIMB, INCLUDING PELVIC GIRDLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7558', 'OTHER SPECIFIED ANOMALIES OF UNSPECIFIED LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('7559', 'UNSPECIFIED ANOMALIES OF UNSPECIFIED LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('756', 'OTHER CONGENITAL MUSCULOSKELETAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7560', 'ANOMALIES OF SKULL AND FACE BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('7561', 'ANOMALIES OF SPINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7562', 'CERVICAL RIB');
INSERT INTO staging.icd9 (code, description) VALUES ('7563', 'OTHER ANOMALIES OF RIBS AND STERNUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7564', 'CHONDRODYSTROPHY');
INSERT INTO staging.icd9 (code, description) VALUES ('7565', 'OSTEODYSTROPHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7566', 'ANOMALIES OF DIAPHRAGM');
INSERT INTO staging.icd9 (code, description) VALUES ('7567', 'ANOMALIES OF ABDOMINAL WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('7568', 'OTHER SPECIFIED ANOMALIES OF MUSCLE, TENDON, FASCIA AND CONNECTIVE TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7569', 'UNSPECIFIED ANOMALIES OF MUSCULOSKELETAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('757', 'CONGENITAL ANOMALIES OF THE INTEGUMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7570', 'HEREDITARY OEDEMA OF LEGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7571', 'ICHTHYOSIS CONGENITA');
INSERT INTO staging.icd9 (code, description) VALUES ('7572', 'DERMATOGLYPHIC ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7573', 'OTHER SPECIFIED ANOMALIES OF SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7574', 'SPECIFIED ANOMALIES OF HAIR');
INSERT INTO staging.icd9 (code, description) VALUES ('7575', 'SPECIFIED ANOMALIES OF NAILS');
INSERT INTO staging.icd9 (code, description) VALUES ('7576', 'SPECIFIED ANOMALIES OF BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('7578', 'OTHER SPECIFIED ANOMALIES OF THE INTEGUMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7579', 'UNSPECIFIED ANOMALIES OF THE INTEGUMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('758', 'CHROMOSOMAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7580', 'DOWN''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7581', 'PATAU''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7582', 'EDWARD''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7583', 'AUTOSOMAL DELETION SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('7584', 'BALANCED AUTOSOMAL TRANSLOCATION IN NORMAL INDIVIDUAL');
INSERT INTO staging.icd9 (code, description) VALUES ('7585', 'OTHER CONDITIONS DUE TO AUTOSOMAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7586', 'GONADAL DYSGENESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7587', 'KLINEFELTER''S SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7588', 'OTHER CONDITIONS DUE TO SEX CHROMOSOME ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7589', 'CONDITIONS DUE TO ANOMALY OF UNSPECIFIED CHROMOSOME');
INSERT INTO staging.icd9 (code, description) VALUES ('759', 'OTHER AND UNSPECIFIED CONGENITAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7590', 'ANOMALIES OF SPLEEN');
INSERT INTO staging.icd9 (code, description) VALUES ('7591', 'ANOMALIES OF ADRENAL GLAND');
INSERT INTO staging.icd9 (code, description) VALUES ('7592', 'ANOMALIES OF OTHER ENDOCRINE GLANDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7593', 'SITUS INVERSUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7594', 'CONJOINED TWINS');
INSERT INTO staging.icd9 (code, description) VALUES ('7595', 'TUBEROUS SCLEROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7596', 'OTHER HAMARTOSES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7597', 'MULTIPLE CONGENITAL ANOMALIES, SO DESCRIBED');
INSERT INTO staging.icd9 (code, description) VALUES ('7598', 'OTHER SPECIFIED ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7599', 'CONGENITAL ANOMALY, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('760', 'FETUS OR NEWBORN AFFECTED BY MATERNAL CONDITIONS WHICH MAY BE UNRELATED TO PRESENT PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('7600', 'MATERNAL HYPERTENSIVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7601', 'MATERNAL RENAL AND URINARY TRACT DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('7602', 'MATERNAL INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7603', 'OTHER CHRONIC MATERNAL CIRCULATORY AND RESPIRATORY DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('7604', 'MATERNAL NUTRITIONAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7605', 'MATERNAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('7606', 'SURGICAL OPERATION ON MOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7607', 'NOXIOUS INFLUENCES TRANSMITTED VIA PLACENTA OR BREAST MILK');
INSERT INTO staging.icd9 (code, description) VALUES ('7608', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('761', 'FETUS OR NEWBORN AFFECTED BY MATERNAL COMPLICATIONS OF PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('7610', 'INCOMPETENT CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('7611', 'PREMATURE RUPTURE OF MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('7612', 'OLIGOHYDRAMNIOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7613', 'POLYHYDRAMNIOS');
INSERT INTO staging.icd9 (code, description) VALUES ('7614', 'ECTOPIC PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('7615', 'MULTIPLE PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('7616', 'MATERNAL DEATH');
INSERT INTO staging.icd9 (code, description) VALUES ('7617', 'MALPRESENTATION BEFORE LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('7618', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7619', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('762', 'FETUS OR NEWBORN AFFECTED BY COMPLICATIONS OF PLACENTA, CORD AND MEMBRANES');
INSERT INTO staging.icd9 (code, description) VALUES ('7620', 'PLACENTA PRAEVIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7621', 'OTHER FORMS OF PLACENTAL SEPARATION AND HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7622', 'OTHER AND UNSPECIFIED MORPHOLOGICAL AND FUNCTIONAL ABNORMALITIES OF PLACENTA');
INSERT INTO staging.icd9 (code, description) VALUES ('7623', 'PLACENTAL TRANSFUSION SYNDROMES');
INSERT INTO staging.icd9 (code, description) VALUES ('7624', 'PROLAPSED CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('7625', 'OTHER COMPRESSION OF UMBILICAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('7626', 'OTHER AND UNSPECIFIED CONDITIONS OF UMBILICAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('7627', 'CHORIOAMNIONITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7628', 'OTHER ABNORMALITIES OF CHORION AND AMNION');
INSERT INTO staging.icd9 (code, description) VALUES ('7629', 'UNSPECIFIED ABNORMALITY OF CHORION AND AMNION');
INSERT INTO staging.icd9 (code, description) VALUES ('763', 'FETUS OR NEWBORN AFFECTED BY OTHER COMPLICATIONS OF LABOUR AND DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7630', 'BREECH DELIVERY AND EXTRACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7631', 'OTHER MALPRESENTATION, MALPOSITION AND DISPROPORTION DURING LABOUR AND DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7632', 'FORCEPS DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7633', 'DELIVERY BY VACUUM EXTRACTOR');
INSERT INTO staging.icd9 (code, description) VALUES ('7634', 'CAESAREAN DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7635', 'MATERNAL ANAESTHESIA AND ANALGESIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7636', 'PRECIPITATE DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7637', 'ABNORMAL UTERINE CONTRACTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7638', 'OTHER COMPLICATIONS OF LABOUR AND DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('764', 'SLOW FETAL GROWTH AND FETAL MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('7640', '"LIGHT-FOR-DATES" WITHOUT MENTION OF FETAL MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('7641', '"LIGHT-FOR-DATES" WITH SIGNS OF FETAL MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('7642', 'FETAL MALNUTRITION WITHOUT MENTION OF "LIGHT-FOR-DATES"');
INSERT INTO staging.icd9 (code, description) VALUES ('7649', 'FETAL GROWTH RETARDATION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('765', 'DISORDERS RELATING TO SHORT GESTATION AND UNSPECIFIED LOW BIRTHWEIGHT');
INSERT INTO staging.icd9 (code, description) VALUES ('7650', 'EXTREME IMMATURITY');
INSERT INTO staging.icd9 (code, description) VALUES ('7651', 'OTHER PRETERM INFANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('766', 'DISORDERS RELATING TO LONG GESTATION AND HIGH BIRTHWEIGHT');
INSERT INTO staging.icd9 (code, description) VALUES ('7660', 'EXCEPTIONALLY LARGE BABY');
INSERT INTO staging.icd9 (code, description) VALUES ('7661', 'OTHER "HEAVY-FOR-DATES" INFANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('7662', 'POST-TERM INFANT, NOT "HEAVY-FOR-DATES"');
INSERT INTO staging.icd9 (code, description) VALUES ('767', 'BIRTH TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('7670', 'SUBDURAL AND CEREBRAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7671', 'INJURIES TO SCALP');
INSERT INTO staging.icd9 (code, description) VALUES ('7672', 'FRACTURE OF CLAVICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('7673', 'OTHER INJURIES TO SKELETON');
INSERT INTO staging.icd9 (code, description) VALUES ('7674', 'INJURY TO SPINE AND SPINAL CORD');
INSERT INTO staging.icd9 (code, description) VALUES ('7675', 'FACIAL NERVE INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('7676', 'INJURY TO BRACHIAL PLEXUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7677', 'OTHER CRANIAL AND PERIPHERAL NERVE INJURIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7678', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7679', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('768', 'INTRAUTERINE HYPOXIA AND BIRTH ASPHYXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7680', 'FETAL DEATH FROM ASPHYXIA OR ANOXIA BEFORE ONSET OF LABOUR OR AT UNSPECIFIED TIME');
INSERT INTO staging.icd9 (code, description) VALUES ('7681', 'FETAL DEATH FROM ASPHYXIA OR ANOXIA DURING LABOUR');
INSERT INTO staging.icd9 (code, description) VALUES ('7682', 'FETAL DISTRESS BEFORE ONSET OF LABOUR, IN LIVEBORN INFANT');
INSERT INTO staging.icd9 (code, description) VALUES ('7683', 'FETAL DISTRESS FIRST NOTED DURING LABOUR, IN LIVEBORN INFANT');
INSERT INTO staging.icd9 (code, description) VALUES ('7684', 'FETAL DISTRESS, UNSPECIFIED, IN LIVEBORN INFANT');
INSERT INTO staging.icd9 (code, description) VALUES ('7685', 'SEVERE BIRTH ASPHYXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7686', 'MILD OR MODERATE BIRTH ASPHYXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7689', 'UNSPECIFIED BIRTH ASPHYXIA IN LIVEBORN INFANT');
INSERT INTO staging.icd9 (code, description) VALUES ('769', 'RESPIRATORY DISTRESS SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('770', 'OTHER RESPIRATORY CONDITIONS OF FETUS AND NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7700', 'CONGENITAL PNEUMONIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7701', 'MASSIVE ASPIRATION SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7702', 'INTERSTITIAL EMPHYSEMA AND RELATED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7703', 'PULMONARY HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7704', 'PRIMARY ATELECTASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7705', 'OTHER AND UNSPECIFIED ATELECTASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7706', 'TRANSITORY TACHYPNOEA OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7707', 'CHRONIC RESPIRATORY DISEASE ARISING IN THE PERINATAL PERIOD');
INSERT INTO staging.icd9 (code, description) VALUES ('7708', 'OTHER RESPIRATORY PROBLEMS AFTER BIRTH');
INSERT INTO staging.icd9 (code, description) VALUES ('7709', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('771', 'INFECTIONS SPECIFIC TO THE PERINATAL PERIOD');
INSERT INTO staging.icd9 (code, description) VALUES ('7710', 'CONGENITAL RUBELLA');
INSERT INTO staging.icd9 (code, description) VALUES ('7711', 'CONGENITAL CYTOMEGALOVIRUS INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7712', 'OTHER CONGENITAL INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7713', 'TETANUS NEONATORUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7714', 'OMPHALITIS OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7715', 'NEONATAL INFECTIVE MASTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7716', 'NEONATAL CONJUNCTIVITIS AND DACRYOCYSTITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7717', 'NEONATAL CANDIDA INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7718', 'OTHER INFECTION SPECIFIC TO THE PERINATAL PERIOD');
INSERT INTO staging.icd9 (code, description) VALUES ('772', 'FETAL AND NEONATAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7720', 'FETAL BLOOD LOSS');
INSERT INTO staging.icd9 (code, description) VALUES ('7721', 'INTRAVENTRICULAR HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7722', 'SUBARACHNOID HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7723', 'UMBILICAL HAEMORRHAGE AFTER BIRTH');
INSERT INTO staging.icd9 (code, description) VALUES ('7724', 'GASTROINTESTINAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7725', 'ADRENAL HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7726', 'CUTANEOUS HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7728', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7729', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('773', 'HAEMOLYTIC DISEASE OF FETUS OR NEWBORN, DUE TO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7730', 'HAEMOLYTIC DISEASE DUE TO RH ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7731', 'HAEMOLYTIC DISEASE DUE TO ABO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7732', 'HAEMOLYTIC DISEASE DUE TO OTHER AND UNSPECIFIED ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7733', 'HYDROPS FETALIS DUE TO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7734', 'KERNICTERUS DUE TO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7735', 'LATE ANAEMIA DUE TO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('774', 'OTHER PERINATAL JAUNDICE');
INSERT INTO staging.icd9 (code, description) VALUES ('7740*', 'PERINATAL JAUNDICE FROM HEREDITARY HAEMOLYTIC ANAEMIAS');
INSERT INTO staging.icd9 (code, description) VALUES ('7741', 'PERINATAL JAUNDICE FROM OTHER EXCESSIVE HAEMOLYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7742', 'NEONATAL JAUNDICE ASSOCIATED WITH PRETERM DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('7743', 'NEONATAL JAUNDICE DUE TO DELAYED CONJUGATION FROM OTHER CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('7744', 'PERINATAL JAUNDICE DUE TO HEPATOCELLULAR DAMAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7745', 'PERINATAL JAUNDICE FROM OTHER CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('7746', 'UNSPECIFIED FETAL AND NEONATAL JAUNDICE');
INSERT INTO staging.icd9 (code, description) VALUES ('7747', 'KERNICTERUS NOT DUE TO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('775', 'ENDOCRINE AND METABOLIC DISTURBANCES SPECIFIC TO THE FETUS AND NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7750', 'SYNDROME OF "INFANT OF A DIABETIC MOTHER"');
INSERT INTO staging.icd9 (code, description) VALUES ('7751', 'NEONATAL DIABETES MELLITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7752', 'NEONATAL MYASTHENIA GRAVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7753', 'NEONATAL THYROTOXICOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7754', 'HYPOCALCAEMIA AND HYPOMAGNESAEMIA OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7755', 'OTHER TRANSITORY NEONATAL ELECTROLYTE DISTURBANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('7756', 'NEONATAL HYPOGLYCAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7757', 'LATE METABOLIC ACIDOSIS OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7758', 'OTHER TRANSITORY NEONATAL ENDOCRINE AND METABOLIC DISTURBANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('7759', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('776', 'HAEMATOLOGICAL DISORDERS OF FETUS AND NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7760', 'HAEMORRHAGIC DISEASE OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7761', 'TRANSIENT NEONATAL THROMBOCYTOPENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7762', 'DISSEMINATED INTRAVASCULAR COAGULATION IN NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7763', 'OTHER TRANSIENT NEONATAL DISORDERS OF COAGULATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7764', 'POLYCYTHAEMIA NEONATORUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7765', 'CONGENITAL ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7766', 'ANAEMIA OF PREMATURITY');
INSERT INTO staging.icd9 (code, description) VALUES ('7767', 'TRANSIENT NEONATAL NEUTROPENIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7768', 'OTHER SPECIFIED TRANSIENT HAEMATOLOGICAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7769', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('777', 'PERINATAL DISORDERS OF DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7770*', 'MECONIUM ILEUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7771', 'OTHER MECONIUM OBSTRUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7772', 'INTESTINAL OBSTRUCTION DUE TO INSPISSATED MILK');
INSERT INTO staging.icd9 (code, description) VALUES ('7773', 'HAEMATEMESIS AND MELAENA DUE TO SWALLOWED MATERNAL BLOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('7774', 'TRANSITORY ILEUS OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7775', 'NECROTIZING ENTEROCOLITIS IN FETUS OR NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7776', 'PERINATAL INTESTINAL PERFORATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7778', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7779', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7913', 'MYOGLOBINURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('778', 'CONDITIONS INVOLVING THE INTEGUMENT AND TEMPERATURE REGULATION OF FETUS AND NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7780', 'HYDROPS FETALIS NOT DUE TO ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7781', 'SCLEREMA NEONATORUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7782', 'COLD INJURY SYNDROME OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7783', 'OTHER HYPOTHERMIA OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7784', 'OTHER DISTURBANCES OF TEMPERATURE REGULATION OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7785', 'OTHER AND UNSPECIFIED OEDEMA OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7786', 'CONGENITAL HYDROCELE');
INSERT INTO staging.icd9 (code, description) VALUES ('7787', 'BREAST ENGORGEMENT IN NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7788', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7789', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('779', 'OTHER AND ILL-DEFINED CONDITIONS ORIGINATING IN THE PERINATAL PERIOD');
INSERT INTO staging.icd9 (code, description) VALUES ('7790', 'CONVULSIONS IN NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7791', 'OTHER AND UNSPECIFIED CEREBRAL IRRITABILITY IN NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7792', 'CEREBRAL DEPRESSION, COMA AND OTHER ABNORMAL CEREBRAL SIGNS');
INSERT INTO staging.icd9 (code, description) VALUES ('7793', 'FEEDING PROBLEMS IN NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7794', 'DRUG REACTIONS AND INTOXICATIONS SPECIFIC TO NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7795', 'DRUG WITHDRAWAL SYNDROME IN NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7796', 'TERMINATION OF PREGNANCY (FETUS)');
INSERT INTO staging.icd9 (code, description) VALUES ('7798', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('7799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('780', 'GENERAL SYMPTOMS');
INSERT INTO staging.icd9 (code, description) VALUES ('7800', 'COMA AND STUPOR');
INSERT INTO staging.icd9 (code, description) VALUES ('7801', 'HALLUCINATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7802', 'SYNCOPE AND COLLAPSE');
INSERT INTO staging.icd9 (code, description) VALUES ('7803', 'CONVULSIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7804', 'DIZZINESS AND GIDDINESS');
INSERT INTO staging.icd9 (code, description) VALUES ('7805', 'SLEEP DISTURBANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('7806', 'PYREXIA OF UNKNOWN ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7807', 'MALAISE AND FATIGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7808', 'HYPERHIDROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7809', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('781', 'SYMPTOMS INVOLVING NERVOUS AND MUSCULOSKELETAL SYSTEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('7810', 'ABNORMAL INVOLUNTARY MOVEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('7811', 'DISTURBANCES OF SENSATION OF SMELL AND TASTE');
INSERT INTO staging.icd9 (code, description) VALUES ('7812', 'ABNORMALITY OF GAIT');
INSERT INTO staging.icd9 (code, description) VALUES ('7813', 'LACK OF COORDINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7814', 'TRANSIENT PARALYSIS OF LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('7815', 'CLUBBING OF FINGERS');
INSERT INTO staging.icd9 (code, description) VALUES ('7816', 'MENINGISMUS');
INSERT INTO staging.icd9 (code, description) VALUES ('7817', 'TETANY');
INSERT INTO staging.icd9 (code, description) VALUES ('7819', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('782', 'SYMPTOMS INVOLVING SKIN AND OTHER INTEGUMENTARY TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('7820', 'DISTURBANCE OF SKIN SENSATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7821', 'RASH AND OTHER NONSPECIFIC SKIN ERUPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7822', 'LOCALIZED SUPERFICIAL SWELLING, MASS OR LUMP');
INSERT INTO staging.icd9 (code, description) VALUES ('7823', 'OEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('7824', 'JAUNDICE UNSPECIFIED, NOT OF NEWBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('7825', 'CYANOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7826', 'PALLOR AND FLUSHING');
INSERT INTO staging.icd9 (code, description) VALUES ('7827', 'SPONTANEOUS ECCHYMOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('7828', 'CHANGES IN SKIN TEXTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('7829', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('783', 'SYMPTOMS CONCERNING NUTRITION, METABOLISM AND DEVELOPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7830', 'ANOREXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7831', 'ABNORMAL WEIGHT GAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7832', 'ABNORMAL LOSS OF WEIGHT');
INSERT INTO staging.icd9 (code, description) VALUES ('7833', 'FEEDING DIFFICULTIES AND MISMANAGEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7834', 'LACK OF EXPECTED NORMAL PHYSIOLOGICAL DEVELOPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('7835', 'POLYDIPSIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7836', 'POLYPHAGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7839', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('784', 'SYMPTOMS INVOLVING HEAD AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7840', 'HEADACHE');
INSERT INTO staging.icd9 (code, description) VALUES ('7841', 'THROAT PAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7842', 'SWELLING, MASS OR LUMP IN HEAD AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('7843', 'APHASIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7844', 'VOICE DISTURBANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('7845', 'OTHER SPEECH DISTURBANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('7846', 'OTHER SYMBOLIC DYSFUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('7847', 'EPISTAXIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7848', 'HAEMORRHAGE FROM THROAT');
INSERT INTO staging.icd9 (code, description) VALUES ('7849', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('785', 'SYMPTOMS INVOLVING CARDIOVASCULAR SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7850', 'TACHYCARDIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7851', 'PALPITATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7852', 'FUNCTIONAL AND UNDIAGNOSED CARDIAC MURMURS');
INSERT INTO staging.icd9 (code, description) VALUES ('7853', 'OTHER ABNORMAL HEART SOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7854', 'GANGRENE');
INSERT INTO staging.icd9 (code, description) VALUES ('7855', 'SHOCK WITHOUT MENTION OF TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('7856', 'ENLARGEMENT OF LYMPH NODES');
INSERT INTO staging.icd9 (code, description) VALUES ('7859', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('786', 'SYMPTOMS INVOLVING RESPIRATORY SYSTEM AND OTHER CHEST SYMPTOMS');
INSERT INTO staging.icd9 (code, description) VALUES ('7860', 'DYSPNOEA AND RESPIRATORY ABNORMALITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7861', 'STRIDOR');
INSERT INTO staging.icd9 (code, description) VALUES ('7862', 'COUGH');
INSERT INTO staging.icd9 (code, description) VALUES ('7863', 'HAEMOPTYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7864', 'ABNORMAL SPUTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7865', 'CHEST PAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7866', 'SWELLING, MASS OR LUMP IN CHEST');
INSERT INTO staging.icd9 (code, description) VALUES ('7867', 'ABNORMAL CHEST SOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7868', 'HICCOUGH');
INSERT INTO staging.icd9 (code, description) VALUES ('7869', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('787', 'SYMPTOMS INVOLVING DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7870', 'NAUSEA AND VOMITING');
INSERT INTO staging.icd9 (code, description) VALUES ('7871', 'HEARTBURN');
INSERT INTO staging.icd9 (code, description) VALUES ('7872', 'DYSPHAGIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7873', 'FLATULENCE, ERUCTATION AND GAS PAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7874', 'VISIBLE PERISTALSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7875', 'ABNORMAL BOWEL SOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('7876', 'INCONTINENCE OF FAECES');
INSERT INTO staging.icd9 (code, description) VALUES ('7877', 'ABNORMAL FAECES');
INSERT INTO staging.icd9 (code, description) VALUES ('7879', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('788', 'SYMPTOMS INVOLVING URINARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7880', 'RENAL COLIC');
INSERT INTO staging.icd9 (code, description) VALUES ('7881', 'DYSURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7882', 'RETENTION OF URINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7883', 'INCONTINENCE OF URINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7884', 'FREQUENCY OF URINATION AND POLYURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7885', 'OLIGURIA AND ANURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7886', 'OTHER ABNORMALITY OF URINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('7887', 'URETHRAL DISCHARGE');
INSERT INTO staging.icd9 (code, description) VALUES ('7888', 'EXTRAVASATION OF URINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7889', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('789', 'OTHER SYMPTOMS INVOLVING ABDOMEN AND PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7890', 'ABDOMINAL PAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7891', 'HEPATOMEGALY');
INSERT INTO staging.icd9 (code, description) VALUES ('7892', 'SPLENOMEGALY');
INSERT INTO staging.icd9 (code, description) VALUES ('7893', 'ABDOMINAL OR PELVIC SWELLING, MASS OR LUMP');
INSERT INTO staging.icd9 (code, description) VALUES ('7894', 'ABDOMINAL RIGIDITY');
INSERT INTO staging.icd9 (code, description) VALUES ('7895', 'ASCITES');
INSERT INTO staging.icd9 (code, description) VALUES ('7899', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('790', 'NONSPECIFIC FINDINGS ON EXAMINATION OF BLOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('7900', 'ABNORMALITY OF RED BLOOD CELLS');
INSERT INTO staging.icd9 (code, description) VALUES ('7901', 'ELEVATED SEDIMENTATION RATE');
INSERT INTO staging.icd9 (code, description) VALUES ('7902', 'ABNORMAL GLUCOSE TOLERANCE TEST');
INSERT INTO staging.icd9 (code, description) VALUES ('7903', 'EXCESSIVE BLOOD LEVEL OF ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('7904', 'NONSPECIFIC ELEVATION OF LEVELS OF TRANSAMINASE OR LACTIC ACID DEHYDROGENASE (LDH)');
INSERT INTO staging.icd9 (code, description) VALUES ('7905', 'OTHER NONSPECIFIC ABNORMAL SERUM ENZYME LEVELS');
INSERT INTO staging.icd9 (code, description) VALUES ('7906', 'OTHER ABNORMAL BLOOD CHEMISTRY');
INSERT INTO staging.icd9 (code, description) VALUES ('7907', 'BACTERAEMIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7908', 'VIRAEMIA, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7909', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('791', 'NONSPECIFIC FINDINGS ON EXAMINATION OF URINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7910', 'PROTEINURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7911', 'CHYLURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7912', 'HAEMOGLOBINURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7914', 'BILIURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7915', 'GLYCOSURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7916', 'ACETONURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7917', 'OTHER CELLS AND CASTS IN URINE');
INSERT INTO staging.icd9 (code, description) VALUES ('7919', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('792', 'NONSPECIFIC ABNORMAL FINDINGS IN OTHER BODY SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('7920', 'CEREBROSPINAL FLUID');
INSERT INTO staging.icd9 (code, description) VALUES ('7921', 'STOOL CONTENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('7922', 'SEMEN');
INSERT INTO staging.icd9 (code, description) VALUES ('7923', 'AMNIOTIC FLUID');
INSERT INTO staging.icd9 (code, description) VALUES ('7924', 'SALIVA');
INSERT INTO staging.icd9 (code, description) VALUES ('7929', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('793', 'NONSPECIFIC ABNORMAL FINDINGS ON RADIOLOGICAL AND OTHER EXAMINATION OF BODY STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('7930', 'SKULL AND HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('7931', 'LUNG FIELD');
INSERT INTO staging.icd9 (code, description) VALUES ('7932', 'OTHER INTRATHORACIC ORGAN');
INSERT INTO staging.icd9 (code, description) VALUES ('7933', 'BILIARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('7934', 'GASTROINTESTINAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('7935', 'GENITOURINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('7936', 'ABDOMINAL AREA, INCLUDING RETROPERITONEUM');
INSERT INTO staging.icd9 (code, description) VALUES ('7937', 'MUSCULOSKELETAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7938', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('7939', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('794', 'NONSPECIFIC ABNORMAL RESULTS OF FUNCTION STUDIES');
INSERT INTO staging.icd9 (code, description) VALUES ('7940', 'BRAIN AND CENTRAL NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('7941', 'PERIPHERAL NERVOUS SYSTEM AND SPECIAL SENSES');
INSERT INTO staging.icd9 (code, description) VALUES ('7942', 'PULMONARY');
INSERT INTO staging.icd9 (code, description) VALUES ('7943', 'CARDIOVASCULAR');
INSERT INTO staging.icd9 (code, description) VALUES ('7944', 'KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('7945', 'THYROID');
INSERT INTO staging.icd9 (code, description) VALUES ('7946', 'OTHER ENDOCRINE FUNCTION STUDY');
INSERT INTO staging.icd9 (code, description) VALUES ('7947', 'BASAL METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('7948', 'LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('7949', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('795', 'NONSPECIFIC ABNORMAL HISTOLOGICAL AND IMMUNOLOGICAL FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7950', 'NONSPECIFIC ABNORMAL PAPANICOLAOU SMEAR OF CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('7951', 'NONSPECIFIC ABNORMAL PAPANICOLAOU SMEAR OF OTHER ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('7952', 'NONSPECIFIC ABNORMAL FINDINGS ON CHROMOSOMAL ANALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7953', 'NONSPECIFIC POSITIVE CULTURE FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7954', 'OTHER NONSPECIFIC ABNORMAL HISTOLOGICAL FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7955', 'NONSPECIFIC REACTION TO TUBERCULIN TEST');
INSERT INTO staging.icd9 (code, description) VALUES ('7956', 'FALSE POSITIVE SEROLOGICAL TEST FOR SYPHILIS');
INSERT INTO staging.icd9 (code, description) VALUES ('7957', 'OTHER NONSPECIFIC IMMUNOLOGICAL FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7958', 'POSITIVE HIV ANTIBODY SEROLOGY OR POSITIVE VIRAL CULTURE FINDINGS FOR HUMAN IMMUNODEFICIENCY VIRUS (HIV)');
INSERT INTO staging.icd9 (code, description) VALUES ('796', 'OTHER NONSPECIFIC ABNORMAL FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7960', 'NONSPECIFIC ABNORMAL TOXICOLOGICAL FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7961', 'ABNORMAL REFLEX');
INSERT INTO staging.icd9 (code, description) VALUES ('7962', 'ELEVATED BLOOD PRESSURE READING WITHOUT DIAGNOSIS OF HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('7963', 'NONSPECIFIC LOW BLOOD PRESSURE READING');
INSERT INTO staging.icd9 (code, description) VALUES ('7964', 'OTHER ABNORMAL CLINICAL FINDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('7969', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('797', 'SENILITY WITHOUT MENTION OF PSYCHOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('798', 'SUDDEN DEATH, CAUSE UNKNOWN');
INSERT INTO staging.icd9 (code, description) VALUES ('7980', 'SUDDEN INFANT DEATH SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('7981', 'INSTANTANEOUS DEATH');
INSERT INTO staging.icd9 (code, description) VALUES ('7982', 'DEATH OCCURRING IN LESS THAN 24 HOURS FROM ONSET OF SYMPTOMS, NOT OTHERWISE EXPLAINED');
INSERT INTO staging.icd9 (code, description) VALUES ('7989', 'UNATTENDED DEATH');
INSERT INTO staging.icd9 (code, description) VALUES ('799', 'OTHER ILL-DEFINED AND UNKNOWN CAUSES OF MORBIDITY AND MORTALITY');
INSERT INTO staging.icd9 (code, description) VALUES ('7990', 'ASPHYXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7991', 'RESPIRATORY FAILURE');
INSERT INTO staging.icd9 (code, description) VALUES ('7992', 'NERVOUSNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('7993', 'DEBILITY, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('7994', 'CACHEXIA');
INSERT INTO staging.icd9 (code, description) VALUES ('7998', 'OTHER ILL-DEFINED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('7999', 'OTHER UNKNOWN AND UNSPECIFIED CAUSE');
INSERT INTO staging.icd9 (code, description) VALUES ('800', 'FRACTURE OF VAULT OF SKULL');
INSERT INTO staging.icd9 (code, description) VALUES ('8000', 'CLOSED WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8001', 'CLOSED WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8002', 'OPEN WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8003', 'OPEN WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('801', 'FRACTURE OF BASE OF SKULL');
INSERT INTO staging.icd9 (code, description) VALUES ('8010', 'CLOSED WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8011', 'CLOSED WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8012', 'OPEN WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8013', 'OPEN WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('802', 'FRACTURE OF FACE BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('8020', 'NASAL BONES, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8021', 'NASAL BONES, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8022', 'MANDIBLE, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8023', 'MANDIBLE, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8024', 'MALAR AND MAXILLARY BONES, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8025', 'MALAR AND MAXILLARY BONES, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8026', 'ORBITAL FLOOR (BLOW-OUT), CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8027', 'ORBITAL FLOOR (BLOW-OUT), OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8028', 'OTHER FACIAL BONES, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8029', 'OTHER FACIAL BONES, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('803', 'OTHER AND UNQUALIFIED SKULL FRACTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('8030', 'CLOSED WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8031', 'CLOSED WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8032', 'OPEN WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8033', 'OPEN WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('804', 'MULTIPLE FRACTURES INVOLVING SKULL OR FACE WITH OTHER BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('8040', 'CLOSED WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8041', 'CLOSED WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8042', 'OPEN WITHOUT MENTION OF INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8043', 'OPEN WITH INTRACRANIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('805', 'FRACTURE OF VERTEBRAL COLUMN WITHOUT MENTION OF SPINAL CORD LESION');
INSERT INTO staging.icd9 (code, description) VALUES ('8050', 'CERVICAL, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8051', 'CERVICAL, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8052', 'DORSAL (THORACIC), CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8053', 'DORSAL (THORACIC), OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8054', 'LUMBAR, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8055', 'LUMBAR, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8056', 'SACRUM AND COCCYX, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8057', 'SACRUM AND COCCYX, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8058', 'UNSPECIFIED, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8059', 'UNSPECIFIED, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('806', 'FRACTURE OF VERTEBRAL COLUMN WITH SPINAL CORD LESION');
INSERT INTO staging.icd9 (code, description) VALUES ('8060', 'CERVICAL, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8061', 'CERVICAL, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8062', 'DORSAL (THORACIC), CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8063', 'DORSAL (THORACIC), OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8064', 'LUMBAR, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8065', 'LUMBAR, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8066', 'SACRUM AND COCCYX, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8067', 'SACRUM AND COCCYX, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8068', 'UNSPECIFIED, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8069', 'UNSPECIFIED, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('807', 'FRACTURE OF RIB(S), STERNUM, LARYNX AND TRACHEA');
INSERT INTO staging.icd9 (code, description) VALUES ('8070', 'RIB(S), CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8071', 'RIB(S), OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8072', 'STERNUM, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8073', 'STERNUM, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8074', 'FLAIL CHEST');
INSERT INTO staging.icd9 (code, description) VALUES ('8075', 'LARYNX AND TRACHEA, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8076', 'LARYNX AND TRACHEA, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('808', 'FRACTURE OF PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('8080', 'ACETABULUM, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8081', 'ACETABULUM, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8082', 'PUBIS, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8083', 'PUBIS, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8084', 'OTHER SPECIFIED PART, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8085', 'OTHER SPECIFIED PART, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8088', 'UNSPECIFIED, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8089', 'UNSPECIFIED, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('809', 'ILL-DEFINED FRACTURES OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('8090', 'FRACTURE OF TRUNK, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8091', 'FRACTURE OF TRUNK, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('810', 'FRACTURE OF CLAVICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8100', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8101', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('811', 'FRACTURE OF SCAPULA');
INSERT INTO staging.icd9 (code, description) VALUES ('8110', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8111', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('812', 'FRACTURE OF HUMERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('8120', 'UPPER END, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8121', 'UPPER END, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8122', 'SHAFT OR UNSPECIFIED PART, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8123', 'SHAFT OR UNSPECIFIED PART, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8124', 'LOWER END, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8125', 'LOWER END, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('813', 'FRACTURE OF RADIUS AND ULNA');
INSERT INTO staging.icd9 (code, description) VALUES ('8130', 'UPPER END OR UNSPECIFIED PART, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8131', 'UPPER END OR UNSPECIFIED PART, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8132', 'SHAFT, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8133', 'SHAFT, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8134', 'LOWER END, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8135', 'LOWER END, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('814', 'FRACTURE OF CARPAL BONE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('8140', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8141', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('815', 'FRACTURE OF METACARPAL BONE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('8150', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8151', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('816', 'FRACTURE OF ONE OR MORE PHALANGES OF HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('8160', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8161', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('817', 'MULTIPLE FRACTURES OF HAND BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('8170', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8171', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('818', 'ILL-DEFINED FRACTURES OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('8180', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8181', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('819', 'MULTIPLE FRACTURES INVOLVING BOTH UPPER LIMBS, AND UPPER LIMB WITH RIB(S) AND STERNUM');
INSERT INTO staging.icd9 (code, description) VALUES ('8190', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8191', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('820', 'FRACTURE OF NECK OF FEMUR');
INSERT INTO staging.icd9 (code, description) VALUES ('8200', 'TRANSCERVICAL FRACTURE, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8201', 'TRANSCERVICAL FRACTURE, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8202', 'PERTROCHANTERIC FRACTURE, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8203', 'PERTROCHANTERIC FRACTURE, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8208', 'UNSPECIFIED PART, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8209', 'UNSPECIFIED PART, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('821', 'FRACTURE OF OTHER AND UNSPECIFIED PARTS OF FEMUR');
INSERT INTO staging.icd9 (code, description) VALUES ('8210', 'SHAFT OR UNSPECIFIED PART, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8211', 'SHAFT OR UNSPECIFIED PART, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8212', 'LOWER END, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8213', 'LOWER END, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('822', 'FRACTURE OF PATELLA');
INSERT INTO staging.icd9 (code, description) VALUES ('8220', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8221', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('823', 'FRACTURE OF TIBIA AND FIBULA');
INSERT INTO staging.icd9 (code, description) VALUES ('8230', 'UPPER END OR UNSPECIFIED PART, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8231', 'UPPER END OR UNSPECIFIED PART, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8232', 'SHAFT, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8233', 'SHAFT, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('824', 'FRACTURE OF ANKLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8240', 'MEDIAL MALLEOLUS, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8241', 'MEDIAL MALLEOLUS, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8242', 'LATERAL MALLEOLUS, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8243', 'LATERAL MALLEOLUS, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8244', 'BIMALLEOLAR, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8245', 'BIMALLEOLAR, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8246', 'TRIMALLEOLAR, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8247', 'TRIMALLEOLAR, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8248', 'UNSPECIFIED, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8249', 'UNSPECIFIED, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('825', 'FRACTURE OF ONE OR MORE TARSAL AND METATARSAL BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('8250', 'FRACTURE OF CALCANEUS, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8251', 'FRACTURE OF CALCANEUS, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8252', 'FRACTURE OF OTHER TARSAL AND METATARSAL BONES, CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8253', 'FRACTURE OF OTHER TARSAL AND METATARSAL BONES, OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('826', 'FRACTURE OF ONE OR MORE PHALANGES OF FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('8260', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8261', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('827', 'OTHER, MULTIPLE AND ILL-DEFINED FRACTURES OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('8270', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8271', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('828', 'MULTIPLE FRACTURES INVOLVING BOTH LOWER LIMBS, LOWER WITH UPPER LIMB, AND LOWER LIMB(S) WITH RIB(S) AND STERNUM');
INSERT INTO staging.icd9 (code, description) VALUES ('8280', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8281', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('829', 'FRACTURE OF UNSPECIFIED BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('8290', 'CLOSED');
INSERT INTO staging.icd9 (code, description) VALUES ('8291', 'OPEN');
INSERT INTO staging.icd9 (code, description) VALUES ('830', 'DISLOCATION OF JAW');
INSERT INTO staging.icd9 (code, description) VALUES ('8300', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8301', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('831', 'DISLOCATION OF SHOULDER');
INSERT INTO staging.icd9 (code, description) VALUES ('8310', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8311', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('832', 'DISLOCATION OF ELBOW');
INSERT INTO staging.icd9 (code, description) VALUES ('8320', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8321', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('833', 'DISLOCATION OF WRIST');
INSERT INTO staging.icd9 (code, description) VALUES ('8330', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8331', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('834', 'DISLOCATION OF FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('8340', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8341', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('835', 'DISLOCATION OF HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('8350', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8351', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('836', 'DISLOCATION OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('8360', 'TEAR OF MEDIAL CARTILAGE OR MENISCUS OF KNEE, CURRENT');
INSERT INTO staging.icd9 (code, description) VALUES ('8361', 'TEAR OF LATERAL CARTILAGE OR MENISCUS OF KNEE, CURRENT');
INSERT INTO staging.icd9 (code, description) VALUES ('8362', 'OTHER TEAR OF CARTILAGE OR MENISCUS OF KNEE, CURRENT');
INSERT INTO staging.icd9 (code, description) VALUES ('8363', 'DISLOCATION OF PATELLA, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8364', 'DISLOCATION OF PATELLA, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8365', 'OTHER DISLOCATION OF KNEE, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8366', 'OTHER DISLOCATION OF KNEE, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('837', 'DISLOCATION OF ANKLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8370', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8371', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('838', 'DISLOCATION OF FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('8380', 'SIMPLE DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8381', 'COMPOUND DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('839', 'OTHER, MULTIPLE AND ILL-DEFINED DISLOCATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('8390', 'CERVICAL VERTEBRA, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8391', 'CERVICAL VERTEBRA, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8392', 'THORACIC AND LUMBAR VERTEBRA, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8393', 'THORACIC AND LUMBAR VERTEBRA, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8394', 'OTHER VERTEBRA, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8395', 'OTHER VERTEBRA, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8396', 'OTHER LOCATION, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8397', 'OTHER LOCATION, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8398', 'MULTIPLE AND ILL-DEFINED, SIMPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8399', 'MULTIPLE AND ILL-DEFINED, COMPOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('840', 'SPRAINS AND STRAINS OF SHOULDER AND UPPER ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('8400', 'ACROMIOCLAVICULAR (JOINT) (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8401', 'CORACOCLAVICULAR (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8402', 'CORACOHUMERAL (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8403', 'INFRASPINATUS (MUSCLE) (TENDON)');
INSERT INTO staging.icd9 (code, description) VALUES ('8404', 'ROTATOR CUFF (CAPSULE)');
INSERT INTO staging.icd9 (code, description) VALUES ('8405', 'SUBSCAPULARIS (MUSCLE)');
INSERT INTO staging.icd9 (code, description) VALUES ('8406', 'SUPRASPINATUS (MUSCLE) (TENDON)');
INSERT INTO staging.icd9 (code, description) VALUES ('8408', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('8409', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('841', 'SPRAINS AND STRAINS OF ELBOW AND FOREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('8410', 'RADIAL COLLATERAL LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('8411', 'ULNAR COLLATERAL LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('8412', 'RADIOHUMERAL (JOINT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8413', 'ULNOHUMERAL (JOINT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8418', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('8419', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('842', 'SPRAINS AND STRAINS OF WRIST AND HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('8420', 'WRIST');
INSERT INTO staging.icd9 (code, description) VALUES ('8421', 'HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('843', 'SPRAINS AND STRAINS OF HIP AND THIGH');
INSERT INTO staging.icd9 (code, description) VALUES ('8430', 'ILIOFEMORAL (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8431', 'ISCHIOCAPSULAR (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8438', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('8439', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('844', 'SPRAINS AND STRAINS OF KNEE AND LEG');
INSERT INTO staging.icd9 (code, description) VALUES ('8440', 'LATERAL COLLATERAL LIGAMENT OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('8441', 'MEDIAL COLLATERAL LIGAMENT OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('8442', 'CRUCIATE LIGAMENT OF KNEE');
INSERT INTO staging.icd9 (code, description) VALUES ('8443', 'TIBIOFIBULAR (JOINT) (LIGAMENT), SUPERIOR');
INSERT INTO staging.icd9 (code, description) VALUES ('8448', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('8449', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('845', 'SPRAINS AND STRAINS OF ANKLE AND FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('8450', 'ANKLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8451', 'FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('846', 'SPRAINS AND STRAINS OF SACROILIAC REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('8460', 'LUMBOSACRAL (JOINT) (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8461', 'SACROILIAC LIGAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('8462', 'SACROSPINATUS (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8463', 'SACROTUBEROUS (LIGAMENT)');
INSERT INTO staging.icd9 (code, description) VALUES ('8468', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('8469', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('847', 'SPRAINS AND STRAINS OF OTHER AND UNSPECIFIED PARTS OF BACK');
INSERT INTO staging.icd9 (code, description) VALUES ('8470', 'NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('8471', 'THORACIC');
INSERT INTO staging.icd9 (code, description) VALUES ('8472', 'LUMBAR');
INSERT INTO staging.icd9 (code, description) VALUES ('8473', 'SACRUM');
INSERT INTO staging.icd9 (code, description) VALUES ('8474', 'COCCYX');
INSERT INTO staging.icd9 (code, description) VALUES ('8479', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('848', 'OTHER AND ILL-DEFINED SPRAINS AND STRAINS');
INSERT INTO staging.icd9 (code, description) VALUES ('8480', 'SEPTAL CARTILAGE OF NOSE');
INSERT INTO staging.icd9 (code, description) VALUES ('8481', 'JAW');
INSERT INTO staging.icd9 (code, description) VALUES ('8482', 'THYROID REGION');
INSERT INTO staging.icd9 (code, description) VALUES ('8483', 'RIBS');
INSERT INTO staging.icd9 (code, description) VALUES ('8484', 'STERNUM');
INSERT INTO staging.icd9 (code, description) VALUES ('8485', 'PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('8488', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('8489', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('850', 'CONCUSSION');
INSERT INTO staging.icd9 (code, description) VALUES ('851', 'CEREBRAL LACERATION AND CONTUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('8510', 'WITHOUT MENTION OF OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8511', 'WITH OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('852', 'SUBARACHNOID, SUBDURAL AND EXTRADURAL HAEMORRHAGE, FOLLOWING INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8520', 'WITHOUT MENTION OF OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8521', 'WITH OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('853', 'OTHER AND UNSPECIFIED INTRACRANIAL HAEMORRHAGE FOLLOWING INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('8530', 'WITHOUT MENTION OF OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8531', 'WITH OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('854', 'INTRACRANIAL INJURY OF OTHER AND UNSPECIFIED NATURE');
INSERT INTO staging.icd9 (code, description) VALUES ('8540', 'WITHOUT MENTION OF OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('8541', 'WITH OPEN INTRACRANIAL WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('860', 'TRAUMATIC PNEUMOTHORAX AND HAEMOTHORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8600', 'PNEUMOTHORAX WITHOUT MENTION OF OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8601', 'PNEUMOTHORAX WITH OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8602', 'HAEMOTHORAX WITHOUT MENTION OF OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8603', 'HAEMOTHORAX WITH OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8604', 'PNEUMOHAEMOTHORAX WITHOUT MENTION OF OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8605', 'PNEUMOHAEMOTHORAX WITH OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('861', 'INJURY TO HEART AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('8610', 'HEART, WITHOUT MENTION OF OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8611', 'HEART, WITH OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8612', 'LUNG, WITHOUT MENTION OF OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('8613', 'LUNG, WITH OPEN WOUND INTO THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('862', 'INJURY TO OTHER AND UNSPECIFIED INTRATHORACIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('8620', 'DIAPHRAGM, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8621', 'DIAPHRAGM, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8622', 'OTHER SPECIFIED INTRATHORACIC ORGAN WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8623', 'OTHER SPECIFIED INTRATHORACIC ORGAN, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8628', 'MULTIPLE AND UNSPECIFIED INTRATHORACIC ORGANS WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8629', 'MULTIPLE AND UNSPECIFIED INTRATHORACIC ORGANS, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('863', 'INJURY TO GASTROINTESTINAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('8630', 'STOMACH, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8631', 'STOMACH, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8632', 'SMALL INTESTINE, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8633', 'SMALL INTESTINE, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8634', 'COLON OR RECTUM, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8635', 'COLON OR RECTUM, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8638', 'OTHER AND UNSPECIFIED SITES, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8639', 'OTHER AND UNSPECIFIED SITES, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('864', 'INJURY TO LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('8640', 'WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8641', 'WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('865', 'INJURY TO SPLEEN');
INSERT INTO staging.icd9 (code, description) VALUES ('8650', 'WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8651', 'WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('866', 'INJURY TO KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('8660', 'WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8661', 'WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('867', 'INJURY TO PELVIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('8670', 'BLADDER AND URETHRA, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8671', 'BLADDER AND URETHRA, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8672', 'URETER, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8673', 'URETER, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8674', 'UTERUS, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8675', 'UTERUS, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8676', 'OTHER PELVIC ORGAN, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8677', 'OTHER PELVIC ORGAN, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8678', 'UNSPECIFIED PART, WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8679', 'UNSPECIFIED PART, WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('868', 'INJURY TO OTHER INTRAABDOMINAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('8680', 'WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8681', 'WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('869', 'INTERNAL INJURY TO UNSPECIFIED OR ILL-DEFINED ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('8690', 'WITHOUT MENTION OF OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('8691', 'WITH OPEN WOUND INTO CAVITY');
INSERT INTO staging.icd9 (code, description) VALUES ('870', 'OPEN WOUND OF OCULAR ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('8700', 'LACERATION OF SKIN OF EYELID AND PERIOCULAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('8701', 'LACERATION OF EYELID, FULL THICKNESS, NOT INVOLVING LACRIMAL PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('8702', 'LACERATION OF EYELID INVOLVING LACRIMAL PASSAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('8703', 'PENETRATING WOUND OF ORBIT WITHOUT MENTION OF FOREIGN BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('8704', 'PENETRATING WOUND OF ORBIT WITH FOREIGN BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('8708', 'OTHER OPEN WOUNDS OF OCULAR ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('8709', 'UNSPECIFIED OPEN WOUND OF OCULAR ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('871', 'OPEN WOUND OF EYEBALL');
INSERT INTO staging.icd9 (code, description) VALUES ('8710', 'OCULAR LACERATION WITHOUT PROLAPSE OF INTRAOCULAR TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('8711', 'OCULAR LACERATION WITH PROLAPSE OR EXPOSURE OF INTRAOCULAR TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('8712', 'RUPTURE OF EYE WITH PARTIAL LOSS OF INTRAOCULAR TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('8713', 'AVULSION OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('8714', 'UNSPECIFIED LACERATION OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('8715', 'PENETRATION OF EYEBALL WITH MAGNETIC FOREIGN BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('8716', 'PENETRATION OF EYEBALL WITH (NONMAGNETIC) FOREIGN BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('8717', 'UNSPECIFIED OCULAR PENETRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8719', 'UNSPECIFIED OPEN WOUND OF EYEBALL');
INSERT INTO staging.icd9 (code, description) VALUES ('872', 'OPEN WOUND OF EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('8720', 'EXTERNAL EAR, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8721', 'EXTERNAL EAR, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8726', 'OTHER SPECIFIED PARTS, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8727', 'OTHER SPECIFIED PARTS, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8728', 'PART UNSPECIFIED, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8729', 'PART UNSPECIFIED, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('873', 'OTHER OPEN WOUND OF HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('8730', 'SCALP, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8731', 'SCALP, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8732', 'NOSE, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8733', 'NOSE, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8734', 'FACE, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8735', 'FACE, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8736', 'INTERNAL STRUCTURES OF MOUTH, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8737', 'INTERNAL STRUCTURES OF MOUTH, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8738', 'OTHER AND UNSPECIFIED OPEN WOUND OF HEAD WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8739', 'OTHER AND UNSPECIFIED OPEN WOUND OF HEAD, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('874', 'OPEN WOUND OF NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('8740', 'LARYNX AND TRACHEA, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8741', 'LARYNX AND TRACHEA, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8742', 'THYROID GLAND, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8743', 'THYROID GLAND, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8744', 'PHARYNX, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8745', 'PHARYNX, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8748', 'OTHER AND UNSPECIFIED PARTS, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8749', 'OTHER AND UNSPECIFIED PARTS, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('875', 'OPEN WOUND OF CHEST (WALL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8750', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8751', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('876', 'OPEN WOUND OF BACK');
INSERT INTO staging.icd9 (code, description) VALUES ('8760', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8761', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('877', 'OPEN WOUND OF BUTTUCK');
INSERT INTO staging.icd9 (code, description) VALUES ('8770', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8771', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('878', 'OPEN WOUND OF GENITAL ORGANS (EXTERNAL), INCLUDING TRAUMATIC AMPUTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8780', 'PENIS, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8781', 'PENIS, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8782', 'SCROTUM AND TESTES, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8783', 'SCROTUM AND TESTES, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8784', 'VULVA, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8785', 'VULVA, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8786', 'VAGINA, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8787', 'VAGINA, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8788', 'OTHER AND UNSPECIFIED PARTS, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8789', 'OTHER AND UNSPECIFIED PARTS, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('879', 'OPEN WOUND OF OTHER AND UNSPECIFIED SITES, EXCEPT LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('8790', 'BREAST, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8791', 'BREAST, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8792', 'ABDOMINAL WALL, ANTERIOR, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8793', 'ABDOMINAL WALL, ANTERIOR, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8794', 'ABDOMINAL WALL, LATERAL, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8795', 'ABDOMINAL WALL, LATERAL, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8796', 'OTHER AND UNSPECIFIED PARTS OF TRUNK, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8797', 'OTHER AND UNSPECIFIED PARTS OF TRUNK, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8798', 'OPEN WOUND(S) (MULTIPLE) OF UNSPECIFIED SITE(S) WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8799', 'OPEN WOUND(S) (MULTIPLE) OF UNSPECIFIED SITE(S), COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('880', 'OPEN WOUND OF SHOULDER AND UPPER ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('8800', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8801', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8802', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('881', 'OPEN WOUND OF ELBOW, FOREARM AND WRIST');
INSERT INTO staging.icd9 (code, description) VALUES ('8810', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8811', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8812', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('882', 'OPEN WOUND OF HAND EXCEPT FINGER(S) ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('8820', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8821', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8822', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('883', 'OPEN WOUND OF FINGER(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('8830', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8831', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8832', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('884', 'MULTIPLE AND UNSPECIFIED OPEN WOUND OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('8840', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8841', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8842', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('885', 'TRAUMATIC AMPUTATION OF THUMB (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8850', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8851', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('886', 'TRAUMATIC AMPUTATION OF OTHER FINGER(S) (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8860', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8861', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('887', 'TRAUMATIC AMPUTATION OF ARM AND HAND (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8870', 'UNILATERAL, BELOW ELBOW, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8871', 'UNILATERAL, BELOW ELBOW, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8872', 'UNILATERAL, AT OR ABOVE ELBOW, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8873', 'UNILATERAL, AT OR ABOVE ELBOW, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8874', 'UNILATERAL, LEVEL NOT SPECIFIED, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8875', 'UNILATERAL, LEVEL NOT SPECIFIED, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8876', 'BILATERAL (ANY LEVEL), WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8877', 'BILATERAL (ANY LEVEL), COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('890', 'OPEN WOUND OF HIP AND THIGH');
INSERT INTO staging.icd9 (code, description) VALUES ('8900', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8901', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8902', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('891', 'OPEN WOUND OF KNEE, LEG (EXCEPT THIGH) AND ANKLE');
INSERT INTO staging.icd9 (code, description) VALUES ('8910', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8911', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8912', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('892', 'OPEN WOUND OF FOOT EXCEPT TOE(S) ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('8920', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8921', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8922', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('893', 'OPEN WOUND OF TOE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('8930', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8931', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8932', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('894', 'MULTIPLE AND UNSPECIFIED OPEN WOUND OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('8940', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8941', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8942', 'WITH TENDON INVOLVEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('895', 'TRAUMATIC AMPUTATION OF TOE(S) (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8950', 'WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8951', 'COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('896', 'TRAUMATIC AMPUTATION OF FOOT (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8960', 'UNILATERAL, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8961', 'UNILATERAL, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8962', 'BILATERAL, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8963', 'BILATERAL, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('897', 'TRAUMATIC AMPUTATION OF LEG(S) (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('8970', 'UNILATERAL, BELOW KNEE, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8971', 'UNILATERAL, BELOW KNEE, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8972', 'UNILATERAL, AT OR ABOVE KNEE, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8973', 'UNILATERAL, AT OR ABOVE KNEE, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8974', 'UNILATERAL, LEVEL NOT SPECIFIED, WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8975', 'UNILATERAL, LEVEL NOT SPECIFIED, COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('8976', 'BILATERAL (ANY LEVEL), WITHOUT MENTION OF COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('8977', 'BILATERAL (ANY LEVEL), COMPLICATED');
INSERT INTO staging.icd9 (code, description) VALUES ('900', 'INJURY TO BLOOD VESSELS OF HEAD AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('9000', 'CAROTID ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('9001', 'INTERNAL JUGULAR VEIN');
INSERT INTO staging.icd9 (code, description) VALUES ('9008', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9009', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('901', 'INJURY TO BLOOD VESSELS OF THORAX');
INSERT INTO staging.icd9 (code, description) VALUES ('9010', 'THORACIC AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('9011', 'INNOMINATE AND SUBCLAVIAN ARTERIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9012', 'SUPERIOR VENA CAVA');
INSERT INTO staging.icd9 (code, description) VALUES ('9013', 'INNOMINATE AND SUBCLAVIAN VEINS');
INSERT INTO staging.icd9 (code, description) VALUES ('9014', 'PULMONARY BLOOD VESSEL');
INSERT INTO staging.icd9 (code, description) VALUES ('9018', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('902', 'INJURY TO BLOOD VESSELS OF ABDOMEN AND PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('9020', 'ABDOMINAL AORTA');
INSERT INTO staging.icd9 (code, description) VALUES ('9021', 'INFERIOR VENA CAVA');
INSERT INTO staging.icd9 (code, description) VALUES ('9022', 'COELIAC AND MESENTERIC ARTERIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9023', 'PORTAL AND SPLENIC VEINS');
INSERT INTO staging.icd9 (code, description) VALUES ('9024', 'RENAL BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9025', 'ILIAC BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9028', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9029', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('903', 'INJURY TO BLOOD VESSELS OF UPPER EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('9030', 'AXILLARY BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9031', 'BRACHIAL BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9032', 'RADIAL  BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9033', 'ULNAR BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9034', 'PALMAR ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('9035', 'DIGITAL BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9038', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9039', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('904', 'INJURY TO BLOOD VESSELS OF LOWER EXTREMITY AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9040', 'COMMON FEMORAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('9041', 'SUPERFICIAL FEMORAL ARTERY');
INSERT INTO staging.icd9 (code, description) VALUES ('9042', 'FEMORAL VEINS');
INSERT INTO staging.icd9 (code, description) VALUES ('9043', 'SAPHENOUS VEINS');
INSERT INTO staging.icd9 (code, description) VALUES ('9044', 'POPLITEAL BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9045', 'TIBIAL BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9046', 'DEEP PLANTAR BLOOD VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('9047', 'OTHER BLOOD VESSELS OF LOWER EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('9048', 'UNSPECIFIED BLOOD VESSELS OF LOWER EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('9049', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('905', 'LATE EFFECTS OF MUSCULOSKELETAL AND CONNECTIVE TISSUE INJURIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9050', 'LATE EFFECT OF FRACTURE OF SKULL AND FACE BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('9051', 'LATE EFFECT OF FRACTURE OF SPINE AND TRUNK WITHOUT MENTION OF SPINAL CORD LESION');
INSERT INTO staging.icd9 (code, description) VALUES ('9052', 'LATE EFFECT OF FRACTURE OF UPPER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9053', 'LATE EFFECT OF FRACTURE OF NECK OF FEMUR');
INSERT INTO staging.icd9 (code, description) VALUES ('9054', 'LATE EFFECT OF FRACTURE OF LOWER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9055', 'LATE EFFECT OF FRACTURE OF MULTIPLE AND UNSPECIFIED BONES');
INSERT INTO staging.icd9 (code, description) VALUES ('9056', 'LATE EFFECT OF DISLOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('9057', 'LATE EFFECT OF SPRAIN AND STRAIN WITHOUT MENTION OF TENDON INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9058', 'LATE EFFECT OF TENDON INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9059', 'LATE EFFECT OF TRAUMATIC AMPUTATION');
INSERT INTO staging.icd9 (code, description) VALUES ('906', 'LATE EFFECTS OF INJURIES TO SKIN AND SUBCUTANEOUS TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('9060', 'LATE EFFECT OF OPEN WOUND OF HEAD, NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9061', 'LATE EFFECT OF OPEN WOUND OF EXTREMITIES WITHOUT MENTION OF TENDON INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9062', 'LATE EFFECT OF SUPERFICIAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9063', 'LATE EFFECT OF CONTUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('9064', 'LATE EFFECT OF CRUSHING');
INSERT INTO staging.icd9 (code, description) VALUES ('9065', 'LATE EFFECT OF BURN OF EYE, FACE, HEAD AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('9066', 'LATE EFFECT OF BURN OF WRIST AND HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('9067', 'LATE EFFECT OF BURN OF OTHER EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9068', 'LATE EFFECT OF BURNS OF OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9069', 'LATE EFFECT OF BURN OF UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('907', 'LATE EFFECTS OF INJURIES TO THE NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('9070', 'LATE EFFECT OF INTRACRANIAL INJURY WITHOUT MENTION OF SKULL FRACTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9071', 'LATE EFFECT OF INJURY TO CRANIAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9072', 'LATE EFFECT OF SPINAL CORD INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9073', 'LATE EFFECT OF INJURY TO NERVE ROOT(S), SPINAL PLEXUS(ES) AND OTHER NERVES OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9074', 'LATE EFFECT OF INJURY TO PERIPHERAL NERVE OF SHOULDER GIRDLE AND UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9075', 'LATE EFFECT OF INJURY TO PERIPHERAL NERVE OF PELVIC GIRDLE AND LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9079', 'LATE EFFECT OF INJURY TO OTHER AND UNSPECIFIED NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('908', 'LATE EFFECTS OF OTHER AND UNSPECIFIED INJURIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9080', 'LATE EFFECT OF INTERNAL INJURY TO CHEST');
INSERT INTO staging.icd9 (code, description) VALUES ('9081', 'LATE EFFECT OF INTERNAL INJURY TO INTRAABDOMINAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('9082', 'LATE EFFECT OF INTERNAL INJURY TO OTHER INTERNAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('9083', 'LATE EFFECT OF INJURY TO BLOOD VESSEL OF HEAD, NECK AND EXTREMITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('9608', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9084', 'LATE EFFECT OF INJURY TO BLOOD VESSEL OF THORAX, ABDOMEN AND PELVIS');
INSERT INTO staging.icd9 (code, description) VALUES ('9085', 'LATE EFFECT OF FOREIGN BODY IN ORIFICE');
INSERT INTO staging.icd9 (code, description) VALUES ('9086', 'LATE EFFECT OF CERTAIN COMPLICATIONS OF TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('9089', 'LATE EFFECT OF UNSPECIFIED INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('909', 'LATE EFFECTS OF OTHER AND UNSPECIFIED EXTERNAL CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('9090', 'LATE EFFECT OF POISONING DUE TO DRUG, MEDICAMENT, OR BIOLOGICAL SUBSTANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('9091', 'LATE EFFECT OF TOXIC EFFECTS OF NONMEDICAL SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('9092', 'LATE EFFECT OF RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('9093', 'LATE EFFECT OF COMPLICATIONS OF SURGICAL AND MEDICAL CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('9094', 'LATE EFFECT OF CERTAIN OTHER EXTERNAL CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('9099', 'LATE EFFECT OF OTHER AND UNSPECIFIED EXTERNAL CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('910', 'SUPERFICIAL INJURY OF FACE, NECK AND SCALP EXCEPT EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('9100', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9101', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9102', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9103', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9104', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9105', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9106', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9107', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9108', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9109', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('911', 'SUPERFICIAL INJURY OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9110', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9111', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9112', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9113', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9114', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9115', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9116', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9117', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9118', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9119', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('912', 'SUPERFICIAL INJURY OF SHOULDER AND UPPER ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('9120', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9121', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9122', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9123', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9124', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9125', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9126', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9127', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9128', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9129', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('913', 'SUPERFICIAL INJURY OF ELBOW, FOREARM AND WRIST');
INSERT INTO staging.icd9 (code, description) VALUES ('9130', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9131', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9132', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9133', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9134', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9135', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9136', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9137', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9138', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9139', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('914', 'SUPERFICIAL INJURY OF HAND(S) EXCEPT FINGER(S) ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('9140', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9141', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9142', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9143', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9144', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9145', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9146', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9147', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9148', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9149', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('915', 'SUPERFICIAL INJURY OF FINGER(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9150', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9151', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9152', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9153', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9154', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9155', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9156', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9157', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9158', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9159', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('916', 'SUPERFICIAL INJURY OF HIP, THIGH, LEG AND ANKLE');
INSERT INTO staging.icd9 (code, description) VALUES ('9160', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9161', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9162', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9163', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9164', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9165', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9166', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9167', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9168', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9169', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('917', 'SUPERFICIAL INJURY OF FOOT AND TOE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9170', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9171', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9172', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9173', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9174', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9175', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9176', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9177', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9178', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9179', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('918', 'SUPERFICIAL INJURY OF EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('9180', 'EYELIDS AND PERIOCULAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('9181', 'CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('9182', 'CONJUNCTIVA');
INSERT INTO staging.icd9 (code, description) VALUES ('9189', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('919', 'SUPERFICIAL INJURY OF OTHER, MULTIPLE AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9190', 'ABRASION OR FRICTION BURN WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9191', 'ABRASION OR FRICTION BURN, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9192', 'BLISTER WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9193', 'BLISTER, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9194', 'INSECT BITE, NONVENOMOUS, WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9195', 'INSECT BITE, NONVENOMOUS, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9196', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND AND WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9197', 'SUPERFICIAL FOREIGN BODY (SPLINTER) WITHOUT MAJOR OPEN WOUND, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('9198', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY WITHOUT MENTION OF INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9199', 'OTHER AND UNSPECIFIED SUPERFICIAL INJURY, INFECTED');
INSERT INTO staging.icd9 (code, description) VALUES ('920', 'CONTUSION OF FACE, SCALP, AND NECK EXCEPT EYE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('921', 'CONTUSION OF EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('9210', 'BLACK EYE, NOT OTHERWISE SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9211', 'CONTUSION OF EYELIDS AND PERIOCULAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('9212', 'CONTUSION OF ORBITAL TISSUES');
INSERT INTO staging.icd9 (code, description) VALUES ('9213', 'CONTUSION OF EYEBALL');
INSERT INTO staging.icd9 (code, description) VALUES ('9219', 'UNSPECIFIED CONTUSION OF EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('922', 'CONTUSION OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9220', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('9221', 'CHEST WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('9222', 'ABDOMINAL WALL');
INSERT INTO staging.icd9 (code, description) VALUES ('9223', 'BACK');
INSERT INTO staging.icd9 (code, description) VALUES ('9224', 'GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('9228', 'MULTIPLE SITES OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9229', 'UNSPECIFIED PART');
INSERT INTO staging.icd9 (code, description) VALUES ('923', 'CONTUSION OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9230', 'SHOULDER AND UPPER ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('9231', 'ELBOW AND FOREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('9232', 'WRIST AND HAND(S), EXCEPT FINGER(S) ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('9233', 'FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('9238', 'MULTIPLE SITES OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9239', 'UNSPECIFIED PART OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('924', 'CONTUSION OF LOWER LIMB AND OF OTHER AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9240', 'HIP AND THIGH');
INSERT INTO staging.icd9 (code, description) VALUES ('9241', 'KNEE AND LOWER LEG');
INSERT INTO staging.icd9 (code, description) VALUES ('9242', 'ANKLE AND FOOT, EXCLUDING TOE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9243', 'TOE');
INSERT INTO staging.icd9 (code, description) VALUES ('9244', 'MULTIPLE SITES OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9245', 'UNSPECIFIED PART OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9248', 'MULTIPLE SITES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9249', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('925', 'CRUSHING INJURY OF FACE, SCALP AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('926', 'CRUSHING INJURY OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9260', 'EXTERNAL GENITALIA');
INSERT INTO staging.icd9 (code, description) VALUES ('9261', 'OTHER SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9268', 'MULTIPLE SITES OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9269', 'UNSPECIFIED PART');
INSERT INTO staging.icd9 (code, description) VALUES ('927', 'CRUSHING INJURY OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9270', 'SHOULDER AND UPPER ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('9271', 'ELBOW AND FOREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('9272', 'WRIST AND HAND(S), EXCEPT FINGER(S) ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('9273', 'FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('9278', 'MULTIPLE SITES OF UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9279', 'UNSPECIFIED PART');
INSERT INTO staging.icd9 (code, description) VALUES ('928', 'CRUSHING INJURY OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9280', 'HIP AND THIGH');
INSERT INTO staging.icd9 (code, description) VALUES ('9281', 'KNEE AND LOWER LEG');
INSERT INTO staging.icd9 (code, description) VALUES ('9282', 'ANKLE AND FOOT, EXCLUDING TOE(S) ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('9283', 'TOE');
INSERT INTO staging.icd9 (code, description) VALUES ('9288', 'MULTIPLE SITES OF LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9289', 'UNSPECIFIED PART');
INSERT INTO staging.icd9 (code, description) VALUES ('929', 'CRUSHING INJURY OF MULTIPLE AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9290', 'MULTIPLE SITES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9299', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('930', 'FOREIGN BODY ON EXTERNAL EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('9300', 'CORNEAL FOREIGN BODY');
INSERT INTO staging.icd9 (code, description) VALUES ('9301', 'FOREIGN BODY IN CONJUNCTIVAL SAC');
INSERT INTO staging.icd9 (code, description) VALUES ('9302', 'FOREIGN BODY IN LACRIMAL PUNCTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('9308', 'OTHER AND COMBINED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9309', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('931', 'FOREIGN BODY IN EAR');
INSERT INTO staging.icd9 (code, description) VALUES ('932', 'FOREIGN BODY IN NOSE');
INSERT INTO staging.icd9 (code, description) VALUES ('933', 'FOREIGN BODY IN PHARYNX AND LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('9330', 'PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('9331', 'LARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('934', 'FOREIGN BODY IN TRACHEA, BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('9340', 'TRACHEA');
INSERT INTO staging.icd9 (code, description) VALUES ('9341', 'MAIN BRONCHUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9348', 'OTHER SPECIFIED PART');
INSERT INTO staging.icd9 (code, description) VALUES ('9349', 'RESPIRATORY TREE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('935', 'FOREIGN BODY IN MOUTH, OESOPHAGUS AND STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('9350', 'MOUTH');
INSERT INTO staging.icd9 (code, description) VALUES ('9351', 'OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9352', 'STOMACH');
INSERT INTO staging.icd9 (code, description) VALUES ('936', 'FOREIGN BODY IN INTESTINE AND COLON');
INSERT INTO staging.icd9 (code, description) VALUES ('937', 'FOREIGN BODY IN ANUS AND RECTUM');
INSERT INTO staging.icd9 (code, description) VALUES ('938', 'FOREIGN BODY IN DIGESTIVE SYSTEM, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('939', 'FOREIGN BODY IN GENITOURINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('9390', 'BLADDER AND URETHRA');
INSERT INTO staging.icd9 (code, description) VALUES ('9391', 'UTERUS, ANY PART');
INSERT INTO staging.icd9 (code, description) VALUES ('9392', 'VULVA AND VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('9393', 'PENIS');
INSERT INTO staging.icd9 (code, description) VALUES ('9399', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('940', 'BURN CONFINED TO EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('9400', 'CHEMICAL BURN OF EYELIDS AND PERIOCULAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('9401', 'OTHER BURNS OF EYELIDS AND PERIOCULAR AREA');
INSERT INTO staging.icd9 (code, description) VALUES ('9402', 'ALKALINE CHEMICAL BURN OF CORNEA AND CONJUNCTIVAL SAC');
INSERT INTO staging.icd9 (code, description) VALUES ('9403', 'ACID CHEMICAL BURN OF CORNEA AND CONJUNCTIVAL SAC');
INSERT INTO staging.icd9 (code, description) VALUES ('9404', 'OTHER BURN OF CORNEA AND CONJUNCTIVAL SAC');
INSERT INTO staging.icd9 (code, description) VALUES ('9405', 'BURN WITH RESULTING RUPTURE AND DESTRUCTION OF EYEBALL');
INSERT INTO staging.icd9 (code, description) VALUES ('9409', 'UNSPECIFIED BURN OF EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('941', 'BURN OF FACE, HEAD AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('9410', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9411', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9412', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9413', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9414', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('942', 'BURN OF TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9420', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9421', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9422', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9423', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9424', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('943', 'BURN OF UPPER LIMB, EXCEPT WRIST AND HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('9430', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9431', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9432', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9433', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9434', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('944', 'BURN OF WRIST(S) AND HAND(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9440', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9441', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9442', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9443', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9444', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('945', 'BURN OF LOWER LIMB(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9450', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9451', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9452', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9453', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9454', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('946', 'BURNS OF MULTIPLE SPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9460', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9461', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9462', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9463', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9464', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('947', 'BURN OF INTERNAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('9470', 'MOUTH AND PHARYNX');
INSERT INTO staging.icd9 (code, description) VALUES ('9471', 'LARYNX, TRACHEA AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('9472', 'OESOPHAGUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9473', 'GASTROINTESTINAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('9474', 'VAGINA AND UTERUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9478', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9479', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('948', 'BURNS CLASSIFIED ACCORDING TO EXTENT OF BODY SURFACE INVOLVED');
INSERT INTO staging.icd9 (code, description) VALUES ('9480', 'LESS THAN 10% OF BODY SURFACE');
INSERT INTO staging.icd9 (code, description) VALUES ('9481', '10-19%');
INSERT INTO staging.icd9 (code, description) VALUES ('9482', '20-29%');
INSERT INTO staging.icd9 (code, description) VALUES ('9483', '30-39%');
INSERT INTO staging.icd9 (code, description) VALUES ('9484', '40-49%');
INSERT INTO staging.icd9 (code, description) VALUES ('9485', '50-59%');
INSERT INTO staging.icd9 (code, description) VALUES ('9486', '60-69%');
INSERT INTO staging.icd9 (code, description) VALUES ('9487', '70-79%');
INSERT INTO staging.icd9 (code, description) VALUES ('9488', '80-89%');
INSERT INTO staging.icd9 (code, description) VALUES ('9489', '90% OR MORE');
INSERT INTO staging.icd9 (code, description) VALUES ('949', 'BURN, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9490', 'UNSPECIFIED DEGREE');
INSERT INTO staging.icd9 (code, description) VALUES ('9491', 'ERYTHEMA (FIRST DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9492', 'BLISTERS, EPIDERMAL LOSS (SECOND DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9493', 'FULL-THICKNESS SKIN LOSS (THIRD DEGREE NOS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9494', 'DEEP NECROSIS OF UNDERLYING TISSUES (DEEP THIRD DEGREE)');
INSERT INTO staging.icd9 (code, description) VALUES ('950', 'INJURY TO OPTIC NERVE AND PATHWAYS');
INSERT INTO staging.icd9 (code, description) VALUES ('9500', 'OPTIC NERVE INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9501', 'INJURY TO OPTIC CHIASM');
INSERT INTO staging.icd9 (code, description) VALUES ('9502', 'INJURY TO OPTIC PATHWAYS');
INSERT INTO staging.icd9 (code, description) VALUES ('9503', 'INJURY TO VISUAL CORTEX');
INSERT INTO staging.icd9 (code, description) VALUES ('9509', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('951', 'INJURY TO OTHER CRANIAL NERVE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9510', 'INJURY TO OCULOMOTOR NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9511', 'INJURY TO TROCHLEAR NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9512', 'INJURY TO TRIGEMINAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9513', 'INJURY TO ABDUCENT NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9514', 'INJURY TO FACIAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9515', 'INJURY TO ACOUSTIC NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9516', 'INJURY TO ACCESSORY NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9517', 'INJURY TO HYPOGLOSSAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9518', 'INJURY TO OTHER SPECIFIED CRANIAL NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9519', 'INJURY TO UNSPECIFIED CRANIAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('952', 'SPINAL CORD LESION WITHOUT EVIDENCE OF SPINAL BONE INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('9520', 'CERVICAL');
INSERT INTO staging.icd9 (code, description) VALUES ('9521', 'DORSAL (THORACIC)');
INSERT INTO staging.icd9 (code, description) VALUES ('9522', 'LUMBAR');
INSERT INTO staging.icd9 (code, description) VALUES ('9523', 'SACRAL');
INSERT INTO staging.icd9 (code, description) VALUES ('9524', 'CAUDA EQUINA');
INSERT INTO staging.icd9 (code, description) VALUES ('9528', 'MULTIPLE SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9529', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('953', 'INJURY TO NERVE ROOTS AND SPINAL PLEXUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9530', 'CERVICAL ROOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9531', 'DORSAL ROOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9532', 'LUMBAR ROOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9533', 'SACRAL ROOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9534', 'BRACHIAL PLEXUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9535', 'LUMBOSACRAL PLEXUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9538', 'MULTIPLE SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9539', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('954', 'INJURY TO OTHER NERVE(S) OF TRUNK EXCLUDING SHOULDER AND PELVIC GIRDLES');
INSERT INTO staging.icd9 (code, description) VALUES ('9540', 'CERVICAL SYMPATHETIC');
INSERT INTO staging.icd9 (code, description) VALUES ('9541', 'OTHER SYMPATHETIC');
INSERT INTO staging.icd9 (code, description) VALUES ('9548', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9549', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('955', 'INJURY TO PERIPHERAL NERVE(S) OF SHOULDER GIRDLE AND UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9550', 'AXILLARY NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9551', 'MEDIAN NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9552', 'ULNAR NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9553', 'RADIAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9554', 'MUSCULOCUTANEOUS NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9555', 'CUTANEOUS SENSORY NERVE, UPPER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9556', 'DIGITAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9557', 'OTHER SPECIFIED NERVE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9558', 'MULTIPLE NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9559', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('956', 'INJURY TO PERIPHERAL NERVE(S) OF PELVIC GIRDLE AND LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9560', 'SCIATIC NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9561', 'FEMORAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9562', 'POSTERIOR TIBIAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9563', 'PERONEAL NERVE');
INSERT INTO staging.icd9 (code, description) VALUES ('9564', 'CUTANEOUS SENSORY NERVE, LOWER LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('9565', 'OTHER SPECIFIED NERVE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9568', 'MULTIPLE NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9569', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('957', 'INJURY TO OTHER AND UNSPECIFIED NERVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9570', 'SUPERFICIAL NERVES OF HEAD AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('9571', 'OTHER SPECIFIED NERVE(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('9578', 'MULTIPLE NERVES IN SEVERAL PARTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9579', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('958', 'CERTAIN EARLY COMPLICATIONS OF TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('9580', 'AIR EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('9581', 'FAT EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('9582', 'SECONDARY AND RECURRENT HAEMORRHAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('9583', 'POST-TRAUMATIC WOUND INFECTION, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9584', 'TRAUMATIC SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('9585', 'TRAUMATIC ANURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('9586', 'VOLKMANN''S ISCHAEMIC CONTRACTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9587', 'TRAUMATIC SUBCUTANEOUS EMPHYSEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('9588', 'OTHER EARLY COMPLICATIONS OF TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('959', 'INJURY, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9590', 'FACE AND NECK');
INSERT INTO staging.icd9 (code, description) VALUES ('9591', 'TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('9592', 'SHOULDER AND UPPER ARM');
INSERT INTO staging.icd9 (code, description) VALUES ('9593', 'ELBOW, FOREARM AND WRIST');
INSERT INTO staging.icd9 (code, description) VALUES ('9594', 'HAND, EXCEPT FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('9595', 'FINGER');
INSERT INTO staging.icd9 (code, description) VALUES ('9596', 'HIP AND THIGH');
INSERT INTO staging.icd9 (code, description) VALUES ('9597', 'KNEE, LEG, ANKLE AND FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9598', 'OTHER SPECIFIED SITES, INCLUDING MULTIPLE');
INSERT INTO staging.icd9 (code, description) VALUES ('9599', 'UNSPECIFIED SITE');
INSERT INTO staging.icd9 (code, description) VALUES ('960', 'POISONING BY ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9600', 'PENICILLINS');
INSERT INTO staging.icd9 (code, description) VALUES ('9601', 'ANTIFUNGAL ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9602', 'CHLORAMPHENICOL GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('9603', 'ERYTHROMYCIN AND OTHER MACROLIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('9604', 'TETRACYCLINE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('9605', 'CEFALOSPORIN GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('9606', 'ANTIMYCOBACTERIAL ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9607', 'ANTINEOPLASTIC ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('961', 'POISONING BY OTHER ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9610', 'SULFONAMIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('9611', 'ARSENICAL ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9612', 'HEAVY METAL ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9613', 'QUINOLINE AND HYDROXYQUINOLINE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9614', 'ANTIMALARIALS AND DRUGS ACTING ON OTHER BLOOD PROTOZOA');
INSERT INTO staging.icd9 (code, description) VALUES ('9615', 'OTHER ANTIPROTOZOAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9616', 'ANTHELMINTHICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9617', 'ANTIVIRAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9618', 'OTHER ANTIMYCOBACTERIAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9619', 'OTHER AND UNSPECIFIED ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('962', 'POISONING BY HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('9620', 'ADRENAL CORTICAL STEROIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9621', 'ANDROGENS AND ANABOLIC CONGENERS');
INSERT INTO staging.icd9 (code, description) VALUES ('9622', 'OVARIAN HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('9623', 'INSULINS AND ANTIDIABETIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9624', 'ANTERIOR PITUITARY HORMONES');
INSERT INTO staging.icd9 (code, description) VALUES ('9625', 'POSTERIOR PITUITARY HORMONES');
INSERT INTO staging.icd9 (code, description) VALUES ('9626', 'PARATHYROID AND PARATHYROID DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9627', 'THYROID AND THYROID DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9628', 'ANTITHYROID AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9629', 'OTHER AND UNSPECIFIED HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('963', 'POISONING BY PRIMARILY SYSTEMIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9630', 'ANTIALLERGIC AND ANTIEMETIC DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9631', 'ANTINEOPLASTIC AND IMMUNOSUPPRESSIVE DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9632', 'ACIDIFYING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9633', 'ALKALIZING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9634', 'ENZYMES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9635', 'VITAMINS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9638', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('964', 'POISONING BY AGENTS PRIMARILY AFFECTING BLOOD CONSTITUENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9640', 'IRON AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9641', 'LIVER PREPARATIONS AND OTHER ANTIANAEMIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9642', 'ANTICOAGULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9643', 'VITAMIN K (PHYTOMENADIONE)');
INSERT INTO staging.icd9 (code, description) VALUES ('9644', 'FIBRINOLYSIS-AFFECTING DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9645', 'ANTICOAGULANT ANTAGONISTS AND OTHER COAGULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9646', 'GAMMA GLOBULIN');
INSERT INTO staging.icd9 (code, description) VALUES ('9647', 'NATURAL BLOOD AND BLOOD PRODUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9648', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9649', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('965', 'POISONING BY ANALGESICS, ANTIPYRETICS AND ANTIRHEUMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9650', 'OPIATES AND RELATED NARCOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9651', 'SALICYLATES');
INSERT INTO staging.icd9 (code, description) VALUES ('9654', 'AROMATIC ANALGESICS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9655', 'PYRAZOLE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9656', 'ANTIRHEUMATICS (ANTIPHLOGISTICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9657', 'OTHER NON-NARCOTIC ANALGESICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9658', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9659', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('966', 'POISONING BY ANTICONVULSANTS AND ANTI-PARKINSONISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9660', 'OXAZOLIDINE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9661', 'HYDANTOIN DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9662', 'SUCCINIMIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('9663', 'OTHER AND UNSPECIFIED ANTICONVULSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9664', 'ANTI-PARKINSONISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('967', 'POISONING BY SEDATIVES AND HYPNOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9670', 'BARBITURATES');
INSERT INTO staging.icd9 (code, description) VALUES ('9671', 'CHLORAL HYDRATE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('9672', 'PARALDEHYDE');
INSERT INTO staging.icd9 (code, description) VALUES ('9673', 'BROMINE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9674', 'METHAQUALONE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9675', 'GLUTETHIMIDE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('9676', 'MIXED SEDATIVES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9678', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9679', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('968', 'POISONING BY OTHER CENTRAL NERVOUS SYSTEM DEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9680', 'CENTRAL NERVOUS SYSTEM MUSCLE-TONE DEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9681', 'HALOTHANE');
INSERT INTO staging.icd9 (code, description) VALUES ('9682', 'OTHER GASEOUS ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9683', 'INTRAVENOUS ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9684', 'OTHER AND UNSPECIFIED GENERAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9685', 'SURFACE AND INFILTRATION ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9686', 'PERIPHERAL NERVE- AND PLEXUS-BLOCKING ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9687', 'SPINAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9689', 'OTHER AND UNSPECIFIED LOCAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('969', 'POISONING BY PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9690', 'ANTIDEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9691', 'PHENOTHIAZINE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('9692', 'BUTYROPHENONE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('9693', 'OTHER ANTIPSYCHOTICS, NEUROLEPTICS AND MAJOR TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('9694', 'BENZODIAZEPINE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('9695', 'OTHER TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('9696', 'PSYCHODYSLEPTICS (HALLUCINOGENS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9697', 'PSYCHOSTIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9698', 'OTHER PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9699', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('970', 'POISONING BY CENTRAL NERVOUS SYSTEM STIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9700', 'ANALEPTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9701', 'OPIATE ANTAGONISTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9708', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9709', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('971', 'POISONING BY DRUGS PRIMARILY AFFECTING THE AUTONOMIC NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('9710', 'PARASYMPATHOMIMETICS (CHOLINERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9711', 'PARASYMPATHOLYTICS (ANTICHOLINERGICS AND ANTIMUSCARINICS) AND SPASMOLYTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9712', 'SYMPATHOMIMETICS (ADRENERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9713', 'SYMPATHOLYTICS (ANTIADRENERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('972', 'POISONING BY AGENTS PRIMARILY AFFECTING THE CARIOVASCULAR SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('9720', 'CARDIAC RHYTHM REGULATORS');
INSERT INTO staging.icd9 (code, description) VALUES ('9721', 'CARDIOTONIC GLYCOSIDES AND DRUGS OF SIMILAR ACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9722', 'ANTILIPAEMIC AND ANTIARTERIOSCLEROTIC DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9723', 'GANGLION-BLOCKING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9724', 'CORONARY VASODILATORS');
INSERT INTO staging.icd9 (code, description) VALUES ('9725', 'OTHER VASODILATORS');
INSERT INTO staging.icd9 (code, description) VALUES ('9726', 'OTHER ANTIHYPERTENSIVE AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9727', 'ANTIVARICOSE DRUGS, INCLUDING SCLEROSING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9728', 'CAPILLARY-ACTIVE DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9729', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('973', 'POISONING BY AGENTS PRIMARILY AFFECTING THE GASTROINTESTINAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('9730', 'ANTACIDS AND ANTIGASTRIC SECRETION DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9731', 'IRRITANT CATHARTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9732', 'EMOLLIENT CATHARTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9733', 'OTHER CATHARTICS, INCLUDING INTESTINAL ATONIA DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9734', 'DIGESTANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9735', 'ANTIDIARRHOEAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9736', 'EMETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('974', 'POISONING BY WATER, MINERAL AND URIC ACID METABOLISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9740', 'MERCURIAL DIURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9741', 'PURINE DERIVATIVE DIURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9742', 'CARBONIC ACID ANHYDRASE INHIBITORS');
INSERT INTO staging.icd9 (code, description) VALUES ('9743', 'SALURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9744', 'OTHER DIURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9745', 'ELECTROLYTIC, CALORIC AND WATER-BALANCE AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9746', 'OTHER MINERAL SALTS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9747', 'URIC ACID METABOLISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('975', 'POISONING BY AGENTS PRIMARILY ACTING ON THE SMOOTH AND SKELETAL MUSCLES AND RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('9750', 'OXYTOCIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9751', 'SMOOTH MUSCLE RELAXANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9752', 'SKELETAL MUSCLE RELAXANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9753', 'OTHER AND UNSPECIFIED DRUGS ACTING ON MUSCLES');
INSERT INTO staging.icd9 (code, description) VALUES ('9754', 'ANTITUSSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('9755', 'EXPECTORANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9756', 'ANTI-COMMON-COLD DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9757', 'ANTIASTHMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9758', 'OTHER AND UNSPECIFIED RESPIRATORY DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('976', 'POISONING BY AGENTS PRIMARILY AFFECTING SKIN AND MUCOUS MEMBRANE, OPHTHALMOLOGICAL, OTORHINOLARYNGOLOGICAL AND DENTAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9760', 'LOCAL ANTI-INFECTIVES AND ANTI-INFLAMMATORY DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9761', 'ANTIPRURITICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9762', 'LOCAL ASTRINGENTS AND LOCAL DETERGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9763', 'EMOLLIENTS, DEMULCENTS AND PROTECTANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9764', 'KERATOLYTICS, KERATOPLASTICS, OTHER HAIR TREATMENT DRUGS AND PREPARATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9765', 'EYE ANTI-INFECTIVES AND OTHER EYE DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9766', 'ANTI-INFECTIVES AND OTHER DRUGS AND PREPARATIONS FOR EAR, NOSE AND THROAT');
INSERT INTO staging.icd9 (code, description) VALUES ('9767', 'DENTAL DRUGS TOPICALLY APPLIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9768', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9769', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('977', 'POISONING BY OTHER AND UNSPECIFIED DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9770', 'DIETETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9771', 'LIPOTROPIC DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('9772', 'ANTIDOTES AND CHELATING AGENTS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9773', 'ALCOHOL DETERRENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9774', 'PHARMACEUTICAL EXCIPIENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9778', 'OTHER DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9779', 'UNSPECIFIED DRUG OR MEDICAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('978', 'POISONING BY BACTERIAL VACCINES');
INSERT INTO staging.icd9 (code, description) VALUES ('9780', 'BCG');
INSERT INTO staging.icd9 (code, description) VALUES ('9781', 'TYPHOID AND PARATYPHOID');
INSERT INTO staging.icd9 (code, description) VALUES ('9782', 'CHOLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('9783', 'PLAGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('9784', 'TETANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9785', 'DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('9786', 'PERTUSSIS VACCINE, INCLUDING COMBINATIONS WITH A PERTUSSIS COMPONENT');
INSERT INTO staging.icd9 (code, description) VALUES ('9788', 'OTHER AND UNSPECIFIED BACTERIAL VACCINES');
INSERT INTO staging.icd9 (code, description) VALUES ('9789', 'MIXED BACTERIAL VACCINES, EXCEPT COMBINATIONS WITH A PERTUSSIS COMPONENT');
INSERT INTO staging.icd9 (code, description) VALUES ('979', 'POISONING BY OTHER VACCINES AND BIOLOGICAL SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('9790', 'SMALLPOX VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('9791', 'RABIES VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('9792', 'TYPHUS VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('9793', 'YELLOW FEVER VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('9794', 'MEASLES VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('9795', 'POLIOMYELITIS VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('9796', 'OTHER AND UNSPECIFIED VIRAL AND RICKETTSIAL VACCINES');
INSERT INTO staging.icd9 (code, description) VALUES ('9797', 'MIXED VIRAL-RICKETTSIAL AND BACTERIAL VACCINES, EXCEPT COMBINATIONS WITH A PERTUSSIS COMPONENT');
INSERT INTO staging.icd9 (code, description) VALUES ('9799', 'OTHER AND UNSPECIFIED VACCINES AND BIOLOGICAL SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('980', 'TOXIC EFFECT OF ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('9800', 'ETHYL ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('9801', 'METHYL ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('9802', 'ISOPROPYL ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('9803', 'FUSEL OIL');
INSERT INTO staging.icd9 (code, description) VALUES ('9808', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9809', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('981', 'TOXIC EFFECT OF PETROLEUM PRODUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('982', 'TOXIC EFFECT OF SOLVENTS OTHER THAN PETROLEUM-BASED');
INSERT INTO staging.icd9 (code, description) VALUES ('9820', 'BENZENE AND HOMOLOGUES');
INSERT INTO staging.icd9 (code, description) VALUES ('9821', 'CARBON TETRACHLORIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('9822', 'CARBON DISULFIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('9823', 'OTHER CHLORINATED HYDROCARBON SOLVENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9824', 'NITROGLYCOL');
INSERT INTO staging.icd9 (code, description) VALUES ('9828', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('983', 'TOXIC EFFECT OF CORROSIVE AROMATICS, ACIDS AND CAUSTIC ALKALIS');
INSERT INTO staging.icd9 (code, description) VALUES ('9830', 'CORROSIVE AROMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('9831', 'ACIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9832', 'CAUSTIC ALKALIS');
INSERT INTO staging.icd9 (code, description) VALUES ('9839', 'CAUSTIC, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('984', 'TOXIC EFFECT OF LEAD AND ITS COMPOUNDS (INCLUDING FUMES)');
INSERT INTO staging.icd9 (code, description) VALUES ('9840', 'INORGANIC LEAD COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9841', 'ORGANIC LEAD COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9848', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9849', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('985', 'TOXIC EFFECT OF OTHER METALS');
INSERT INTO staging.icd9 (code, description) VALUES ('9850', 'MERCURY AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9851', 'ARSENIC AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9852', 'MANGANESE AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9853', 'BERYLLIUM AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9854', 'ANTIMONY AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9855', 'CADMIUM AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('9856', 'CHROMIUM');
INSERT INTO staging.icd9 (code, description) VALUES ('9858', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9859', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('986', 'TOXIC EFFECT OF CARBON MONOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('987', 'TOXIC EFFECT OF OTHER GASES, FUMES OR VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('9870', 'LIQUEFIED PETROLEUM GASES');
INSERT INTO staging.icd9 (code, description) VALUES ('9871', 'OTHER HYDROCARBON GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('9872', 'NITROGEN OXIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('9873', 'SULPHUR DIOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('9874', 'FREON');
INSERT INTO staging.icd9 (code, description) VALUES ('9875', 'LACRIMOGENIC GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('9876', 'CHLORINE GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('9877', 'HYDROCYANIC ACID GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('9878', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9879', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('988', 'TOXIC EFFECT OF NOXIOUS SUBSTANCES EATEN AS FOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('9880', 'FISH AND SHELLFISH');
INSERT INTO staging.icd9 (code, description) VALUES ('9881', 'MUSHROOMS');
INSERT INTO staging.icd9 (code, description) VALUES ('9882', 'BERRIES AND OTHER PLANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9888', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9889', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('989', 'TOXIC EFFECT OF OTHER SUBSTANCES, CHIEFLY NONMEDICINAL AS TO SOURCE');
INSERT INTO staging.icd9 (code, description) VALUES ('9890', 'HYDROCYANIC ACID AND CYANIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('9891', 'STRYCHNINE AND SALTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9892', 'CHLORINATED HYDROCARBONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9893', 'ORGANOPHOSPHATE AND CARBAMATE');
INSERT INTO staging.icd9 (code, description) VALUES ('9894', 'OTHER PESTICIDES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9895', 'VENOM');
INSERT INTO staging.icd9 (code, description) VALUES ('9896', 'SOAPS AND DETERGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9897', 'AFLATOXIN AND OTHER MYCOTOXIN (FOOD CONTAMINANTS)');
INSERT INTO staging.icd9 (code, description) VALUES ('9898', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9899', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('990', 'EFFECTS OF RADIATION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('991', 'EFFECTS OF REDUCED TEMPERATURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9910', 'FROSTBITE OF FACE');
INSERT INTO staging.icd9 (code, description) VALUES ('9911', 'FROSTBITE OF HAND');
INSERT INTO staging.icd9 (code, description) VALUES ('9912', 'FROSTBITE OF FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9913', 'FROSTBITE OF OTHER AND UNSPECIFIED SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('9914', 'IMMERSION FOOT');
INSERT INTO staging.icd9 (code, description) VALUES ('9915', 'CHILBLAINS');
INSERT INTO staging.icd9 (code, description) VALUES ('9916', 'HYPOTHERMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('9918', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9919', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('992', 'EFFECTS OF HEAT AND LIGHT');
INSERT INTO staging.icd9 (code, description) VALUES ('9920', 'HEAT STROKE AND SUNSTROKE');
INSERT INTO staging.icd9 (code, description) VALUES ('9921', 'HEAT SYNCOPE');
INSERT INTO staging.icd9 (code, description) VALUES ('9922', 'HEAT CRAMPS');
INSERT INTO staging.icd9 (code, description) VALUES ('9923', 'HEAT EXHAUSTION, ANHYDROTIC');
INSERT INTO staging.icd9 (code, description) VALUES ('9924', 'HEAT EXHAUSTION DUE TO SALT DEPLETION');
INSERT INTO staging.icd9 (code, description) VALUES ('9925', 'HEAT EXHAUSTION, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9926', 'HEAT FATIGUE, TRANSIENT');
INSERT INTO staging.icd9 (code, description) VALUES ('9927', 'HEAT OEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('9928', 'OTHER HEAT EFFECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('9929', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('993', 'EFFECTS OF AIR PRESSURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9930', 'BAROTRAUMA, OTITIC');
INSERT INTO staging.icd9 (code, description) VALUES ('9931', 'BAROTRAUMA, SINUS');
INSERT INTO staging.icd9 (code, description) VALUES ('9932', 'OTHER AND UNSPECIFIED EFFECTS OF HIGH ALTITUDE');
INSERT INTO staging.icd9 (code, description) VALUES ('9933', 'CAISSON DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('9934', 'EFFECTS OF AIR PRESSURE CAUSED BY EXPLOSION');
INSERT INTO staging.icd9 (code, description) VALUES ('9938', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('9939', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('994', 'EFFECTS OF OTHER EXTERNAL CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('9940', 'EFFECTS OF LIGHTNING');
INSERT INTO staging.icd9 (code, description) VALUES ('9941', 'DROWNING AND NONFATAL SUBMERSION');
INSERT INTO staging.icd9 (code, description) VALUES ('9942', 'EFFECTS OF HUNGER');
INSERT INTO staging.icd9 (code, description) VALUES ('9943', 'EFFECTS OF THIRST');
INSERT INTO staging.icd9 (code, description) VALUES ('9944', 'EXHAUSTION DUE TO EXPOSURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9945', 'EXHAUSTION DUE TO EXCESSIVE EXERTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9946', 'MOTION SICKNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('9947', 'ASPHYXIATION AND STRANGULATION');
INSERT INTO staging.icd9 (code, description) VALUES ('9948', 'ELECTROCUTION AND NONFATAL EFFECTS OF ELECTRIC CURRENT');
INSERT INTO staging.icd9 (code, description) VALUES ('9949', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('995', 'CERTAIN ADVERSE EFFECTS NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9950', 'ANAPHYLACTIC SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('9951', 'ANGIONEUROTIC OEDEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('9952', 'UNSPECIFIED ADVERSE EFFECT OF DRUG, MEDICAMENT AND BIOLOGICAL');
INSERT INTO staging.icd9 (code, description) VALUES ('9953', 'ALLERGY, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9954', 'SHOCK DUE TO ANAESTHESIA');
INSERT INTO staging.icd9 (code, description) VALUES ('9955', 'CHILD MALTREATMENT SYNDROME');
INSERT INTO staging.icd9 (code, description) VALUES ('9958', 'OTHER SPECIFIED ADVERSE EFFECTS NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('996', 'COMPLICATIONS PECULIAR TO CERTAIN SPECIFIED PROCEDURES');
INSERT INTO staging.icd9 (code, description) VALUES ('9960', 'MECHANICAL COMPLICATION OF CARDIAC DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9961', 'MECHANICAL COMPLICATION OF OTHER VASCULAR DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9962', 'MECHANICAL COMPLICATION OF NERVOUS SYSTEM DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9963', 'MECHANICAL COMPLICATION OF GENITOURINARY DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9964', 'MECHANICAL COMPLICATION OF INTERNAL ORTHOPAEDIC DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9965', 'MECHANICAL COMPLICATION OF OTHER SPECIFIED PROSTHETIC DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9966', 'INFECTION AND INFLAMMATORY REACTION DUE TO INTERNAL PROSTHETIC DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9967', 'OTHER COMPLICATIONS OF INTERNAL PROSTHETIC DEVICE, IMPLANT AND GRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('9968', 'COMPLICATIONS OF TRANSPLANTED ORGAN');
INSERT INTO staging.icd9 (code, description) VALUES ('9969', 'COMPLICATIONS OF REATTACHED EXTREMITY');
INSERT INTO staging.icd9 (code, description) VALUES ('997', 'COMPLICATIONS AFFECTING SPECIFIED BODY SYSTEMS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9970', 'CENTRAL NERVOUS SYSTEM COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9971', 'CARDIAC COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9972', 'PERIPHERAL VASCULAR COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9973', 'RESPIRATORY COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9974', 'GASTROINTESTINAL COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9975', 'URINARY COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9976', 'LATE AMPUTATION STUMP COMPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('9979', 'COMPLICATIONS AFFECTING OTHER SPECIFIED BODY SYSTEMS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('998', 'OTHER COMPLICATIONS OF PROCEDURES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9980', 'POSTOPERATIVE SHOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('9981', 'HAEMORRHAGE OR HAEMATOMA COMPLICATING A PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9982', 'ACCIDENTAL PUNCTURE OR LACERATION DURING A PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9983', 'DISRUPTION OF OPERATION WOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('9984', 'FOREIGN BODY ACCIDENTALLY LEFT DURING A PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9985', 'POSTOPERATIVE INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9986', 'PERSISTENT POSTOPERATIVE FISTULA');
INSERT INTO staging.icd9 (code, description) VALUES ('9987', 'ACUTE REACTION TO FOREIGN SUBSTANCE ACCIDENTALLY LEFT DURING A PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('9988', 'OTHER SPECIFIED COMPLICATIONS OF PROCEDURES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9989', 'UNSPECIFIED COMPLICATION OF PROCEDURE, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('999', 'COMPLICATIONS OF MEDICAL CARE, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('9990', 'GENERALIZED VACCINIA');
INSERT INTO staging.icd9 (code, description) VALUES ('9991', 'AIR EMBOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('9992', 'OTHER VASCULAR COMPLICATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('9993', 'OTHER INFECTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9994', 'ANAPHYLACTIC SHOCK DUE TO SERUM');
INSERT INTO staging.icd9 (code, description) VALUES ('9995', 'OTHER SERUM REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9996', 'ABO INCOMPATIBILITY REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9997', 'RH INCOMPATIBILITY REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9998', 'OTHER TRANSFUSION REACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('9999', 'OTHER AND UNSPECIFIED COMPLICATIONS OF MEDICAL CARE, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E800', 'RAILWAY ACCIDENT INVOLVING COLLISION WITH ROLLING STOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('E8000', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8001', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8002', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8003', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8008', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8009', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E801', 'RAILWAY ACCIDENT INVOLVING COLLISION WITH OTHER OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8010', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8011', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8012', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8013', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8018', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8019', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E802', 'RAILWAY ACCIDENT INVOLVING DERAILMENT WITHOUT ANTECEDENT COLLISION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8020', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8021', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8022', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8023', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8028', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8029', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E803', 'RAILWAY ACCIDENT INVOLVING EXPLOSION, FIRE OR BURNING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8030', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8031', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8032', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8033', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8038', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8039', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E804', 'FALL IN, ON OR FROM RAILWAY TRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8040', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8041', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8042', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8043', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8048', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8049', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E805', 'HIT BY ROLLING STOCK');
INSERT INTO staging.icd9 (code, description) VALUES ('E8050', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8051', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8052', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8053', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8058', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8059', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E806', 'OTHER SPECIFIED RAILWAY ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8060', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8061', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8062', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8063', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8068', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8069', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E807', 'RAILWAY ACCIDENT OF UNSPECIFIED NATURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8070', 'RAILWAY EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8071', 'PASSENGER ON RAILWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8072', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8073', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8078', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8079', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E810', 'MOTOR VEHICLE TRAFFIC ACCIDENT INVOLVING COLLISION WITH TRAIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8100', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8101', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8102', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8103', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8104', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8105', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8106', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8107', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8108', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8109', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E811', 'MOTOR VEHICLE TRAFFIC ACCIDENT INVOLVING RE-ENTRANT COLLISION WITH ANOTHER MOTOR VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8110', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8111', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8112', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8113', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8114', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8115', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8116', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8117', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8118', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8119', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E812', 'OTHER MOTOR VEHICLE TRAFFIC ACCIDENT INVOLVING COLLISION WITH ANOTHER MOTOR VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8120', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8121', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8122', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8123', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8124', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8125', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8126', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8127', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8128', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8129', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E813', 'MOTOR VEHICLE TRAFFIC ACCIDENT INVOLVING COLLISION WITH OTHER VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8130', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8131', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8132', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8133', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8134', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8135', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8136', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8137', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8138', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8139', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E814', 'MOTOR VEHICLE TRAFFIC ACCIDENT INVOLVING COLLISION WITH PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8140', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8141', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8142', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8143', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8144', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8145', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8146', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8147', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8148', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8149', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E815', 'OTHER MOTOR VEHICLE TRAFFIC ACCIDENT INVOLVING COLLISION ON THE HIGHWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8150', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8151', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8152', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8153', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8154', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8155', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8156', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8157', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8158', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8159', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E816', 'MOTOR VEHICLE TRAFFIC ACCIDENT DUE TO LOSS OF CONTROL, WITHOUT COLLISION ON THE HIGHWAY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8160', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8161', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8162', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8163', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8164', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8165', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8166', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8167', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8168', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8169', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E817', 'NONCOLLISION MOTOR VEHICLE TRAFFIC ACCIDENT WHILE BOARDING OR ALIGHTING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8170', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8171', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8172', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8173', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8174', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8175', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8176', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8177', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8178', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8179', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E818', 'OTHER NONCOLLISION MOTOR VEHICLE TRAFFIC ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8180', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8181', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8182', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8183', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8184', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8185', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8186', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8187', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8188', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8189', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E819', 'MOTOR VEHICLE TRAFFIC ACCIDENT OF UNSPECIFIED NATURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8190', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8191', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8192', 'MOTORCYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8193', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8194', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8195', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8196', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8197', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8198', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8199', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E820', 'NONTRAFFIC ACCIDENT INVOLVING MOTOR-DRIVEN SNOW VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8200', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8201', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8202', 'MOTOR CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8203', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8204', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8205', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8206', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8207', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8208', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8209', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E821', 'NONTRAFFIC ACCIDENT INVOLVING OTHER OFF-ROAD MOTOR VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8210', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8211', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8212', 'MOTOR CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8213', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8214', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8215', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8216', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8217', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8218', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8219', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E822', 'OTHER MOTOR VEHICLE NONTRAFFIC ACCIDENT INVOLVING COLLISION WITH MOVING OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8220', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8221', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8222', 'MOTOR CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8223', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8224', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8225', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8226', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8227', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8228', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8229', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E823', 'OTHER MOTOR VEHICLE NONTRAFFIC ACCIDENT INVOLVING COLLISION WITH STATIONARY OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8230', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8231', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8232', 'MOTOR CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8233', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8234', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8235', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8236', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8237', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8238', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8239', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E824', 'OTHER MOTOR VEHICLE NONTRAFFIC ACCIDENT WHILE BOARDING AND ALIGHTING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8240', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8241', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8242', 'MOTOR CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8243', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8244', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8245', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8246', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8247', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8248', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8249', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E825', 'OTHER MOTOR VEHICLE NONTRAFFIC ACCIDENT OF OTHER AND UNSPECIFIED NATURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8250', 'DRIVER OF MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8251', 'PASSENGER IN MOTOR VEHICLE OTHER THAN MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8252', 'MOTOR CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8253', 'PASSENGER ON MOTORCYCLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8254', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8255', 'RIDER OF ANIMAL; OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8256', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8257', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8258', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8259', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E826', 'PEDAL CYCLE ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8260', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8261', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8262', 'RIDER OF ANIMAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8263', 'OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8264', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8268', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8269', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E827', 'ANIMAL-DRAWN VEHICLE ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8270', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8271', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8272', 'RIDER OF ANIMAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8273', 'OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8274', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8278', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8279', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E828', 'ACCIDENT INVOLVING ANIMAL BEING RIDDEN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8280', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8281', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8282', 'RIDER OF ANIMAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8283', 'OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8284', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8288', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8289', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E829', 'OTHER ROAD VEHICLE ACCIDENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8290', 'PEDESTRIAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8291', 'PEDAL CYCLIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8292', 'RIDER OF ANIMAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8293', 'OCCUPANT OF ANIMAL-DRAWN VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8294', 'OCCUPANT OF STREETCAR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8298', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8299', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E830', 'ACCIDENT TO WATERCRAFT CAUSING SUBMERSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8300', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8301', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8302', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8303', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8304', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8305', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8306', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8308', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8309', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E831', 'ACCIDENT TO WATERCRAFT CAUSING OTHER INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8310', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8311', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8312', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8313', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8314', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8315', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8316', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8318', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8319', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E832', 'OTHER ACCIDENTAL SUBMERSION OR DROWNING IN WATER TRANSPORT ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8320', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8321', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8322', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8323', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8324', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8325', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8326', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8328', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8329', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E833', 'FALL ON STAIRS OR LADDERS IN WATER TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8330', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8331', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8332', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8333', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8334', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8335', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8336', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8338', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8339', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E834', 'OTHER FALL FROM ONE LEVEL TO ANOTHER IN WATER TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8340', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8341', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8342', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8343', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8344', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8345', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8346', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8348', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8349', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E835', 'OTHER AND UNSPECIFIED FALL IN WATER TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8350', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8351', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8352', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8353', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8354', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8355', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8356', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8358', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8359', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E836', 'MACHINERY ACCIDENT IN WATER TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8360', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8361', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8362', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8363', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8364', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8365', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8366', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8368', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8369', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E837', 'EXPLOSION, FIRE OR BURNING IN WATERCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8370', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8371', 'OCCUPANT OF SMALL BOAT, POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8372', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8373', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8374', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8375', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8376', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8378', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8379', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E838', 'OTHER AND UNSPECIFIED WATER TRANSPORT ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8380', 'OCCUPANT OF SMALL BOAT, UNPOWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8381', 'OCCUPANT OF SMALL BOAT  POWERED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8382', 'OCCUPANT OF OTHER WATERCRAFT - CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8383', 'OCCUPANT OF OTHER WATERCRAFT - OTHER THAN CREW');
INSERT INTO staging.icd9 (code, description) VALUES ('E8384', 'WATER SKIER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8385', 'SWIMMER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8386', 'DOCKERS, STEVEDORES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8388', 'OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8389', 'UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E840', 'ACCIDENT TO POWERED AIRCRAFT AT TAKEOFF OR LANDING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8400', 'OCCUPANT OF SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8401', 'OCCUPANT OF MILITARY AIRCRAFT, ANY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8402', 'CREW OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8403', 'OTHER OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8404', 'OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO AIR TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8405', 'OCCUPANT OF OTHER POWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8406', 'OCCUPANT OF UNPOWERED AIRCRAFT, EXCEPT PARACHUTIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8407', 'PARACHUTIST (MILITARY) (OTHER)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8408', 'GROUND CREW, AIRLINE EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8409', 'OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E841', 'ACCIDENT TO POWERED AIRCRAFT, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8410', 'OCCUPANT OF SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8411', 'OCCUPANT OF MILITARY AIRCRAFT, ANY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8412', 'CREW OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8413', 'OTHER OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8414', 'OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO AIR TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8415', 'OCCUPANT OF OTHER POWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8416', 'OCCUPANT OF UNPOWERED AIRCRAFT, EXCEPT PARACHUTIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8417', 'PARACHUTIST (MILITARY) (OTHER)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8418', 'GROUND CREW, AIRLINE EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8419', 'OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E842', 'ACCIDENT TO UNPOWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8420', 'OCCUPANT OF SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8421', 'OCCUPANT OF MILITARY AIRCRAFT, ANY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8422', 'CREW OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8423', 'OTHER OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8424', 'OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO AIR TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8425', 'OCCUPANT OF OTHER POWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8426', 'OCCUPANT OF UNPOWERED AIRCRAFT, EXCEPT PARACHUTIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8427', 'PARACHUTIST (MILITARY) (OTHER)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8428', 'GROUND CREW, AIRLINE EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8429', 'OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E843', 'FALL IN, ON OR FROM AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8430', 'OCCUPANT OF SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8431', 'OCCUPANT OF MILITARY AIRCRAFT, ANY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8432', 'CREW OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8433', 'OTHER OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8434', 'OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO AIR TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8435', 'OCCUPANT OF OTHER POWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8436', 'OCCUPANT OF UNPOWERED AIRCRAFT, EXCEPT PARACHUTIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8437', 'PARACHUTIST (MILITARY) (OTHER)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8438', 'GROUND CREW, AIRLINE EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8439', 'OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E844', 'OTHER SPECIFIED AIR TRANSPORT ACCIDENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8440', 'OCCUPANT OF SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8441', 'OCCUPANT OF MILITARY AIRCRAFT, ANY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8442', 'CREW OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8443', 'OTHER OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8444', 'OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO AIR TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8445', 'OCCUPANT OF OTHER POWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8446', 'OCCUPANT OF UNPOWERED AIRCRAFT, EXCEPT PARACHUTIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8447', 'PARACHUTIST (MILITARY) (OTHER)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8448', 'GROUND CREW, AIRLINE EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8449', 'OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E845', 'ACCIDENT INVOLVING SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8450', 'OCCUPANT OF SPACECRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8451', 'OCCUPANT OF MILITARY AIRCRAFT, ANY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8452', 'CREW OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8453', 'OTHER OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO SURFACE TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8454', 'OCCUPANT OF COMMERCIAL AIRCRAFT (POWERED) IN SURFACE TO AIR TRANSPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8455', 'OCCUPANT OF OTHER POWERED AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8456', 'OCCUPANT OF UNPOWERED AIRCRAFT, EXCEPT PARACHUTIST');
INSERT INTO staging.icd9 (code, description) VALUES ('E8457', 'PARACHUTIST (MILITARY) (OTHER)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8458', 'GROUND CREW, AIRLINE EMPLOYEE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8459', 'OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E846', 'ACCIDENTS INVOLVING POWERED VEHICLES USED SOLELY WITHIN THE BUILDINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E847', 'ACCIDENTS INVOLVING CABLE CARS NOT RUNNING ON RAILS');
INSERT INTO staging.icd9 (code, description) VALUES ('E848', 'ACCIDENTS INVOLVING OTHER VEHICLES NOT ELSEWHERE CLASSIFIABLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E850', 'ACCIDENTAL POISONING BY ANALGESICS, ANTIPYRETICS, ANTIRHEUMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8500', 'OPIATES AND RELATED NARCOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8501', 'SALICYLATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8502', 'AROMATIC ANALGESICS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8503', 'PYRAZOLE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8504', 'ANTIRHEUMATICS (ANTIPHLOGISTICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8505', 'OTHER NON-NARCOTIC ANALGESICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8508', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8509', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E851', 'ACCIDENTAL POISONING BY BARBITURATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E852', 'ACCIDENTAL POISONING BY OTHER SEDATIVES AND HYPNOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8520', 'CHLORAL HYDRATE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E8521', 'PARALDEHYDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8522', 'BROMINE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8523', 'METHAQUALONE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8524', 'GLUTETHIMIDE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E8525', 'MIXED SEDATIVES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8528', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8529', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E853', 'ACCIDENTAL POISONING BY OTHER TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8530', 'PHENOTHIAZINE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8531', 'BUTYROPHENONE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8532', 'BENZODIAZEPINE BASED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8538', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8539', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E854', 'ACCIDENTAL POISONING BY OTHER PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8540', 'ANTIDEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8541', 'PSYCHODYSLEPTICS (HALLUCINOGENS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8542', 'PSYCHOSTIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8543', 'CENTRAL NERVOUS SYSTEM STIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E855', 'ACCIDENTAL POISONING BY OTHER DRUGS ACTING ON CENTRAL AND AUTONOMIC NERVOUS SYSTEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8550', 'ANTICONVULSANT AND ANTI-PARKINSONISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8551', 'OTHER CENTRAL NERVOUS SYSTEM DEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8552', 'LOCAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8553', 'PARASYMPATHOMIMETICS (CHOLINERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8554', 'PARASYMPATHOLYTICS (ANTICHOLINERGICS AND ANTIMUSCARINICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8555', 'SYMPATHOMIMETICS (ADRENERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8556', 'SYMPATHOLYTICS (ANTIADRENERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8558', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8559', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E856', 'ACCIDENTAL POISONING BY ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E857', 'ACCIDENTAL POISONING BY ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E858', 'ACCIDENTAL POISONING BY OTHER DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8580', 'HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8581', 'PRIMARILY SYSTEMIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8582', 'AGENTS PRIMARILY AFFECTING BLOOD CONSTITUENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8583', 'AGENTS PRIMARILY AFFECTING CARDIOVASCULAR SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E8584', 'AGENTS PRIMARILY AFFECTING GASTROINTESTINAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E8585', 'WATER, MINERAL AND URIC ACID METABOLISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8586', 'AGENTS PRIMARILY ACTING ON THE SMOOTH AND SKELETAL MUSCLES AND RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E8587', 'AGENTS PRIMARILY AFFECTING SKIN AND MUCOUS MEMBRANE, OPHTHALMOLOGICAL, OTORHINOLARYNGOLOGICAL AND DENTAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8588', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8589', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E860', 'ACCIDENTAL POISONING BY ALCOHOL, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8600', 'ALCOHOLIC BEVERAGES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8601', 'OTHER AND UNSPECIFIED ETHYL ALCOHOL AND ITS PRODUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8602', 'METHYL ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8603', 'ISOPROPYL ALCOHOL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8604', 'FUSEL OIL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8608', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E861', 'ACCIDENTAL POISONING BY CLEANSING AND POLISHING AGENTS, DISINFECTANTS, PAINTS AND VARNISHES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8610', 'SYNTHETIC DETERGENTS AND SHAMPOOS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8611', 'SOAP PRODUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8612', 'POLISHES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8613', 'OTHER CLEANSING AND POLISHING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8614', 'DISINFECTANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8615', 'LEAD PAINTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8616', 'OTHER PAINTS AND VARNISHES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8619', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E862', 'ACCIDENTAL POISONING BY PETROLEUM PRODUCTS, OTHER SOLVENTS AND THEIR VAPOURS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8620', 'PETROLEUM SOLVENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8621', 'PETROLEUM FUELS AND CLEANERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8622', 'LUBRICATING OILS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8623', 'PETROLEUM SOLIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8624', 'OTHER SOLVENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8629', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E863', 'ACCIDENTAL POISONING BY AGRICULTURAL AND HORTICULTURAL CHEMICAL AND');
INSERT INTO staging.icd9 (code, description) VALUES ('E8630', 'INSECTICIDES OF ORGANOCHLORINE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8631', 'INSECTICIDES OF ORGANOPHOSPHORUS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8632', 'CARBAMATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8633', 'MIXTURES OF INSECTICIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8634', 'OTHER AND UNSPECIFIED INSECTICIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8635', 'HERBICIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8636', 'FUNGICIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8637', 'RODENTICIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8638', 'FUMIGANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8639', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E864', 'ACCIDENTAL POISONING BY CORROSIVES AND CAUSTICS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8640', 'CORROSIVE AROMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8641', 'ACIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8642', 'CAUSTIC ALKALIS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8643', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8644', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E865', 'ACCIDENTAL POISONING FROM FOODSTUFFS AND POISONOUS PLANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8650', 'MEAT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8651', 'SHELLFISH');
INSERT INTO staging.icd9 (code, description) VALUES ('E8652', 'OTHER FISH');
INSERT INTO staging.icd9 (code, description) VALUES ('E8653', 'BERRIES AND SEEDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8654', 'OTHER PLANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8655', 'MUSHROOMS AND OTHER FUNGI');
INSERT INTO staging.icd9 (code, description) VALUES ('E8658', 'OTHER FOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('E8659', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E866', 'ACCIDENTAL POISONING BY OTHER AND UNSPECIFIED SOLID AND LIQUID SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8660', 'LEAD AND ITS COMPOUNDS AND FUMES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8661', 'MERCURY AND ITS COMPOUNDS AND FUMES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8662', 'ANTIMONY AND ITS COMPOUNDS AND FUMES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8663', 'ARSENIC AND ITS COMPOUNDS AND FUMES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8664', 'OTHER METALS AND THEIR COMPOUNDS AND FUMES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8665', 'PLANT FOODS AND FERTILIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8666', 'GLUES AND ADHESIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8667', 'COSMETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8668', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8669', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E867', 'ACCIDENTAL POISONING BY GAS DISTRIBUTED BY PIPELINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E868', 'ACCIDENTAL POISONING BY OTHER UTILITY GAS AND OTHER CARBON MONOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8680', 'LIQUEFIED PETROLEUM GAS DISTRIBUTED IN MOBILE CONTAINERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8681', 'OTHER AND UNSPECIFIED UTILITY GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8682', 'MOTOR VEHICLE EXHAUST GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8683', 'CARBON MONOXIDE FROM INCOMPLETE COMBUSTION OF OTHER DOMESTIC FUELS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8688', 'CARBON MONOXIDE FROM OTHER SOURCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8689', 'UNSPECIFIED CARBON MONOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E869', 'ACCIDENTAL POISONING BY OTHER GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8690', 'NITROGEN OXIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8691', 'SULPHER DIOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8692', 'FREON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8693', 'LACRIMOGENIC GAS (TEAR GAS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8698', 'OTHER SPECIFIED GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8699', 'UNSPECIFIED GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E870', 'ACCIDENTAL CUT, PUNCTURE, PERFORATION OR HAEMORRHAGE DURING MEDICAL CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8700', 'SURGICAL OPERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8701', 'INFUSION OR TRANSFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8702', 'KIDNEY DIALYSIS OR OTHER PERFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8703', 'INJECTION OR VACCINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8704', 'ENDOSCOPIC EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8705', 'ASPIRATION OF FLUID OR TISSUE, PUNCTURE AND CATHETERIZATION (ANY,');
INSERT INTO staging.icd9 (code, description) VALUES ('E8706', 'HEART CATHETERIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8707', 'ADMINISTRATION OF ENEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('E8708', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8709', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E871', 'FOREIGN OBJECT LEFT IN BODY DURING PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8710', 'SURGICAL OPERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8711', 'INFUSION OR TRANSFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8712', 'KIDNEY DIALYSIS OR OTHER PERFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8713', 'INJECTION OR VACCINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8714', 'ENDOSCOPIC EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8715', 'ASPIRATION OF FLUID OR TISSUE, PUNCTURE AND CATHETERIZATION (ANY, EXCEPT HEART CATHETERIZATION)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8716', 'HEART CATHETERIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8717', 'REMOVAL OF CATHETER OR PACKING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8718', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E872', 'FAILURE OF STERILE PRECAUTIONS DURING PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8720', 'SURGICAL OPERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8721', 'INFUSION OR TRANSFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8722', 'KIDNEY DIALYSIS AND OTHER PERFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8723', 'INJECTION OR VACCINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8724', 'ENDOSCOPIC EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8725', 'ASPIRATION OF FLUID OR TISSUE, PUNCTURE AND CATHETERIZATION (ANY,');
INSERT INTO staging.icd9 (code, description) VALUES ('E8726', 'HEART CATHETERIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8728', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8729', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E873', 'FAILURE IN DOSAGE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8730', 'EXCESSIVE AMOUNT OF BLOOD OR OTHER FLUID DURING TRANSFUSION OR INFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8731', 'INCORRECT DILUTION OF FLUID DURING INFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8732', 'OVERDOSE OF RADIATION IN THERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8733', 'INADVERTENT EXPOSURE OF PATIENT TO RADIATION DURING MEDICAL CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8734', 'FAILURE IN DOSAGE IN ELECTROSHOCK OR INSULIN-SHOCK THERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8735', 'INAPPROPRIATE (TOO HOT OR TOO COLD) TEMPERATURE IN LOCAL APPLICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8736', 'NONADMINISTRATION OF NECESSARY DRUG OR MEDICAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E874', 'MECHANICAL FAILURE OF INSTRUMENT OR APPARATUS DURING PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8740', 'SURGICAL OPERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8741', 'INFUSION AND TRANSFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8742', 'KIDNEY DIALYSIS AND OTHER PERFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8743', 'ENDOSCOPIC EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8744', 'ASPIRATION OF FLUID OR TISSUE, PUNCTURE AND CATHETERIZATION (ANY, EXCEPT HEART CATHETERIZATION)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8745', 'HEART CATHETERIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8748', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8749', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E875', 'CONTAMINATED OR INFECTED BLOOD, OTHER FLUID, DRUG OR BIOLOGICAL SUBSTANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8750', 'CONTAMINATED SUBSTANCE TRANSFUSED OR INFUSED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8751', 'CONTAMINATED SUBSTANCE INJECTED OR USED FOR VACCINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8752', 'CONTAMINATED DRUG OR BIOLOGICAL SUBSTANCE ADMINISTERED BY OTHER MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8758', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8759', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E876', 'OTHER AND UNSPECIFIED MISADVENTURES DURING MEDICAL CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8760', 'MISMATCHED BLOOD IN TRANSFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8761', 'WRONG FLUID IN INFUSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8762', 'FAILURE IN SUTURE AND LIGATURE DURING SURGICAL OPERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8763', 'ENDOTRACHEAL TUBE WRONGLY PLACED DURING ANAESTHETIC PROCEDURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8764', 'FAILURE TO INTRODUCE OR TO REMOVE OTHER TUBE OR INSTRUMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8765', 'PERFORMANCE OF INAPPROPRIATE OPERATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8768', 'OTHER SPECIFIED MISADVENTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8769', 'UNSPECIFIED MISADVENTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E878', 'SURGICAL OPERATION AND OTHER SURGICAL PROCEDURES AS THE CAUSE OF');
INSERT INTO staging.icd9 (code, description) VALUES ('E8780', 'SURGICAL OPERATION WITH TRANSPLANT OF WHOLE ORGAN');
INSERT INTO staging.icd9 (code, description) VALUES ('E8781', 'SURGICAL OPERATION WITH IMPLANT OF ARTIFICIAL INTERNAL DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8782', 'SURGICAL OPERATION WITH ANASTOMOSIS, BYPASS OR GRAFT, WITH NATURAL OR ARTIFICIAL TISSUES USED AS IMPLANT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8783', 'SURGICAL OPERATION WITH FORMATION OF EXTERNAL STOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('E8784', 'OTHER RESTORATIVE SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8785', 'AMPUTATION OF LIMB(S)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8786', 'REMOVAL OF OTHER ORGAN (PARTIAL) (TOTAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8788', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8789', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E879', 'OTHER PROCEDURES, WITHOUT MENTION OF MISADVENTURE AT THE TIME OF PROCEDURE, AS THE CAUSE OF ABNORMAL REACTION OF PATIENT, OR OF LATER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8790', 'CARDIAC CATHETERIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8791', 'KIDNEY DIALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8792', 'RADIOLOGICAL PROCEDURE AND RADIOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8793', 'SHOCK THERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('E8794', 'ASPIRATION OF FLUID');
INSERT INTO staging.icd9 (code, description) VALUES ('E8795', 'INSERTION OF GASTRIC OR DUODENAL SOUND');
INSERT INTO staging.icd9 (code, description) VALUES ('E8796', 'URINARY CATHETERIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8797', 'BLOOD SAMPLING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8798', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E880', 'FALL ON OR FROM STAIRS OR STEPS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8800', 'ESCALATOR');
INSERT INTO staging.icd9 (code, description) VALUES ('E8809', 'OTHER STAIRS OR STEPS');
INSERT INTO staging.icd9 (code, description) VALUES ('E881', 'FALL ON OR FROM LADDERS OR SCAFFOLDING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8810', 'FALL FROM LADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8811', 'FALL FROM SCAFFOLDING');
INSERT INTO staging.icd9 (code, description) VALUES ('E882', 'FALL FROM OR OUT OF BUILDING OR OTHER STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E883', 'FALL INTO HOLE OR OTHER OPENING IN SURFACE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8830', 'ACCIDENT FROM DIVING OR JUMPING INTO WATER (SWIMMING POOL)');
INSERT INTO staging.icd9 (code, description) VALUES ('E8831', 'ACCIDENTAL FALL INTO WELL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8832', 'ACCIDENTAL FALL INTO STORM DRAIN OR MANHOLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8839', 'FALL INTO OTHER HOLE OR OTHER OPENING IN SURFACE');
INSERT INTO staging.icd9 (code, description) VALUES ('E884', 'OTHER FALL FROM ONE LEVEL TO ANOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E8840', 'FALL FROM PLAYGROUND EQUIPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E8841', 'FALL FROM CLIFF');
INSERT INTO staging.icd9 (code, description) VALUES ('E8842', 'FALL FROM CHAIR OR BED');
INSERT INTO staging.icd9 (code, description) VALUES ('E8849', 'OTHER FALL FROM ONE LEVEL TO ANOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E885', 'FALL ON SAME LEVEL FROM SLIPPING, TRIPPING OR STUMBLING');
INSERT INTO staging.icd9 (code, description) VALUES ('E886', 'FALL ON SAME LEVEL FROM COLLISION, PUSHING OR SHOVING, BY OR WITH OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E8860', 'IN SPORTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E8869', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E887', 'FRACTURE, CAUSE UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E888', 'OTHER AND UNSPECIFIED FALL');
INSERT INTO staging.icd9 (code, description) VALUES ('E890', 'CONFLAGRATION IN PRIVATE DWELLING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8900', 'EXPLOSION CAUSED BY CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8901', 'FUMES FROM COMBUSTION OF POLYVINYLCHLORIDE (PVC) AND SIMILAR 1 MATERIAL IN CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8902', 'OTHER SMOKE AND FUMES FROM CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8903', 'BURNING CAUSED BY CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8908', 'OTHER ACCIDENT RESULTING FROM CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8909', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E891', 'CONFLAGRATION IN OTHER AND UNSPECIFIED BUILDING OR STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8910', 'EXPLOSION CAUSED BY CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8911', 'FUMES FROM COMBUSTION OF POLYVINYLCHLORIDE (PVC) AND SIMILAR MATERIAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E8912', 'OTHER SMOKE AND FUMES FROM CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8913', 'BURNING CAUSED BY CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8918', 'OTHER ACCIDENT RESULTING FROM CONFLAGRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E8919', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E892', 'CONFLAGRATION NOT IN BUILDING OR STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E893', 'ACCIDENT CAUSED BY IGNITION OF CLOTHING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8930', 'FROM CONTROLLED FIRE IN PRIVATE DWELLING');
INSERT INTO staging.icd9 (code, description) VALUES ('E8931', 'FROM CONTROLLED FIRE IN OTHER BUILDING OR STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8932', 'FROM CONTROLLED FIRE NOT IN BUILDING OR STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E8938', 'FROM OTHER SOURCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8939', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E894', 'IGNITION OF HIGHLY INFLAMMABLE MATERIAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E895', 'ACCIDENT CAUSED BY CONTROLLED FIRE IN PRIVATE DWELLING');
INSERT INTO staging.icd9 (code, description) VALUES ('E896', 'ACCIDENT CAUSED BY CONTROLLED FIRE IN OTHER AND UNSPECIFIED BUILDING OR STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E897', 'ACCIDENT CAUSED BY CONTROLLED FIRE NOT IN BUILDING OR STRUCTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E898', 'ACCIDENT CAUSED BY OTHER SPECIFIED FIRE AND FLAMES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8980', 'BURNING BEDCLOTHES');
INSERT INTO staging.icd9 (code, description) VALUES ('E8981', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E899', 'ACCIDENT CAUSED BY UNSPECIFIED FIRE');
INSERT INTO staging.icd9 (code, description) VALUES ('E900', 'EXCESSIVE HEAT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9000', 'DUE TO WEATHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9001', 'OF MANMADE ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9009', 'OF UNSPECIFIED ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E901', 'EXCESSIVE COLD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9010', 'DUE TO WEATHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9011', 'OF MANMADE ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9018', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9019', 'OF UNSPECIFIED ORIGIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E902', 'HIGH AND LOW AIR PRESSURE AND CHANGES IN AIR PRESSURE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9020', 'RESIDENCE OR PROLONGED VISIT AT HIGH ALTITUDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9021', 'IN AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9022', 'DUE TO DIVING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9028', 'DUE TO OTHER SPECIFIED CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9029', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E903', 'TRAVEL AND MOTION');
INSERT INTO staging.icd9 (code, description) VALUES ('E904', 'HUNGER, THIRST, EXPOSURE, NEGLECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9040', 'ABANDONMENT OR NEGLECT OF INFANTS AND HELPLESS PERSONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9041', 'LACK OF FOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9042', 'LACK OF WATER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9043', 'EXPOSURE (TO WEATHER CONDITIONS) NOT ELSEWHERE CLASSIFIABLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9049', 'PRIVATION, UNQUALIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E905', 'VENOMOUS ANIMALS AND PLANTS AS THE CAUSE OF POISONING AND TOXIC REACTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9050', 'VENOMOUS SNAKES AND LIZARDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9051', 'VENOMOUS SPIDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9052', 'SCORPION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9053', 'HORNETS, WASPS AND BEES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9054', 'CENTIPEDE AND VENOMOUS MILLIPEDE (TROPICAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9055', 'OTHER VENOMOUS ARTHROPODS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9056', 'VENOMOUS MARINE ANIMALS AND PLANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9057', 'POISONING AND TOXIC REACTIONS CAUSED BY OTHER PLANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9058', 'OTHER SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9059', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E906', 'OTHER INJURY CAUSED BY ANIMALS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9060', 'DOG BITE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9061', 'RAT BITE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9062', 'BITE OF NONVENOMOUS SNAKES AND LIZARDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9063', 'BITE OF OTHER ANIMAL EXCEPT ARTHROPOD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9064', 'BITE OF NONVENOMOUS ARTHROPOD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9068', 'OTHER SPECIFIED INJURY CAUSED BY ANIMAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E9069', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E907', 'LIGHTNING');
INSERT INTO staging.icd9 (code, description) VALUES ('E908', 'CATACLYSMIC STORMS, AND FLOODS RESULTING FROM STORMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E909', 'CATACLYSMIC EARTH SURFACE MOVEMENTS AND ERUPTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E910', 'ACCIDENTAL DROWNING AND SUBMERSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9100', 'WHILE WATER SKIING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9101', 'WHILE ENGAGED IN OTHER SPORT OR RECREATIONAL ACTIVITY WITH DIVING EQUIPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9102', 'WHILE ENGAGED IN OTHER SPORT OR RECREATIONAL ACTIVITY WITHOUT DIVING EQUIPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9103', 'WHILE SWIMMING OR DIVING FOR PURPOSES OTHER THAN RECREATION OR SPORT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9104', 'IN BATHTUB');
INSERT INTO staging.icd9 (code, description) VALUES ('E9108', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9109', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E911', 'INHALATION AND INGESTION OF FOOD CAUSING OBSTRUCTION OF RESPIRATORY TRACT OR SUFFOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E912', 'INHALATION AND INGESTION OF OTHER OBJECT CAUSING OBSTRUCTION OF RESPIRATORY TRACT OR SUFFOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E913', 'ACCIDENTAL MECHANICAL SUFFOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9130', 'IN BED OR CRADLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9131', 'BY PLASTIC BAG');
INSERT INTO staging.icd9 (code, description) VALUES ('E9132', 'DUE TO LACK OF AIR (IN CLOSED PLACE)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9133', 'BY FALLING EARTH OR OTHER SUBSTANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9138', 'OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9139', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E914', 'FOREIGN BODY ACCIDENTALLY ENTERING EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('E915', 'FOREIGN BODY ACCIDENTALLY ENTERING OTHER ORIFICE');
INSERT INTO staging.icd9 (code, description) VALUES ('E916', 'STRUCK ACCIDENTALLY BY FALLING OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E917', 'STRIKING AGAINST OR STRUCK ACCIDENTALLY BY OBJECTS OR PERSONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9170', 'IN SPORTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9171', 'CAUSED BY A CROWD, BY COLLECTIVE FEAR OR PANIC');
INSERT INTO staging.icd9 (code, description) VALUES ('E9172', 'IN RUNNING WATER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9179', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E918', 'CAUGHT ACCIDENTALLY IN OR BETWEEN OBJECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E919', 'ACCIDENTS CAUSED BY MACHINERY');
INSERT INTO staging.icd9 (code, description) VALUES ('E9190', 'AGRICULTURAL MACHINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9191', 'MINING AND EARTH-DRILLING MACHINERY');
INSERT INTO staging.icd9 (code, description) VALUES ('E9192', 'LIFTING MACHINES AND APPLIANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9193', 'METALWORKING MACHINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9194', 'WOODWORKING AND FORMING MACHINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9195', 'PRIME MOVERS, EXCEPT ELECTRICAL MOTORS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9196', 'TRANSMISSION MACHINERY');
INSERT INTO staging.icd9 (code, description) VALUES ('E9197', 'EARTH MOVING, SCRAPING AND OTHER EXCAVATING MACHINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9198', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9199', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E920', 'ACCIDENTS CAUSED BY CUTTING AND PIERCING INSTRUMENTS OR OBJECTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9200', 'POWERED LAWN MOWER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9201', 'OTHER POWERED HAND TOOLS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9202', 'POWERED HOUSEHOLD APPLIANCES AND IMPLEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9203', 'KNIVES, SWORDS AND DAGGERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9204', 'OTHER HAND TOOLS AND IMPLEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9208', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9209', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E921', 'ACCIDENT CAUSED BY EXPLOSION OF PRESSURE VESSEL');
INSERT INTO staging.icd9 (code, description) VALUES ('E9210', 'BOILERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9211', 'GAS CYLINDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9218', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9219', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E922', 'ACCIDENT CAUSED BY FIREARM MISSILE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9220', 'HAND GUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9221', 'SHOTGUN (AUTOMATIC)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9222', 'HUNTING RIFLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9223', 'MILITARY FIREARMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9228', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9229', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E923', 'ACCIDENT CAUSED BY EXPLOSIVE MATERIAL');
INSERT INTO staging.icd9 (code, description) VALUES ('E9230', 'FIREWORKS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9231', 'BLASTING MATERIALS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9232', 'EXPLOSIVE GASES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9238', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9239', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E924', 'ACCIDENT CAUSED BY HOT SUBSTANCE OR OBJECT, CAUSTIC OR CORROSIVE MATERIAL AND STEAM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9240', 'HOT LIQUIDS AND VAPOURS, INCLUDING STEAM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9241', 'CAUSTIC AND CORROSIVE SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9248', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9249', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E925', 'ACCIDENT CAUSED BY ELECTRIC CURRENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9250', 'DOMESTIC WIRING AND APPLIANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9251', 'ELECTRIC POWER GENERATING PLANTS, DISTRIBUTION STATIONS,');
INSERT INTO staging.icd9 (code, description) VALUES ('E9252', 'INDUSTRIAL WIRING, APPLIANCES AND ELECTRICAL MACHINERY');
INSERT INTO staging.icd9 (code, description) VALUES ('E9258', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9259', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E926', 'EXPOSURE TO RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9260', 'RADIOFREQUENCY RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9261', 'INFRARED HEATERS AND LAMPS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9262', 'VISIBLE AND ULTRAVIOLET LIGHT SOURCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9263', 'X-RAYS AND OTHER ELECTROMAGNETIC IONIZING RADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9264', 'LASERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9265', 'RADIOACTIVE ISOTOPES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9268', 'OTHER SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E927', 'OVEREXERTION AND STRENUOUS MOVEMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E928', 'OTHER AND UNSPECIFIED ENVIRONMENTAL AND ACCIDENTAL CAUSES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9280', 'PROLONGED STAY IN WEIGHTLESS ENVIRONMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9281', 'EXPOSURE TO NOISE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9282', 'VIBRATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9288', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9289', 'UNSPECIFIED ACCIDENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E929', 'LATE EFFECTS OF ACCIDENTAL INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('E9290', 'LATE EFFECTS OF MOTOR VEHICLE ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9291', 'LATE EFFECTS OF OTHER TRANSPORT ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9292', 'LATE EFFECTS OF ACCIDENTAL POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9293', 'LATE EFFECTS OF ACCIDENTAL FALL');
INSERT INTO staging.icd9 (code, description) VALUES ('E9294', 'LATE EFFECTS OF ACCIDENT CAUSED BY FIRE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9295', 'LATE EFFECTS OF ACCIDENT DUE TO NATURAL AND ENVIRONMENTAL FACTORS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9298', 'LATE EFFECTS OF OTHER ACCIDENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9299', 'LATE EFFECTS OF UNSPECIFIED ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E930', 'ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9300', 'PENICILLINS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9301', 'ANTIFUNGAL ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9302', 'CHLORAMPHENICOL GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E9303', 'ERYTHROMYCIN AND OTHER MACROLIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9304', 'TETRACYCLINE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E9305', 'CEFALOSPORIN GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E9306', 'ANTIMYCOBACTERIAL ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9307', 'ANTINEOPLASTIC ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9308', 'OTHER SPECIFIED ANTIBIOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9309', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E931', 'OTHER ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9310', 'SULFONAMIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9311', 'ARSENICAL ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9312', 'HEAVY METAL ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9313', 'QUINOLINE AND HYDROXYQUINOLINE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9314', 'ANTIMALARIALS AND DRUGS ACTING ON OTHER BLOOD PROTOZOA');
INSERT INTO staging.icd9 (code, description) VALUES ('E9315', 'OTHER ANTIPROTOZOAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9316', 'ANTHELMINTHICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9317', 'ANTIVIRAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9318', 'OTHER ANTIMYCOBACTERIAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9319', 'OTHER AND UNSPECIFIED ANTI-INFECTIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E932', 'HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9320', 'ADRENAL CORTICAL STEROIDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9321', 'ANDROGENS AND ANABOLIC CONGENERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9322', 'OVARIAN HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9323', 'INSULINS AND ANTIDIABETIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9324', 'ANTERIOR PITUITARY HORMONES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9325', 'POSTERIOR PITUITARY HORMONES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9326', 'PARATHYROID AND PARATHYROID DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9327', 'THYROID AND THYROID DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9328', 'ANTITHYROID AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9329', 'OTHER AND UNSPECIFIED HORMONES AND SYNTHETIC SUBSTITUTES');
INSERT INTO staging.icd9 (code, description) VALUES ('E933', 'PRIMARILY SYSTEMIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9330', 'ANTIALLERGIC AND ANTIEMETIC DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9331', 'ANTINEOPLASTIC AND IMMUNOSUPPRESSIVE DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9332', 'ACIDIFYING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9333', 'ALKALIZING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9334', 'ENZYMES NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9335', 'VITAMINS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9338', 'OTHER SYSTEMIC AGENTS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9339', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E934', 'AGENTS PRIMARILY AFFECTING BLOOD CONSTITUENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9340', 'IRON AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9341', 'LIVER PREPARATIONS AND OTHER ANTIANAEMIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9342', 'ANTICOAGULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9343', 'VITAMIN K (PHYTOMENADIONE)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9344', 'FIBRINOLYSIS-AFFECTING DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9345', 'ANTICOAGULANT ANTAGONISTS AND OTHER COAGULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9346', 'GAMMA GLOBULIN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9347', 'NATURAL BLOOD AND BLOOD PRODUCTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9348', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9349', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E935', 'ANALGESICS, ANTIPYRETICS AND ANTIRHEUMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9350', 'OPIATES AND RELATED NARCOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9351', 'SALICYLATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9352', 'AROMATIC ANALGESICS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9353', 'PYRAZOLE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9354', 'ANTIRHEUMATICS (ANTIPHLOGISTICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9355', 'OTHER NON-NARCOTIC ANALGESICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9358', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9359', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E936', 'ANTICONVULSANTS AND ANTI-PARKINSONISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9360', 'OXAZOLIDINE DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9361', 'HYDANTOIN DERIVATIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9362', 'SUCCINIMIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9363', 'OTHER AND UNSPECIFIED ANTICONVULSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9364', 'ANTI-PARKINSONISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E937', 'SEDATIVES AND HYPNOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9370', 'BARBITURATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9371', 'CHLORAL HYDRATE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E9372', 'PARALDEHYDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9373', 'BROMINE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9374', 'METHAQUALONE COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9375', 'GLUTETHIMIDE GROUP');
INSERT INTO staging.icd9 (code, description) VALUES ('E9376', 'MIXED SEDATIVES, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9378', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9379', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E938', 'OTHER CENTRAL NERVOUS SYSTEM DEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9380', 'CENTRAL NERVOUS SYSTEM MUSCLE-TONE DEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9381', 'HALOTHANE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9382', 'OTHER GASEOUS ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9383', 'INTRAVENOUS ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9384', 'OTHER AND UNSPECIFIED GENERAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9385', 'SURFACE AND INFILTRATION ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9386', 'PERIPHERAL NERVE- AND PLEXUS-BLOCKING ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9387', 'SPINAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9389', 'OTHER AND UNSPECIFIED LOCAL ANAESTHETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E939', 'PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9390', 'ANTIDEPRESSANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9391', 'PHENOTHIAZINE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9392', 'BUTYROPHENONE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9393', 'OTHER ANTIPSYCHOTICS, NEUROLEPTICS AND MAJOR TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9394', 'BENZODIAZEPINE-BASED TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9395', 'OTHER TRANQUILLIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9396', 'PSYCHODYSLEPTICS (HALLUCINOGENS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9397', 'PSYCHOSTIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9398', 'OTHER PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9399', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E940', 'CENTRAL NERVOUS SYSTEM STIMULANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9400', 'ANALEPTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9401', 'OPIATE ANTAGONISTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9408', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9409', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E941', 'DRUGS PRIMARILY AFFECTING THE AUTONOMIC NERVOUS SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9410', 'PARASYMPATHOMIMETICS (CHOLINERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9411', 'PARASYMPATHOLYTICS (ANTICHOLINERGICS AND ANTIMUSCARINICS) AND SPAMOLYTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9412', 'SYMPATHOMIMETICS (ADRENERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9413', 'SYMPATHOLYTICS (ANTIADRENERGICS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9419', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E942', 'AGENTS PRIMARILY AFFECTING THE CARDIOVASCULAR SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9420', 'CARDIAC RHYTHM REGULATORS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9421', 'CARDIOTONIC GLYCOSIDES AND DRUGS OF SIMILAR ACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9422', 'ANTILIPAEMIC AND ANTIARTERIOSCLEROTIC DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9423', 'GANGLION-BLOCKING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9424', 'CORONARY VASODILATORS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9425', 'OTHER VASODILATORS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9426', 'OTHER ANTIHYPERTENSIVE AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9427', 'ANTIVARICOSE DRUGS, INCLUDING SCLEROSING AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9428', 'CAPILLARY-ACTIVE DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9429', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E943', 'AGENTS PRIMARILY AFFECTING GASTROINTESTINAL SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9430', 'ANTACIDS AND ANTI-GASTRIC-SECRETION DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9431', 'IRRITANT CATHARTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9432', 'EMOLLIENT CATHARTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9433', 'OTHER CATHARTICS, INCLUDING INTESTINAL ATONIA DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9434', 'DIGESTANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9435', 'ANTIDIARRHOEAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9436', 'EMETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9438', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9439', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E944', 'WATER, MINERAL AND URIC ACID METABOLISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9440', 'MERCURIAL DIURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9441', 'PURINE DERIVATIVE DIURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9442', 'CARBONIC ACID ANHYDRASE INHIBITORS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9443', 'SALURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9444', 'OTHER DIURETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9445', 'ELECTROLYTIC, CALORIC AND WATER-BALANCE AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9446', 'OTHER MINERAL SALTS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9447', 'URIC ACID METABOLISM DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E945', 'AGENTS PRIMARILY ACTING ON THE SMOOTH AND SKELETAL MUSCLES AND RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9450', 'OXYTOCIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9451', 'SMOOTH MUSCLE RELAXANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9452', 'SKELETAL MUSCLE RELAXANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9453', 'OTHER AND UNSPECIFIED DRUGS ACTING ON MUSCLES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9454', 'ANTITUSSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9455', 'EXPECTORANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9456', 'ANTI-COMMON-COLD DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9457', 'ANTIASTHMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9458', 'OTHER AND UNSPECIFIED RESPIRATORY DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E946', 'AGENTS PRIMARILY AFFECTING SKIN AND MUCOUS MEMBRANE, OPHTHALMOLOGICAL, OTORHINOLARYNGOLOGICAL AND DENTAL DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9460', 'LOCAL ANTI-INFECTIVES AND ANTI-INFLAMMATORY DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9461', 'ANTIPRURITICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9462', 'LOCAL ASTRINGENTS AND LOCAL DETERGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9463', 'EMOLLIENTS, DEMULCENTS AND PROTECTANTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9464', 'KERATOLYTICS, KERATOPLASTICS, OTHER HAIR TREATMENT DRUGS AND PREPARATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9465', 'EYE ANTI-INFECTIVES AND OTHER EYE DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9466', 'ANTI-INFECTIVE AND OTHER DRUGS AND PREPARATIONS FOR EAR, NOSE AND THROAT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9467', 'DENTAL DRUGS TOPICALLY APPLIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9468', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9469', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E947', 'OTHER AND UNSPECIFIED DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9470', 'DIETETICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9471', 'LIPOTROPIC DRUGS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9472', 'ANTIDOTES AND CHELATING AGENTS, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9473', 'ALCOHOL DETERRENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9474', 'PHARMACEUTICAL EXCIPIENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9478', 'OTHER DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9479', 'UNSPECIFIED DRUG OR MEDICAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E948', 'BACTERIAL VACCINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9480', 'BCG VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9481', 'TYPHOID AND PARATYPHOID');
INSERT INTO staging.icd9 (code, description) VALUES ('E9482', 'CHOLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('E9483', 'PLAGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9484', 'TETANUS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9485', 'DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('E9486', 'PERTUSSIS VACCINE, INCLUDING COMBINATIONS WITH A PERTUSSIS COMPONENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9488', 'OTHER AND UNSPECIFIED BACTERIAL VACCINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9489', 'MIXED BACTERIAL VACCINES, EXCEPT COMBINATIONS WITH A PERTUSSIS COMPONENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E949', 'OTHER VACCINES AND BIOLOGICAL SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9490', 'SMALLPOX VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9491', 'RABIES VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9492', 'TYPHUS VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9493', 'YELLOW FEVER VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9494', 'MEASLES VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9495', 'POLIOMYLETIS VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9496', 'OTHER AND UNSPECIFIED VIRAL AND RICKETTSIAL VACCINES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9497', 'MIXED VIRAL-RICKETTSIAL AND BACTERIAL VACCINES, EXCEPT COMBINATIONS WITH A PERTUSSIS COMPONENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9499', 'OTHER AND UNSPECIFIED VACCINES AND BIOLOGICAL SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E950', 'SUICIDE AND SELFINFLICTED POISONING BY SOLID OR LIQUID SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9500', 'ANALGESICS, ANTIPYRETICS AND ANTIRHEUMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9501', 'BARBITURATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9502', 'OTHER SEDATIVES AND HYPNOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9503', 'TRANQUILLIZERS AND OTHER PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9504', 'OTHER SPECIFIED DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9505', 'UNSPECIFIED DRUG OR MEDICAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9506', 'AGRICULTURAL AND HORTICULTURAL CHEMICAL AND PHARMACEUTICAL PREPARATIONS OTHER THAN PLANT FOODS AND FERTILIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9507', 'CORROSIVE AND CAUSTIC SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9508', 'ARSENIC AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9509', 'OTHER AND UNSPECIFIED SOLID AND LIQUID SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E951', 'SUICIDE AND SELFINFLICTED POISONING BY GASES IN DOMESTIC USE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9510', 'GAS DISTRIBUTED BY PIPELINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9511', 'LIQUIFIED PETROLEUM GAS DISTRIBUTED IN MOBILE CONTAINERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9518', 'OTHER UTILITY GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E952', 'SUICIDE AND SELFINFLICTED POISONING BY OTHER GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9520', 'MOTOR VEHICLE EXHAUST GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9521', 'OTHER CARBON MONOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9528', 'OTHER SPECIFIED GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9529', 'UNSPECIFIED GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E953', 'SUICIDE AND SELFINFLICTED INJURY BY HANGING, STRANGULATION AND SUFFOCATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9530', 'HANGING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9531', 'SUFFOCATION BY PLASTIC BAG');
INSERT INTO staging.icd9 (code, description) VALUES ('E9538', 'OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9539', 'UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E954', 'SUICIDE AND SELFINFLICTED INJURY BY SUBMERSION (DROWNING)');
INSERT INTO staging.icd9 (code, description) VALUES ('E955', 'SUICIDE AND SELFINFLICTED INJURY BY FIREARMS AND EXPLOSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9550', 'HAND GUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9551', 'SHOT GUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9552', 'HUNTING RIFLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9553', 'MILITARY FIREARMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9554', 'OTHER AND UNSPECIFIED FIREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9555', 'EXPLOSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9559', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E956', 'SUICIDE AND SELFINFLICTED INJURY BY CUTTING AND PIERCING INSTRUMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E957', 'SUICIDE AND SELFINFLICTED INJURY BY JUMPING FROM HIGH PLACE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9570', 'RESIDENTIAL PREMISES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9571', 'OTHER MANMADE STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9572', 'NATURAL SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E958', 'SUICIDE AND SELFINFLICTED INJURY BY OTHER AND UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9580', 'JUMPING OR LYING BEFORE MOVING OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9581', 'BURNS, FIRE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9582', 'SCALD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9583', 'EXTREMES OF COLD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9584', 'ELECTROCUTION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9585', 'CRASHING OF MOTOR VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9586', 'CRASHING OF AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9587', 'CAUSTIC SUBSTANCES, EXCEPT POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9588', 'OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9589', 'UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E959', 'LATE EFFECTS OF SELFINFLICTED INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('E960', 'FIGHT, BRAWL, RAPE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9600', 'UNARMED FIGHT OR BRAWL');
INSERT INTO staging.icd9 (code, description) VALUES ('E9601', 'RAPE');
INSERT INTO staging.icd9 (code, description) VALUES ('E961', 'ASSAULT BY CORROSIVE OR CAUSTIC SUBSTANCE, EXCEPT POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('E962', 'ASSAULT BY POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9620', 'DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9621', 'OTHER SOLID AND LIQUID SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9622', 'OTHER GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9629', 'UNSPECIFIED POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('E963', 'ASSAULT BY HANGING AND STRANGULATION');
INSERT INTO staging.icd9 (code, description) VALUES ('E964', 'ASSAULT BY SUBMERSION (DROWNING)');
INSERT INTO staging.icd9 (code, description) VALUES ('E965', 'ASSAULT BY FIREARMS AND EXPLOSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9650', 'HANDGUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9651', 'SHOTGUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9652', 'HUNTING RIFLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9653', 'MILITARY FIREARMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9654', 'OTHER AND UNSPECIFIED FIREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9655', 'ANTIPERSONNEL BOMB');
INSERT INTO staging.icd9 (code, description) VALUES ('E9656', 'PETROL BOMB');
INSERT INTO staging.icd9 (code, description) VALUES ('E9657', 'LETTER BOMB');
INSERT INTO staging.icd9 (code, description) VALUES ('E9658', 'OTHER SPECIFIED EXPLOSIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9659', 'UNSPECIFIED EXPLOSIVE');
INSERT INTO staging.icd9 (code, description) VALUES ('E966', 'ASSAULT BY CUTTING AND PIERCING INSTRUMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E967', 'CHILD BATTERING AND OTHER MALTREATMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9670', 'BY PARENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9671', 'BY OTHER SPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E9679', 'BY UNSPECIFIED PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E968', 'ASSAULT BY OTHER AND UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9680', 'FIRE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9681', 'PUSHING FROM HIGH PLACE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9682', 'STRIKING BY BLUNT OR THROWN OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9683', 'HOT LIQUID');
INSERT INTO staging.icd9 (code, description) VALUES ('E9684', 'CRIMINAL NEGLECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9688', 'OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9689', 'UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E969', 'LATE EFFECTS OF INJURY PURPOSELY INFLICTED BY OTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('E970', 'INJURY DUE TO LEGAL INTERVENTION BY FIREARMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E971', 'INJURY DUE TO LEGAL INTERVENTION BY EXPLOSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E972', 'INJURY DUE TO LEGAL INTERVENTION BY GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E973', 'INJURY DUE TO LEGAL INTERVENTION BY BLUNT OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E974', 'INJURY DUE TO LEGAL INTERVENTION BY CUTTING AND PIERCING INSTRUMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E975', 'INJURY DUE TO LEGAL INTERVENTION BY OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E976', 'INJURY DUE TO LEGAL INTERVENTION BY UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E977', 'LATE EFFECTS OF INJURIES DUE TO LEGAL INTERVENTION');
INSERT INTO staging.icd9 (code, description) VALUES ('E978', 'LEGAL EXECUTION');
INSERT INTO staging.icd9 (code, description) VALUES ('E980', 'POISONING BY SOLID OR LIQUID SUBSTANCES, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9800', 'ANALGESICS, ANTIPYRETICS AND ANTIRHEUMATICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9801', 'BARBITURATES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9802', 'OTHER SEDATIVES AND HYPNOTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9803', 'TRANQUILLIZERS AND OTHER PSYCHOTROPIC AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9804', 'OTHER SPECIFIED DRUGS AND MEDICAMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9805', 'UNSPECIFIED DRUG OR MEDICAMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9806', 'CORROSIVE AND CAUSTIC SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9807', 'AGRICULTURAL AND HORTICULTURAL CHEMICAL AND PHARMACEUTICAL PREPARATIONS OTHER THAN PLANT FOODS AND FERTILIZERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9808', 'ARSENIC AND ITS COMPOUNDS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9809', 'OTHER AND UNSPECIFIED SOLID AND LIQUID SUBSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E981', 'POISONING BY GASES IN DOMESTIC USE, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9810', 'GAS DISTRIBUTED BY PIPELINE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9811', 'LIQUIFIED PETROLEUM GAS DISTRIBUTED IN MOBILE CONTAINERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9818', 'OTHER UTILITY GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E982', 'POISONING BY OTHER GASES, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9820', 'MOTOR VEHICLE EXHAUST GAS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9821', 'OTHER CARBON MONOXIDE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9828', 'OTHER SPECIFIED GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9829', 'UNSPECIFIED GASES AND VAPOURS');
INSERT INTO staging.icd9 (code, description) VALUES ('E983', 'HANGING, STRANGULATION OR SUFFOCATION, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9830', 'HANGING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9831', 'SUFFOCATION BY PLASTIC BAG');
INSERT INTO staging.icd9 (code, description) VALUES ('E9838', 'OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9839', 'UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E984', 'SUBMERSION (DROWNING), UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E985', 'INJURY BY FIREARMS AND EXPLOSIVES, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9850', 'HAND GUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9851', 'SHOT GUN');
INSERT INTO staging.icd9 (code, description) VALUES ('E9852', 'HUNTING RIFLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9853', 'MILITARY FIREARMS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9854', 'OTHER AND UNSPECIFIED FIREARM');
INSERT INTO staging.icd9 (code, description) VALUES ('E9855', 'EXPLOSIVES');
INSERT INTO staging.icd9 (code, description) VALUES ('E986', 'INJURY BY CUTTING AND PIERCING INSTRUMENTS, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E987', 'FALLING FROM HIGH PLACE, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9870', 'RESIDENTIAL PREMISES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9871', 'OTHER MAN-MADE STRUCTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9872', 'NATURAL SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('E9879', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E988', 'INJURY BY OTHER AND UNSPECIFIED MEANS, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E9880', 'JUMPING OR LYING BEFORE MOVING OBJECT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9881', 'BURNS, FIRE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9882', 'SCALD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9883', 'EXTREMES OF COLD');
INSERT INTO staging.icd9 (code, description) VALUES ('E9884', 'ELECTROCUTION');
INSERT INTO staging.icd9 (code, description) VALUES ('E9885', 'CRASHING OF MOTOR VEHICLE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9886', 'CRASHING OF AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E9887', 'CAUSTIC SUBSTANCES, EXCEPT POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('E9888', 'OTHER SPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9889', 'UNSPECIFIED MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('E989', 'LATE EFFECTS OF INJURY, UNDETERMINED WHETHER ACCIDENTALLY OR PURPOSELY INFLICTED');
INSERT INTO staging.icd9 (code, description) VALUES ('E990', 'INJURY DUE TO WAR OPERATIONS BY FIRES AND CONFLAGRATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9900', 'FROM PETROL BOMB');
INSERT INTO staging.icd9 (code, description) VALUES ('E9909', 'FROM OTHER AND UNSPECIFIED SOURCES');
INSERT INTO staging.icd9 (code, description) VALUES ('E991', 'INJURY DUE TO WAR OPERATIONS BY BULLETS AND FRAGMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9910', 'RUBBER BULLETS (RIFLE)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9911', 'PELLETS (RIFLE)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9912', 'OTHER BULLETS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9913', 'ANTIPERSONNEL BOMB (FRAGMENTS)');
INSERT INTO staging.icd9 (code, description) VALUES ('E9919', 'OTHER AND UNSPECIFIED FRAGMENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('E992', 'INJURY DUE TO WAR OPERATIONS BY EXPLOSION OF MARINE WEAPONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E993', 'INJURY DUE TO WAR OPERATIONS BY OTHER EXPLOSION');
INSERT INTO staging.icd9 (code, description) VALUES ('E994', 'INJURY DUE TO WAR OPERATIONS BY DESTRUCTION OF AIRCRAFT');
INSERT INTO staging.icd9 (code, description) VALUES ('E995', 'INJURY DUE TO WAR OPERATIONS BY OTHER AND UNSPECIFIED FORMS OF CONVENTIONAL WARFARE');
INSERT INTO staging.icd9 (code, description) VALUES ('E996', 'INJURY DUE TO WAR OPERATIONS BY NUCLEAR WEAPONS');
INSERT INTO staging.icd9 (code, description) VALUES ('E997', 'INJURY DUE TO WAR OPERATIONS BY OTHER FORMS OF UNCONVENTIONAL WARFARE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9970', 'LASERS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9971', 'BIOLOGICAL WARFARE');
INSERT INTO staging.icd9 (code, description) VALUES ('E9972', 'GASES, FUMES AND CHEMICALS');
INSERT INTO staging.icd9 (code, description) VALUES ('E9978', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('E9979', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('E998', 'INJURY DUE TO WAR OPERATIONS BUT OCCURRING AFTER CESSATION OF HOSTILITIES');
INSERT INTO staging.icd9 (code, description) VALUES ('E999', 'LATE EFFECTS OF INJURY DUE TO WAR OPERATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V01', 'CONTACT WITH OR EXPOSURE TO COMMUNICABLE DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V010', 'CHOLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('V011', 'TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V012', 'POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V013', 'SMALLPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('V014', 'RUBELLA');
INSERT INTO staging.icd9 (code, description) VALUES ('V015', 'RABIES');
INSERT INTO staging.icd9 (code, description) VALUES ('V016', 'VENEREAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V017', 'OTHER VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V018', 'OTHER COMMUNICABLE DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V019', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V02', 'CARRIER OR SUSPECTED CARRIER OF INFECTIOUS DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V020', 'CHOLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('V021', 'TYPHOID');
INSERT INTO staging.icd9 (code, description) VALUES ('V022', 'AMOEBIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V023', 'OTHER GASTROINTESTINAL PATHOGENS');
INSERT INTO staging.icd9 (code, description) VALUES ('V024', 'DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V025', 'OTHER SPECIFIED BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V026', 'VIRAL HEPATITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V027', 'GONORRHOEA');
INSERT INTO staging.icd9 (code, description) VALUES ('V028', 'OTHER VENEREAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V029', 'OTHER SPECIFIED INFECTIOUS ORGANISM');
INSERT INTO staging.icd9 (code, description) VALUES ('V03', 'NEED FOR PROPHYLACTIC VACCINATION AND INOCULATION AGAINST BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V030', 'CHOLERA ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V031', 'TYPHOID-PARATYPHOID ALONE (TAB)');
INSERT INTO staging.icd9 (code, description) VALUES ('V032', 'TUBERCULOSIS (BCG)');
INSERT INTO staging.icd9 (code, description) VALUES ('V033', 'PLAGUE');
INSERT INTO staging.icd9 (code, description) VALUES ('V034', 'TULARAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V035', 'DIPHTHERIA ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V036', 'PERTUSSIS ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V037', 'TETANUS TOXOID ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V038', 'OTHER SPECIFIED VACCINATIONS AGAINST SINGLE BACTERIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V039', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V04', 'NEED FOR PROPHYLACTIC VACCINATION AND INOCULATION AGAINST CERTAIN VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V040', 'POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V041', 'SMALLPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('V042', 'MEASLES ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V043', 'RUBELLA ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V044', 'YELLOW FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('V045', 'RABIES');
INSERT INTO staging.icd9 (code, description) VALUES ('V046', 'MUMPS ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V047', 'COMMON COLD');
INSERT INTO staging.icd9 (code, description) VALUES ('V048', 'INFLUENZA');
INSERT INTO staging.icd9 (code, description) VALUES ('V05', 'NEED FOR OTHER PROPHYLACTIC VACCINATION AND INOCULATION AGAINST SINGLE DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V050', 'ARTHROPOD-BORNE VIRAL ENCEPHALITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V051', 'OTHER ARTHROPOD-BORNE VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V052', 'LEISHMANIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V058', 'OTHER SPECIFIED DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V059', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V06', 'NEED FOR PROPHYLACTIC VACCINATION AND INOCULATION AGAINST COMBINATIONS OF DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V060', 'CHOLERA WITH TYPHOID-PARATYPHOID (CHOLERA + TAB)');
INSERT INTO staging.icd9 (code, description) VALUES ('V061', 'DIPHTHERIA-TETANUS-PERTUSSIS, COMBINED (DTP)');
INSERT INTO staging.icd9 (code, description) VALUES ('V062', 'DIPHTHERIA-TETANUS-PERTUSSIS WITH TYPHOID-PARATYPHOID (DTP + TAB)');
INSERT INTO staging.icd9 (code, description) VALUES ('V063', 'DIPHTHERIA-TETANUS-PERTUSSIS WITH POLIOMYELITIS (DTP + POLIO)');
INSERT INTO staging.icd9 (code, description) VALUES ('V064', 'MEASLES-MUMPS-RUBELLA (MMR)');
INSERT INTO staging.icd9 (code, description) VALUES ('V068', 'OTHER COMBINATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V069', 'UNSPECIFIED COMBINED VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('V07', 'NEED FOR ISOLATION AND OTHER PROPHYLACTIC MEASURES');
INSERT INTO staging.icd9 (code, description) VALUES ('V070', 'ISOLATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V071', 'DESENSITIZATION TO ALLERGENS');
INSERT INTO staging.icd9 (code, description) VALUES ('V072', 'PROPHYLACTIC IMMUNOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V073', 'OTHER PROPHYLACTIC CHEMOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V078', 'OTHER SPECIFIED PROPHYLACTIC MEASURE');
INSERT INTO staging.icd9 (code, description) VALUES ('V079', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V10', 'PERSONAL HISTORY OF MALIGNANT NEOPLASM');
INSERT INTO staging.icd9 (code, description) VALUES ('V100', 'GASTROINTESTINAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('V101', 'TRACHEA, BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('V102', 'OTHER RESPIRATORY AND INTRATHORACIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V103', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('V104', 'GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V105', 'URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V106', 'LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V107', 'OTHER LYMPHATIC AND HAEMATOPOIETIC NEOPLASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V108', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V109', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V11', 'PERSONAL HISTORY OF MENTAL DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('V12', 'PERSONAL HISTORY OF CERTAIN OTHER DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V120', 'INFECTIOUS AND PARASITIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V121', 'NUTRITIONAL DEFICIENCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V122', 'ENDOCRINE, METABOLIC AND IMMUNITY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V123', 'DISEASES OF BLOOD AND BLOOD-FORMING ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V124', 'DISORDERS OF NERVOUS SYSTEM AND SENSE ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V125', 'DISEASES OF CIRCULATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('V126', 'DISEASES OF RESPIRATORY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('V127', 'DISEASES OF DIGESTIVE SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('V13', 'PERSONAL HISTORY OF OTHER DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V130', 'DISORDERS OF URINARY SYSTEM');
INSERT INTO staging.icd9 (code, description) VALUES ('V131', 'TROPHOBLASTIC DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V132', 'OTHER GENITAL SYSTEM AND OBSTETRIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V133', 'DISEASES OF SKIN AND SUBCUTANEOUS TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('V134', 'ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V135', 'OTHER MUSCULOSKELETAL DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V136', 'CONGENITAL MALFORMATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V137', 'PERINATAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V138', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V139', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V14', 'PERSONAL HISTORY OF ALLERGY TO MEDICINAL AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('V140', 'PENICILLIN');
INSERT INTO staging.icd9 (code, description) VALUES ('V141', 'OTHER ANTIBIOTIC AGENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V142', 'SULFONAMIDES');
INSERT INTO staging.icd9 (code, description) VALUES ('V143', 'OTHER ANTI-INFECTIVE AGENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V144', 'ANAESTHETIC AGENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V145', 'NARCOTIC AGENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V146', 'ANALGESIC AGENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V147', 'SERUM OR VACCINE');
INSERT INTO staging.icd9 (code, description) VALUES ('V148', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V149', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V15', 'OTHER PERSONAL HISTORY PRESENTING HAZARDS TO HEALTH');
INSERT INTO staging.icd9 (code, description) VALUES ('V150', 'ALLERGY, OTHER THAN TO MEDICINAL AGENTS');
INSERT INTO staging.icd9 (code, description) VALUES ('V151', 'SURGERY TO HEART AND GREAT VESSELS');
INSERT INTO staging.icd9 (code, description) VALUES ('V152', 'SURGERY TO OTHER MAJOR ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V153', 'IRRADIATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V154', 'PSYCHOLOGICAL TRAUMA');
INSERT INTO staging.icd9 (code, description) VALUES ('V155', 'INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('V156', 'POISONING');
INSERT INTO staging.icd9 (code, description) VALUES ('V157', 'CONTRACEPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V158', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V159', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V16', 'FAMILY HISTORY OF MALIGNANT NEOPLASM');
INSERT INTO staging.icd9 (code, description) VALUES ('V160', 'GASTROINTESTINAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('V161', 'TRACHEA, BRONCHUS AND LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('V162', 'OTHER RESPIRATORY AND INTRATHORACIC ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V163', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('V164', 'GENITAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V165', 'URINARY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V166', 'LEUKAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V167', 'OTHER LYMPHATIC AND HAEMATOPOIETIC NEOPLASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V168', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V169', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V17', 'FAMILY HISTORY OF CERTAIN CHRONIC DISABLING DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V170', 'PSYCHIATRIC CONDITION');
INSERT INTO staging.icd9 (code, description) VALUES ('V171', 'STROKE (CEREBROVASCULAR)');
INSERT INTO staging.icd9 (code, description) VALUES ('V172', 'OTHER NEUROLOGICAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V173', 'ISCHAEMIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V174', 'OTHER CARDIOVASCULAR DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V175', 'ASTHMA');
INSERT INTO staging.icd9 (code, description) VALUES ('V176', 'OTHER CHRONIC RESPIRATORY CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V177', 'ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V178', 'OTHER MUSCULOSKELETAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V18', 'FAMILY HISTORY OF CERTAIN OTHER SPECIFIC CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V180', 'DIABETES MELLITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V181', 'OTHER ENDOCRINE AND METABOLIC DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V182', 'ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V183', 'OTHER BLOOD DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V184', 'MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V185', 'DIGESTIVE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V186', 'KIDNEY DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V187', 'OTHER GENITOURINARY DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V188', 'INFECTIOUS DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V19', 'FAMILY HISTORY OF OTHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V190', 'BLINDNESS OR VISUAL LOSS');
INSERT INTO staging.icd9 (code, description) VALUES ('V191', 'OTHER EYE DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V192', 'DEAFNESS OR HEARING LOSS');
INSERT INTO staging.icd9 (code, description) VALUES ('V193', 'OTHER EAR DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V194', 'SKIN CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V195', 'CONGENITAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('V196', 'ALLERGIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V197', 'CONSANGUINITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V198', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V20', 'HEALTH SUPERVISION OF INFANT OR CHILD');
INSERT INTO staging.icd9 (code, description) VALUES ('V200', 'FOUNDLING');
INSERT INTO staging.icd9 (code, description) VALUES ('V201', 'OTHER HEALTHY INFANT RECEIVING CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V202', 'ROUTINE CHILD HEALTH CHECK');
INSERT INTO staging.icd9 (code, description) VALUES ('V21', 'CONSTITUTIONAL STATES IN DEVELOPMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V210', 'PERIOD OF RAPID GROWTH IN CHILDHOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('V211', 'PUBERTY');
INSERT INTO staging.icd9 (code, description) VALUES ('V212', 'OTHER ADOLESCENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('V218', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V219', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V22', 'NORMAL PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V220', 'SUPERVISION OF NORMAL FIRST PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V221', 'SUPERVISION OF OTHER NORMAL PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V222', 'PREGNANT STATE, INCIDENTAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V23', 'SUPERVISION OF HIGH-RISK PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V230', 'PREGNANCY WITH HISTORY OF INFERTILITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V231', 'PREGNANCY WITH HISTORY OF TROPHOBLASTIC DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V232', 'PREGNANCY WITH HISTORY OF ABORTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V233', 'GRAND MULTIPARITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V234', 'PREGNANCY WITH OTHER POOR OBSTETRIC HISTORY');
INSERT INTO staging.icd9 (code, description) VALUES ('V235', 'PREGNANCY WITH OTHER POOR REPRODUCTIVE HISTORY');
INSERT INTO staging.icd9 (code, description) VALUES ('V238', 'OTHER HIGH-RISK PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V239', 'UNSPECIFIED HIGH-RISK PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V24', 'POSTPARTUM CARE AND EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V240', 'IMMEDIATELY AFTER DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('V241', 'LACTATING MOTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V242', 'ROUTINE POSTPARTUM FOLLOW-UP');
INSERT INTO staging.icd9 (code, description) VALUES ('V25', 'CONTRACEPTIVE MANAGEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V250', 'GENERAL COUNSELLING AND ADVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V251', 'INSERTION OF INTRAUTERINE CONTRACEPTIVE DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V252', 'STERILIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V253', 'MENSTRUAL EXTRACTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V254', 'SURVEILLANCE OF PREVIOUSLY PRESCRIBED CONTRACEPTIVE METHODS');
INSERT INTO staging.icd9 (code, description) VALUES ('V258', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V259', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V26', 'PROCREATIVE MANAGEMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V260', 'TUBOPLASTY OR VASOPLASTY AFTER PREVIOUS STERILIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V261', 'ARTIFICIAL INSEMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V262', 'INVESTIGATION AND TESTING');
INSERT INTO staging.icd9 (code, description) VALUES ('V263', 'GENETIC COUNSELLING');
INSERT INTO staging.icd9 (code, description) VALUES ('V264', 'GENERAL COUNSELLING AND ADVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V268', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V269', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V27', 'OUTCOME OF DELIVERY');
INSERT INTO staging.icd9 (code, description) VALUES ('V270', 'SINGLE LIVE BIRTH');
INSERT INTO staging.icd9 (code, description) VALUES ('V271', 'SINGLE STILLBIRTH');
INSERT INTO staging.icd9 (code, description) VALUES ('V272', 'TWINS, BOTH LIVE BORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V273', 'TWINS, ONE LIVE BORN AND ONE STILLBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V274', 'TWINS, BOTH STILLBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V275', 'OTHER MULTIPLE BIRTH, ALL LIVE BORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V276', 'OTHER MULTIPLE BIRTH, SOME LIVE BORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V277', 'OTHER MULTIPLE BIRTH, ALL STILLBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V279', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V28', 'ANTENATAL SCREENING');
INSERT INTO staging.icd9 (code, description) VALUES ('V280', 'SCREENING FOR CHROMOSOMAL ANOMALIES BY AMNIOCENTESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V281', 'SCREENING FOR RAISED ALPHAFETOPROTEIN LEVELS IN AMNIOTIC FLUID');
INSERT INTO staging.icd9 (code, description) VALUES ('V282', 'OTHER SCREENING BASED ON AMNIOCENTESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V283', 'SCREENING FOR MALFORMATIONS USING ULTRASONICS');
INSERT INTO staging.icd9 (code, description) VALUES ('V284', 'SCREENING FOR FETAL GROWTH RETARDATION USING ULTRASONICS');
INSERT INTO staging.icd9 (code, description) VALUES ('V285', 'SCREENING FOR ISOIMMUNIZATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V288', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V289', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V30', 'SINGLETON');
INSERT INTO staging.icd9 (code, description) VALUES ('V300', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V301', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V302', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V31', 'TWIN, MATE LIVE BORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V310', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V311', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V312', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V32', 'TWIN, MATE STILLBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V320', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V321', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V322', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V33', 'TWIN, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V330', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V331', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V332', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V34', 'OTHER MULTIPLE, MATES ALL LIVE BORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V340', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V341', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V342', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V35', 'OTHER MULTIPLE, MATES ALL STILLBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V350', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V351', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V352', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V36', 'OTHER MULTIPLE, MATES LIVE- AND STILLBORN');
INSERT INTO staging.icd9 (code, description) VALUES ('V360', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V361', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V362', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V37', 'OTHER MULTIPLE, UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V370', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V371', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V372', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V39', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V390', 'BORN IN HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V391', 'BORN BEFORE ADMISSION TO HOSPITAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V392', 'BORN OUTSIDE HOSPITAL AND NOT HOSPITALIZED');
INSERT INTO staging.icd9 (code, description) VALUES ('V40', 'MENTAL AND BEHAVIOURAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V400', 'PROBLEMS WITH LEARNING');
INSERT INTO staging.icd9 (code, description) VALUES ('V401', 'PROBLEMS WITH COMMUNICATION (INCLUDING SPEECH)');
INSERT INTO staging.icd9 (code, description) VALUES ('V402', 'OTHER MENTAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V403', 'OTHER BEHAVIOURAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V409', 'UNSPECIFIED MENTAL OR BEHAVIOURAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V41', 'PROBLEMS WITH SPECIAL SENSES AND OTHER SPECIAL FUNCTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V410', 'PROBLEMS WITH SIGHT');
INSERT INTO staging.icd9 (code, description) VALUES ('V411', 'OTHER EYE PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V412', 'PROBLEMS WITH HEARING');
INSERT INTO staging.icd9 (code, description) VALUES ('V413', 'OTHER EAR PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V414', 'PROBLEMS WITH VOICE PRODUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V415', 'PROBLEMS WITH SMELL AND TASTE');
INSERT INTO staging.icd9 (code, description) VALUES ('V416', 'PROBLEMS WITH SWALLOWING AND MASTICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V417', 'PROBLEMS WITH SEXUAL FUNCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V418', 'OTHER PROBLEMS WITH SPECIFIED FUNCTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V419', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V42', 'ORGAN OR TISSUE REPLACED BY TRANSPLANT');
INSERT INTO staging.icd9 (code, description) VALUES ('V420', 'KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('V421', 'HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('V422', 'HEART VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('V423', 'SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('V424', 'BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V425', 'CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('V426', 'LUNG');
INSERT INTO staging.icd9 (code, description) VALUES ('V427', 'LIVER');
INSERT INTO staging.icd9 (code, description) VALUES ('V428', 'OTHER SPECIFIED ORGAN OR TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('V429', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V43', 'ORGAN OR TISSUE REPLACED BY OTHER MEANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V430', 'EYE GLOBE');
INSERT INTO staging.icd9 (code, description) VALUES ('V431', 'LENS');
INSERT INTO staging.icd9 (code, description) VALUES ('V432', 'HEART');
INSERT INTO staging.icd9 (code, description) VALUES ('V433', 'HEART VALVE');
INSERT INTO staging.icd9 (code, description) VALUES ('V434', 'BLOOD VESSEL');
INSERT INTO staging.icd9 (code, description) VALUES ('V435', 'BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('V436', 'JOINT');
INSERT INTO staging.icd9 (code, description) VALUES ('V437', 'LIMB');
INSERT INTO staging.icd9 (code, description) VALUES ('V438', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V44', 'ARTIFICIAL OPENING STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V440', 'TRACHEOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V441', 'GASTROSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V442', 'ILEOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V443', 'COLOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V444', 'OTHER ARTIFICIAL OPENING OF GASTROINTESTINAL TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('V445', 'CYSTOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V446', 'OTHER ARTIFICIAL OPENING OF URINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('V447', 'ARTIFICIAL VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('V448', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V449', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V45', 'OTHER POSTSURGICAL STATES');
INSERT INTO staging.icd9 (code, description) VALUES ('V450', 'CARDIAC PACEMAKER IN SITU');
INSERT INTO staging.icd9 (code, description) VALUES ('V451', 'RENAL DIALYSIS STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V452', 'PRESENCE OF CEREBROSPINAL FLUID DRAINAGE DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V453', 'INTESTINAL BYPASS OR ANASTOMOSIS STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V454', 'ARTHRODESIS STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V455', 'PRESENCE OF INTRAUTERINE CONTRACEPTIVE DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V456', 'STATES FOLLOWING SURGERY OF EYE AND ADNEXA');
INSERT INTO staging.icd9 (code, description) VALUES ('V458', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V46', 'OTHER DEPENDENCE ON MACHINES');
INSERT INTO staging.icd9 (code, description) VALUES ('V460', 'ASPIRATOR');
INSERT INTO staging.icd9 (code, description) VALUES ('V461', 'RESPIRATOR');
INSERT INTO staging.icd9 (code, description) VALUES ('V468', 'OTHER ENABLING MACHINES');
INSERT INTO staging.icd9 (code, description) VALUES ('V469', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V47', 'OTHER PROBLEMS WITH INTERNAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V470', 'DEFICIENCIES OF INTERNAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V471', 'MECHANICAL AND MOTOR PROBLEMS WITH INTERNAL ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V472', 'OTHER CARDIORESPIRATORY PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V473', 'OTHER DIGESTIVE PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V474', 'OTHER URINARY PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V475', 'OTHER GENITAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V479', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V48', 'PROBLEMS WITH HEAD, NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('V480', 'DEFICIENCIES OF HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('V481', 'DEFICIENCIES OF NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('V482', 'MECHANICAL AND MOTOR PROBLEMS WITH HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('V483', 'MECHANICAL AND MOTOR PROBLEMS WITH NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('V484', 'SENSORY PROBLEM WITH HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('V485', 'SENSORY PROBLEM WITH NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('V486', 'DISFIGUREMENTS OF HEAD');
INSERT INTO staging.icd9 (code, description) VALUES ('V487', 'DISFIGUREMENTS OF NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('V488', 'OTHER PROBLEMS WITH HEAD, NECK AND TRUNK');
INSERT INTO staging.icd9 (code, description) VALUES ('V489', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V49', 'PROBLEMS WITH LIMBS AND OTHER PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V490', 'DEFICIENCIES OF LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('V491', 'MECHANICAL PROBLEMS WITH LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('V492', 'MOTOR PROBLEMS WITH LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('V493', 'SENSORY PROBLEMS WITH LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('V494', 'DISFIGUREMENTS OF LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('V495', 'OTHER PROBLEMS WITH LIMBS');
INSERT INTO staging.icd9 (code, description) VALUES ('V498', 'OTHER SPECIFIED PROBLEMS INFLUENCING HEALTH STATUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V499', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V669', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V50', 'ELECTIVE SURGERY FOR PURPOSES OTHER THAN REMEDYING HEALTH STATES');
INSERT INTO staging.icd9 (code, description) VALUES ('V500', 'HAIR TRANSPLANT');
INSERT INTO staging.icd9 (code, description) VALUES ('V501', 'OTHER PLASTIC SURGERY FOR UNACCEPTABLE COSMETIC APPEARANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('V502', 'ROUTINE OR RITUAL CIRCUMCISION');
INSERT INTO staging.icd9 (code, description) VALUES ('V503', 'EAR PIERCING');
INSERT INTO staging.icd9 (code, description) VALUES ('V508', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V509', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V51', 'AFTERCARE INVOLVING THE USE OF PLASTIC SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('V52', 'FITTING AND ADJUSTMENT OF PROSTHETIC DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V520', 'ARTIFICIAL ARM (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('V521', 'ARTIFICIAL LEG (COMPLETE) (PARTIAL)');
INSERT INTO staging.icd9 (code, description) VALUES ('V522', 'ARTIFICIAL EYE');
INSERT INTO staging.icd9 (code, description) VALUES ('V523', 'DENTAL PROSTHETIC DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V524', 'BREAST PROSTHESIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V528', 'OTHER SPECIFIED PROSTHETIC DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V529', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V53', 'FITTING AND ADJUSTMENT OF OTHER DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V530', 'DEVICES RELATED TO NERVOUS SYSTEM AND SPECIAL SENSES');
INSERT INTO staging.icd9 (code, description) VALUES ('V531', 'SPECTACLES AND CONTACT LENSES');
INSERT INTO staging.icd9 (code, description) VALUES ('V532', 'HEARING AID');
INSERT INTO staging.icd9 (code, description) VALUES ('V533', 'CARDIAC PACEMAKER');
INSERT INTO staging.icd9 (code, description) VALUES ('V534', 'ORTHODONTIC DEVICES');
INSERT INTO staging.icd9 (code, description) VALUES ('V535', 'ILEOSTOMY OR OTHER INTESTINAL APPLIANCE');
INSERT INTO staging.icd9 (code, description) VALUES ('V536', 'URINARY DEVICES');
INSERT INTO staging.icd9 (code, description) VALUES ('V537', 'ORTHOPAEDIC DEVICES');
INSERT INTO staging.icd9 (code, description) VALUES ('V538', 'WHEELCHAIR');
INSERT INTO staging.icd9 (code, description) VALUES ('V539', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V54', 'OTHER ORTHOPAEDIC AFTERCARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V540', 'AFTERCARE INVOLVING REMOVAL OF FRACTURE PLATE OR OTHER INTERNAL FIXATION DEVICE');
INSERT INTO staging.icd9 (code, description) VALUES ('V548', 'OTHER ORTHOPAEDIC AFTERCARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V549', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V55', 'ATTENTION TO ARTIFICIAL OPENINGS');
INSERT INTO staging.icd9 (code, description) VALUES ('V550', 'TRACHEOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V551', 'GASTROSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V552', 'ILEOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V553', 'COLOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V554', 'OTHER ARTIFICIAL OPENING OF DIGESTIVE TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('V555', 'CYSTOSTOMY');
INSERT INTO staging.icd9 (code, description) VALUES ('V556', 'OTHER ARTIFICIAL OPENING OF URINARY TRACT');
INSERT INTO staging.icd9 (code, description) VALUES ('V557', 'ARTIFICIAL VAGINA');
INSERT INTO staging.icd9 (code, description) VALUES ('V558', 'OTHER SPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V559', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V56', 'AFTERCARE INVOLVING INTERMITTENT DIALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V560', 'EXTRACORPOREAL DIALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V568', 'OTHER DIALYSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V57', 'CARE INVOLVING USE OF REHABILITATION PROCEDURES');
INSERT INTO staging.icd9 (code, description) VALUES ('V570', 'BREATHING EXERCISES');
INSERT INTO staging.icd9 (code, description) VALUES ('V571', 'OTHER PHYSICAL THERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V572', 'OCCUPATIONAL THERAPY AND VOCATIONAL REHABILITATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V573', 'SPEECH THERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V574', 'ORTHOPTIC TRAINING');
INSERT INTO staging.icd9 (code, description) VALUES ('V578', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V579', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V58', 'OTHER AND UNSPECIFIED AFTERCARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V580', 'RADIOTHERAPY SESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('V581', 'MAINTENANCE CHEMOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V582', 'BLOOD TRANSFUSION, WITHOUT REPORTED DIAGNOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V583', 'ATTENTION TO SURGICAL DRESSINGS AND SUTURES');
INSERT INTO staging.icd9 (code, description) VALUES ('V584', 'OTHER AFTERCARE FOLLOWING SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('V585', 'ORTHODONTICS');
INSERT INTO staging.icd9 (code, description) VALUES ('V588', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V589', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V59', 'DONORS');
INSERT INTO staging.icd9 (code, description) VALUES ('V590', 'BLOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('V591', 'SKIN');
INSERT INTO staging.icd9 (code, description) VALUES ('V592', 'BONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V593', 'BONE MARROW');
INSERT INTO staging.icd9 (code, description) VALUES ('V594', 'KIDNEY');
INSERT INTO staging.icd9 (code, description) VALUES ('V595', 'CORNEA');
INSERT INTO staging.icd9 (code, description) VALUES ('V598', 'OTHER SPECIFIED ORGAN OR TISSUE');
INSERT INTO staging.icd9 (code, description) VALUES ('V599', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V60', 'HOUSING, HOUSEHOLD AND ECONOMIC CIRCUMSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('V600', 'LACK OF HOUSING');
INSERT INTO staging.icd9 (code, description) VALUES ('V601', 'INADEQUATE HOUSING');
INSERT INTO staging.icd9 (code, description) VALUES ('V602', 'INADEQUATE MATERIAL RESOURCES');
INSERT INTO staging.icd9 (code, description) VALUES ('V603', 'PERSON LIVING ALONE');
INSERT INTO staging.icd9 (code, description) VALUES ('V604', 'NO OTHER HOUSEHOLD MEMBER ABLE TO RENDER CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V605', 'HOLIDAY RELIEF CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V606', 'PERSON LIVING IN RESIDENTIAL INSTITUTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V608', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V609', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V61', 'OTHER FAMILY CIRCUMSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('V610', 'FAMILY DISRUPTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V611', 'MARITAL PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V612', 'PARENT-CHILD PROBLEMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V613', 'PROBLEMS WITH AGED PARENTS OR IN-LAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('V614', 'HEALTH PROBLEMS WITHIN FAMILY');
INSERT INTO staging.icd9 (code, description) VALUES ('V615', 'MULTIPARITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V616', 'ILLEGITIMACY OR ILLEGITIMATE PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V617', 'OTHER UNWANTED PREGNANCY');
INSERT INTO staging.icd9 (code, description) VALUES ('V618', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V619', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V62', 'OTHER PSYCHOSOCIAL CIRCUMSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('V620', 'UNEMPLOYMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V621', 'ADVERSE EFFECTS OF WORK ENVIRONMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V622', 'OTHER OCCUPATIONAL CIRCUMSTANCES OR MALADJUSTMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V623', 'EDUCATIONAL CIRCUMSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('V624', 'SOCIAL MALADJUSTMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V625', 'LEGAL CIRCUMSTANCES');
INSERT INTO staging.icd9 (code, description) VALUES ('V626', 'REFUSAL OF TREATMENT FOR REASONS OF RELIGION OR CONSCIENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('V628', 'OTHER PSYCHOLOGICAL OR PHYSICAL STRAIN, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V629', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V63', 'UNAVAILABILITY OF OTHER MEDICAL FACILITIES FOR CARE');
INSERT INTO staging.icd9 (code, description) VALUES ('V630', 'RESIDENCE REMOTE FROM HOSPITAL OR OTHER HEALTH CARE FACILITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V631', 'MEDICAL SERVICES IN HOME NOT AVAILABLE');
INSERT INTO staging.icd9 (code, description) VALUES ('V632', 'PERSON AWAITING ADMISSION TO ADEQUATE FACILITY ELSEWHERE');
INSERT INTO staging.icd9 (code, description) VALUES ('V638', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V639', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V64', 'PERSONS ENCOUNTERING HEALTH SERVICES FOR SPECIFIC PROCEDURES, NOT CARRIED OUT');
INSERT INTO staging.icd9 (code, description) VALUES ('V640', 'VACCINATION NOT CARRIED OUT BECAUSE OF CONTRAINDICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V641', 'SURGICAL OR OTHER PROCEDURE NOT CARRIED OUT BECAUSE OF CONTRAINDICATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V642', 'SURGICAL OR OTHER PROCEDURE NOT CARRIED OUT BECAUSE OF PATIENT''S DECISION');
INSERT INTO staging.icd9 (code, description) VALUES ('V643', 'PROCEDURE NOT CARRIED OUT FOR OTHER REASONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V65', 'OTHER PERSONS SEEKING CONSULTATION WITHOUT COMPLAINT OR SICKNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('V650', 'HEALTHY PERSON ACCOMPANYING SICK PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('V651', 'PERSON CONSULTING ON BEHALF OF ANOTHER PERSON');
INSERT INTO staging.icd9 (code, description) VALUES ('V652', 'PERSON FEIGNING ILLNESS');
INSERT INTO staging.icd9 (code, description) VALUES ('V653', 'DIETARY SURVEILLANCE AND COUNSELLING');
INSERT INTO staging.icd9 (code, description) VALUES ('V654', 'OTHER COUNSELLING, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V655', 'PERSON WITH FEARED COMPLAINT IN WHOM NO DIAGNOSIS WAS MADE');
INSERT INTO staging.icd9 (code, description) VALUES ('V658', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V659', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V66', 'CONVALESCENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('V660', 'FOLLOWING SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('V661', 'FOLLOWING RADIOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V662', 'FOLLOWING CHEMOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V663', 'FOLLOWING PSYCHOTHERAPY AND OTHER TREATMENT FOR MENTAL DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('V664', 'FOLLOWING TREATMENT OF FRACTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('V665', 'FOLLOWING OTHER TREATMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V666', 'FOLLOWING COMBINED TREATMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V67', 'FOLLOW-UP EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V670', 'FOLLOWING SURGERY');
INSERT INTO staging.icd9 (code, description) VALUES ('V671', 'FOLLOWING RADIOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V672', 'FOLLOWING CHEMOTHERAPY');
INSERT INTO staging.icd9 (code, description) VALUES ('V673', 'FOLLOWING PSYCHOTHERAPY AND OTHER TREATMENT FOR MENTAL DISORDER');
INSERT INTO staging.icd9 (code, description) VALUES ('V674', 'FOLLOWING TREATMENT OF FRACTURE');
INSERT INTO staging.icd9 (code, description) VALUES ('V675', 'FOLLOWING OTHER TREATMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V676', 'FOLLOWING COMBINED TREATMENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V679', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V68', 'ENCOUNTERS FOR ADMINISTRATIVE PURPOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('V680', 'ISSUE OF MEDICAL CERTIFICATES');
INSERT INTO staging.icd9 (code, description) VALUES ('V681', 'ISSUE OF REPEAT PRESCRIPTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V682', 'REQUEST FOR EXPERT EVIDENCE');
INSERT INTO staging.icd9 (code, description) VALUES ('V688', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V689', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V70', 'GENERAL MEDICAL EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V700', 'ROUTINE GENERAL MEDICAL EXAMINATION AT A HEALTH CARE FACILITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V701', 'GENERAL PSYCHIATRIC EXAMINATION, REQUESTED BY THE AUTHORITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V702', 'GENERAL PSYCHIATRIC EXAMINATION, OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V703', 'OTHER MEDICAL EXAMINATION FOR ADMINISTRATIVE PURPOSES');
INSERT INTO staging.icd9 (code, description) VALUES ('V704', 'EXAMINATION FOR MEDICOLEGAL REASONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V705', 'HEALTH EXAMINATION OF DEFINED SUBPOPULATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V706', 'HEALTH EXAMINATION IN POPULATION SURVEYS');
INSERT INTO staging.icd9 (code, description) VALUES ('V707', 'EXAMINATION FOR NORMAL COMPARISON OR CONTROL IN CLINICAL RESEARCH');
INSERT INTO staging.icd9 (code, description) VALUES ('V708', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V709', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V71', 'OBSERVATION AND EVALUATION FOR SUSPECTED CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V710', 'MENTAL');
INSERT INTO staging.icd9 (code, description) VALUES ('V711', 'OBSERVATION FOR SUSPECTED MALIGNANT NEOPLASM');
INSERT INTO staging.icd9 (code, description) VALUES ('V712', 'OBSERVATION FOR SUSPECTED TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V713', 'OBSERVATION FOLLOWING ACCIDENT AT WORK');
INSERT INTO staging.icd9 (code, description) VALUES ('V714', 'OBSERVATION FOLLOWING OTHER ACCIDENT');
INSERT INTO staging.icd9 (code, description) VALUES ('V715', 'OBSERVATION FOLLOWING ALLEGED RAPE OR SEDUCTION');
INSERT INTO staging.icd9 (code, description) VALUES ('V716', 'OBSERVATION FOLLOWING OTHER INFLICTED INJURY');
INSERT INTO staging.icd9 (code, description) VALUES ('V717', 'OBSERVATION FOR SUSPECTED CARDIOVASCULAR DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V718', 'OBSERVATION FOR OTHER SPECIFIED SUSPECTED CONDITION');
INSERT INTO staging.icd9 (code, description) VALUES ('V719', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V72', 'SPECIAL INVESTIGATIONS AND EXAMINATIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V720', 'EXAMINATION OF EYES AND VISION');
INSERT INTO staging.icd9 (code, description) VALUES ('V721', 'EXAMINATION OF EARS AND HEARING');
INSERT INTO staging.icd9 (code, description) VALUES ('V722', 'DENTAL EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V723', 'GYNAECOLOGICAL EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V724', 'PREGNANCY EXAMINATION OR TEST, PREGNANCY UNCONFIRMED');
INSERT INTO staging.icd9 (code, description) VALUES ('V725', 'RADIOLOGICAL EXAMINATION, NOT ELSEWHERE CLASSIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V726', 'LABORATORY EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V727', 'DIAGNOSTIC SKIN AND SENSITIZATION TESTS');
INSERT INTO staging.icd9 (code, description) VALUES ('V728', 'OTHER SPECIFIED EXAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V729', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V73', 'SPECIAL SCREENING EXAMINATION FOR VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V730', 'POLIOMYELITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V731', 'SMALLPOX');
INSERT INTO staging.icd9 (code, description) VALUES ('V732', 'MEASLES');
INSERT INTO staging.icd9 (code, description) VALUES ('V733', 'RUBELLA');
INSERT INTO staging.icd9 (code, description) VALUES ('V734', 'YELLOW FEVER');
INSERT INTO staging.icd9 (code, description) VALUES ('V735', 'OTHER ARTHROPOD-BORNE VIRAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V736', 'TRACHOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('V738', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V739', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V74', 'SPECIAL SCREENING EXAMINATION FOR BACTERIAL AND SPIROCHAETAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V740', 'CHOLERA');
INSERT INTO staging.icd9 (code, description) VALUES ('V741', 'PULMONARY TUBERCULOSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V742', 'LEPROSY');
INSERT INTO staging.icd9 (code, description) VALUES ('V743', 'DIPHTHERIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V744', 'BACTERIAL CONJUNCTIVITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V745', 'VENEREAL DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V746', 'YAWS');
INSERT INTO staging.icd9 (code, description) VALUES ('V748', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V749', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V75', 'SPECIAL SCREENING EXAMINATION FOR OTHER INFECTIOUS DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V750', 'RICKETTSIAL DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V751', 'MALARIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V752', 'LEISHMANIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V753', 'TRYPANOSOMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V754', 'MYCOTIC INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V755', 'SCHISTOSOMIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V756', 'FILARIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V757', 'INTESTINAL HELMINTHIASIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V758', 'OTHER SPECIFIED PARASITIC INFECTIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V759', 'UNSPECIFIED INFECTIOUS DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V76', 'SPECIAL SCREENING FOR MALIGNANT NEOPLASMS');
INSERT INTO staging.icd9 (code, description) VALUES ('V760', 'RESPIRATORY ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V761', 'BREAST');
INSERT INTO staging.icd9 (code, description) VALUES ('V762', 'CERVIX');
INSERT INTO staging.icd9 (code, description) VALUES ('V763', 'BLADDER');
INSERT INTO staging.icd9 (code, description) VALUES ('V764', 'OTHER SITES');
INSERT INTO staging.icd9 (code, description) VALUES ('V768', 'OTHER NEOPLASM');
INSERT INTO staging.icd9 (code, description) VALUES ('V769', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V77', 'SPECIAL SCREENING FOR ENDOCRINE, NUTRITIONAL, METABOLIC AND IMMUNITY DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V770', 'THYROID DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V771', 'DIABETES MELLITUS');
INSERT INTO staging.icd9 (code, description) VALUES ('V772', 'MALNUTRITION');
INSERT INTO staging.icd9 (code, description) VALUES ('V773', 'PHENYLKETONURIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V774', 'GALACTOSAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V775', 'GOUT');
INSERT INTO staging.icd9 (code, description) VALUES ('V776', 'CYSTIC FIBROSIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V777', 'OTHER INBORN ERRORS OF METABOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('V778', 'OBESITY');
INSERT INTO staging.icd9 (code, description) VALUES ('V779', 'OTHER AND UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V78', 'SPECIAL SCREENING FOR DISORDERS OF BLOOD AND BLOOD-FORMING ORGANS');
INSERT INTO staging.icd9 (code, description) VALUES ('V780', 'IRON DEFICIENCY ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V781', 'OTHER AND UNSPECIFIED DEFICIENCY ANAEMIA');
INSERT INTO staging.icd9 (code, description) VALUES ('V782', 'SICKLE-CELL DISEASE OR TRAIT');
INSERT INTO staging.icd9 (code, description) VALUES ('V783', 'OTHER HAEMOGLOBINOPATHIES');
INSERT INTO staging.icd9 (code, description) VALUES ('V788', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V789', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V79', 'SPECIAL SCREENING FOR MENTAL DISORDERS AND DEVELOPMENTAL HANDICAPS');
INSERT INTO staging.icd9 (code, description) VALUES ('V790', 'DEPRESSION');
INSERT INTO staging.icd9 (code, description) VALUES ('V791', 'ALCOHOLISM');
INSERT INTO staging.icd9 (code, description) VALUES ('V792', 'MENTAL RETARDATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V793', 'DEVELOPMENTAL HANDICAPS IN EARLY CHILDHOOD');
INSERT INTO staging.icd9 (code, description) VALUES ('V798', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V799', 'UNSPECIFIED');
INSERT INTO staging.icd9 (code, description) VALUES ('V80', 'SPECIAL SCREENING FOR NEUROLOGICAL, EYE AND EAR DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V800', 'NEUROLOGICAL CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V801', 'GLAUCOMA');
INSERT INTO staging.icd9 (code, description) VALUES ('V802', 'OTHER EYE CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V803', 'EAR DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V81', 'SPECIAL SCREENING FOR CARDIOVASCULAR, RESPIRATORY AND GENITOURINARY DISEASES');
INSERT INTO staging.icd9 (code, description) VALUES ('V810', 'ISCHAEMIC HEART DISEASE');
INSERT INTO staging.icd9 (code, description) VALUES ('V811', 'HYPERTENSION');
INSERT INTO staging.icd9 (code, description) VALUES ('V812', 'OTHER AND UNSPECIFIED CARDIOVASCULAR CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V813', 'CHRONIC BRONCHITIS AND EMPHYSEMA');
INSERT INTO staging.icd9 (code, description) VALUES ('V814', 'OTHER AND UNSPECIFIED RESPIRATORY CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V815', 'NEPHROPATHY');
INSERT INTO staging.icd9 (code, description) VALUES ('V816', 'OTHER AND UNSPECIFIED GENITOURINARY CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V82', 'SPECIAL SCREENING FOR OTHER CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V820', 'SKIN CONDITIONS');
INSERT INTO staging.icd9 (code, description) VALUES ('V821', 'RHEUMATIOD ARTHRITIS');
INSERT INTO staging.icd9 (code, description) VALUES ('V822', 'OTHER RHEUMATIC DISORDERS');
INSERT INTO staging.icd9 (code, description) VALUES ('V823', 'CONGENITAL DISLOCATION OF HIP');
INSERT INTO staging.icd9 (code, description) VALUES ('V824', 'POSTNATAL SCREENING FOR CHROMOSOMAL ANOMALIES');
INSERT INTO staging.icd9 (code, description) VALUES ('V825', 'CHEMICAL POISONING AND OTHER CONTAMINATION');
INSERT INTO staging.icd9 (code, description) VALUES ('V826', 'MULTIPHASIC SCREENING');
INSERT INTO staging.icd9 (code, description) VALUES ('V828', 'OTHER');
INSERT INTO staging.icd9 (code, description) VALUES ('V829', 'UNSPECIFIED');


--
-- PostgreSQL database dump complete
--



-- ===========================================================
-- add to ref.icd9 if does not already exist
-- ===========================================================

-- provide for linkage to ICD9 source if does not exist
INSERT INTO Ref.data_source (
  version,
  lang,
  name_short,
  name_long,
  source
)
SELECT '1975', 'en', 'ICD-9', 'WHO International Classification of Diseases, Ninth Revision', 'http://www.who.int/classifications/icd/en/' FROM Ref.data_source
WHERE NOT EXISTS (SELECT 1 FROM Ref.data_source WHERE version = '1975' and UPPER(name_short) = 'ICD-9' and lang = 'en')
LIMIT 1
;

-- add to ref.icd9 where does not already exist
INSERT INTO ref.icd9 (	
	code,
	term,
	fk_data_source
) 
SELECT code, description, (SELECT pk FROM Ref.data_source WHERE version = '1975' and UPPER(name_short) = 'ICD-9' and lang = 'en')
	FROM staging.icd9 AS s_i
	WHERE s_i.code NOT IN
		(
		SELECT code
		FROM ref.icd9 r_i
		WHERE r_i.code = s_i.code
		)
;

commit;

-- =================
-- cleanup and exit
-- =================

\unset ON_ERROR_STOP
DROP TABLE staging.icd9 CASCADE;
\set ON_ERROR_STOP 1

-- end